@@ -1,26 +1,26 @@
 /*************************************************************************
  * extrema.c - tools for non-maxima gradient point suppression
  *
- * $Id$
+ * $Id: extrema.c,v 1.1 2005/12/02 22:22:13 ziad Exp $
  *
- * LICENSE:
- * GPL v3.0 (see gpl-3.0.txt for details)
+ * CopyrightINRIA 1999
  *
  * DESCRIPTION: 
  *
  *
  * AUTHOR:
- * Gregoire Malandain (gregoire.malandain@inria.fr)
+ * Gregoire Malandain (greg@sophia.inria.fr)
  * 
  * CREATION DATE: 
  * June, 9 1998
  *
+ * Copyright Gregoire Malandain, INRIA
+ *
  * ADDITIONS, CHANGES
  *
  */
 
 #include <extrema.h>
-#include <convert.h>
 
 static int _VERBOSE_ = 0;
 
@@ -615,7 +615,7 @@ int Extract_Gradient_Maxima_3D( void *bufferIn,
   /*
    * last slice 
    * 
-   * Components and modulus of the gradient are 
+   * Components and moduls of the gradient are 
    * already computed.
    *
    * - 2D suppression of the non maxima
@@ -653,7 +653,7 @@ void Remove_Gradient_NonMaxima_Slice_2D( float *maxima,
   /* 
    * the buffer norme[0] contains the gradient modulus of the 
    * previous slice, the buffer norme[1] the ones of the
-   * slice under study, while norme[2] contains the ones
+   * slice under study, while norme[2] containes the ones
    * of the next slice.
    */
   /*
@@ -912,7 +912,7 @@ void Remove_Gradient_NonMaxima_Slice_3D( float *maxima,
   /* 
    * the buffer norme[0] contains the gradient modulus of the 
    * previous slice, the buffer norme[1] the ones of the
-   * slice under study, while norme[2] contains the ones
+   * slice under study, while norme[2] containes the ones
    * of the next slice.
    */
   /*
