@@ -1,13 +1,13 @@
 /*************************************************************************
  * typedefs.h - 
  *
- * $Id$
+ * $Id: typedefs.h,v 1.1 2005/12/02 22:22:15 ziad Exp $
  *
- * LICENSE:
- * GPL v3.0 (see gpl-3.0.txt for details)
+ * CopyrightINRIA 1998
  *
  * AUTHOR:
- * Gregoire Malandain (gregoire.malandain@inria.fr)
+ * Gregoire Malandain (greg@sophia.inria.fr)
+ * http://www.inria.fr/epidaure/personnel/malandain/
  * 
  * CREATION DATE: 
  * June, 9 1998
@@ -26,7 +26,8 @@ extern "C" {
 
 
 
-/* Different type coding for images and buffers.
+
+/* Differents type coding for images and buffers.
  */
 typedef enum {
   TYPE_UNKNOWN /* unknown type */,
@@ -34,7 +35,6 @@ typedef enum {
   SCHAR  /* signed char */,
   USHORT /* unsigned short int */,
   SSHORT /* signed short int */,
-  UINT   /* unsigned int */,
   INT    /* signed int */,
   ULINT  /* unsigned long int */,
   FLOAT  /* float */,
@@ -47,7 +47,6 @@ typedef short int          s16;
 typedef unsigned short int u16;
 typedef int                i32;
 typedef int                s32;
-typedef unsigned int       u32;
 typedef unsigned long int  u64;
 typedef float              r32;
 typedef double             r64;
@@ -55,20 +54,15 @@ typedef double             r64;
 
 
 
-
-/* Typedef Boolean
+#if 0
+/* Typedef Booleen (False causes a parse error when compiling from AFNI)
+   These do not appear used
  */
-#ifdef False
-   #undef False
-#endif
-#ifdef True
-   #undef True
-#endif
 typedef enum {
   False = 0,
   True = 1
 } typeBoolean;
-
+#endif
 
 #ifdef __cplusplus
 }
