@@ -1,30 +1,25 @@
 /*************************************************************************
  * zcross.c - zero-crossings
  *
- * $Id$
+ * $Id: zcross.c,v 1.1 2005/12/02 22:22:14 ziad Exp $
  *
- * LICENSE:
- * GPL v3.0 (see gpl-3.0.txt for details)
+ * CopyrightINRIA 2000
  *
  * DESCRIPTION: 
  *
  *
  * AUTHOR:
- * Gregoire Malandain (gregoire.malandain@inria.fr)
+ * Gregoire Malandain (greg@sophia.inria.fr)
  * 
  * CREATION DATE: 
  * Tue Nov 28 10:00:36 MET 2000
  *
+ * Copyright Gregoire Malandain, INRIA
+ *
  * ADDITIONS, CHANGES
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-
-#include <convert.h>
-#include <recbuffer.h>
 #include <zcross.h>
 
 static int _VERBOSE_ = 0;
