@@ -20,8 +20,7 @@ int main( int argc , char * argv[] )
    THD_3dim_dataset *inset=NULL , *outset ;
    char *prefix="bandpass" ;
    byte *mask=NULL ;
-   int mask_nx=0,mask_ny=0,mask_nz=0,nmask , verb=1 , 
-       nx,ny,nz,nvox , nfft=0 , kk ;
+   int mask_nx,mask_ny,mask_nz,nmask , verb=1 , nx,ny,nz,nvox , nfft=0 , kk ;
    float **vec , **ort=NULL ; int nort=0 , vv , nopt , ntime  ;
    MRI_vectim *mrv ;
    float pvrad=0.0f ; int nosat=0 ;
@@ -29,23 +28,8 @@ int main( int argc , char * argv[] )
 
    /*-- help? --*/
 
-   AFNI_SETUP_OMP(0) ;  /* 24 Jun 2013 */
-
    if( argc < 2 || strcmp(argv[1],"-help") == 0 ){
      printf(
-       "\n"
-       "--------------------------------------------------------------------------\n"
-       "** NOTA BENE:  For the purpose of preparing resting-state FMRI datasets **\n"
-       "** for analysis (e.g., with 3dGroupInCorr),  this program is now mostly **\n"
-       "** superseded by the afni_proc.py script.  See the 'afni_proc.py -help' **\n"
-       "** section 'Resting state analysis (modern)' to get our current rs-FMRI **\n"
-       "** pre-processing recommended sequence of steps. -- RW Cox, et alii.    **\n"
-       "--------------------------------------------------------------------------\n"
-       "** If you insist on doing your own bandpassing, I now recommend using   **\n"
-       "** program 3dTproject instead of this program.  3dTproject also can do  **\n"
-       "** censoring and other nuisance regression at the same time -- RW Cox.  **\n"
-       "--------------------------------------------------------------------------\n"
-       "\n"
        "Usage: 3dBandpass [options] fbot ftop dataset\n"
        "\n"
        "* One function of this program is to prepare datasets for input\n"
@@ -78,9 +62,19 @@ int main( int argc , char * argv[] )
        "\n"
        "* The actual FFT length used will be printed, and may be larger\n"
        "   than the input time series length for the sake of efficiency.\n"
-       "  ++ The program will use a power-of-2, possibly multiplied by\n"
-       "     a power of 3 and/or 5 (up to and including the 3rd power of\n"
-       "     each of these: 3, 9, 27, and 5, 25, 125).\n"
+       "  ++ The program will use a power-of-2, possibly multiplied by]\n"
+       "     a single factor of 3 and/or a single factor of 5; e.g.,\n"
+       "     240=16*3*5 would be chosen if there are 239 time points.\n"
+       "  ++ If you use the '-nfft' option, you can choose an FFT length\n"
+       "     that includes factors 3^2, 3^3, 5^2, and 5^3 in addition to\n"
+       "     the automatic selection list (which only allows 3^1 and 5^1).\n"
+       "     ++ Such FFT lengths are slower, and you should know what you\n"
+       "        are doing if you choose this option!\n"
+       "     ++ For example, if the input time series has length 136,\n"
+       "        the default FFT length would be 160 = 32*5, but you\n"
+       "        could legally use '-nfft 144' since 144 = 16*9.\n"
+       "     ++ Why you would want this level of control is between you and\n"
+       "        Cooley and Tukey.\n"
        "\n"
        "* Note that the results of combining 3dDetrend and 3dBandpass will\n"
        "   depend on the order in which you run these programs.  That's why\n"
@@ -129,7 +123,7 @@ int main( int argc , char * argv[] )
        "                    width (FWHM) of 'fff' millimeters.\n"
        " -localPV rrr    = Replace each vector by the local Principal Vector\n"
        "                    (AKA first singular vector) from a neighborhood\n"
-       "                    of radius 'rrr' millimeters.\n"
+       "                    of radius 'rrr' millimiters.\n"
        "                   ++ Note that the PV time series is L2 normalized.\n"
        "                   ++ This option is mostly for Bob Cox to have fun with.\n"
        "\n"
@@ -140,9 +134,8 @@ int main( int argc , char * argv[] )
        " -quiet          = Turn off the fun and informative messages. (Why?)\n"
        "\n"
        " -notrans        = Don't check for initial positive transients in the data:\n"
-       "  *OR*             ++ The test is a little slow, so skipping it is OK,\n"
-       " -nosat               if you KNOW the data time series are transient-free.\n"
-       "                   ++ Or set AFNI_SKIP_SATCHECK to YES.\n"
+       "                   ++ The test is a little slow, so skipping it is OK,\n"
+       "                      if you know the data time series are transient-free.\n"
        "                   ++ Initial transients won't be handled well by the\n"
        "                      bandpassing algorithm, and in addition may seriously\n"
        "                      contaminate any further processing, such as inter-voxel\n"
@@ -164,11 +157,6 @@ int main( int argc , char * argv[] )
    AFNI_logger("3dBandpass",argc,argv);
    PRINT_VERSION("3dBandpass"); AUTHOR("RW Cox");
 
-   WARNING_message("(-: For most purposes, 3dTproject is superior to 3dBandpass :-)") ;
-   WARNING_message("(-: Even better is to use afni_proc.py for pre-processing!! :-)") ;
-
-   nosat =  AFNI_yesenv("AFNI_SKIP_SATCHECK") ;
-
    nopt = 1 ;
    while( nopt < argc && argv[nopt][0] == '-' ){
 
@@ -316,7 +304,7 @@ int main( int argc , char * argv[] )
    if( ntime < 9 ) ERROR_exit("Input dataset is too short!") ;
 
    if( nfft <= 0 ){
-     nfft = csfft_nextup_even(ntime) ;
+     nfft = csfft_nextup_one35(ntime) ;
      if( verb ) INFO_message("Data length = %d  FFT length = %d",ntime,nfft) ;
      (void)THD_bandpass_set_nfft(nfft) ;
    } else if( nfft < ntime ){
@@ -368,7 +356,7 @@ int main( int argc , char * argv[] )
      float val ;
      INFO_message(
       "Checking dataset for initial transients [use '-notrans' to skip this test]") ;
-     val = THD_saturation_check(inset,mask,0,0) ; kk = (int)(val+0.54321f) ;
+     val = THD_saturation_check(inset,mask) ; kk = (int)(val+0.54321f) ;
      if( kk > 0 )
        ININFO_message(
         "Looks like there %s %d non-steady-state initial time point%s :-(" ,
@@ -411,33 +399,6 @@ int main( int argc , char * argv[] )
      }
    }
 
-   /* check whether processing leaves any DoF remaining  18 Mar 2015 [rickr] */
-   {
-      int nbprem = THD_bandpass_remain_dim(ntime, dt, fbot, ftop, 1);
-      int bpused, nremain;
-      int wlimit;               /* warning limit */
-
-      bpused = ntime - nbprem;  /* #dim lost in bandpass step */
-
-      nremain = nbprem - nort;  /* #dim left in output */
-      if( nortset == 1 ) nremain--;
-      nremain -= (qdet+1);
-
-      if( verb ) INFO_message("%d dimensional data reduced to %d by:\n"
-                    "    %d (bandpass), %d (-ort), %d (-dsort), %d (detrend)",
-                    ntime, nremain, bpused, nort, nortset?1:0, qdet+1);
-
-      /* possibly warn (if 95% lost) user or fail */
-      wlimit = ntime/20;
-      if( wlimit < 3 ) wlimit = 3;
-      if( nremain < wlimit && nremain > 0 )
-         WARNING_message("dimensionality reduced from %d to %d, be careful!",
-                         ntime, nremain);
-      if( nremain <= 0 ) /* FAILURE */
-         ERROR_exit("dimensionality reduced from %d to %d, failing!",
-                    ntime, nremain);
-   }
-
    /* all the real work now */
 
    if( do_despike ){
@@ -495,10 +456,7 @@ int main( int argc , char * argv[] )
 
    if( verb ) INFO_message("Creating output dataset in memory, then writing it") ;
    outset = EDIT_empty_copy(inset) ;
-   /* do not copy scalars    11 Sep 2015 [rickr] */
-   EDIT_dset_items( outset , ADN_prefix,prefix ,
-                             ADN_brick_fac,NULL ,
-                    ADN_none ) ;
+   EDIT_dset_items( outset , ADN_prefix,prefix , ADN_none ) ;
    tross_Copy_History( inset , outset ) ;
    tross_Make_History( "3dBandpass" , argc,argv , outset ) ;
 
@@ -540,7 +498,7 @@ void THD_vectim_localpv( MRI_vectim *mrv , float rad )
   ind = (int *)malloc(sizeof(int)*nbhd->num_pt) ;
   pv  = (float *)malloc(sizeof(float)*mrv->nvals) ;
 
-  kk = thd_floatscan( (size_t)mrv->nvec*(size_t)mrv->nvals , mrv->fvec ) ;
+  kk = thd_floatscan( mrv->nvec*mrv->nvals , mrv->fvec ) ;
   if( kk > 0 )
     WARNING_message("fixed %d float error%s before localPV",kk,(kk==1)?"\0":"s");
 
@@ -565,10 +523,10 @@ void THD_vectim_localpv( MRI_vectim *mrv , float rad )
     }
   }
 
-  memcpy( mrv->fvec , qrv->fvec , sizeof(float)*(size_t)mrv->nvec*(size_t)mrv->nvals ) ;
+  memcpy( mrv->fvec , qrv->fvec , sizeof(float)*mrv->nvec*mrv->nvals ) ;
   VECTIM_destroy(qrv) ;
 
-  kk = thd_floatscan( (size_t)mrv->nvec*(size_t)mrv->nvals , mrv->fvec ) ;
+  kk = thd_floatscan( mrv->nvec*mrv->nvals , mrv->fvec ) ;
   if( kk > 0 )
     WARNING_message("fixed %d float error%s after localPV",kk,(kk==1)?"\0":"s");
 
