@@ -2,13 +2,10 @@
 
 #ifdef USE_OMP
 #include <omp.h>
-#include "mri_blur3d_variable.c"
 #endif
 
 #define MASK_MIN 9
 
-#define FFAC 0.045084f
-
 static int verb = 1 ;
 
 extern short * UniqueShort( short *y, int ysz, int *kunq, int Sorted ) ;
@@ -30,32 +27,19 @@ int main( int argc , char *argv[] )
    short      *unval_mmask=NULL ; int nuniq_mmask=0 ;
    int do_preserve=0 , use_qsar ;         /* 19 Oct 2009 */
 
-   THD_3dim_dataset *fwhmset=NULL ;
-   MRI_IMAGE *fxim=NULL, *fyim=NULL, *fzim=NULL ;  /* 13 Jun 2016 */
-   int niter_fxyz=0 ; float dmax=0.0f , dmin=0.0f ;
-
-   float fwhmxx=0.0f , fwhmyy=0.0f , fwhmzz=0.0f ; /* 24 Mar 2021 */
-   int   do_addfwhm3=0 ;
-
    /*------- help the pitifully ignorant luser? -------*/
 
-   AFNI_SETUP_OMP(0) ;  /* 24 Jun 2013 */
-
    if( argc < 2 || strcmp(argv[1],"-help") == 0 ){
      printf(
-      "Usage: ~1~\n"
-      "3dBlurInMask [options]\n"
-      "Blurs a dataset spatially inside a mask. That's all. Experimental.\n"
+      "Usage: 3dBlurInMask [options]\n"
+      "Blurs a dataset spatially inside a mask.  That's all.  Experimental.\n"
       "\n"
-      "OPTIONS ~1~\n"
+      "OPTIONS\n"
       "-------\n"
       " -input  ddd = This required 'option' specifies the dataset\n"
       "               that will be smoothed and output.\n"
-      " -FWHM   f   = Add 'f' amount of smoothness to the dataset (in mm).\n"
+      " -FWHM   f   = Add this amount of smoothness to the dataset.\n"
       "              **N.B.: This is also a required 'option'.\n"
-      " -FWHMdset d = Read in dataset 'd' and add the amount of smoothness\n"
-      "               given at each voxel -- spatially variable blurring.\n"
-      "              ** EXPERIMENTAL EXPERIMENTAL EXPERIMENTAL **\n"
       " -mask   mmm = Mask dataset, if desired.  Blurring will\n"
       "               occur only within the mask.  Voxels NOT in\n"
       "               the mask will be set to zero in the output.\n"
@@ -81,25 +65,8 @@ int main( int argc , char *argv[] )
       "                      the ONLY purpose of the '-float' option is to\n"
       "                      force an all-shorts input dataset to be saved\n"
       "                      as all-floats after blurring.\n"
-      " ** NEW IN 2021 **\n"
-      " -FWHMxyz fx fy fz = Add different amounts of smoothness in the 3\n"
-      "                     spatial directions.\n"
-      "                    ** If one of the 'f' values is 0, no smoothing is done\n"
-      "                       in that direction.\n"
-      "                    ** Here, the axes names ('x', 'y', 'z') refer to the\n"
-      "                       order of storage in the dataset, as can be seen\n"
-      "                       in the output of 3dinfo; for example, from a dataset\n"
-      "                       that I happen to have lying around:\n"
-      "                         Data Axes Orientation:\n"
-      "                         first  (x) = Anterior-to-Posterior\n"
-      "                         second (y) = Superior-to-Inferior\n"
-      "                         third  (z) = Left-to-Right   \n"
-      "                       In this example, 'fx' is the FWHM blurring along the\n"
-      "                       A-P direction, et cetera.\n"
-      "                    ** In other words, x-y-z does not necessarily refer\n"
-      "                       to the DICOM order of coordinates (R-L, A-P, I-S)!\n"
       "\n"
-      "NOTES ~1~\n"
+      "NOTES\n"
       "-----\n"
       " * If you don't provide a mask, then all voxels will be included\n"
       "     in the blurring.  (But then why are you using this program?)\n"
@@ -165,7 +132,7 @@ int main( int argc , char *argv[] )
        iarg++ ; continue ;
      }
 
-     if( strcasecmp(argv[iarg],"-Mmask") == 0 ){   /* 07 Oct 2009 */
+     if( strcmp(argv[iarg],"-Mmask") == 0 ){   /* 07 Oct 2009 */
        if( ++iarg >= argc ) ERROR_exit("Need argument after '-Mmask'") ;
        if( mmask != NULL || mask != NULL || automask ) ERROR_exit("Can't have two mask inputs") ;
        mset = THD_open_dataset( argv[iarg] ) ;
@@ -214,18 +181,6 @@ int main( int argc , char *argv[] )
        automask = 1 ; iarg++ ; continue ;
      }
 
-     if( strcasecmp(argv[iarg],"-FWHMxyz") == 0 || strcasecmp(argv[iarg],"-FHWMxyz") == 0 ){
-       iarg++ ;
-       if( iarg+2 >= argc ) ERROR_exit("Need 3 arguments after '%s'",argv[iarg-1]);
-       fwhmxx = (float)strtod(argv[iarg++],NULL) ;
-       fwhmyy = (float)strtod(argv[iarg++],NULL) ;
-       fwhmzz = (float)strtod(argv[iarg++],NULL) ;
-       if( fwhmxx <= 0.0f && fwhmyy <= 0.0f && fwhmzz <= 0.0f )
-         ERROR_exit("All values after option '%s' are non-positive :(",argv[iarg-4]) ;
-       do_addfwhm3 = 1 ;
-       continue ;
-     }
-
      if( strcasecmp(argv[iarg],"-FWHM") == 0 || strcasecmp(argv[iarg],"-FHWM") == 0 ){
        if( ++iarg >= argc ) ERROR_exit("Need argument after '%s'",argv[iarg-1]);
        val = (float)strtod(argv[iarg],NULL) ;
@@ -235,14 +190,6 @@ int main( int argc , char *argv[] )
        iarg++ ; continue ;
      }
 
-     if( strcasecmp(argv[iarg],"-FWHMdset") == 0 ){
-       if( ++iarg >= argc ) ERROR_exit("Need argument after '%s'",argv[iarg-1]);
-       if( fwhmset != NULL ) ERROR_exit("You can't use option '-FWHMdset' twice :(") ;
-       fwhmset = THD_open_dataset( argv[iarg] ) ;
-       CHECK_OPEN_ERROR(fwhmset,argv[iarg]) ;
-       do_preserve = 1 ; iarg++ ; continue ;
-     }
-
      if( strncmp(argv[iarg],"-float",6) == 0 ){    /* 18 May 2009 */
        floatize = 1 ; iarg++ ; continue ;
      }
@@ -258,37 +205,25 @@ int main( int argc , char *argv[] )
      }
 #endif
 
-     ERROR_exit("Unknown option '%s'",argv[iarg]) ;
+     ERROR_exit("Uknown option '%s'",argv[iarg]) ;
 
    } /*--- end of loop over options ---*/
 
    /*----- check for stupid inputs, load datasets, et cetera -----*/
 
-   if( fwhmset == NULL && fwhm_goal == 0.0f && !do_addfwhm3 )
+   if( fwhm_goal == 0.0f )
      ERROR_exit("No -FWHM option given! What do you want?") ;
 
-   if( fwhmset != NULL && fwhm_goal > 0.0f ){
-     WARNING_message("-FWHMdset option replaces -FWHM value") ;
-     fwhm_goal = 0.0f ;
-   }
-
-   if( fwhmset != NULL && mmask != NULL )
-     ERROR_exit("Sorry: -FWHMdset and -Mmask don't work together (yet)") ;
-
    if( inset == NULL ){
      if( iarg >= argc ) ERROR_exit("No input dataset on command line?") ;
      inset = THD_open_dataset( argv[iarg] ) ;
      CHECK_OPEN_ERROR(inset,argv[iarg]) ;
    }
-
    nvox = DSET_NVOX(inset)     ;
    dx   = fabs(DSET_DX(inset)) ; if( dx == 0.0f ) dx = 1.0f ;
    dy   = fabs(DSET_DY(inset)) ; if( dy == 0.0f ) dy = 1.0f ;
    dz   = fabs(DSET_DZ(inset)) ; if( dz == 0.0f ) dz = 1.0f ;
 
-   dmax = MAX(dx,dy) ; if( dmax < dz ) dmax = dz ;  /* 13 Jun 2016 */
-   dmin = MIN(dx,dy) ; if( dmin > dz ) dmin = dz ;
-
    if( !floatize ){    /* 18 May 2009 */
      if( !THD_datum_constant(inset->dblk)     ||
          THD_need_brick_factor(inset)         ||
@@ -337,67 +272,8 @@ int main( int argc , char *argv[] )
      if( verb ) INFO_message("No mask ==> processing all %d voxels",nvox);
    }
 
-   /*--- process FWHMdset [13 Jun 2016] ---*/
-
-   if( fwhmset != NULL ){
-     float *fxar,*fyar,*fzar , *fwar ; MRI_IMAGE *fwim ;
-     float fwmax=0.0f , fsx,fsy,fsz ; int ii, nfpos=0 ;
-
-     if( DSET_NX(inset) != DSET_NX(fwhmset) ||
-         DSET_NY(inset) != DSET_NY(fwhmset) ||
-         DSET_NZ(inset) != DSET_NZ(fwhmset)   )
-       ERROR_exit("grid dimensions for FWHMdset and input dataset do not match :(") ;
-
-STATUS("get fwim") ;
-     DSET_load(fwhmset) ;
-     fwim = mri_scale_to_float(DSET_BRICK_FACTOR(fwhmset,0),DSET_BRICK(fwhmset,0));
-     fwar = MRI_FLOAT_PTR(fwim);
-     DSET_unload(fwhmset) ;
-STATUS("process fwar") ;
-     for( ii=0 ; ii < nvox ; ii++ ){
-       if( mask[ii] && fwar[ii] > 0.0f ){
-         nfpos++ ;
-         if( fwar[ii] > fwmax ) fwmax = fwar[ii] ;
-       } else {
-         fwar[ii] = 0.0f ; mask[ii] = 0 ;
-       }
-     }
-     if( nfpos < 100 )
-       ERROR_exit("Cannot proceed: too few (%d) voxels are positive in -FWHMdset!",nfpos) ;
-
-     niter_fxyz = (int)rintf(2.0f*fwmax*fwmax*FFAC/(0.05f*dmin*dmin)) + 1 ;
-
-     if( verb ) INFO_message("-FWHMdset: niter=%d  npos=%d",niter_fxyz,nfpos) ;
-
-STATUS("create fxim etc.") ;
-
-     fxim = mri_new_conforming(fwim,MRI_float); fxar = MRI_FLOAT_PTR(fxim);
-     fyim = mri_new_conforming(fwim,MRI_float); fyar = MRI_FLOAT_PTR(fyim);
-     fzim = mri_new_conforming(fwim,MRI_float); fzar = MRI_FLOAT_PTR(fzim);
-
-     fsx = FFAC/(dx*dx*niter_fxyz) ;
-     fsy = FFAC/(dy*dy*niter_fxyz) ;
-     fsz = FFAC/(dz*dz*niter_fxyz) ;
-/** INFO_message("fsx=%g fsy=%g fsz=%g",fsx,fsy,fsz) ; **/
-
-     for( ii=0 ; ii < nvox ; ii++ ){
-       if( fwar[ii] > 0.0f ){
-         fxar[ii] = fwar[ii]*fwar[ii] * fsx ;
-         fyar[ii] = fwar[ii]*fwar[ii] * fsy ;
-         fzar[ii] = fwar[ii]*fwar[ii] * fsz ;
-       } else {
-         fxar[ii] = fyar[ii] = fzar[ii] = 0.0f ;
-       }
-     }
-
-STATUS("free(fwim)") ;
-     mri_free(fwim) ;
-   }
-
    /*--- process input dataset ---*/
 
-STATUS("load input") ;
-
    DSET_load(inset) ; CHECK_LOAD_ERROR(inset) ;
 
    outset = EDIT_empty_copy( inset ) ;   /* moved here 04 Jun 2007 */
@@ -413,8 +289,8 @@ STATUS("load input") ;
  AFNI_OMP_START ;
 #pragma omp parallel if( nvals > 1 )
  {
-   MRI_IMAGE *dsim ; int ids,qit ; byte *qmask=NULL ; register int vv ;
-   MRI_IMAGE *qim=NULL, *qsim=NULL; float *qar=NULL, *dsar, *qsar=NULL;
+   MRI_IMAGE *dsim ; int ids ; byte *qmask=NULL ; register int vv ;
+   MRI_IMAGE *qim=NULL, *qsim=NULL; float *qar, *dsar, *qsar;
 #pragma omp critical (MALLOC)
    { if( use_qsar ){
        qsim  = mri_new_conforming(DSET_BRICK(inset,0),MRI_float); qsar = MRI_FLOAT_PTR(qsim);
@@ -441,16 +317,7 @@ STATUS("load input") ;
        for( vv=0 ; vv < nvox ; vv++ ) qsar[vv] = 0.0f ;
      }
 
-     if( fwhmset != NULL ){       /* 13 Jun 2016: spatially variable blurring */
-
-       for( qit=0 ; qit < niter_fxyz ; qit++ ){
-         mri_blur3D_variable( dsim , mask , fxim,fyim,fzim ) ;
-       }
-       if( do_preserve ){
-         for( vv=0 ; vv < nvox ; vv++ ) if( mask[vv] ) qsar[vv] = dsar[vv] ;
-       }
-
-     } else if( mmask != NULL ){         /* 07 Oct 2009: multiple masks */
+     if( mmask != NULL ){         /* 07 Oct 2009: multiple masks */
        int qq ; register short uval ;
        for( qq=0 ; qq < nuniq_mmask ; qq++ ){
          uval = unval_mmask[qq] ; if( uval == 0 ) continue ;
@@ -462,11 +329,7 @@ STATUS("load input") ;
            /* copy data from dataset to qar */
            for( vv=0 ; vv < nvox ; vv++ ) if( qmask[vv] ) qar[vv] = dsar[vv] ;
            /* blur qar (output will be zero where qmask==0) */
-           if( do_addfwhm3 ){
-             mri_blur3D_addfwhm3( qim , qmask , fwhmxx,fwhmyy,fwhmzz ) ;
-           } else {
-             mri_blur3D_addfwhm ( qim , qmask , fwhm_goal ) ;  /** the real work **/
-           }
+           mri_blur3D_addfwhm( qim , qmask , fwhm_goal ) ;  /** the real work **/
            /* copy results back to qsar */
            for( vv=0 ; vv < nvox ; vv++ ) if( qmask[vv] ) qsar[vv] = qar[vv] ;
          }
@@ -474,11 +337,7 @@ STATUS("load input") ;
 
      } else {                      /* the olden way: 1 mask */
 
-       if( do_addfwhm3 ){
-         mri_blur3D_addfwhm3( dsim , mask , fwhmxx,fwhmyy,fwhmzz ) ;
-       } else {
-         mri_blur3D_addfwhm ( dsim , mask , fwhm_goal ) ;  /** all the work **/
-       }
+       mri_blur3D_addfwhm( dsim , mask , fwhm_goal ) ;  /** all the work **/
 
        /* dsim will be zero where mask==0;
           if we want to preserve the input values, copy dsar into qsar now
