@@ -7,7 +7,7 @@
 /*---------------------------------------------------------------------------*/
 /*
   This program implements the False Discovery Rate (FDR) algorithm for
-  thresholding of voxelwise statistics.
+  thresholding of voxelwise statistics.  
 
   File:    3dFDR.c
   Author:  B. Douglas Ward
@@ -21,6 +21,7 @@
 #define PROGRAM_INITIAL "31 January 2002" /* date of initial program release */
 #define PROGRAM_LATEST "18 January 2008"    /* date of last program revision */
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Include header files and source code files.
@@ -28,9 +29,10 @@
 
 #include "mrilib.h"
 
+
 /*---------------------------------------------------------------------------*/
 /*
-  Structure declarations
+  Structure declarations 
 */
 
 struct voxel;
@@ -42,10 +44,13 @@ typedef struct voxel
   struct voxel * next_voxel;           /* pointer to next voxel in list */
 } voxel;
 
+
+
 /*-------------------------- global data ------------------------------------*/
 
 #define  FDR_MAX_LL 10000        /* maximum number of linked lists of voxels */
 
+
 static int    FDR_quiet      = 0;      /* flag for suppress screen output */
 static int    FDR_list       = 0;      /* flag for list voxel q-values */
 static float  FDR_mask_thr   = 1.0;    /* mask threshold */
@@ -63,7 +68,7 @@ static float * FDR_input1D_data = NULL;    /* input array of p-values */
 static voxel * FDR_head_voxel[FDR_MAX_LL]; /* linked lists of voxels */
 
 static char * commandline = NULL;          /* command line for history notes */
-static THD_3dim_dataset * FDR_dset = NULL; /* input dataset */
+static THD_3dim_dataset * FDR_dset = NULL; /* input dataset */  
 
 /*---------------------------------------------------------------------------*/
 /*** 18 Jan 2008 changes [RWCox]:
@@ -140,7 +145,7 @@ void FDR_error (char * message)
 #define MTEST(ptr) \
 if((ptr)==NULL) \
 ( FDR_error ("Cannot allocate memory") )
-
+     
 
 /*---------------------------------------------------------------------------*/
 /*
@@ -167,10 +172,6 @@ printf(
 "                                                                           \n"
 "               stat ==> p-value ==> FDR q-value ==> FDR z-score            \n"
 "                                                                           \n"
-"The reason for the final conversion from q to z is so that larger values   \n"
-"are more 'significant', which is how the usual thresholding procedure      \n"
-"in the AFNI GUI works.                                                     \n"
-"                                                                           \n"
 );
 
 printf(
@@ -313,7 +314,7 @@ printf(
 "* cf. http://dx.doi.org/10.1093/bioinformatics/bti448   [False Negative Rate]\n"
 "* cf. http://dx.doi.org/10.1093/biomet/93.3.491         [m0 adjustment idea]\n"
 "* cf. C implementation in mri_fdrize.c                  [trust in the Source]\n"
-"* cf. https://afni.nimh.nih.gov/pub/dist/doc/misc/FDR/FDR_Jan2008.pdf\n"
+"* cf. http://afni.nimh.nih.gov/pub/dist/doc/misc/FDR/FDR_Jan2008.pdf\n"
 ) ;
 
    PRINT_COMPILE_DATE ;
@@ -322,6 +323,7 @@ printf(
 
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
    Read the arguments, load the global variables
@@ -335,7 +337,7 @@ void read_options ( int argc , char * argv[] )
 
 
   if( AFNI_yesenv("AFNI_FLOATIZE") ) FDR_float = 1 ;
-
+  
   /*----- main loop over input options -----*/
   while( nopt < argc )
     {
@@ -351,8 +353,8 @@ void read_options ( int argc , char * argv[] )
 	  nopt++;
 	  continue;
 	}
-
-
+      
+      
       /*-----   -input1D dname   -----*/
       if (strcmp(argv[nopt], "-input1D") == 0)
 	{
@@ -364,8 +366,8 @@ void read_options ( int argc , char * argv[] )
 	  nopt++;
 	  continue;
 	}
-
-
+      
+      
       /*-----   -mask_file mname   -----*/
       if (strcmp(argv[nopt], "-mask_file") == 0 || strcmp(argv[nopt],"-mask") == 0)
 	{
@@ -377,16 +379,16 @@ void read_options ( int argc , char * argv[] )
 	  nopt++;
 	  continue;
 	}
-
+      
 
       /*----- -mask_thr m -----*/
       if( strcmp(argv[nopt],"-mask_thr") == 0 ){
 	 float fval;
          nopt++ ;
          if( nopt >= argc ){
-            FDR_error (" need 1 argument after -mask_thr");
+            FDR_error (" need 1 argument after -mask_thr"); 
          }
-	 sscanf (argv[nopt], "%f", &fval);
+	 sscanf (argv[nopt], "%f", &fval); 
 	 if (fval < 0.0){
             FDR_error (" Require mask_thr >= 0.0 ");
          }
@@ -429,14 +431,14 @@ void read_options ( int argc , char * argv[] )
          nopt++ ; continue ;
       }
 
-
+      
       /*----- -cdep -----*/
       if( strcmp(argv[nopt],"-cdep") == 0 ){
          FDR_cn = -1.0;
          nopt++ ; continue ;
       }
 
-
+      
       /*----- -quiet -----*/
       if( strcmp(argv[nopt],"-quiet") == 0 ){
          FDR_quiet = 1;
@@ -446,14 +448,14 @@ void read_options ( int argc , char * argv[] )
          FDR_quiet = 0 ; nopt++ ; continue ;
       }
 
-
+      
       /*----- -list -----*/
       if( strcmp(argv[nopt],"-list") == 0 ){
          FDR_list = 1;
          nopt++ ; continue ;
       }
 
-
+      
       /*----- -prefix prefix -----*/
       if( strcmp(argv[nopt],"-prefix") == 0 ||
           strcmp(argv[nopt],"-output") == 0   ){
@@ -461,7 +463,7 @@ void read_options ( int argc , char * argv[] )
          if( nopt >= argc ){
             FDR_error (" need argument after -prefix!");
          }
-	 FDR_output_prefix = (char *) malloc (sizeof(char) * THD_MAX_PREFIX);
+	 FDR_output_prefix = (char *) malloc (sizeof(char) * THD_MAX_PREFIX); 
          MCW_strncpy( FDR_output_prefix , argv[nopt++] , THD_MAX_PREFIX ) ;
          continue ;
       }
@@ -470,7 +472,7 @@ void read_options ( int argc , char * argv[] )
       /*----- unknown command -----*/
       sprintf(message,"Unrecognized command line option: %s\n", argv[nopt]);
       FDR_error (message);
-
+      
 
    }  /*----- end of loop over command line arguments -----*/
 
@@ -502,13 +504,14 @@ void read_options ( int argc , char * argv[] )
    return ;
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Read time series from specified file name.  This file name may have
   a column selector attached.
 */
 
-float * read_time_series
+float * read_time_series 
 (
   char * ts_filename,          /* time series file name (plus column index) */
   int * ts_length              /* output value for time series length */
@@ -519,7 +522,7 @@ float * read_time_series
   char * cpt;                    /* pointer to column suffix */
   char filename[THD_MAX_NAME];   /* time series file name w/o column index */
   char subv[THD_MAX_NAME];       /* string containing column index */
-  MRI_IMAGE * im, * flim;  /* pointers to image structures
+  MRI_IMAGE * im, * flim;  /* pointers to image structures 
 			      -- used to read 1D ASCII */
   float * far;             /* pointer to MRI_IMAGE floating point data */
   int nx;                  /* number of time points in time series */
@@ -548,27 +551,28 @@ float * read_time_series
   if( ny > 1 ){
     fprintf(stderr,"WARNING: time series %s has more than 1 column\n",ts_filename);
   }
-
+  
 
   /*----- Save the time series data -----*/
   *ts_length = nx;
   ts_data = (float *) malloc (sizeof(float) * nx);
   MTEST (ts_data);
   for (ipt = 0;  ipt < nx;  ipt++)
-    ts_data[ipt] = far[ipt + iy*nx];
-
-
+    ts_data[ipt] = far[ipt + iy*nx];   
+  
+  
   mri_free (flim);  flim = NULL;
 
   return (ts_data);
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Routine to check whether one output file already exists.
 */
 
-void check_one_output_file
+void check_one_output_file 
 (
   THD_3dim_dataset * dset_time,     /* input 3d+time data set */
   char * filename                   /* name of output file */
@@ -580,27 +584,27 @@ void check_one_output_file
   int ierror;                         /* number of errors in editing data */
 
 ENTRY("check_one_output_file") ;
-
+  
   /*----- make an empty copy of input dataset -----*/
   new_dset = EDIT_empty_copy( dset_time ) ;
-
-
+  
+  
   ierror = EDIT_dset_items( new_dset ,
 			    ADN_prefix , filename ,
 			    ADN_label1 , filename ,
 			    ADN_self_name , filename ,
-			    ADN_type , ISHEAD(dset_time) ? HEAD_FUNC_TYPE :
+			    ADN_type , ISHEAD(dset_time) ? HEAD_FUNC_TYPE : 
                                			           GEN_FUNC_TYPE ,
 			    ADN_none ) ;
-
+  
   if( ierror > 0 )
     {
       sprintf (message,
-	       "*** %d errors in attempting to create output dataset!\n",
+	       "*** %d errors in attempting to create output dataset!\n", 
 	       ierror);
       FDR_error (message);
     }
-
+  
   if( THD_is_file(new_dset->dblk->diskptr->header_name) )
     {
       sprintf (message,
@@ -609,13 +613,14 @@ ENTRY("check_one_output_file") ;
 	       new_dset->dblk->diskptr->header_name);
       FDR_error (message);
     }
-
-  /*----- deallocate memory -----*/
+  
+  /*----- deallocate memory -----*/   
   THD_delete_3dim_dataset( new_dset , False ) ; new_dset = NULL ;
-
-  EXRETURN ;
+ 
+  EXRETURN ; 
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Routine to initialize the program: get all operator inputs; create mask
@@ -629,19 +634,19 @@ void initialize_program (int argc, char * argv[])
   float * ffim = NULL;     /* sub-brick data in floating point format */
   int ixyz;                /* voxel index */
   int nx, ny, nz, nxyz;    /* numbers of voxels in input dataset */
-  int mx=0, my=0, mz=0, mxyz;    /* numbers of voxels in mask dataset */
-  int nthr=0;                /* number of voxels above mask threshold */
+  int mx, my, mz, mxyz;    /* numbers of voxels in mask dataset */
+  int nthr;                /* number of voxels above mask threshold */
   char message[80];        /* error message */
   int ibin;                /* p-value bin index */
 
 
   /*-- 20 Apr 2001: addto the arglist, if user wants to [RWCox] --*/
-  machdep() ;
+  machdep() ; 
   { int new_argc ; char ** new_argv ;
   addto_args( argc , argv , &new_argc , &new_argv ) ;
   if( new_argv != NULL ){ argc = new_argc ; argv = new_argv ; }
   }
-
+  
 
   /*----- Save command line for history notes -----*/
   commandline = tross_commandline( PROGRAM_NAME , argc,argv ) ;
@@ -650,9 +655,9 @@ void initialize_program (int argc, char * argv[])
   /*----- Does user request help menu? -----*/
   if( argc < 2 || strcmp(argv[1],"-help") == 0 ) FDR_Syntax() ;
 
-
+  
   /*----- Add to program log -----*/
-  AFNI_logger (PROGRAM_NAME,argc,argv);
+  AFNI_logger (PROGRAM_NAME,argc,argv); 
 
 
   /*----- Read input options -----*/
@@ -662,13 +667,13 @@ void initialize_program (int argc, char * argv[])
   /*----- Open the mask dataset -----*/
   if (FDR_mask_filename != NULL)
     {
-      if (!FDR_quiet)
+      if (!FDR_quiet) 
         printf ("Reading mask dataset: %s \n", FDR_mask_filename);
       DOPEN (FDR_dset, FDR_mask_filename);
 
       if (FDR_dset == NULL)
       {
-        sprintf (message, "Cannot open mask dataset %s", FDR_mask_filename);
+        sprintf (message, "Cannot open mask dataset %s", FDR_mask_filename); 
         FDR_error (message);
       }
 
@@ -677,8 +682,8 @@ void initialize_program (int argc, char * argv[])
 
 
       /*----- Get dimensions of mask dataset -----*/
-      mx   = DSET_NX(FDR_dset);
-      my   = DSET_NY(FDR_dset);
+      mx   = DSET_NX(FDR_dset);   
+      my   = DSET_NY(FDR_dset);   
       mz   = DSET_NZ(FDR_dset);
       mxyz = mx*my*mz;
 
@@ -693,13 +698,13 @@ void initialize_program (int argc, char * argv[])
       EDIT_coerce_scale_type (mxyz, DSET_BRICK_FACTOR(FDR_dset,iv),
 			      DSET_BRICK_TYPE(FDR_dset,iv), vfim,  /* input  */
 			      MRI_float                   , ffim); /* output */
-
-
+  
+      
       /*----- Allocate memory for mask volume -----*/
       FDR_mask = (byte *) malloc (sizeof(byte) * mxyz);
       MTEST (FDR_mask);
-
-
+      
+      
       /*----- Create mask of voxels above mask threshold -----*/
       nthr = 0;
       for (ixyz = 0;  ixyz < mxyz;  ixyz++){
@@ -707,9 +712,9 @@ void initialize_program (int argc, char * argv[])
         else                                   FDR_mask[ixyz] = 0;
       }
 
-      if (!FDR_quiet)
+      if (!FDR_quiet)  
         printf ("Number of voxels above mask threshold = %d \n", nthr);
-      if (nthr < 1)
+      if (nthr < 1)  
         FDR_error ("No voxels above mask threshold.  Cannot continue.");
 
 
@@ -727,20 +732,20 @@ void initialize_program (int argc, char * argv[])
   if (FDR_input1D_filename != NULL)
     {
       /*----- Read the input .1D file -----*/
-      if (!FDR_quiet)  printf ("Reading input data: %s \n",
+      if (!FDR_quiet)  printf ("Reading input data: %s \n", 
 			       FDR_input1D_filename);
       FDR_input1D_data = read_time_series (FDR_input1D_filename, &nxyz);
 
-      if (FDR_input1D_data == NULL)
-	{
-	  sprintf (message,  "Unable to read input .1D data file: %s",
+      if (FDR_input1D_data == NULL)  
+	{ 
+	  sprintf (message,  "Unable to read input .1D data file: %s", 
 		   FDR_input1D_filename);
 	  FDR_error (message);
 	}
-
-      if (nxyz < 1)
-	{
-	  sprintf (message,  "No p-values in input .1D data file: %s",
+      
+      if (nxyz < 1)  
+	{ 
+	  sprintf (message,  "No p-values in input .1D data file: %s", 
 		   FDR_input1D_filename);
 	  FDR_error (message);
 	}
@@ -748,22 +753,22 @@ void initialize_program (int argc, char * argv[])
       FDR_nxyz = nxyz;
       FDR_nthr = nxyz;
     }
-
+  
   else
     {
       /*----- Open the input 3D dataset -----*/
-      if (!FDR_quiet)  printf ("Reading input dataset: %s \n",
+      if (!FDR_quiet)  printf ("Reading input dataset: %s \n", 
 			       FDR_input_filename);
       FDR_dset = THD_open_dataset(FDR_input_filename);
       CHECK_OPEN_ERROR(FDR_dset,FDR_input_filename);
-
+      
       /*----- Get dimensions of input dataset -----*/
-      nx   = DSET_NX(FDR_dset);
-      ny   = DSET_NY(FDR_dset);
+      nx   = DSET_NX(FDR_dset);   
+      ny   = DSET_NY(FDR_dset);   
       nz   = DSET_NZ(FDR_dset);
       nxyz = nx*ny*nz;
-
-
+      
+      
       /*----- Check for compatible dimensions -----*/
       if (FDR_mask != NULL)
 	{
@@ -795,7 +800,7 @@ void initialize_program (int argc, char * argv[])
       if (!FDR_quiet)
 	printf ("c(N) = %f \n", FDR_cn);
     }
-
+  
   /*----- Initialize voxel pointers -----*/
   for (ibin = 0;  ibin < FDR_MAX_LL;  ibin++)
     FDR_head_voxel[ibin] = NULL;
@@ -803,26 +808,28 @@ void initialize_program (int argc, char * argv[])
   return ;
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Create an empty voxel.
 */
-
+  
 voxel * create_voxel ()
 {
   voxel * voxel_ptr = NULL;
 
   voxel_ptr = (voxel *) malloc (sizeof(voxel));
   MTEST (voxel_ptr);
-
+  
   voxel_ptr->ixyz = 0;
   voxel_ptr->pvalue = 0.0;
   voxel_ptr->next_voxel = NULL;
 
   return (voxel_ptr);
-
+  
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Add a new voxel to the linked list of voxels.
@@ -842,10 +849,10 @@ voxel * add_voxel (voxel * new_voxel, voxel * head_voxel)
     {
       voxel_ptr = head_voxel;
 
-      while ((voxel_ptr->next_voxel != NULL) &&
+      while ((voxel_ptr->next_voxel != NULL) && 
 	     (new_voxel->pvalue < voxel_ptr->next_voxel->pvalue))
 	voxel_ptr = voxel_ptr->next_voxel;
-
+      
       new_voxel->next_voxel = voxel_ptr->next_voxel;
       voxel_ptr->next_voxel = new_voxel;
     }
@@ -853,6 +860,7 @@ voxel * add_voxel (voxel * new_voxel, voxel * head_voxel)
   return (head_voxel);
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Create and initialize a new voxel, and add to list of voxels.
@@ -871,9 +879,10 @@ voxel * new_voxel (int ixyz, float pvalue, voxel * head_voxel)
   head_voxel = add_voxel (voxel_ptr, head_voxel);
 
   return (head_voxel);
-
+  
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Deallocate memory for all voxel lists.
@@ -886,7 +895,7 @@ void delete_all_voxels ()
   voxel * next_voxel = NULL;     /* pointer to next voxel */
 
 
-  for (ibin = 0;  ibin < FDR_MAX_LL;  ibin++)
+  for (ibin = 0;  ibin < FDR_MAX_LL;  ibin++) 
     {
       voxel_ptr = FDR_head_voxel[ibin];
       while (voxel_ptr != NULL)
@@ -897,9 +906,10 @@ void delete_all_voxels ()
 	}
       FDR_head_voxel[ibin] = NULL;
     }
-
+  
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Save voxel contents of all voxels into float array (sub-brick).
@@ -909,17 +919,17 @@ void save_all_voxels (float * far)
 {
   int ixyz, ibin;
   voxel * voxel_ptr  = NULL;     /* pointer to voxel */
-
+  
 
   /*----- Initialize all voxels to zero -----*/
   for (ixyz = 0;  ixyz < FDR_nxyz;  ixyz++)
     far[ixyz] = 0.0;
 
 
-  for (ibin = 0;  ibin < FDR_MAX_LL;  ibin++)
+  for (ibin = 0;  ibin < FDR_MAX_LL;  ibin++) 
     {
       voxel_ptr = FDR_head_voxel[ibin];
-
+  
       while (voxel_ptr != NULL)
 	{
 	  far[voxel_ptr->ixyz] = voxel_ptr->pvalue;
@@ -930,6 +940,7 @@ void save_all_voxels (float * far)
 
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Calculate FDR z-scores for all voxels within one volume.
@@ -987,7 +998,7 @@ void process_volume (float * ffim, int statcode, float * stataux)
   }
 
   /*---------------- back to the 'old' method ------------------*/
-
+  
   /*----- Allocate memory for screen output arrays -----*/
   if (FDR_list)
     {
@@ -996,8 +1007,8 @@ void process_volume (float * ffim, int statcode, float * stataux)
       qarray = (float *) malloc (sizeof(float) * FDR_nthr);   MTEST(qarray);
       zarray = (float *) malloc (sizeof(float) * FDR_nthr);   MTEST(zarray);
     }
-
-
+  
+  
   /*----- Loop over all voxels; sort p-values -----*/
   icount = FDR_nthr;
 
@@ -1015,7 +1026,7 @@ void process_volume (float * ffim, int statcode, float * stataux)
       else
 	pval = THD_stat_to_pval (fval, statcode, stataux);
 
-      if (pval >= 1.0)
+      if (pval >= 1.0)  
 	{
 	  /*----- Count but don't sort voxels with p-value = 1 -----*/
 	  icount--;
@@ -1028,7 +1039,7 @@ void process_volume (float * ffim, int statcode, float * stataux)
 	    }
 	}
       else
-	{
+	{ 
 	  /*----- Place voxel in p-value bin -----*/
 	  ibin = (int)  (pval * (FDR_MAX_LL));
 	  if (ibin < 0)  ibin = 0;
@@ -1042,10 +1053,10 @@ void process_volume (float * ffim, int statcode, float * stataux)
   qval_min = 1.0;
   ibin = FDR_MAX_LL-1;
   numer = (FDR_pmask) ? icount : FDR_nthr ;  /* 18 Jan 2008 */
-  while (ibin >= 0)
+  while (ibin >= 0) 
     {
       voxel_ptr = FDR_head_voxel[ibin];
-
+  
       while (voxel_ptr != NULL)
 	{
           /*----- Convert sorted p-values to FDR q-values -----*/
@@ -1084,7 +1095,7 @@ void process_volume (float * ffim, int statcode, float * stataux)
   /*----- Write out the calculated values -----*/
   if (FDR_list)
     {
-      printf ("%12s %12s %12s %12s \n",
+      printf ("%12s %12s %12s %12s \n", 
 	      "Index", "p-value", "q-value", "z-score");
       for (icount = 0;  icount < FDR_nthr;  icount++)
 	{
@@ -1092,7 +1103,7 @@ void process_volume (float * ffim, int statcode, float * stataux)
 	    ixyz = iarray[icount] + 1;
 	  else
 	    ixyz = iarray[icount];
-	  printf ("%12d %12.6f %12.6f %12.6f \n",
+	  printf ("%12d %12.6f %12.6f %12.6f \n",  
 		  ixyz, parray[icount], qarray[icount], zarray[icount]);
 	}
 
@@ -1110,6 +1121,7 @@ void process_volume (float * ffim, int statcode, float * stataux)
 
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Perform all processing for this array of p-values.
@@ -1120,7 +1132,7 @@ void process_1ddata ()
 {
   float * ffim = NULL;     /* input list of p-values */
 
-
+  
   /*----- Set pointer to input array of p-values -----*/
   ffim = FDR_input1D_data;
 
@@ -1159,7 +1171,7 @@ void process_subbrick (THD_3dim_dataset * dset, int ibrick)
 ENTRY("process_subbrick") ;
   if (!FDR_quiet)  printf ("Processing sub-brick #%d \n", ibrick);
 
-
+  
   /*----- Allocate memory for float data -----*/
   ffim = (float *) malloc (sizeof(float) * FDR_nxyz);   MTEST (ffim);
 
@@ -1180,7 +1192,7 @@ ENTRY("process_subbrick") ;
   if( !FDR_float || DSET_BRICK_TYPE(dset,ibrick)==MRI_float ){
     SUB_POINTER (dset, ibrick, 0, vfim);
     factor = EDIT_coerce_autoscale_new (FDR_nxyz, MRI_float, ffim,
-				      DSET_BRICK_TYPE(dset,ibrick), vfim);
+				      DSET_BRICK_TYPE(dset,ibrick), vfim);  
     if (factor < EPSILON)  factor = 0.0;
     else factor = 1.0 / factor;
     if( DSET_BRICK_TYPE(dset,ibrick) == MRI_short )
@@ -1190,7 +1202,7 @@ ENTRY("process_subbrick") ;
     EDIT_substitute_brick( dset , ibrick , MRI_float , ffim ) ;
     ffim = NULL ; factor = 0.0f ;
   }
-
+  
 
   /*----- edit the sub-brick -----*/
   if( FDR_qval ) strcpy (brick_label, "FDRq:");
@@ -1207,6 +1219,7 @@ ENTRY("process_subbrick") ;
   EXRETURN ;
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Process the input dataset.
@@ -1235,7 +1248,7 @@ ENTRY("process_dataset") ;
     }
 
 
-  /*----- Deallocate memory for input dataset -----*/
+  /*----- Deallocate memory for input dataset -----*/   
   THD_delete_3dim_dataset (FDR_dset , False );  FDR_dset = NULL ;
 
 
@@ -1248,8 +1261,8 @@ ENTRY("process_dataset") ;
       if (FUNC_IS_STAT(statcode) || FDR_force )
 	{
 	  /*----- Process the statistical sub-bricks -----*/
-	  if (!FDR_quiet)
-	    printf ("ibrick = %3d   statcode = %5s \n",
+	  if (!FDR_quiet)  
+	    printf ("ibrick = %3d   statcode = %5s \n", 
 		    ibrick, FUNC_prefixstr[MAX(statcode,0)]);
 	  process_subbrick (new_dset, ibrick);
 	}
@@ -1259,6 +1272,7 @@ ENTRY("process_dataset") ;
   RETURN(new_dset);
 }
 
+
 /*---------------------------------------------------------------------------*/
 /*
   Output the results as a bucket dataset.
@@ -1273,7 +1287,7 @@ void output_results (THD_3dim_dataset * new_dset)
   ierror = EDIT_dset_items( new_dset ,
 			    ADN_func_type , FUNC_BUCK_TYPE,
 			    ADN_none ) ;
-  if (ierror > 0)
+  if (ierror > 0)  
     FDR_error ("Errors in attempting to create output dataset.");
 
 
@@ -1283,26 +1297,27 @@ void output_results (THD_3dim_dataset * new_dset)
 
   THD_write_3dim_dataset( NULL,NULL , new_dset , True ) ;
   if( !FDR_quiet ) fprintf(stderr,"Wrote output to %s\n", DSET_BRIKNAME(new_dset) );
+  
 
-
-  /*----- Deallocate memory for output dataset -----*/
+  /*----- Deallocate memory for output dataset -----*/   
   THD_delete_3dim_dataset( new_dset , False ) ; new_dset = NULL ;
-
+  
 }
 
+
 /*---------------------------------------------------------------------------*/
 
 int main( int argc , char * argv[] )
 
 {
   THD_3dim_dataset * new_dset = NULL;      /* output bucket dataset */
-
+  
 
   /*----- Identify software -----*/
 #if 0
   printf ("\n\n");
   printf ("Program:          %s \n", PROGRAM_NAME);
-  printf ("Author:           %s \n", PROGRAM_AUTHOR);
+  printf ("Author:           %s \n", PROGRAM_AUTHOR); 
   printf ("Initial Release:  %s \n", PROGRAM_INITIAL);
   printf ("Latest Revision:  %s \n", PROGRAM_LATEST);
   printf ("\n");
@@ -1310,7 +1325,7 @@ int main( int argc , char * argv[] )
 
   PRINT_VERSION("3dFDR") ; AUTHOR(PROGRAM_AUTHOR); mainENTRY("3dFDR main") ; machdep() ;
 
-  /*----- Initialize program:  get all operator inputs;
+  /*----- Initialize program:  get all operator inputs; 
     create mask for voxels above mask threshold -----*/
   initialize_program (argc, argv);
 
@@ -1328,6 +1343,6 @@ int main( int argc , char * argv[] )
       /*----- Output the results as a bucket dataset -----*/
       output_results (new_dset);
     }
-
+  
   exit(0) ;
 }
