@@ -64,10 +64,10 @@
 
 static char * anat_filename = NULL;      /* file name for input anat dataset */
 static char * prefix_filename = NULL;    /* prefix name for output dataset */
-static RwcBoolean write_mask = FALSE;       /* flag for generate 'fim' mask */
-static RwcBoolean quiet = FALSE;            /* flag for suppress screen output */
+static Boolean write_mask = FALSE;       /* flag for generate 'fim' mask */
+static Boolean quiet = FALSE;            /* flag for suppress screen output */
 static char * commandline = NULL ;       /* command line for history notes */
-static RwcBoolean nosmooth = FALSE;         /* flag to delete spatial smoothing */
+static Boolean nosmooth = FALSE;         /* flag to delete spatial smoothing */
 
 
 /*---------------------------------------------------------------------------*/
@@ -659,7 +659,7 @@ void write_afni_data
 void SEGMENT_auto ()
 {
   short * cv = NULL;           /* volume with 1's at target voxel locations */
-  int ok;                      /* binary, for successful operation */
+  int ok;                      /* Boolean for successful operation */
 
 
   /*----- Perform initialization for automatic segmentation algorithm -----*/
@@ -715,9 +715,7 @@ int main
 
   mainENTRY("3dIntracranial:main") ; machdep() ; PRINT_VERSION("3dIntracranial") ;
   AUTHOR(PROGRAM_AUTHOR) ;
-  WARNING_message("This program (3dIntracranial) is old, obsolete, and not maintained!") ;
-  INFO_message("3dSkullStrip is almost always superior to 3dIntracranial :)") ;
-
+  INFO_message("3dSkullStrip is usually superior to 3dIntracranial") ;
 
   /*----- Program initialization -----*/
   initialize_program (argc, argv);
