@@ -17,6 +17,7 @@ static int myTHD_extract_nbhd( THD_3dim_dataset *dset, byte *mask,
 
 /*------------------------------------------------------------------------*/
 
+#ifndef USE_OMP
 static void vstep_print(void)
 {
    static char xx[10] = "0123456789" ; static int vn=0 ;
@@ -24,17 +25,17 @@ static void vstep_print(void)
    if( vn%10 == 9) fprintf(stderr,".") ;
    vn++ ;
 }
+#endif
 
 /*------------------------------------------------------------------------*/
 /* Adapted from 3dLocalSVD, to be more efficient when #evals=1 */
 
 int main( int argc , char *argv[] )
 {
-   THD_3dim_dataset *inset=NULL , *outset=NULL , *evset=NULL , *outset2=NULL ;
+   THD_3dim_dataset *inset=NULL , *outset=NULL , *evset=NULL ;
    MCW_cluster *nbhd=NULL ;
-   byte *mask=NULL ; int mask_nx=0,mask_ny=0,mask_nz=0 , automask=0 ;
-   char *prefix ="./LocalPV" ;
-   char *prefix2=NULL ;
+   byte *mask=NULL ; int mask_nx,mask_ny,mask_nz , automask=0 ;
+   char *prefix="./LocalPV" ;
    char *evprefix=NULL ; int nev ;
    int iarg=1 , verb=1 , ntype=0 , kk,nx,ny,nz,nxy,nxyz,nt , vstep=0 ;
    float na,nb,nc , dx,dy,dz ;
@@ -44,16 +45,14 @@ int main( int argc , char *argv[] )
    unsigned int gseed ;
    int despike=0 ;  /* 14 Oct 2010 */
 
-   AFNI_SETUP_OMP(0) ;  /* 24 Jun 2013 */
-
    if( argc < 2 || strcmp(argv[1],"-help") == 0 ){
      printf(
        "Usage: 3dLocalPV [options] inputdataset\n"
        "* You may want to use 3dDetrend before running this program,\n"
        "   or at least use the '-polort' option.\n"
-       "* This program is highly experimental.  And slowish. Real slowish.\n"
+       "* This program is highly experimental.  And slowish.\n"
        "* Computes the SVD of the time series from a neighborhood of each\n"
-       "   voxel.  An inricate way of 'smoothing' 3D+time datasets, kind of, sort of.\n"
+       "   voxel.  An inricate way of 'smoothing' 3D+time datasets, sort of.\n"
        "* This is like 3dLocalSVD, except that the '-vproj' option doesn't\n"
        "   allow anything but 1 and 2 dimensional projection.  This is because\n"
        "   3dLocalPV uses a special method to compute JUST the first 1 or 2\n"
@@ -64,8 +63,6 @@ int main( int argc , char *argv[] )
        " -automask           = create a mask from time series dataset\n"
        " -prefix ppp         = save SVD vector result into this new dataset\n"
        "                        [default = 'LocalPV']\n"
-       " -prefix2 qqq        = save second principal vector into this new dataset\n"
-       "                        [default = don't save it]\n"
        " -evprefix ppp       = save singular value at each voxel into this dataset\n"
        "                        [default = don't save]\n"
        " -input inputdataset = input time series dataset\n"
@@ -75,11 +72,11 @@ int main( int argc , char *argv[] )
        " -vnorm              = normalize data vectors [strongly recommended]\n"
        " -vproj [2]          = project central data time series onto local SVD vector;\n"
        "                        if followed by '2', then the central data time series\n"
-       "                        will be projected on the 2-dimensional subspace\n"
+       "                        will be projected on the the 2-dimensional subspace\n"
        "                        spanned by the first 2 principal SVD vectors.\n"
        "                        [default: just output principal singular vector]\n"
        "                        [for 'smoothing' purposes, '-vnorm -vproj' is an idea]\n"
-#if 0  /* this option not actually implemented */
+#if 0
        "\n"
        " -use_nonmask         = Allow the computation of the local SVD time series\n"
        "                         even from voxels that are NOT in the mask, provided\n"
@@ -94,12 +91,7 @@ int main( int argc , char *argv[] )
        "Notes:\n"
        "* On my Mac Pro, about 30%% faster than 3dLocalSVD computing the same thing.\n"
        "* If you're curious, the 'special method' used for the eigensolution is\n"
-       "   a variant of matrix power iteration, called 'simultaneous iteration'.\n"
-       "* This method uses pseudo-random numbers to initialize the vector iterations.\n"
-       "   If you wish to control that seed, set environment variable\n"
-       "   AFNI_RANDOM_SEEDVAL to some nonzero number. Otherwise, a random seed will\n"
-       "   be selected from the time, which means otherwise identical runs will give\n"
-       "   slightly different results.\n"
+       "  a variant of matrix power iteration, called 'simultaneous iteration'.\n"
        "* By contrast, 3dLocalSVD uses EISPACK functions for eigensolution-izing.\n"
      ) ;
      PRINT_AFNI_OMP_USAGE("3dLocalPV",NULL) ;
@@ -111,10 +103,7 @@ int main( int argc , char *argv[] )
    PRINT_VERSION("3dLocalPV"); mainENTRY("3dLocalPV main"); machdep();
    AFNI_logger("3dLocalPV",argc,argv); AUTHOR("Emperor Zhark the Iterator");
 
-   gseed = (unsigned int)AFNI_numenv("AFNI_RANDOM_SEEDVAL") ;
-   if( gseed == 0 )
-     gseed = ((unsigned int)time(NULL)) + 17*(unsigned int)getpid() ;
-   INFO_message("random seed set to %u from AFNI_RANDOM_SEEDVAL",gseed) ;
+   gseed = ((unsigned int)time(NULL)) + 17*(unsigned int)getpid() ;
 
    /*---- loop over options ----*/
 
@@ -145,7 +134,6 @@ int main( int argc , char *argv[] )
        char *cpt ;
        if( ++iarg >= argc ) ERROR_exit("Need argument after '-polort'") ;
        polort = (int)strtod(argv[iarg],&cpt) ;
-       if( *cpt != '\0' ) WARNING_message("Illegal non-numeric value after -polort") ;
        iarg++ ; continue ;
      }
 
@@ -160,16 +148,6 @@ int main( int argc , char *argv[] )
      if( strcmp(argv[iarg],"-prefix") == 0 ){
        if( ++iarg >= argc ) ERROR_exit("Need argument after '-prefix'") ;
        prefix = strdup(argv[iarg]) ;
-       if( ! THD_filename_ok(prefix) )
-         ERROR_exit("-prefix '%s' is illegal",prefix) ;
-       iarg++ ; continue ;
-     }
-
-     if( strcmp(argv[iarg],"-prefix2") == 0 ){
-       if( ++iarg >= argc ) ERROR_exit("Need argument after '-prefix2'") ;
-       prefix2 = strdup(argv[iarg]) ;
-       if( ! THD_filename_ok(prefix2) )
-         ERROR_exit("-prefix '%s' is illegal",prefix2) ;
        iarg++ ; continue ;
      }
 
@@ -341,23 +319,12 @@ int main( int argc , char *argv[] )
 
    /** create output dataset **/
 
-   if( prefix != NULL && strcmp(prefix,"NULL") != 0 ){
-     outset = EDIT_empty_copy(inset) ;
-     EDIT_dset_items( outset, ADN_prefix,prefix, ADN_brick_fac,NULL, ADN_none );
-     tross_Copy_History( inset , outset ) ;
-     tross_Make_History( "3dLocalPV" , argc,argv , outset ) ;
-     for( kk=0 ; kk < nt ; kk++ )                         /* create bricks */
-       EDIT_substitute_brick( outset , kk , MRI_float , NULL ) ;
-   }
-
-   if( prefix2 != NULL && strcmp(prefix2,"NULL") != 0 ){   /* 27 Apr 2016 */
-     outset2 = EDIT_empty_copy(inset) ;
-     EDIT_dset_items( outset2, ADN_prefix,prefix2, ADN_brick_fac,NULL, ADN_none );
-     tross_Copy_History( inset , outset2 ) ;
-     tross_Make_History( "3dLocalPV" , argc,argv , outset2 ) ;
-     for( kk=0 ; kk < nt ; kk++ )                         /* create bricks */
-       EDIT_substitute_brick( outset2 , kk , MRI_float , NULL ) ;
-   }
+   outset = EDIT_empty_copy(inset) ;
+   EDIT_dset_items( outset, ADN_prefix,prefix, ADN_brick_fac,NULL, ADN_none );
+   tross_Copy_History( inset , outset ) ;
+   tross_Make_History( "3dLocalPV" , argc,argv , outset ) ;
+   for( kk=0 ; kk < nt ; kk++ )                         /* create bricks */
+     EDIT_substitute_brick( outset , kk , MRI_float , NULL ) ;
 
    if( evprefix != NULL ){
      evset = EDIT_empty_copy(inset) ;
@@ -403,7 +370,7 @@ int main( int argc , char *argv[] )
  { int kk , xx,yy,zz , vv,ii , mm ;
    float *zar=NULL , *nbar ; int *ivar ;
    float *tsar , *uvec , *vvec=NULL , *ws=NULL ;
-   unsigned short xran[3] ; int ithr=0 ; float sval,tval=0.0 ;
+   unsigned short xran[3] ; int ithr=0 ; float sval,tval ;
 
 #ifdef USE_OMP
   ithr = omp_get_thread_num() ;
@@ -416,7 +383,7 @@ int main( int argc , char *argv[] )
      ws   = pv_get_workspace(nt,nbhd->num_pt) ;
      nbar = (float *)malloc(sizeof(float)*nt*nbhd->num_pt) ;
      ivar = (int *)malloc(sizeof(int)*nbhd->num_pt) ;
-     if( do_vproj == 2 || outset2 != NULL )
+     if( do_vproj == 2 )
        vvec = (float *)malloc(sizeof(float)*nt) ;
      if( do_vproj )
        zar = (float *)malloc(sizeof(float)*nt) ;
@@ -428,12 +395,9 @@ int main( int argc , char *argv[] )
 
 #pragma omp for
    for( kk=0 ; kk < nxyz ; kk++ ){
-
-#if 0
-#pragma omp critical
-     { if( vstep && kk%vstep==vstep-1 ) vstep_print() ; }
+#ifndef USE_OMP
+     if( vstep && kk%vstep==vstep-1 ) vstep_print() ;
 #endif
-
      if( !INMASK(kk) ) continue ;
      IJK_TO_THREE( kk , xx,yy,zz , nx,nxy ) ;
 
@@ -453,7 +417,7 @@ int main( int argc , char *argv[] )
        }
      }
      tsar = nbar ;
-     if( do_vproj <= 1 && outset2 == NULL ){
+     if( do_vproj <= 1 ){
        sval = principal_vector( nt, mm, 0,nbar, uvec, (do_vproj) ? NULL : tsar, ws,xran ) ;
      } else {
        float_pair spair ;
@@ -476,10 +440,7 @@ int main( int argc , char *argv[] )
          for( ii=0 ; ii < nt ; ii++ ) uvec[ii] += sum*vvec[ii] ;
        }
      }
-     if( outset != NULL )
-       THD_insert_series( kk, outset , nt, MRI_float, uvec, 0 ) ;
-     if( outset2 != NULL )
-       THD_insert_series( kk, outset2, nt, MRI_float, vvec, 0 ) ;
+     THD_insert_series( kk, outset, nt, MRI_float, uvec, 0 ) ;
      if( evar != NULL ) evar[kk] = sval ;
      if( fvar != NULL ) fvar[kk] = tval ;
    }
@@ -500,13 +461,7 @@ int main( int argc , char *argv[] )
    /*** cleanup and exit ***/
 
    DSET_delete(inset) ;
-
-   if( outset != NULL ){
-     DSET_write(outset) ; WROTE_DSET(outset) ; DSET_delete(outset) ;
-   }
-   if( outset2 != NULL ){
-     DSET_write(outset2) ; WROTE_DSET(outset2) ; DSET_delete(outset2) ;
-   }
+   DSET_write(outset) ; WROTE_DSET(outset) ; DSET_delete(outset) ;
 
    if( evset != NULL ){
      DSET_write(evset) ; WROTE_DSET(evset) ; DSET_delete(evset) ;
