@@ -31,7 +31,7 @@
   Mod:     Restructured matrix calculations to improve execution speed.
   Date:    16 December 1998
 
-  Mod:     Add use of the argument list extension routine addto_args
+  Mod:     Add use of the argument list extenstion routine addto_args
            to allow the last switch '-@' to get further command line
            arguments from stdin
   Date:    22 February 1999 -- RWCox
@@ -69,11 +69,7 @@
 
 /*---------------------------------------------------------------------------*/
 
-#if 0
 #define SUFFIX ".3dregana"                     /* suffix for temporary files */
-#else
-char SUFFIX[1024] = ".3dregana." ;
-#endif
 
 #include <stdio.h>
 #include <math.h>
@@ -400,7 +396,7 @@ void check_piece
 {
   FILE * far = NULL;                 /* pointer to temporary file */
   char sfilename[MAX_NAME_LENGTH];   /* name of temporary file */
-  char message[MAX_NAME_LENGTH+128]; /* error message: fname+message */
+  char message[MAX_NAME_LENGTH];     /* error message */
   
   
   /*-----  see if piece file already exists -----*/
@@ -430,7 +426,7 @@ void read_piece
 
 {
   char sfilename[MAX_NAME_LENGTH];   /* piece file name */
-  char message[MAX_NAME_LENGTH+128]; /* error message: fname + message */
+  char message[MAX_NAME_LENGTH];     /* error message */
   FILE * far = NULL;                 /* floating point input file */
   int count;                         /* number of data items read from disk */
   
@@ -475,7 +471,7 @@ void write_piece
 
 {
   char sfilename[MAX_NAME_LENGTH];   /* piece file name */ 
-  char message[MAX_NAME_LENGTH+128]; /* error message */
+  char message[MAX_NAME_LENGTH];     /* error message */
   FILE * far = NULL;                 /* floating point output file */
   int count;                         /* number of data items written to disk */
 
@@ -1096,8 +1092,8 @@ void get_inputs
   int nopt = 1;                    /* input option argument counter */
   int ival, index;                 /* integer input */
   float fval;                      /* float input */
-  int rows=0, cols=0;                  /* number rows and columns for x matrix */
-  int irows=0, jcols;                /* data point counters */ 
+  int rows, cols;                  /* number rows and columns for x matrix */
+  int irows, jcols;                /* data point counters */ 
   THD_3dim_dataset * dset=NULL;    /* test whether data set exists */
   char message[MAX_NAME_LENGTH];   /* error message */
   char label[MAX_NAME_LENGTH];     /* sub-brick label */
@@ -2542,8 +2538,8 @@ void write_afni_data
   int output_datum;                   /* data type for output data */
   short * tsp = NULL;                 /* 2nd sub-brick data pointer */
   void  * vdif = NULL;                /* 1st sub-brick data pointer */
-  float top, bot, func_scale_short=0.0;   /* parameters for scaling data */
-  int top_ss, bot_ss=0;                 /* 2nd sub-brick value limits */
+  float top, bot, func_scale_short;   /* parameters for scaling data */
+  int top_ss, bot_ss;                 /* 2nd sub-brick value limits */
   char label[80];                     /* label for output file history */ 
   
   
@@ -2636,7 +2632,7 @@ void write_afni_data
       bot_ss =  0;
     }
   else
-    RA_error ("Illegal output dataset function type");
+    RA_error ("Illegal ouput dataset function type");
   
   top = top_ss / func_scale_short;
   bot = bot_ss / func_scale_short;
@@ -3213,8 +3209,6 @@ int main
   printf ("\n");
 #endif
 
-   UNIQ_idcode_fill(SUFFIX+strlen(SUFFIX)) ;  /* 27 Apr 2012 */
-
   /*-- 22 Feb 1999: addto the arglist, if user wants to --*/
 
    PRINT_VERSION("3dRegAna") ; AUTHOR(PROGRAM_AUTHOR);
