@@ -64,6 +64,8 @@ typedef struct {
    
 } RP_UD;
 
+#define ABS(a) ( (a) < 0 ? (-a):(a) )
+#define SIGN(a) ( (a) < 0 ? -1:1 )
 #define PHASE_R2D(a) ( (a)*180.0/PI )
 #define PHASE_360(a) ( (a) < 0.0 ? 360.0+(a):(a) )
 int Phase_Type_to_Dir(int p) {
@@ -190,18 +192,18 @@ char * Phase_Dirs_ulbl(int p) {
    return(ps);
 }
 
-int Dir_is_eccentricity(int d) {
+int Dir_is_eccentricity(d) {
    if (d == CONT || d == EXP) return(1);
    return(0);
 }
 
-int Dir_is_polar(int d) {
+int Dir_is_polar(d) {
    if (d == CLW || d == CCW) return(1);
    return(0);
 }
 
 
-int Dir2Type(int p) {
+int Dir2Type(p) {
    switch (p){
       case CONT:
       case EXP:
@@ -217,7 +219,7 @@ int Dir2Type(int p) {
    }  
 }
 
-void Show_RP_UD(RP_UD *u, char *str) {
+Show_RP_UD(RP_UD *u, char *str) {
    if (str) {
       fprintf(stderr,"%s", str);
    }
@@ -260,19 +262,13 @@ void Show_RP_UD(RP_UD *u, char *str) {
                   u->Dsamp, u->rvec, u->rvec_len, u->rvec_num, u->iref);
 }
 
-int SetFreqBin(float fresp, float fstep, int stk[], float stw[], int nfft) {
+SetFreqBin(float fresp, float fstep, int stk[], float stw[]) {
    float stf = fresp/fstep;   /* stimulus freq. index */
    
    stk[0] = (int)floor(stf);    /* floor of freq. index */
       stw[0] = (1.0 - stf          + stk[0]);  /*floor weight*/
    stk[1] = (int)ceil (stf);    /* ceil of freq. index */
       stw[1] = (1.0 - stk[1] + stf  );        /*ceil weight*/
-   if (stk[0] > nfft/2 || stk[1] > nfft/2) {
-      ERROR_message("Frequency indices %d and/or %d outside max of %d\n", 
-                    stk[0], stk[1], nfft/2);
-      return(0);
-   }
-   return(1);
 }
 
 
@@ -345,7 +341,7 @@ THD_3dim_dataset * Combine_Opposites(THD_3dim_dataset *dset1,
                  
    EDIT_substitute_brick( oset , 0 , MRI_float  , sum ) ; /* do not free sum */
    EDIT_substitute_brick( oset , 1 , MRI_float  , dif ) ; /* do not free dif */
-   EDIT_substitute_brick( oset , 2 , MRI_float  , mxxc ) ;/* do not free mxxc */
+   EDIT_substitute_brick( oset , 2 , MRI_float  , mxxc ) ;/* do not free dif */
    if (Dir_is_eccentricity(rpud->dir)) {
       EDIT_BRICK_LABEL(oset , 0, "Eccentricity");
    } else if (Dir_is_polar(rpud->dir)) {
@@ -445,36 +441,14 @@ static void RP_tsfunc( double tzero, double tdelta ,
          stimharm   = (int *)     calloc( sizeof(int)     , rpud->nfft);
 
          /* signal bin */
-         if (!SetFreqBin(rpud->Fresp[st], 
-                    rpud->fstep, rpud->stk, rpud->stw,
-                    rpud->nfft)) {
-            ERROR_message("Failed to set bins. Fresp=%f, "
-                          "fstep=%f, stk=[%d,%d], stw=[%f,%f], nfft=%d\n"
-                          "Is your dataset's TR of %f sec valid?", 
-                          rpud->Fresp[st], rpud->fstep, 
-                          rpud->stk[0], rpud->stk[1], 
-                          rpud->stw[0], rpud->stw[1],rpud->nfft,
-                          rpud->dt);
-            return;          
-         }
+         SetFreqBin(rpud->Fresp[st], 
+                     rpud->fstep, rpud->stk, rpud->stw);
          {
             int nharm = 1, stk[2];
             float fharm=0.0, stw[2];
-            while (( (fharm = nharm*rpud->Fresp[st]) - 
-                     rpud->nfft/2.0*rpud->fstep ) < -0.00001) {
-                        /* Difference was added to get around round off errors
-                        which might get you a frequency at the precipice as 
-                        in the bug reported by Phil Burton     Nov. 2014 */ 
-               if (!SetFreqBin(fharm, rpud->fstep, stk, stw, rpud->nfft)) {
-                  ERROR_message("Failed to set bins. Fresp=%f, fdiff=%f "
-                          "fstep=%f, stk=[%d,%d], stw=[%f,%f], nfft=%d\n"
-                          "Is your dataset's TR of %f sec valid?", 
-                          rpud->Fresp[st], fharm-rpud->nfft/2.0*rpud->fstep,
-                          rpud->fstep, 
-                          rpud->stk[0], rpud->stk[1], 
-                          rpud->stw[0], rpud->stw[1],rpud->nfft,rpud->dt);
-                  break;   
-               }
+            while ((fharm = nharm*rpud->Fresp[st]) < 
+                     rpud->nfft/2.0*rpud->fstep ) {
+               SetFreqBin(fharm, rpud->fstep, stk, stw);
                stimharm[stk[0]] = nharm;
                stimharm[stk[1]] = nharm; 
                if (rpud->verb > 2) 
@@ -617,7 +591,7 @@ static void RP_tsfunc( double tzero, double tdelta ,
    } else {
       val[0] =  phz[rpud->stk[1]];
    }
-   /* linear interpolation between closest frequencies for amplitude */
+   /* linear interpolation between closest frequecies for amplitude */
    val[1] = (  mag[rpud->stk[0]]*rpud->stw[0] + 
                mag[rpud->stk[1]]*rpud->stw[1] );
    val[1] *= val[1]; /* square for power*/
@@ -653,7 +627,7 @@ static void DEL_tsfunc( double tzero, double tdelta ,
                  "rpud %p, ud %p\n", rpud, ud);
    }
    
-   /* Now initialize */
+   /* Now intialize */
    if( val == NULL ){
       if (rpud->verb > 1) {
          INFO_message("First call npts=%d\n", npts);
@@ -813,8 +787,7 @@ byte *MaskSetup(THD_3dim_dataset *old_dset, THD_3dim_dataset *mask_dset,
          ERROR_message("No voxels in the mask!\n") ;
          return(NULL);
       }
-      if( rpud->verb ) INFO_message("%d voxels in the mask dset %s\n",
-                                 *mcount, DSET_PREFIX(mask_dset)) ;
+      if( rpud->verb ) INFO_message("%d voxels in the mask\n",mcount) ;
       DSET_delete(mask_dset) ;
    }
 
@@ -980,7 +953,7 @@ int main( int argc , char * argv[] )
 "        with the polar stimuli having two wedges. After creating \n"
 "        the reference time series with waver (32 sec. block period \n"
 "        eccentricity, 32/2=16 sec. block period for polar), run \n" 
-"        4 3ddelay commands as such:\n"
+"        4 3ddelay command as such:\n"
 "                      for an expanding ring of 32 second period:\n"
 "           3ddelay  -input exp.niml.dset \\\n"
 "                    -ideal_file ECC.1D   \\\n"
@@ -989,7 +962,7 @@ int main( int argc , char * argv[] )
 "                    -phzreverse -phzscale 1.0 \\\n"
 "                    -prefix ecc+.del.niml.dset\\n"
 "\n"
-"              Repeat for contracting ring, remove -phzreverse \n"
+"                       for contracting ring, remove -phzreverse \n"
 "\n"
 "                       for clockwise two wedge of 32 second period:\n"
 "           3ddelay  -input clw.niml.dset \\\n"
@@ -999,16 +972,12 @@ int main( int argc , char * argv[] )
 "                    -phzreverse -phzscale 0.5 \\\n"
 "                    -prefix pol+.del.niml.dset\\n"
 "\n"
-"              Repeat for counterclockwise remove -phzreverse \n"
+"                       for counterclockwise remove -phzreverse \n"
 "     Instead of the 3ddelay mess, all you do is run 3dRetinoPhase with the \n"
 "        following extra options: "
 "              -phase_estimate DELAY -ref_ts ECC.1D\n"
 "        or    -phase_estimate DELAY -ref_ts POL.1D\n"  
 "\n"
-"     If you are not familiar with the use of program 'waver' for creating\n"
-"     reference time series, take a look at demo script @Proc.PK.All_D in\n"
-"     AfniRetinoDemo.tgz.\n"
-"\n"
 " -multi_ref_ts MULTI_REF_TS: Multiple 0 lag reference time series. \n"
 "                             This allows you to test multiple regressors.\n"
 "                             The program will run a separate analysis for \n"
@@ -1031,10 +1000,10 @@ int main( int argc , char * argv[] )
 "       an output identical to that of -ref_ts. \n"
 "\n"        
 "  See usage in @RetinoProc and demo data in\n"
-"  https://afni.nimh.nih.gov/pub/dist/tgz/AfniRetinoDemo.tgz \n"
+"  http://afni.nimh.nih.gov/pub/dist/tgz/AfniRetinoDemo.tgz \n"
 "\n"
 "References for this program:\n"
-"   [1] RW Cox.  AFNI: Software for analysis and visualization of functional\n"
+"   [1] RW Cox.  AFNI: Software for analysis and visualization of functional"
 "                      magnetic resonance neuroimages.  \n"
 "                      Computers and Biomedical Research, 29: 162-173, 1996.\n"
 "   [2] Saad Z.S., et al.  SUMA: An Interface For Surface-Based Intra- And\n" 
@@ -1066,7 +1035,7 @@ Bring them back after testing. */
 #endif
 
    /*-- options --*/
-   set_obliquity_report(0); /* silence obliquity */
+
 
    while( iarg < argc && argv[iarg][0] == '-' ){
 
@@ -1410,30 +1379,9 @@ Bring them back after testing. */
 
          if (!nset) {
             rpud.nvals = DSET_NUM_TIMES(old_dset);
-            if (rpud.nvals < 10) {
-               ERROR_exit( "Dataset has too few (%d) time points.\n", 
-                           rpud.nvals);
-            }
-            rpud.dt = DSET_TR_SEC(old_dset);
-            if (rpud.dt > 100) {
-               ERROR_exit("TR of %f sec of %s is very suspiciously high.\n"
-                       "Program assumes this is a mistake in the header.\n"
-                       "You can use 3drefit's -TR option to fix the problem.\n",
-                       rpud.dt, in_name[stype]);
-            }
+            rpud.dt = old_dset->taxis->ttdel;
             mmm = MaskSetup(old_dset, mask_dset, &rpud, cmask, 
                            &ncmask, mask_bot, mask_top, &mcount);
-         } else {
-            if (DSET_NUM_TIMES(old_dset) != rpud.nvals) {
-               ERROR_exit( "Dataset %s has %d time points while %s has %d\n",
-                           in_name[stype], DSET_NUM_TIMES(old_dset),
-                           DSET_PREFIX(rpud.iset), rpud.nvals); 
-            }
-            if (DSET_TR_SEC(old_dset) !=  rpud.dt) {
-               ERROR_exit( "Dataset %s has a TR of %f sec while %s has %f sec\n",
-                           in_name[stype], DSET_TR_SEC(old_dset),
-                           DSET_PREFIX(rpud.iset), rpud.dt); 
-            }
          }
          rpud.iset = old_dset;
          rpud.dir = Phase_Type_to_Dir(stype);
@@ -1474,8 +1422,7 @@ Bring them back after testing. */
                           2 ,                   /* number of briks */
                           RP_tsfunc,          /* timeseries processor */
                           (void *)(&rpud),    /* data for tsfunc */
-                          mmm,
-                          0   /* Allow auto scaling of output */
+                          mmm
                        ) ;
             
             if( new_dset[stype] != NULL ){
@@ -1498,8 +1445,7 @@ Bring them back after testing. */
                              2 ,                   /* number of briks */
                              DEL_tsfunc,          /* timeseries processor */
                              (void *)(&rpud),    /* data for tsfunc */
-                             mmm,
-                             0   /* Allow auto scaling of output */
+                             mmm
                           ))) {
                   ERROR_exit("Unable to compute %d output dataset!\n", 
                               rpud.iref) ;        
