@@ -4,6 +4,7 @@
 #include "afni.h"
 #include <stdio.h>
 #include <stdlib.h>
+#include "thd_atlas.h"
 
 #define SEG_UNKNOWN  0
 #define SEG_CSF      1
@@ -130,7 +131,7 @@ SEG_OPTS *Segment_ParseInput (char *argv[], int argc)
                            much. The most critical remains a good
                            initialization with the startup masks*/ 
    brk = 0;
-	while (kar < argc) { /* loop across command line options */
+	while (kar < argc) { /* loop accross command ine options */
 		/*fprintf(stdout, "%s verbose: Parsing command line...\n", FuncName);*/
 		if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
 			 Segment_usage();
@@ -356,18 +357,7 @@ int mri_nstat_3dSeg( MRI_IMAGE *im, int *code_vec, int N_code, float *val_vec )
           outval /= npt ;
         }
         break ;
-        case NSTAT_NZNUM:{
-          register int ii ;
-          for( ii=0 ; ii < npt ; ii++ ) if (far[ii] != 0.0f) outval += 1 ;
-        }
-        break ;
-        case NSTAT_FNZNUM:{
-          register int ii ;
-          for( ii=0 ; ii < npt ; ii++ ) if (far[ii] != 0.0f) outval += 1 ;
-          outval /= npt;
-        }
-        break ;
-        
+
         case NSTAT_SIGMA:   /* these 3 need the mean and variance sums */
         case NSTAT_CVAR:
         case NSTAT_VAR:{
