@@ -1,64 +1,11 @@
 #include "mrilib.h"
 
-#undef  PREP_SPEARMAN
-#undef  PREP_DEMEAN
-#undef  PREP_QUANTILE
-
-#define PREP_SPEARMAN  1
-#define PREP_DEMEAN    2
-#define PREP_QUANTILE  3
-
-static int num_quantile = 9 ;
-
-/*--------------------------------------------------------------------------*/
-/* These PREP function process the data in-place. */
-
-void PREP_demean( int n , float *ar )
-{
-   int ii ; float bb ;
-   for( bb=0.0f,ii=0 ; ii < n ; ii++ ) bb += ar[ii] ;
-   bb /= n ;
-   for( ii=0 ; ii < n ; ii++ ) ar[ii] -= bb ;
-   return ;
-}
-
-/*--------------------------------------------------------------------------*/
-
-void PREP_spearman( int n , float *ar )
-{
-   int ii ; float rb ;
-   rank_order_float(n,ar) ;     /*  ranks are 0..n-1 (cf. thd_correlate.c) */
-   rb = 0.5f*(n-1) ;                                          /* mean rank */
-   for( ii=0 ; ii < n ; ii++ ) ar[ii] -= rb ;          /* remove mean rank */
-   return ;
-}
-
-/*--------------------------------------------------------------------------*/
-
-void PREP_quantile( int n , float *a )
-{
-   int ii ; float rb , jf ;
-
-   jf = 0.001f + 1.00001f * (n-0.5f) / (float)num_quantile ;
-   if( jf <= 2.0f ){ PREP_spearman(n,a) ; return ; }
-   jf = 1.0f / jf ;
-
-   rank_order_float(n,a) ;        /* convert to ranks */
-
-   for( rb=0.0f,ii=0 ; ii < n ; ii++ ){
-     a[ii] = (int)( (a[ii]+0.333f)*jf ) ; rb += a[ii] ;
-   }
-   rb /= n ;
-   for( ii=0 ; ii < n ; ii++ ) a[ii] -= rb ;
-   return ;
-}
-
 /*--------------------------------------------------------------------------*/
 
 char * get_surf_param(char *sname, char *parname)
 {
    char com[1024]={""};
-   static char buf[1024]={""};
+   char buf[1024]={""};
    char *out=NULL;
 
    FILE *output = NULL;
@@ -69,7 +16,7 @@ char * get_surf_param(char *sname, char *parname)
       return(out);
    }
 
-   out = afni_fgets(buf, sizeof(buf), output);
+   out = fgets(buf, sizeof(buf), output);
    pclose(output);
 
    if (0) {
@@ -82,21 +29,38 @@ char * get_surf_param(char *sname, char *parname)
 }
 
 /*--------------------------------------------------------------------------*/
-void usage_3dSetupGroupInCorr(int detail)
+
+int main( int argc , char * argv[] )
 {
-        printf(
+   THD_3dim_dataset **inset ; int ndset,ids ;
+   char *prefix      = "Group"           ;
+   char *suffix_head = ".grpincorr.niml" ;
+   char *suffix_data = ".grpincorr.data" ;
+   char *hfname , *dfname ;
+   char atrib[2048] , *buf , *gstr ;
+   byte *mask=NULL ;
+   int mask_nx=0,mask_ny=0,mask_nz=0,nmask=0 , nx=0,ny=0,nz=0,nvox=0 ;
+   NI_element *nel ;
+   int nvec , *nvals , *ivec=NULL , iv,kk,nvv , nopt , do_delete=0 ;
+   float *fac , *fv , val,top ;
+   NI_float_array *facar ; NI_int_array *nvar ;
+   short *sv=NULL; sbyte *bv=NULL ; MRI_vectim *mv ; FILE *fp ; long long fsize ;
+   int atim,btim,ctim ;
+   int LRpairs = 0, Ns[2]={-1,-1}, Nv[2]={-1,-1}, Nm[2]={0, 0};
+   int do_byte = 1 ;
+   char **dset_labels=NULL ; int ndset_labels=0 ;  /* 14 May 2010 */
+   char  *dset_labels_all  ; int len_all=0 ;
+   char *cmdline ;                                 /* 26 May 2010 */
+
+   /*-- help? --*/
+
+   if( argc < 2 || strcmp(argv[1],"-help") == 0 ){
+     printf(
  "Usage: 3dSetupGroupInCorr [options] dataset dataset ...\n"
  "\n"
  "This program is used to pre-process a collection of AFNI\n"
  "3D+time datasets for use with Group InstaCorr (3dGroupInCorr).\n"
  "\n"
- "* By itself, this program just collects all its input datasets\n"
- "  together for convenient processing later.  Pre-processing\n"
- "  (e.g., detrending, bandpassing, despiking) must be done BEFORE\n"
- "  running 3dSetupGroupInCorr -- for example, with 3dBandpass.\n"
- "  The actual calculations of group t-tests of correlations is\n"
- "  done AFTER running 3dSetupGroupInCorr, in program 3dGroupInCorr.\n"
- "\n"
  "* All the datasets input here will be treated as one sample\n"
  "  for the t-test performed in 3dGroupInCorr.  If you are going\n"
  "  to do a 2-sample t-test, then you will need to run this\n"
@@ -123,15 +87,13 @@ void usage_3dSetupGroupInCorr(int detail)
  "  of time points or time spacing.  But each dataset must have\n"
  "  at least 9 points along the time axis!\n"
  "\n"
- "* The ONLY pre-processing herein for each time series is to L2\n"
+ "* The only pre-processing herein for each time series is to L2\n"
  "  normalize it (sum of squares = 1) and scale it to 8-bit bytes\n"
  "  (or to 16-bit shorts).\n"
  "  ++ You almost certainly want to use 3dBandpass and/or some other\n"
  "     code to pre-process the datasets BEFORE input to this program.\n"
  "  ++ See the SAMPLE SCRIPT below for a semi-reasonable way to\n"
  "     pre-process a collection of datasets for 3dGroupInCorr.\n"
- "  ++ [10 May 2012] The '-prep' option now allows for some limited\n"
- "     pre-processing operations.\n"
  "\n"
  "* The outputs from this program are 2 files:\n"
  "  ++ PREFIX.grpincorr.niml is a text file containing the header\n"
@@ -146,13 +108,10 @@ void usage_3dSetupGroupInCorr(int detail)
  "\n"
  "* See the help for 3dGroupInCorr for information on running that program.\n"
  "* The PDF file\n"
- "  https://afni.nimh.nih.gov/pub/dist/edu/latest/afni_handouts/afni20_instastuff.pdf\n"
+ "  http://afni.nimh.nih.gov/pub/dist/edu/latest/afni_handouts/instastuff.pdf\n"
  "  also has some information on the Group InstaCorr process (as well as all\n"
  "  the other 'Insta' functions added to AFNI).\n"
  "\n"
- "* The program 3dExtractGroupInCorr can be used to reconstruct the\n"
- "  input datasets from the .niml and .data files, if needed.\n"
- "\n"
  "-------\n"
  "OPTIONS\n"
  "-------\n"
@@ -188,11 +147,6 @@ void usage_3dSetupGroupInCorr(int detail)
  "                 ++ If you don't use this option, then the list of labels will\n"
  "                    comprise the list of prefixes from the input datasets.\n"
  "                 ++ Labels cannot contain a space character, a comma, or a semicolon.\n"
- "                 ++ When using the -LRpairs option, you should specify only\n"
- "                    one label for eah pair. \n"
- "                    If you don't use the -labels option with -LRpairs the \n"
- "                    labels are taken from the 'L' only dataset names, that\n"
- "                    would be the first name of each LRpair.\n"
  "\n"
  "  -DELETE        = Delete input datasets from disk after\n"
  "                   processing them one at a time into the\n"
@@ -208,14 +162,6 @@ void usage_3dSetupGroupInCorr(int detail)
  "                    temporary 3dBandpass outputs as soon\n"
  "                    as they are no longer needed.\n"
  "\n"
- "  -prep XXX      = Prepare (or preprocess) each data time series in some\n"
- "                   fashion before L2 normalization and storing, where\n"
- "                   'XXX' is one of these:\n"
- "                 ++ SPEARMAN ==> convert data to ranks, so that the\n"
- "                                 resulting individual subject correlations\n"
- "                                 in 3dGroupInCorr are Spearman correlations.\n"
- "                 ++ DEMEAN   ==> remove the mean\n"
- "\n"
 "    Variations for surface-based data:\n"
 "    ----------------------------------\n"
 "    If you are working with one surface, no special options are needed.\n"
@@ -263,16 +209,15 @@ void usage_3dSetupGroupInCorr(int detail)
  "/bin/rm -f *_amask+tlrc.*\n"
  "\n"
  "# Bandpass and blur each dataset inside the group mask\n"
- "#  * Skip first 4 time points.\n"
- "#  * If you want to remove the global mean signal, you would use the '-ort'\n"
- "#    option for 3dBandpass -- but we recommend that you do NOT do this:\n"
- "#    http://dx.doi.org/10.1089/brain.2012.0080\n"
+ "# (skip first 4 time points, and also remove global signal)\n"
  "\n"
  "foreach fred ( sub*_rest+tlrc.HEAD )\n"
  "  set sub = `basename $fred _rest+tlrc.HEAD`\n"
+ "  3dmaskave -mask ALL_amask5050+tlrc -quiet $fred'[4..$]' > ${sub}_GS.1D\n"
  "  3dBandpass -mask ALL_amask5050+tlrc -blur 6.0 -band 0.01 0.10 -prefix ${sub}_BP\\\n"
- "             -input $fred'[4..$]'\n"
+ "             -input $fred'[4..$]' -ort ${sub}_GS.1D\n"
  "end\n"
+ "/bin/rm -f *_GS.1D\n"
  "\n"
  "# Extract data for 3dGroupInCorr\n"
  "\n"
@@ -297,84 +242,16 @@ void usage_3dSetupGroupInCorr(int detail)
  "* With encouragement from MMK.\n"
  "\n"
      ) ;
-     PRINT_COMPILE_DATE ;
-   return;
-}
-
-/*--------------------------------------------------------------------------*/
-
-int main( int argc , char * argv[] )
-{
-   THD_3dim_dataset **inset ; int ndset,ids ;
-   char *prefix      = "Group"           ;
-   char *suffix_head = ".grpincorr.niml" ;
-   char *suffix_data = ".grpincorr.data" ;
-   char *hfname , *dfname ;
-   char atrib[2048] , *buf , *gstr ;
-   byte *mask=NULL ;
-   int mask_nx=0,mask_ny=0,mask_nz=0,nmask=0 , nx=0,ny=0,nz=0,nvox=0 ;
-   NI_element *nel ;
-   int nvec , *nvals , *ivec=NULL , iv,kk , nopt , do_delete=0 ;
-   int64_t nvv , kvv ;         /* 27 Aug 2013 */
-   float *fac , *fv , val,top ;
-   NI_float_array *facar ; NI_int_array *nvar ;
-   short *sv=NULL; sbyte *bv=NULL ; MRI_vectim *mv ; FILE *fp ; long long fsize ;
-   int atim,btim,ctim ;
-   int LRpairs = 0, Ns[2]={-1,-1}, Nv[2]={-1,-1}, Nm[2]={0, 0};
-   int do_byte = 1 ;
-   char **dset_labels=NULL ; int ndset_labels=0 ;  /* 14 May 2010 */
-   char  *dset_labels_all  ; int len_all=0 ;
-   char *cmdline ;                                 /* 26 May 2010 */
-   int   prepcode=0 ;                              /* 10 May 2012 */
-   void *prepfunc=NULL ;
-   char prepname[128] = "normalize" ;
-
-   /*--- official AFNI startup stuff ---*/
+     PRINT_COMPILE_DATE ; exit(0) ;
+   }
 
    mainENTRY("3dSetupGroupInCorr"); machdep();
    AFNI_logger("3dSetupGroupInCorr",argc,argv);
    PRINT_VERSION("3dSetupGroupInCorr"); AUTHOR("RW Cox");
-   THD_check_AFNI_version("3dSetupGroupInCorr") ;
 
    nopt = 1 ;
    while( nopt < argc && argv[nopt][0] == '-' ){
 
-      if( strcmp(argv[nopt],"-help") == 0 ||
-          strcmp(argv[nopt],"-h") == 0 ){
-         usage_3dSetupGroupInCorr(strlen(argv[nopt]) > 3 ? 2:1);
-         exit(0) ;
-      }
-
-     if( strcasecmp(argv[nopt],"-prep") == 0 ){   /* 10 May 2012 */
-       if( ++nopt >= argc ) ERROR_exit("need an argument after %s",argv[nopt-1]) ;
-       if( strcasecmp(argv[nopt],"SPEARMAN") == 0 ){
-         prepcode = PREP_SPEARMAN ;
-         prepfunc = (void *)PREP_spearman ;
-         strcpy(prepname,"SPEARMAN/normalize") ;
-       } else if( strcasecmp(argv[nopt],"DEMEAN") == 0 ){
-         prepcode = PREP_DEMEAN ;
-         prepfunc = (void *)PREP_demean ;
-         strcpy(prepname,"DEMEAN/normalize") ;
-       } else if( strncasecmp(argv[nopt],"QUANTILE",8) == 0 ){
-         char *cpt ;
-                           cpt = strchr(argv[nopt],':') ;
-         if( cpt == NULL ) cpt = strchr(argv[nopt],'#') ;
-         if( cpt == NULL ) cpt = strchr(argv[nopt],'@') ;
-         if( cpt == NULL ) cpt = strchr(argv[nopt],'_') ;
-         if( cpt == NULL ) cpt = argv[nopt]+8 ;
-         if( isdigit(*(cpt+1)) ){
-           kk = (int)strtod(cpt+1,NULL) ;
-           if( kk > 1 && kk < 100 ) num_quantile = kk ;
-         }
-         prepcode = PREP_QUANTILE ;
-         prepfunc = (void *)PREP_quantile ;
-         sprintf(prepname,"QUANTILE:%d/normalize",num_quantile) ;
-       } else {
-         ERROR_exit("Illegal string '%s' after option %s",argv[nopt],argv[nopt-1]) ;
-       }
-       nopt++ ; continue ;
-     }
-
      if( strncmp(argv[nopt],"-labels",6) == 0 ){  /* 14 May 2010 */
        char *sf ; NI_str_array *sar ;
        if( ndset_labels > 0 ) ERROR_exit("Can't use -labels TWICE!") ;
@@ -382,7 +259,6 @@ int main( int argc , char * argv[] )
        sf = AFNI_suck_file( argv[nopt] ) ;
        if( sf == NULL || *sf == '\0' )
          ERROR_exit("Can't read file '%s' after -labels!",argv[nopt]) ;
-       len_all = strlen(sf);
        sar = NI_decode_string_list(sf,",;") ;
        if( sar == NULL || sar->num <= 0 )
          ERROR_exit("Can't get label list from file '%s'",argv[nopt]) ;
@@ -450,17 +326,7 @@ int main( int argc , char * argv[] )
 
        nopt++ ; continue ;
      }
-     ERROR_message("Unknown option: '%s'",argv[nopt]) ;
-     suggest_best_prog_option(argv[0], argv[nopt]);
-     exit(1);
-   }
-
-   /*-- help? --*/
-
-   if( argc < 2){
-      ERROR_message("Too few options");
-      usage_3dSetupGroupInCorr(0);
-      exit(1) ;
+     ERROR_exit("Unknown option: '%s'",argv[nopt]) ;
    }
 
    if (LRpairs && mask) {
@@ -493,28 +359,13 @@ int main( int argc , char * argv[] )
                 "number of datasets on the command line!") ;
    }
 
-   if (!LRpairs) {
-      if( ndset_labels > 0 && ndset_labels != ndset ){  /* 14 May 2010 */
-        if( ndset_labels < ndset )
-          ERROR_exit("Not enough labels for %d datasets on command line!",
-                     ndset) ;
-        else
-          WARNING_message("Too many labels for %d datasets on command line!",
-                          ndset) ;
-      } else if( ndset_labels == 0 ){
-         dset_labels = (char **)malloc(sizeof(char *)*ndset) ;
-      }
-   } else {
-      if( ndset_labels > 0 && ndset_labels != ndset/2 ){  /* 14 May 2010 */
-        if( ndset_labels < ndset/2 )
-          ERROR_exit("Not enough labels for %d LR pairs on command line!",
-                     ndset/2) ;
-        else
-          WARNING_message("Too many labels for %d LR pairs on command line!",
-                          ndset/2) ;
-      } else if( ndset_labels == 0 ){
-         dset_labels = (char **)malloc(sizeof(char *)*ndset/2) ;
-      }
+   if( ndset_labels > 0 && ndset_labels != ndset ){  /* 14 May 2010 */
+     if( ndset_labels < ndset )
+       ERROR_exit("Not enough labels for %d datasets on command line!",ndset) ;
+     else
+       WARNING_message("Too many labels for %d datasets on command line!",ndset) ;
+   } else if( ndset_labels == 0 ){
+      dset_labels = (char **)malloc(sizeof(char *)*ndset) ;
    }
 
    inset = (THD_3dim_dataset **)malloc(sizeof(THD_3dim_dataset *)*ndset) ;
@@ -526,17 +377,9 @@ int main( int argc , char * argv[] )
      inset[ids] = THD_open_dataset(argv[nopt+ids]) ;    /* read header */
      CHECK_OPEN_ERROR(inset[ids],argv[nopt+ids]) ;      /* fail ==> bail */
      nvals[ids] = DSET_NVALS(inset[ids]) ;              /* save # time points */
-     if( ndset_labels == 0 ) {
-       if (!LRpairs) {
-         dset_labels[ids] = strdup(DSET_PREFIX(inset[ids])) ;  /* 14 May 2010 */
-         len_all += strlen( dset_labels[ids] ) ;
-       } else {
-         if (ids%2 == 0) {
-            dset_labels[ids/2] = strdup(DSET_PREFIX(inset[ids])) ;
-            len_all += strlen( dset_labels[ids/2] ) ;
-         }
-       }
-     }
+     if( ndset_labels == 0 )
+       dset_labels[ids] = strdup(DSET_PREFIX(inset[ids])) ;  /* 14 May 2010 */
+     len_all += strlen( dset_labels[ids] ) ;
      if (!LRpairs) {
       if( ids > 0 && !EQUIV_GRIDS(inset[0],inset[ids]) ) /* check for errors */
          ERROR_exit("Dataset grid %s doesn't match %s" ,
@@ -551,22 +394,17 @@ int main( int argc , char * argv[] )
                   argv[nopt+ids] , nvals[ids] ) ;
    }
 
+   /* 14 May 2010: manufacture list of all dataset labels in one big string */
+
+   dset_labels_all = (char *)calloc(sizeof(char),(len_all+4*ndset+13)) ;
+   for( ids=0 ; ids < ndset ; ids++ ){
+     strcat( dset_labels_all , dset_labels[ids] ) ;
+     if( ids < ndset-1 ) strcat( dset_labels_all , ";") ;
+   }
 
    if (!LRpairs) {
-     /* 14 May 2010: manufacture list of all dataset labels in one big string */
-
-     dset_labels_all = (char *)calloc(sizeof(char),(len_all+4*ndset+13)) ;
-     for( ids=0 ; ids < ndset ; ids++ ){
-       strcat( dset_labels_all , dset_labels[ids] ) ;
-       if( ids < ndset-1 ) strcat( dset_labels_all , ";") ;
-     }
      nx = DSET_NX(inset[0]) ;
    } else {
-     dset_labels_all = (char *)calloc(sizeof(char),(len_all+4*(ndset/2)+13)) ;
-     for( ids=0 ; ids < ndset/2 ; ids++ ){
-       strcat( dset_labels_all , dset_labels[ids] ) ;
-       if( ids < ndset/2-1 ) strcat( dset_labels_all , ";") ;
-     }
      nx = DSET_NX(inset[0]) + DSET_NX(inset[1]);
    }
    nz = DSET_NZ(inset[0]) ;
@@ -656,18 +494,17 @@ int main( int argc , char * argv[] )
 
         /* save memory by removing the two input dataset */
 
-        THD_delete_3dim_dataset( inset[ids] , (RwcBoolean)do_delete ) ;
+        THD_delete_3dim_dataset( inset[ids] , (Boolean)do_delete ) ;
         inset[ids] = NULL ;
-        THD_delete_3dim_dataset( inset[ids+1] , (RwcBoolean)do_delete ) ;
+        THD_delete_3dim_dataset( inset[ids+1] , (Boolean)do_delete ) ;
         inset[ids+1] = NULL ;
 
-        THD_vectim_applyfunc( mv , prepfunc ) ;  /* prep each time series */
-        THD_vectim_normalize( mv ) ;     /* L2 normalize each time series */
+        THD_vectim_normalize( mv ) ; /* L2 normalize each time series */
 
         /* find largest absolute value over all vectors */
-        nvv = (int64_t)mv->nvec * (int64_t)mv->nvals ; top = 0.0f ; fv = mv->fvec ;
-        for( kvv=0 ; kvv < nvv ; kvv++ ){
-          val = fabsf(fv[kvv]) ; if( val > top ) top = val ;
+        nvv = mv->nvec * mv->nvals ; top = 0.0f ; fv = mv->fvec ;
+        for( kk=0 ; kk < nvv ; kk++ ){
+          val = fabsf(fv[kk]) ; if( val > top ) top = val ;
         }
 
         if( top == 0.0f ){
@@ -679,31 +516,25 @@ int main( int argc , char * argv[] )
         if( do_byte ){
           top = 127.4f / top ; fac[ids/2] = 1.0f / top ;  /* save scale factor */
           bv = (sbyte *)malloc(sizeof(sbyte)*nvv) ;       /* output array */
-          for( kvv=0 ; kvv < nvv ; kvv++ ){
-            val = fv[kvv]*top ;
-            bv[kvv] = (val >= 0.0f) ? (sbyte)(val+0.499f) : (sbyte)(val-0.499f) ;
-          }
+          for( kk=0 ; kk < nvv ; kk++ ) bv[kk] = (sbyte)rintf(top*fv[kk]) ;
         } else {
           top = 32766.0f / top ; fac[ids/2] = 1.0f / top ;  /* save scale factor */
-          sv = (short *)malloc(sizeof(short)*nvv) ;         /* output array */
-          for( kvv=0 ; kvv < nvv ; kvv++ ){
-            val = fv[kvv]*top ;
-            sv[kvv] = (val >= 0.0f) ? (short)(val+0.499f) : (short)(val-0.499f) ;
-          }
+          sv = (short *)malloc(sizeof(short)*nvv) ;       /* output array */
+          for( kk=0 ; kk < nvv ; kk++ ) sv[kk] = (short)rintf(top*fv[kk]) ;
         }
         VECTIM_destroy(mv) ;
 
         ctim = NI_clock_time() ;
-        fprintf(stderr," %s =%5d ms;",prepname,ctim-btim) ;
+        fprintf(stderr," normalize =%5d ms;",ctim-btim) ;
         btim = ctim ;
 
         /* write output array */
 
-        if( do_byte ) kvv = fwrite( bv , sizeof(sbyte) , nvv , fp ) ;
-        else          kvv = fwrite( sv , sizeof(short) , nvv , fp ) ;
-        if( kvv < nvv ){
+        if( do_byte ) kk = fwrite( bv , sizeof(sbyte) , nvv , fp ) ;
+        else          kk = fwrite( sv , sizeof(short) , nvv , fp ) ;
+        if( kk < nvv ){
           fclose(fp) ; remove(dfname) ;
-          ERROR_exit("Write to '%s' failed -- is disk full? permission problem?",dfname) ;
+          ERROR_exit("Write to '%s' failed -- disk full? permission?",dfname) ;
         }
         if( do_byte ) free(bv) ;
         else          free(sv) ;  /* toss this trash */
@@ -721,7 +552,7 @@ int main( int argc , char * argv[] )
          ndset /= 2;
    } else {
       for( ids=0 ; ids < ndset ; ids++ ){
-        fprintf(stderr,"++ Dataset %d/%d: %s",ids+1,ndset,DSET_BRIKNAME(inset[ids])) ;
+        fprintf(stderr,"++ Dataset %s:",DSET_BRIKNAME(inset[ids])) ;
         btim = NI_clock_time() ;
 
         /* extract all time series in the mask, as floats */
@@ -735,49 +566,17 @@ int main( int argc , char * argv[] )
 
         /* save memory by removing this input dataset */
 
-        THD_delete_3dim_dataset( inset[ids] , (RwcBoolean)do_delete ) ;
+        THD_delete_3dim_dataset( inset[ids] , (Boolean)do_delete ) ;
         inset[ids] = NULL ;
-#if 1
-        /* find largest absolute value over all vectors */
-        nvv = (int64_t)mv->nvec * (int64_t)mv->nvals ; top = 0.0f ; fv = mv->fvec ;
-        for( kvv=0 ; kvv < nvv ; kvv++ ){
-          val = fabsf(fv[kvv]) ; if( val > top ) top = val ;
-        }
-        fprintf(stderr," [input max=%g]",top) ;
-#endif
 
-        THD_vectim_applyfunc( mv , prepfunc ) ;  /* prep each time series */
-#if 1
-        if( prepfunc != NULL ){
-          /* find largest absolute value over all vectors */
-          nvv = (int64_t)mv->nvec * (int64_t)mv->nvals ; top = 0.0f ; fv = mv->fvec ;
-          for( kvv=0 ; kvv < nvv ; kvv++ ){
-            val = fabsf(fv[kvv]) ; if( val > top ) top = val ;
-          }
-          fprintf(stderr," [processed max=%g]",top) ;
-        }
-#endif
-        THD_vectim_normalize( mv ) ;     /* L2 normalize each time series */
+        THD_vectim_normalize( mv ) ; /* L2 normalize each time series */
 
-#if 0
-        { float sq ;
-          for( iv=0 ; iv < mv->nvec ; iv++ ){
-            sq = 0.0f ; fv = VECTIM_PTR(mv,iv) ;
-            for( kk=0 ; kk < mv->nvals ; kk++ ) sq += fv[kk]*fv[kk] ;
-            if( sq != 0.0f && fabsf(sq-1.0f) > 0.0001f ) ININFO_message("index=%d sq=%g",iv,sq) ;
-          }
-        }
-#endif
-
-#if 1
         /* find largest absolute value over all vectors */
 
-        nvv = (int64_t)mv->nvec * (int64_t)mv->nvals ; top = 0.0f ; fv = mv->fvec ;
-        for( kvv=0 ; kvv < nvv ; kvv++ ){
-          val = fabsf(fv[kvv]) ; if( val > top ) top = val ;
+        nvv = mv->nvec * mv->nvals ; top = 0.0f ; fv = mv->fvec ;
+        for( kk=0 ; kk < nvv ; kk++ ){
+          val = fabsf(fv[kk]) ; if( val > top ) top = val ;
         }
-        fprintf(stderr," [output max=%g]",top) ;
-#endif
 
         if( top == 0.0f ){
           fclose(fp) ; remove(dfname) ; ERROR_exit("Dataset is all zero?!") ;
@@ -788,29 +587,23 @@ int main( int argc , char * argv[] )
         if( do_byte ){
           top = 127.4f / top ; fac[ids] = 1.0f / top ;  /* save scale factor */
           bv = (sbyte *)malloc(sizeof(sbyte)*nvv) ;     /* output array */
-          for( kvv=0 ; kvv < nvv ; kvv++ ){
-            val = fv[kvv]*top ;
-            bv[kvv] = (val >= 0.0f) ? (sbyte)(val+0.499f) : (sbyte)(val-0.499f) ;
-          }
+          for( kk=0 ; kk < nvv ; kk++ ) bv[kk] = (sbyte)rintf(top*fv[kk]) ;
         } else {
           top = 32766.0f / top ; fac[ids] = 1.0f / top ;  /* save scale factor */
           sv = (short *)malloc(sizeof(short)*nvv) ;       /* output array */
-          for( kvv=0 ; kvv < nvv ; kvv++ ){
-            val = fv[kvv]*top ;
-            sv[kvv] = (val >= 0.0f) ? (short)(val+0.499f) : (short)(val-0.499f) ;
-          }
+          for( kk=0 ; kk < nvv ; kk++ ) sv[kk] = (short)rintf(top*fv[kk]) ;
         }
         VECTIM_destroy(mv) ;
 
         ctim = NI_clock_time() ;
-        fprintf(stderr," %s =%5d ms;",prepname,ctim-btim) ;
+        fprintf(stderr," normalize =%5d ms;",ctim-btim) ;
         btim = ctim ;
 
         /* write output array */
 
-        if( do_byte ) kvv = fwrite( bv , sizeof(sbyte) , nvv , fp ) ;
-        else          kvv = fwrite( sv , sizeof(short) , nvv , fp ) ;
-        if( kvv < nvv ){
+        if( do_byte ) kk = fwrite( bv , sizeof(sbyte) , nvv , fp ) ;
+        else          kk = fwrite( sv , sizeof(short) , nvv , fp ) ;
+        if( kk < nvv ){
           fclose(fp) ; remove(dfname) ;
           ERROR_exit("Write to '%s' failed -- disk full? permission?",dfname) ;
         }
@@ -888,9 +681,6 @@ int main( int argc , char * argv[] )
      free(cmdline) ;
    }
 
-   if( prepname != NULL && prepname[0] != '\0' )               /* 23 May 2012 */
-     NI_set_attribute( nel , "prep" , prepname ) ;
-
    /*--- write header file ---*/
 
    kk = NI_write_element_tofile( hfname , nel , NI_BINARY_MODE ) ;
