@@ -49,6 +49,13 @@
 #include "mrilib.h"
 #include "matrix.h"
 
+
+/*---------------------------------------------------------------------------*/
+
+#ifndef myXtFree
+#   define myXtFree(xp) (XtFree((char *)(xp)) , (xp)=NULL)
+#endif
+
 /*---------------------------------------------------------------------------*/
 
 /** macro to test a malloc-ed pointer for validity **/
@@ -164,7 +171,7 @@ void SC_Syntax(void)
     "\n"
     "-thresh t tname  = Use threshold statistic from file tname. \n"
     "                   Only voxels whose threshold statistic is greater \n"
-    "                   than t in absolute value will be considered. \n"
+    "                   than t in abolute value will be considered. \n"
     "                     [If file tname contains more than 1 sub-brick, \n"
     "                     the threshold stat. sub-brick must be specified!]\n"
     "-nclust n        = This specifies the maximum number of clusters for \n"
