@@ -761,7 +761,7 @@ void check_for_valid_inputs
       NLfit_error ("Must have minimum constraints <= maximum constraints");
   for (ip = 0;  ip < p;  ip++)
     if (min_sconstr[ip] > max_sconstr[ip])
-      NLfit_error("Must have minimum constraints <= maximum constraints");
+      NLfit_error("Must have mininum constraints <= maximum constraints");
       
 
   /*----- check whether any of the output files already exist -----*/
@@ -1331,7 +1331,7 @@ void write_bucket_data
   int brick_coef;           /* regression coefficient index for sub-brick */
   char * brick_label;       /* character string label for sub-brick */
   int ierror;               /* number of errors in editing data */
-  float * volume=NULL;           /* volume of floating point data */
+  float * volume;           /* volume of floating point data */
   int dimension;            /* dimension of full model = p + q */
   char label[80];           /* label for output file history */ 
 
