@@ -11,10 +11,14 @@
   super-dataset.  Adapted from 3dbucket.c -- RWCox 21 Sep 1998.
 ----------------------------------------------------------------------------*/
 
+#ifndef myXtFree
+#   define myXtFree(xp) (XtFree((char *)(xp)) , (xp)=NULL)
+#endif
+
 /*-------------------------- global data --------------------------*/
 
 static THD_3dim_dataset_array *TCAT_dsar  = NULL ;  /* input datasets */
-static RwcPointer_array        *TCAT_subv  = NULL ;  /* sub-brick selectors */
+static XtPointer_array        *TCAT_subv  = NULL ;  /* sub-brick selectors */
 static int                     TCAT_nvox  = -1 ;    /* # voxels */
 static int                     TCAT_dry   = 0 ;     /* dry run? */
 static int                     TCAT_verb  = 0 ;     /* verbose? */
@@ -28,9 +32,6 @@ static int                     TCAT_rct   = 0 ;     /* 15 Nov 1999 */
 
 static int                     TCAT_relabel = 0 ;   /* 03 Nov 2010 */
 
-static char *                  TCAT_tpattern = NULL;/* 08 Mar 2013 [rickr] */
-static float                   TCAT_tr    = 0.0 ;   /* 08 Mar 2013 [rickr] */
-
 static char TCAT_output_prefix[THD_MAX_PREFIX] = "tcat" ;
 static char TCAT_session[THD_MAX_NAME]         = "./"   ;
 
@@ -90,30 +91,6 @@ void TCAT_read_opts( int argc , char *argv[] )
          continue ;
       }
 
-      /**** -tpattern PATTERN ****/
-
-      if( strncmp(argv[nopt],"-tpat",5) == 0 ) {
-         nopt++ ;
-         if( nopt >= argc )
-           ERROR_exit("need argument after -tpattern!") ;
-         TCAT_tpattern = argv[nopt] ;
-         /* allow @tpattern   02 Sep 2014 [rickr] */
-         nopt++ ; continue ;
-      }
-
-      /**** -tr TR ****/
-
-      if( strcmp(argv[nopt],"-tr") == 0 || strcmp(argv[nopt],"-TR") == 0 ){
-         nopt++ ;
-         if( nopt >= argc )
-           ERROR_exit("need argument after -tr!") ;
-         TCAT_tr = atof(argv[nopt]) ;
-         if( TCAT_tr <= 0.0 ) ERROR_exit("illegal -tr value: %s", argv[nopt]);
-         if( TCAT_tr >= 100.0 )
-            WARNING_message("-tr is in seconds, so %g seems big", TCAT_tr);
-         nopt++ ; continue ;
-      }
-
       /**** -session directory ****/
 
       if( strncmp(argv[nopt],"-session",6) == 0 ){
@@ -247,17 +224,13 @@ void TCAT_read_opts( int argc , char *argv[] )
         if( nexp == 0 ){ ebad = nexp = 1 ; fexp = argv+nopt ; }
         nopt++ ;
 
-        if( TCAT_verb )
-           INFO_message("3dTcat, file_expand nexp = %d, fexp[0] = %s\n", 
-                        nexp, *fexp);
-
         for( ee=0 ; ee < nexp ; ee++ ){ 
 
           /**** read dataset ****/
 
           cpt = strstr(fexp[ee],"[") ;  /* look for the sub-brick selector */
 
-          subv = NULL;   /* Need to reset this variable ZSS Nov. 24 2010 */
+          subv = NULL;   /* Need to resest this variable ZSS Nov. 24 2010 */
           if( cpt == NULL ){              /* no selector */
             strcpy(dname,fexp[ee]) ;
           } else if( cpt == fexp[ee] ){ /* can't be at start!*/
@@ -268,26 +241,13 @@ void TCAT_read_opts( int argc , char *argv[] )
             subv = cpt;   /* no length limit    17 Jun 2010 [rickr] */
           }
 
-          if( TCAT_verb > 1 )
-             INFO_message("opening one tcat dset #%d, %s", ee, dname);
-
           dset = THD_open_one_dataset( dname ) ;
-          /* rather than failing, try new-fangled open   4 Apr 2016 [rickr] */
-          /* NOTE: let THD_open_dataset parse sub-brick selectors */
-          if( dset == NULL ) {
-             if( TCAT_verb > 1 )
-                INFO_message("opening tcat dset #%d, %s", ee, fexp[ee]);
-
-             dset = THD_open_dataset( fexp[ee] ) ;
-             subv = NULL;
-          }
           if( dset == NULL ) ERROR_exit("Can't open dataset %s",dname) ;
           THD_force_malloc_type( dset->dblk , DATABLOCK_MEM_MALLOC ) ;
 
           if( TCAT_type < 0 ) TCAT_type = dset->type ;
 
-          /* 16 Mar 2010 */
-          TCAT_ccode = COMPRESS_filecode(dset->dblk->diskptr->brick_name) ;
+          TCAT_ccode = COMPRESS_filecode(dset->dblk->diskptr->brick_name) ; /* 16 Mar 2010 */
 
           /* check if voxel counts match */
 
@@ -359,7 +319,7 @@ int * TCAT_get_subv( int nvals , char *str )
    /* No selection list ==> select it all */
 
    if( str == NULL || str[0] == '\0' ){
-      subv = (int *) RwcMalloc( sizeof(int) * (nvals+1) ) ;
+      subv = (int *) XtMalloc( sizeof(int) * (nvals+1) ) ;
       subv[0] = nvals ;
       for( ii=0 ; ii < nvals ; ii++ ) subv[ii+1] = ii ;
       return subv ;
@@ -367,7 +327,7 @@ int * TCAT_get_subv( int nvals , char *str )
 
    /* skip initial '[' */
 
-   subv    = (int *) RwcMalloc( sizeof(int) * 2 ) ;
+   subv    = (int *) XtMalloc( sizeof(int) * 2 ) ;
    subv[0] = nout = 0 ;
 
    ipos = 0 ;
@@ -375,7 +335,7 @@ int * TCAT_get_subv( int nvals , char *str )
 
    /* do we have a count string in there ? */
    if (strstr(str,"count ")) {
-      return(get_count_intlist (str, &ii, nvals-1));
+      return(get_count_intlist ( str, &ii));
    }
 
 
@@ -390,10 +350,10 @@ int * TCAT_get_subv( int nvals , char *str )
          ibot = nvals-1 ; ipos++ ;
       } else {                 /* decode an integer */
          ibot = strtol( str+ipos , &cpt , 10 ) ;
-         if( ibot < 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( ibot < 0 ){ myXtFree(subv) ; return NULL ; }
          if( ibot >= nvals ) ibot = nvals-1 ;
          nused = (cpt-(str+ipos)) ;
-         if( ibot == 0 && nused == 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( ibot == 0 && nused == 0 ){ myXtFree(subv) ; return NULL ; }
          ipos += nused ;
       }
 
@@ -401,7 +361,7 @@ int * TCAT_get_subv( int nvals , char *str )
 
       if( str[ipos] == ',' || str[ipos] == '\0' || str[ipos] == ']' ){
          nout++ ;
-         subv = (int *) RwcRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
+         subv = (int *) XtRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
          subv[0]    = nout ;
          subv[nout] = ibot ;
          ipos++ ; continue ;  /* re-start loop at next sub-selector */
@@ -414,7 +374,7 @@ int * TCAT_get_subv( int nvals , char *str )
       } else if( str[ipos] == '.' && str[ipos+1] == '.' ){
          ipos++ ; ipos++ ;
       } else {
-         myRwcFree(subv) ; return NULL ;
+         myXtFree(subv) ; return NULL ;
       }
 
       /** get ending value for loop now **/
@@ -423,10 +383,10 @@ int * TCAT_get_subv( int nvals , char *str )
          itop = nvals-1 ; ipos++ ;
       } else {                 /* decode an integer */
          itop = strtol( str+ipos , &cpt , 10 ) ;
-         if( itop < 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( itop < 0 ){ myXtFree(subv) ; return NULL ; }
          if( itop >= nvals ) itop = nvals-1 ;
          nused = (cpt-(str+ipos)) ;
-         if( itop == 0 && nused == 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( itop == 0 && nused == 0 ){ myXtFree(subv) ; return NULL ; }
          ipos += nused ;
       }
 
@@ -439,7 +399,7 @@ int * TCAT_get_subv( int nvals , char *str )
       if( str[ipos] == '(' ){  /* decode an integer */
          ipos++ ;
          istep = strtol( str+ipos , &cpt , 10 ) ;
-         if( istep == 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( istep == 0 ){ myXtFree(subv) ; return NULL ; }
          nused = (cpt-(str+ipos)) ;
          ipos += nused ;
          if( str[ipos] == ')' ) ipos++ ;
@@ -449,7 +409,7 @@ int * TCAT_get_subv( int nvals , char *str )
 
       for( ii=ibot ; (ii-itop)*istep <= 0 ; ii += istep ){
          nout++ ;
-         subv = (int *) RwcRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
+         subv = (int *) XtRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
          subv[0]    = nout ;
          subv[nout] = ii ;
       }
@@ -515,39 +475,11 @@ void TCAT_Syntax(void)
     "                       with the input dataset name -- this might help\n"
     "                       identify the sub-bricks in the output dataset.\n"
     "\n"
-    "     -tpattern PATTERN = Specify the timing pattern for the output\n"
-    "                       dataset, using patterns described in the\n"
-    "                       'to3d -help' output (alt+z, seq, alt-z2, etc).\n"
-    "\n"
-    "     -tr TR      = Specify the TR (in seconds) for the output dataset.\n"
-    "\n"
-    "     -DAFNI_GLOB_SELECTORS=YES\n"
-    "                     Setting the environment variable AFNI_GLOB_SELECTORS\n"
-    "                     to YES (as done temporarily with this option) means\n"
-    "                     that sub-brick selectors '[..]' will not be used\n"
-    "                     as wildcards.  For example:\n"
-    " 3dTcat -DAFNI_GLOB_SELECTORS=YES -relabel -prefix EPIzero 'rest_*+tlrc.HEAD[0]'\n"
-    "                     will work to make a dataset with the #0 sub-brick\n"
-    "                     from each of a number of 3D+time datasets.\n"
-    "                  ** Note that the entire dataset specification is in quotes\n"
-    "                     to prevent the shell from doing the '*' wildcard expansion\n"
-    "                     -- it will be done inside the program itself, after the\n"
-    "                     sub-brick selector is temporarily detached from the string\n"
-    "                     -- and then a copy of the selector is re-attached to each\n"
-    "                     expanded filename.\n"
-    "                  ** Very few other AFNI '3d' programs do internal\n"
-    "                     wildcard expansion -- most of them rely on the shell.\n"
-    "\n"
     "Command line arguments after the above are taken as input datasets.\n"
     "A dataset is specified using one of these forms:\n"
-    "   prefix+view\n"
-    "   prefix+view.HEAD\n"
-    "   prefix+view.BRIK\n"
-    "   prefix.nii\n"
-    "   prefix.nii.gz\n"
+    "   'prefix+view', 'prefix+view.HEAD', or 'prefix+view.BRIK'.\n"
     "\n"
     "SUB-BRICK SELECTION:\n"
-    "--------------------\n"
     "You can also add a sub-brick selection list after the end of the\n"
     "dataset name.  This allows only a subset of the sub-bricks to be\n"
     "included into the output (by default, all of the input dataset\n"
@@ -561,32 +493,19 @@ void TCAT_Syntax(void)
     "to indicate the last sub-brick in a dataset; for example, you\n"
     "can select every third sub-brick by using the selection list\n"
     "  fred+orig[0..$(3)]\n"
-    "You can reverse the order of sub-bricks with a list like\n"
-    "  fred+origh[$..0(-1)]\n"
-    "(Exactly WHY you might want to time-reverse a dataset is a mystery.)\n"
     "\n"
     "You can also use a syntax based on the usage of the program count.\n"
     "This would be most useful when randomizing (shuffling) the order of\n"
     "the sub-bricks. Example:\n"
     "  fred+orig[count -seed 2 5 11 s] is equivalent to something like:\n"
     "  fred+orig[ 6, 5, 11, 10, 9, 8, 7] \n"
-    "You could also do: fred+orig[`count_afni -seed 2 -digits 1 -suffix ',' 5 11 s`]\n"
+    "You could also do: fred+orig[`count -seed 2 -digits 1 -suffix ',' 5 11 s`]\n"
     "but if you have lots of numbers, the command line would get too\n"
     "long for the shell to process it properly. Omit the seed option if\n"
     "you want the code to generate a seed automatically.\n"
     "You cannot mix and match count syntax with other selection gimmicks.\n"
     "\n"
-    "If you have a lot of bricks to select in a particular order, you will\n"
-    "also run into name length problems. One solution is to put the indices\n"
-    "in a .1D file then use the following syntax. For example, say you have\n"
-    "the selection in file reorder.1D. You can extract the sub-bricks with:\n"
-    "   fred+orig'[1dcat reorder.1D]' \n"
-    "As with count, you cannot mix and match 1dcat syntax with other \n"
-    "selection gimmicks.\n"
-    "\n"
     "NOTES:\n"
-    "------\n"
-    "You can also add a sub-brick selection list after the end of the\n"
     "* The TR and other time-axis properties are taken from the\n"
     "  first input dataset that is itself 3D+time.  If no input\n"
     "  datasets contain such information, then TR is set to 1.0.\n"
@@ -646,8 +565,7 @@ int main( int argc , char *argv[] )
    float *rlt0=NULL , *rlt1=NULL ;
    float *rltsum=NULL ;             /* 16 Sep 1999 */
    int   nrltsum ;
-   float dTR , nTR;
-   double angle=0.0 ;
+   float dTR , nTR ;
 
    /*** read input options ***/
 
@@ -656,9 +574,7 @@ int main( int argc , char *argv[] )
    /*-- 20 Apr 2001: addto the arglist, if user wants to [RWCox] --*/
 
    mainENTRY("3dTcat main"); machdep() ; PRINT_VERSION("3dTcat") ;
-   set_obliquity_report(0); /* silence obliquity */
-   (void)COX_clock_time() ;
-   
+
    { int new_argc ; char ** new_argv ;
      addto_args( argc , argv , &new_argc , &new_argv ) ;
      if( new_argv != NULL ){ argc = new_argc ; argv = new_argv ; }
@@ -696,20 +612,9 @@ int main( int argc , char *argv[] )
    /* 23 May 2005: check for axis consistency */
 
    for( iv=0 ; iv < ninp ; iv++ ){
-     if( iv != ids ) {
-       if (!EQUIV_DATAXES(new_dset->daxes,DSUB(iv)->daxes) ) {
-         WARNING_message("%s grid mismatch with %s",
+     if( iv != ids && !EQUIV_DATAXES(new_dset->daxes,DSUB(iv)->daxes) )
+       WARNING_message("%s grid mismatch with %s",
                DSET_BRIKNAME(dset) , DSET_BRIKNAME(DSUB(iv)) ) ;
-       }
-       /* allow for small angle differences   22 May 2015 [rickr] */
-       angle = dset_obliquity_angle_diff(new_dset, DSUB(iv),OBLIQ_ANGLE_THRESH);
-       if (angle > 0.0) {
-         WARNING_message(
-            "dataset %s has an obliquity difference of %f degrees with %s\n",
-            new_dset ,
-            angle, DSUB(iv) );
-       }
-     }
    }
 
    tross_Make_History( "3dTcat" , argc,argv , new_dset ) ;
@@ -727,9 +632,8 @@ int main( int argc , char *argv[] )
                     ADN_none ) ;
 
    /* check if we have a valid time axis; if not, make one up */
-   /* (do this as an initialization, even if -TCAT_tr/pattern) */
 
-   if ( DSET_TIMESTEP(new_dset) <= 0.0 ){
+   if( DSET_TIMESTEP(new_dset) <= 0.0 ){
       float TR = 1.0 ;
       float torg = 0.0 , tdur = 0.0 ;
       int tunits = UNITS_SEC_TYPE ;
@@ -751,39 +655,7 @@ int main( int argc , char *argv[] )
                           ADN_ttorg  , torg ,
                           ADN_ttdur  , tdur ,
                        ADN_none ) ;
-      if (DSET_NVALS(new_dset) > 1 && TCAT_tr <= 0.0) {
-         WARNING_message("Set TR of output dataset to 1.0 s") ;
-      }
-   }
-
-   /* 8 Mar 2013 [rickr] :                                        */
-   /* now that time axis is set, adjust it for TR or tpat options */
-   if( TCAT_tr > 0.0 ) {
-      EDIT_dset_items( new_dset ,
-                          ADN_tunits , UNITS_SEC_TYPE ,
-                          ADN_ttdel  , TCAT_tr ,
-                       ADN_none ) ;
-      if( TCAT_verb ) printf("-verb: setting TR to %g\n", TCAT_tr);
-   }
-
-   if( TCAT_tpattern ) {
-      int     nz = DSET_NZ(new_dset);
-      float   tr = DSET_TIMESTEP(new_dset);
-      float * tpat = TS_parse_tpattern(nz, tr, TCAT_tpattern);
-      if( !tpat ) ERROR_exit("cannot get timing for nz=%d, tr=%g, tpat=%s",
-                             nz, tr, TCAT_tpattern);
-
-      EDIT_dset_items( new_dset ,
-                          ADN_nsl ,     nz ,
-                          ADN_toff_sl , tpat ,
-                       ADN_none ) ;
-      if( TCAT_verb ) {
-         printf("-verb: setting timing to :");
-         for( kv=0; kv < nz; kv++ ) printf(" %g", tpat[kv]);
-         putchar('\n');
-      }
-
-      free(tpat);
+      WARNING_message("Set TR of output dataset to 1.0 s") ;
    }
 
    /* 10 Dec 2007: check if time steps are coherent */
@@ -791,8 +663,7 @@ int main( int argc , char *argv[] )
    nTR = DSET_TIMESTEP(new_dset) ;
    for( ids=0 ; ids < ninp ; ids++ ){
      dset = DSUB(ids) ; dTR = DSET_TIMESTEP(dset) ;
-     if( dTR > 0.0f && fabsf(dTR-nTR) > 0.001f &&
-         DSET_NVALS(new_dset) > 1)
+     if( dTR > 0.0f && fabsf(dTR-nTR) > 0.001f )
        WARNING_message("TR=%g in dataset %s; differs from output TR=%g",
                        dTR , DSET_HEADNAME(dset) , nTR ) ;
    }
@@ -831,7 +702,7 @@ int main( int argc , char *argv[] )
 
    /*** loop over input datasets ***/
 
-   if( ninp > 1 ) myRwcFree( new_dset->keywords ) ;
+   if( ninp > 1 ) myXtFree( new_dset->keywords ) ;
 
    ivout = 0 ;
    for( ids=0 ; ids < ninp ; ids++ ){
@@ -1010,7 +881,6 @@ int main( int argc , char *argv[] )
                for( kk=ivbot ; kk < ivtop ; kk++ ){     /* detrend */
                   qq = kk - ivbot ;
                   switch( DSET_BRICK_TYPE(new_dset,kk) ){
-                     default: break ; /* should not happen, I hope */
 
 #undef  ROUND
 #define ROUND(qq) ((short)rint((qq)+0.00001))
@@ -1057,7 +927,6 @@ int main( int argc , char *argv[] )
 
       for( kk=0 ; kk < new_nvals ; kk++ ){
          switch( DSET_BRICK_TYPE(new_dset,kk) ){
-            default: break ; /* should not happen, I hope */
             case MRI_short:{
                short * bar = (short *) DSET_ARRAY(new_dset,kk) ;
                float fac = DSET_BRICK_FACTOR(new_dset,kk) , val,finv ;
@@ -1096,7 +965,6 @@ int main( int argc , char *argv[] )
       THD_write_3dim_dataset( NULL,NULL , new_dset , True ) ;
       if( TCAT_verb ) INFO_message("-verb: Wrote output to %s",
                               DSET_BRIKNAME(new_dset) ) ;
-      INFO_message("elapsed time = %.1f s",COX_clock_time()) ;
    }
 
    exit(0) ;
