@@ -56,67 +56,34 @@
 
 #define METH_CENTROMEAN   31  /* RWC 01 Nov 2010 */
 
-#define METH_CVARINV      32  /* RWC 09 Aug 2011 */
-#define METH_CVARINVNOD   33
-
-#define METH_ZCOUNT        34
-#define METH_NZMEDIAN      35  /* RCR 27 Jun 2012 */
-#define METH_SIGNED_ABSMAX 36  /* RCR 31 Aug 2012 */
-#define METH_L2_NORM       37  /* RCR 07 Jan 2013 */
-#define METH_NZCOUNT       38
-
-#define METH_NZSTDEV       39  /* RWC 29 Jul 2015 */
-
-#define METH_PERCENTILE    40  /* RWC 05 May 2016 */
-static int perc_val = -666;
-
-#define METH_FIRSTVALUE    41 /* returns the 1st value - to avoid exiting on invalid 1-input-methods */
-#define METH_TSNR          42 /* JKR 10 April 2017 */
-
-#define METH_MEAN_SSD      43 /* 19 Mar 2018 */
-#define METH_MEAN_SSDQ     44
-#define METH_MEDIAN_ASD    45
-
-#define METH_SKEWNESS      46 /* PDL 17 July 2020 */
-#define METH_KURTOSIS      47 /* PDL 17 July 2020 */
-
-#define MAX_NUM_OF_METHS   48
+#define MAX_NUM_OF_METHS  32
 
 /* allow single inputs for some methods (test as we care to add) */
-#define NUM_1_INPUT_METHODS 12
+#define NUM_1_INPUT_METHODS 4
 static int valid_1_input_methods[NUM_1_INPUT_METHODS]
-           = { METH_MEAN, METH_MAX, METH_MIN, METH_SUM,
-               METH_ARGMAX, METH_ARGMIN, METH_ARGABSMAX,METH_SUM,
-               METH_ABSSUM, METH_NZMEAN, METH_SUM_SQUARES, METH_FIRSTVALUE };
-
+           = { METH_MEAN, METH_MAX, METH_MIN, METH_SUM };
+/* maybe add:  METH_ARGMAX, METH_ARGMIN, METH_ARGABSMAX,
+               METH_SUM, METH_ABSSUM, METH_NZMEAN, METH_SUM_SQUARES
+*/
 
 static int meth[MAX_NUM_OF_METHS]  = {METH_MEAN};
 static int nmeths                  = 0;
 static char prefix[THD_MAX_PREFIX] = "stat" ;
 static int datum                   = MRI_float ;
-static int nscale                  = 0;
 static float basepercent           = 0.5;  /* 50% assumed for duration unless user specified */
 
 static int do_tdiff = 0 ;  /* 25 May 2011 */
 
-#if 1
-# include "Tstat.h"
-#else
- static char *meth_names[] = {
-    "Mean"          , "Slope"        , "Std Dev"       , "Coef of Var" ,
-    "Median"        , "Med Abs Dev"  , "Max"           , "Min"         ,
-    "Durbin-Watson" , "Std Dev(NOD)" , "Coef Var(NOD)" , "AutoCorr"    ,
-    "AutoReg"       , "Absolute Max" , "ArgMax"        , "ArgMin"      ,
-    "ArgAbsMax"     , "Sum"          , "Duration"      , "Centroid"    ,
-    "CentDuration"  , "Absolute Sum" , "Non-zero Mean" , "Onset"       ,
-    "Offset"        , "Accumulate"   , "SS"            , "BiwtMidV"    ,
-    "ArgMin+1"      , "ArgMax+1"     , "ArgAbsMax+1"   , "CentroMean"  ,
-    "CVarInv"       , "CvarInv (NOD)", "ZeroCount"     , "NZ Median"   ,
-    "Signed Absmax" , "L2 Norm"      , "NonZero Count" , "NZ Stdev"    ,
-    "Percentile %d" , "FirstValue"   , "TSNR"          , "MSSD"        ,
-    "MSSDsqrt"      , "MASDx"
- };
-#endif
+static char *meth_names[] = {
+   "Mean"          , "Slope"        , "Std Dev"       , "Coef of Var" ,
+   "Median"        , "Med Abs Dev"  , "Max"           , "Min"         ,
+   "Durbin-Watson" , "Std Dev(NOD)" , "Coef Var(NOD)" , "AutoCorr"    ,
+   "AutoReg"       , "Absolute Max" , "ArgMax"        , "ArgMin"      ,
+   "ArgAbsMax"     , "Sum"          , "Duration"      , "Centroid"    ,
+   "CentDuration"  , "Absolute Sum" , "Non-zero Mean" , "Onset"       ,
+   "Offset"        , "Accumulate"   , "SS"            , "BiwtMidV"    ,
+   "ArgMin+1"      , "ArgMax+1"     , "ArgAbsMax+1"   , "CentroMean"
+};
 
 static void STATS_tsfunc( double tzero , double tdelta ,
                          int npts , float *ts , double ts_mean ,
@@ -128,10 +95,25 @@ static int Calc_duration(float *ts, int npts, float vmax, int max_index,
    int *onset, int *offset);
 static float Calc_centroid(float *ts, int npts);
 
-void usage_3dTstat(int detail)
-{
 
-     printf(
+int main( int argc , char *argv[] )
+{
+   THD_3dim_dataset *old_dset , *new_dset ;  /* input and output datasets */
+   THD_3dim_dataset *mask_dset=NULL  ;
+   float mask_bot=666.0 , mask_top=-666.0 ;
+   byte *cmask=NULL ; int ncmask=0 ;
+   byte *mmm   = NULL ;
+   int mcount=0, verb=0;
+   int nopt, nbriks, ii ;
+   int addBriks = 0 ;   /* n-1 sub-bricks out */
+   int fullBriks = 0 ;  /* n   sub-bricks out */
+   int tsout = 0 ;      /* flag to output a time series (not a stat bucket) */
+   int numMultBriks,methIndex,brikIndex;
+
+   /*----- Help the pitiful user? -----*/
+
+   if( argc < 2 || strcasecmp(argv[1],"-help") == 0 ){
+      printf(
 "Usage: 3dTstat [options] dataset\n"
  "Computes one or more voxel-wise statistics for a 3D+time dataset\n"
  "and stores them in a bucket dataset.  If no statistic option is\n"
@@ -139,52 +121,33 @@ void usage_3dTstat(int detail)
  "Multiple statistics options may be given, and will result in\n"
  "a multi-volume dataset.\n"
  "\n"
- "Statistics Options (note where detrending does/does not occur):\n"
-"\n"
- " -sum       = compute sum of input voxels\n"
- " -abssum    = compute absolute sum of input voxels\n"
- " -sos       = compute sum of squares\n"
- " -l2norm    = compute L2 norm (sqrt(sum squares))\n"
- " -mean      = compute mean of input voxels\n"
- " -slope     = compute the slope of input voxels vs. time\n"
+ "Statistics Options:\n"
+ " -mean   = compute mean of input voxels\n"
+ " -sum    = compute sum of input voxels\n"
+ " -abssum = compute absolute sum of input voxels\n"
+ " -slope  = compute the slope of input voxels vs. time\n"
+ " -sos    = compute sum of squares\n"
+ " -stdev  = compute standard deviation of input voxels\n"
+ "             [N.B.: this is computed after    ]\n"
+ "             [      the slope has been removed]\n"
+ " -cvar   = compute coefficient of variation of input\n"
+ "             voxels = stdev/fabs(mean)\n"
+ "   **N.B.: You can add NOD to the end of the above 2\n"
+ "           options only, to turn off detrending, as in\n"
+ "             -stdevNOD  and/or  -cvarNOD\n"
  "\n"
- " -stdev     = compute standard deviation of input voxels\n"
- "              NB: input is detrended by first removing mean+slope\n"
- " -stdevNOD  = like '-stdev', but no initial detrending\n"
- " -cvar      = compute coefficient of variation of input:\n"
- "                 voxels = stdev/fabs(mean)\n"
- "              NB: in stdev calc, input is detrended by removing mean+slope\n"
- " -cvarNOD   = like '-cvar', but no initial detrending in stdev calc\n"
- " -cvarinv   = 1.0/cvar = 'signal to noise ratio' [for Vinai]\n"
- "              NB: in stdev calc, input is detrended by removing mean+slope\n"
- " -cvarinvNOD = like '-cvarinv', but no detrending in stdev calc\n"
- "\n"
- " -tsnr      = compute temporal signal to noise ratio\n"
- "                fabs(mean)/stdev NOT DETRENDED (same as -cvarinvNOD)\n"
- " -MAD       = compute MAD (median absolute deviation) of\n"
- "                input voxels = median(|voxel-median(voxel)|)\n"
- "                [N.B.: the trend is NOT removed for this]\n"
- " -DW        = compute Durbin-Watson Statistic of input voxels\n"
- "                [N.B.: the trend IS removed for this]\n"
- " -median    = compute median of input voxels  [undetrended]\n"
- " -nzmedian  = compute median of non-zero input voxels [undetrended]\n"
- " -nzstdev   = standard deviation of non-zero input voxel [undetrended]\n"
- " -bmv       = compute biweight midvariance of input voxels [undetrended]\n"
- "                [actually is 0.989*sqrt(biweight midvariance), to make]\n"
- "                [the value comparable to the standard deviation output]\n"
- " -MSSD      = Von Neumann's Mean of Successive Squared Differences\n"
- "               = average of sum of squares of first time difference\n"
- " -MSSDsqrt  = Sqrt(MSSD)\n"
- " -MASDx     = Median of absolute values of first time differences\n"
- "               times 1.4826 (to scale it like standard deviation)\n"
- "               = a robust alternative to MSSDsqrt\n"
- " -min       = compute minimum of input voxels [undetrended]\n"
- " -max       = compute maximum of input voxels [undetrended]\n"
+ " -MAD    = compute MAD (median absolute deviation) of\n"
+ "             input voxels = median(|voxel-median(voxel)|)\n"
+ "             [N.B.: the trend is NOT removed for this]\n"
+ " -DW    = compute Durbin-Watson Statistic of input voxels\n"
+ "             [N.B.: the trend IS removed for this]\n"
+ " -median = compute median of input voxels  [undetrended]\n"
+ " -bmv    = compute biweight midvariance of input voxels [undetrended]\n"
+ "             [actually is 0.989*sqrt(biweight midvariance), to make]\n"
+ "             [the value comparable to the standard deviation output]\n"
+ " -min    = compute minimum of input voxels [undetrended]\n"
+ " -max    = compute maximum of input voxels [undetrended]\n"
  " -absmax    = compute absolute maximum of input voxels [undetrended]\n"
- " -signed_absmax = (signed) value with absolute maximum [undetrended]\n"
- " -percentile P  = the P-th percentile point (0=min, 50=median, 100=max)\n"
- "                  of the data in each voxel time series.\n"
- "                  [this option can only be used once!]\n"
  " -argmin    = index of minimum of input voxels [undetrended]\n"
  " -argmin1   = index + 1 of minimum of input voxels [undetrended]\n"
  " -argmax    = index of maximum of input voxels [undetrended]\n"
@@ -201,8 +164,6 @@ void usage_3dTstat(int detail)
  "              (sum(i*f(i)) / sum(f(i)))\n"
  " -centduration = compute duration using centroid's index as center\n"
  " -nzmean    = compute mean of non-zero voxels\n"
- " -zcount    = count number of zero values at each voxel\n"
- " -nzcount    = count number of non zero values at each voxel\n"
  "\n"
  " -autocorr n = compute autocorrelation function and return\n"
  "               first n coefficients\n"
@@ -217,11 +178,6 @@ void usage_3dTstat(int detail)
  "\n"
  " -centromean = compute mean of middle 50%% of voxel values [undetrended]\n"
  "\n"
- " -skewness = measure of asymmetry in distribution - based on Pearson's\n"
- "             moment, coefficient of skewness.\n"
- " -kurtosis = measure of the 'tailedness' of the probability distribution\n"
- "             - the fourth standardized moment.  Never negative.\n"
- " -firstvalue = first value in dataset - typically just placeholder\n\n"
  " ** If no statistic option is given, then '-mean' is assumed **\n"
  "\n"
  "Other Options:\n"
@@ -232,8 +188,6 @@ void usage_3dTstat(int detail)
  " -datum d  = use data type 'd' for the type of storage\n"
  "               of the output, where 'd' is one of\n"
  "               'byte', 'short', or 'float' [DEFAULT=float]\n"
- " -nscale = Do not scale output values when datum is byte or short.\n"
- "           Scaling is done by default.\n"
  "\n"
  " -basepercent nn = Percentage of maximum for duration calculation\n"
  "\n"
@@ -298,60 +252,24 @@ void usage_3dTstat(int detail)
   "option, then the output will be written into a NIML-formatted 1D\n"
   "dataset, which you might find slightly confusing (but still usable).\n"
  ) ;
-
-   PRINT_COMPILE_DATE ;
-
-   return;
-}
-
-int main( int argc , char *argv[] )
-{
-   THD_3dim_dataset *old_dset , *new_dset ;  /* input and output datasets */
-   THD_3dim_dataset *mask_dset=NULL  ;
-   float mask_bot=666.0 , mask_top=-666.0 ;
-   byte *cmask=NULL ; int ncmask=0 ;
-   byte *mmm   = NULL ;
-   int mcount=0, verb=0;
-   int nopt, nbriks, ii ;
-   int addBriks = 0 ;   /* n-1 sub-bricks out */
-   int fullBriks = 0 ;  /* n   sub-bricks out */
-   int tsout = 0 ;      /* flag to output a time series (not a stat bucket) */
-   int numMultBriks,methIndex,brikIndex;
-
-   /*----- Help the pitiful user? -----*/
-
+      PRINT_COMPILE_DATE ; exit(0) ;
+   }
 
    /* bureaucracy */
+
    mainENTRY("3dTstat main"); machdep(); AFNI_logger("3dTstat",argc,argv);
    PRINT_VERSION("3dTstat"); AUTHOR("KR Hammett & RW Cox");
 
    /*--- scan command line for options ---*/
 
-   if (argc == 1) { usage_3dTstat(1); exit(0); } /* Bob's help shortcut */
    nopt = 1 ;
    nbriks = 0 ;
    nmeths = 0 ;
    verb = 0;
    while( nopt < argc && argv[nopt][0] == '-' ){
-      if (strcmp(argv[nopt], "-h") == 0 || strcmp(argv[nopt], "-help") == 0) {
-         usage_3dTstat(strlen(argv[nopt]) > 3 ? 2:1);
-         exit(0);
-      }
-
-      if( strcmp(argv[nopt],"-verb") == 0 ){
-        verb++ ; nopt++ ; continue ;
-      }
 
       /*-- methods --*/
 
-      if( strcasecmp(argv[nopt],"-methnum") == 0 ){    /* 20 Mar 2018 */
-        if( ++nopt == argc )                           /* for plugin use */
-          ERROR_exit("no arg after '%s'",argv[nopt-1]);
-        meth[nmeths++] = (int)strtod(argv[nopt],NULL) ;
-        nbriks++ ;
-        nopt++ ; continue ;
-      }
-
       if( strcasecmp(argv[nopt],"-centromean") == 0 ){ /* 01 Nov 2010 */
          meth[nmeths++] = METH_CENTROMEAN ;
          nbriks++ ;
@@ -370,36 +288,12 @@ int main( int argc , char *argv[] )
          nopt++ ; continue ;
       }
 
-      if( strcasecmp(argv[nopt],"-nzmedian") == 0 ){
-         meth[nmeths++] = METH_NZMEDIAN ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-
-      if( strcasecmp(argv[nopt],"-nzstdev") == 0 ){
-         meth[nmeths++] = METH_NZSTDEV ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-
       if( strcasecmp(argv[nopt],"-DW") == 0 ){
          meth[nmeths++] = METH_DW ;
          nbriks++ ;
          nopt++ ; continue ;
       }
 
-      if( strcasecmp(argv[nopt],"-zcount") == 0 ){
-         meth[nmeths++] = METH_ZCOUNT ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-
-      if( strcasecmp(argv[nopt],"-nzcount") == 0 ){
-         meth[nmeths++] = METH_NZCOUNT ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-
       if( strcasecmp(argv[nopt],"-MAD") == 0 ){
          meth[nmeths++] = METH_MAD ;
          nbriks++ ;
@@ -412,50 +306,6 @@ int main( int argc , char *argv[] )
          nopt++ ; continue ;
       }
 
-      if( strcasecmp(argv[nopt],"-percentile") == 0 ){ /* 05 May 2016 */
-         if( ++nopt >= argc )
-           ERROR_exit("need argument after option '%s'",argv[nopt-1]) ;
-         if( perc_val >= 0 )
-           ERROR_exit("you can't use option '%s' twice!",argv[nopt-1]) ;
-         perc_val = (int)strtod(argv[nopt],NULL) ;
-         if( perc_val < 0 || perc_val > 100 )
-           ERROR_exit("illegal number '%d' after option '%s'",
-                      perc_val , argv[nopt-1]) ;
-         if( perc_val == 0 )
-           WARNING_message("option '%s 0' is the same as '-min'",argv[nopt-1]) ;
-         if( perc_val == 100 )
-           WARNING_message("option '%s 100' is the same as '-max'",argv[nopt-1]) ;
-         meth[nmeths++] = METH_PERCENTILE ;
-         nbriks++ ; nopt++ ; continue ;
-      }
-
-      if( strcasecmp(argv[nopt],"-MSSD") == 0 ){  /* 19 Mar 2018 */
-         meth[nmeths++] = METH_MEAN_SSD ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-      if( strcasecmp(argv[nopt],"-MSSDQ")    == 0 ||
-          strcasecmp(argv[nopt],"-MSSDsqrt") == 0 ){  /* 20 Mar 2018 */
-         meth[nmeths++] = METH_MEAN_SSDQ ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-      if( strcasecmp(argv[nopt],"-MASDx") == 0 ){  /* 19 Mar 2018 */
-         meth[nmeths++] = METH_MEDIAN_ASD ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-      if( strcasecmp(argv[nopt],"-skewness") == 0 ){  /* 19 Mar 2018 */
-         meth[nmeths++] = METH_SKEWNESS ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-      if( strcasecmp(argv[nopt],"-kurtosis") == 0 ){  /* 19 Mar 2018 */
-         meth[nmeths++] = METH_KURTOSIS ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-
       if( strcasecmp(argv[nopt],"-sum") == 0 ){
          meth[nmeths++] = METH_SUM ;
          nbriks++ ;
@@ -493,12 +343,6 @@ int main( int argc , char *argv[] )
          nopt++ ; continue ;
       }
 
-      if( strcasecmp(argv[nopt],"-cvarinv") == 0 ){
-         meth[nmeths++] = METH_CVARINV ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-
       if( strcasecmp(argv[nopt],"-stdevNOD") == 0 ||
           strcasecmp(argv[nopt],"-sigmaNOD") == 0   ){  /* 07 Dec 2001 */
 
@@ -513,18 +357,6 @@ int main( int argc , char *argv[] )
          nopt++ ; continue ;
       }
 
-      if( strcasecmp(argv[nopt],"-cvarinvNOD") == 0 ){
-         meth[nmeths++] = METH_CVARINVNOD ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-
-     if( strcasecmp(argv[nopt],"-tsnr") == 0 ){     /* 10 April 2017 */
-        meth[nmeths++] = METH_TSNR ;
-        nbriks++ ;
-        nopt++ ; continue ;
-      }
-
       if( strcasecmp(argv[nopt],"-min") == 0 ){
          meth[nmeths++] = METH_MIN ;
          nbriks++ ;
@@ -543,12 +375,6 @@ int main( int argc , char *argv[] )
          nopt++ ; continue ;
       }
 
-      if( strcasecmp(argv[nopt],"-signed_absmax") == 0 ){
-         meth[nmeths++] = METH_SIGNED_ABSMAX ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-
       if( strcasecmp(argv[nopt],"-argmin") == 0 ){
          meth[nmeths++] = METH_ARGMIN ;
          nbriks++ ;
@@ -683,12 +509,6 @@ int main( int argc , char *argv[] )
          nopt++ ; continue ;
       }
 
-      if( strcasecmp(argv[nopt],"-l2norm") == 0 ){  /* 07 Jan 2013 [rickr] */
-         meth[nmeths++] = METH_L2_NORM ;
-         nbriks++ ;
-         nopt++ ; continue ;
-      }
-
       /*-- prefix --*/
 
       if( strcasecmp(argv[nopt],"-prefix") == 0 ){
@@ -705,12 +525,6 @@ int main( int argc , char *argv[] )
         do_tdiff = 1 ; nopt++ ; continue ;
       }
 
-      /*-- nscale --*/
-
-      if( strcasecmp(argv[nopt],"-nscale") == 0 ){  /* 25 May 2011 */
-        nscale = 1 ; nopt++ ; continue ;
-      }
-
       /*-- datum --*/
 
       if( strcasecmp(argv[nopt],"-datum") == 0 ){
@@ -738,14 +552,7 @@ int main( int argc , char *argv[] )
 
       /*-- Quien sabe'? --*/
 
-      ERROR_message("Unknown option: %s\n",argv[nopt]) ;
-      suggest_best_prog_option(argv[0], argv[nopt]);
-      exit(1);
-   }
-
-   if (argc < 2) {
-     ERROR_message("Too few options, use -help for details");
-     exit(1);
+      ERROR_exit("Unknown option: %s\n",argv[nopt]) ;
    }
 
    /*--- If no options selected, default to single stat MEAN -- KRH ---*/
@@ -776,7 +583,7 @@ int main( int argc , char *argv[] )
       ERROR_exit("Time series is of length 0?\n") ;
    }
    else if( DSET_NVALS(old_dset) == 1 || (do_tdiff && DSET_NVALS(old_dset)==2) ) {
-     int methOK;
+     int methOK, OK = 1;
      /* see if each method is valid for nvals == 1 */
      for( methIndex = 0; methIndex < nmeths; methIndex++ ) {
         methOK = 0;
@@ -785,11 +592,9 @@ int main( int argc , char *argv[] )
                 methOK = 1;
                 break;
             }
-            else
-               meth[methIndex] = METH_FIRSTVALUE;
         }
         if( ! methOK )
-           WARNING_message("Using dataset with only %d values per voxel and giving back just the first value!" ,
+           ERROR_exit("Can't use dataset with %d values per voxel!" ,
                       DSET_NVALS(old_dset) ) ;
      }
      /* tell the library function that this case is okay */
@@ -797,9 +602,7 @@ int main( int argc , char *argv[] )
    }
 
    if( DSET_NUM_TIMES(old_dset) < 2 ){
-     /* be more quiet, on the orders of P Taylor       [20 Jun 2024 rickr] */
-     /* WARNING_message("Input dataset is not 3D+time; assuming TR=1.0") ; */
-
+     WARNING_message("Input dataset is not 3D+time; assuming TR=1.0") ;
      EDIT_dset_items( old_dset ,
                         ADN_ntt    , DSET_NVALS(old_dset) ,
                         ADN_ttorg  , 0.0 ,
@@ -859,8 +662,7 @@ int main( int argc , char *argv[] )
                  nbriks ,               /* number of briks */
                  STATS_tsfunc ,         /* timeseries processor */
                  NULL,                  /* data for tsfunc */
-                 mmm,
-                 nscale
+                 mmm
               ) ;
 
    if( new_dset != NULL ){
@@ -890,10 +692,6 @@ int main( int argc , char *argv[] )
           }
           methIndex++;
           brikIndex += numMultBriks - 1;
-        } else if( meth[methIndex] == METH_PERCENTILE ){ /* 05 May 2016 */
-          char plabel[32] ;
-          sprintf(plabel,meth_names[METH_PERCENTILE],perc_val) ;
-          EDIT_BRICK_LABEL(new_dset, brikIndex, plabel ) ;
         } else {
           EDIT_BRICK_LABEL(new_dset, brikIndex, meth_names[meth[methIndex]]) ;
         }
@@ -950,7 +748,7 @@ static void STATS_tsfunc( double tzero, double tdelta ,
    if( do_tdiff ){
      float tsm , tss ;
      ts_dif = (float*)calloc(npts, sizeof(float)) ;
-     for( ii=1 ; ii < npts ; ii++ ) ts_dif[ii-1] = ts[ii]-ts[ii-1] ;
+	  for( ii=1 ; ii < npts ; ii++ ) ts_dif[ii-1] = ts[ii]-ts[ii-1] ;
      get_linear_trend( npts-1 , ts_dif , &tsm , &tss ) ;
      ts_mean = (double)tsm ; ts_slope = (double)tss ;
      npts-- ; ts = ts_dif ;
@@ -981,7 +779,6 @@ static void STATS_tsfunc( double tzero, double tdelta ,
     switch( meth[meth_index] ){
 
       default:
-      case METH_FIRSTVALUE:  val[out_index] = ts[0]; break ; /* placeholder drg 06/13/2016 */
       case METH_MEAN:  val[out_index] = ts_mean  ; break ;
 
       case METH_SUM:   val[out_index] = ts_mean * npts; break; /* 24 Apr 2006 */
@@ -995,100 +792,40 @@ static void STATS_tsfunc( double tzero, double tdelta ,
       }
       break;
 
-      case METH_PERCENTILE:{         /* 05 May 2016 */
-        float* ts_copy; int ii , fi ;
-        ts_copy = (float*)calloc(npts, sizeof(float));
-        memcpy( ts_copy, ts, npts * sizeof(float));
-        qsort_float(npts,ts_copy) ;
-        fi = (perc_val * npts)*0.01f ;
-        ii = (int)fi ; fi = fi - ii ;
-        if( ii >= npts-1 ){                  /* max */
-          val[out_index] = ts_copy[npts-1] ;
-        } else if( ii < 0 ){                 /* should never happen */
-          val[out_index] = ts_copy[0] ;
-        } else {                             /* the usual suspects */
-          val[out_index] = (1.0f-fi)*ts_copy[ii] + fi*ts_copy[ii+1] ;
-        }
-        free(ts_copy) ;
-      }
-      break ;
-
-      case METH_L2_NORM:                /* 07 Jan 2013 [rickr] */
       case METH_SUM_SQUARES:{           /* 18 Dec 2008 */
         register int ii ;
         register float sum ;
         sum = 0.0;
         for(ii=0; ii< npts; ii++) sum += ts[ii]*ts[ii];
-
-        /* check multiple methods here */
-        if ( meth[meth_index] == METH_SUM_SQUARES )
-           val[out_index] = sum;
-        else if ( meth[meth_index] == METH_L2_NORM ) {
-           /* theory and practice do not always seem to agree, so... */
-           if( sum >= 0.0 ) val[out_index] = sqrt(sum);
-           else             val[out_index] = 0.0;
-        }
+        val[out_index] = sum;
       }
       break;
 
       case METH_SLOPE: val[out_index] = ts_slope ; break ;
 
-      case METH_CVAR_NOD:     /* methods that depend on the mean and stdev */
+      case METH_CVAR_NOD:
       case METH_SIGMA_NOD:
-      case METH_CVARINVNOD:
       case METH_CVAR:
-      case METH_CVARINV:
       case METH_SIGMA:{
         register int ii ;
         register double sum ;
 
-        int mm = meth[meth_index] ;
-        int nod = (mm == METH_CVAR_NOD)  ||   /* no detrend flag */
-                  (mm == METH_SIGMA_NOD) ||
-                  (mm == METH_CVARINVNOD)  ;
-
         sum = 0.0 ;
-        if( !nod ){   /* not no detrend ==> use detrended data */
+        if((meth[meth_index] == METH_CVAR) || (meth[meth_index] == METH_SIGMA )){
           for( ii=0 ; ii < npts ; ii++ ) sum += ts_det[ii] * ts_det[ii] ;
-        } else {      /* use data as God gave it to us */
+        } else {
           for( ii=0 ; ii < npts ; ii++ ) sum += (ts[ii]-ts_mean)
                                                *(ts[ii]-ts_mean) ;
         }
 
-        sum = sqrt( sum/(npts-1.0) ) ;  /* stdev */
+        sum = sqrt( sum/(npts-1) ) ;
 
-        if( mm == METH_SIGMA ||  mm == METH_SIGMA_NOD )
+        if((meth[meth_index] == METH_SIGMA) || (meth[meth_index] == METH_SIGMA_NOD))
           val[out_index] = sum ;
-        else if( mm == METH_CVAR || mm == METH_CVAR_NOD )
-          val[out_index] = (ts_mean != 0.0) ? sum/fabs(ts_mean) : 0.0 ;
+        else if( ts_mean != 0.0 )
+          val[out_index] = sum / fabs(ts_mean) ;
         else
-          val[out_index] = (sum     != 0.0) ? fabs(ts_mean)/sum : 0.0 ;
-      }
-      break ;
-
-      case METH_TSNR:{
-        register int ii ;
-        register double std = 0.0;
-        register double sum = 0.0;
-
-        /* no detrending */
-        for( ii=0 ; ii < npts ; ii++ ) sum += (ts[ii]-ts_mean)
-                                           *(ts[ii]-ts_mean) ;
-        std = sqrt( sum/(npts-1.0) ) ;  /* stdev */
-        val[out_index] = (std != 0.0) ? fabs(ts_mean)/std : 0.0 ;
-      }
-      break ;
-
-      case METH_MEAN_SSDQ:
-      case METH_MEAN_SSD:{  /* 19 Mar 2018 */
-        val[out_index] = cs_mean_square_sd( npts , ts ) ;
-        if( meth[meth_index] == METH_MEAN_SSDQ )
-          val[out_index] = sqrtf( MAX(val[out_index],0.0f) ) ;
-      }
-      break ;
-
-      case METH_MEDIAN_ASD:{  /* 19 Mar 2018 */
-        val[out_index] = cs_median_abs_sd( npts , ts , NULL ) * 1.4826f ;
+          val[out_index] = 0.0 ;
       }
       break ;
 
@@ -1104,36 +841,6 @@ static void STATS_tsfunc( double tzero, double tdelta ,
       }
       break ;
 
-      case METH_NZMEDIAN:{      /* 27 Jun 2012 [rickr] */
-        float* ts_copy;
-        int    lind, lnzcount;
-        ts_copy = (float*)calloc(npts, sizeof(float));
-        /* replace memcpy with non-zero copy */
-        lnzcount=0;
-        for (lind=0; lind < npts; lind++)
-           if( ts[lind] ) ts_copy[lnzcount++] = ts[lind];
-        /* and get the result from the possibly shortened array */
-        if( lnzcount > 0 ) val[out_index] = qmed_float( lnzcount , ts_copy ) ;
-        else               val[out_index] = 0.0 ;
-        free(ts_copy);
-      }
-      break ;
-
-      case METH_NZSTDEV:{      /* 29 Jul 2015 [RWC] */
-        float* ts_copy;
-        int    lind, lnzcount;
-        ts_copy = (float*)calloc(npts, sizeof(float));
-        /* replace memcpy with non-zero copy */
-        lnzcount=0;
-        for (lind=0; lind < npts; lind++)
-           if( ts[lind] ) ts_copy[lnzcount++] = ts[lind];
-        /* and get the result from the possibly shortened array */
-        if( lnzcount > 1 ) meansigma_float( lnzcount,ts_copy, NULL,val+out_index ) ;
-        else               val[out_index] = 0.0 ;
-        free(ts_copy);
-      }
-      break ;
-
       case METH_CENTROMEAN:{  /* 01 Nov 2010 */
         float* ts_copy;
         ts_copy = (float*)calloc(npts, sizeof(float));
@@ -1182,20 +889,6 @@ static void STATS_tsfunc( double tzero, double tdelta ,
       }
       break ;
 
-      case METH_ZCOUNT:{  /* 05 Apr 2012 */
-        int ii , zc ;
-        for( ii=zc=0 ; ii < npts ; ii++ ) if( ts[ii] == 0.0f ) zc++ ;
-        val[out_index] = zc ;
-      }
-      break ;
-
-      case METH_NZCOUNT:{  /* Turkey 2014 */
-        int ii , zc ;
-        for( ii=zc=0 ; ii < npts ; ii++ ) if( ts[ii] == 0.0f ) zc++ ;
-        val[out_index] = npts-zc ;
-      }
-      break ;
-
       case METH_DW:{
          register int ii ;
          register float den=ts[0]*ts[0] ;
@@ -1217,7 +910,6 @@ static void STATS_tsfunc( double tzero, double tdelta ,
       case METH_OFFSET:
       case METH_DURATION:
       case METH_ABSMAX:
-      case METH_SIGNED_ABSMAX:
       case METH_ARGMAX:
       case METH_ARGMAX1:
       case METH_ARGABSMAX:
@@ -1226,7 +918,7 @@ static void STATS_tsfunc( double tzero, double tdelta ,
       case METH_CENTDURATION:
       case METH_CENTROID:{
          register int ii, outdex=0 ;
-         register float vm=ts[0];
+         register float vm=ts[0] ;
          if ( (meth[meth_index] == METH_ABSMAX) ||
                (meth[meth_index] == METH_ARGABSMAX) ||
                (meth[meth_index] == METH_ARGABSMAX1)  ) {
@@ -1237,16 +929,6 @@ static void STATS_tsfunc( double tzero, double tdelta ,
                outdex = ii ;
              }
            }
-         } else if ( meth[meth_index] == METH_SIGNED_ABSMAX ) {
-           /* for P Hamilton    31 Aug 2012 [rickr] */
-           register float avm=fabs(vm);
-           for( ii=1 ; ii < npts ; ii++ ) {
-             if( fabs(ts[ii]) > avm ) {
-               vm = ts[ii] ;
-               avm = fabs(vm) ;
-               outdex = ii ;
-             }
-           }
          } else {
            for( ii=1 ; ii < npts ; ii++ ) {
              if( ts[ii] > vm ) {
@@ -1258,7 +940,6 @@ static void STATS_tsfunc( double tzero, double tdelta ,
        switch( meth[meth_index] ){
             default:
             case METH_ABSMAX:
-            case METH_SIGNED_ABSMAX:
             case METH_MAX:
                val[out_index] = vm ;
             break;
@@ -1413,7 +1094,7 @@ static void STATS_tsfunc( double tzero, double tdelta ,
         /* populate the appropriate BRIKs with the data.    */
         for( ii = 0; ii < numVals; ii++) {
           val[out_index + ii] = y[ii];
-          if (!isfinite(y[ii])){
+          if (!finite(y[ii])){
             WARNING_message("BAD FLOAT y[%d]=%f; Call#%d\n",ii,y[ii],ncall);
             val[out_index + ii] = 0.0f ;
           }
@@ -1449,20 +1130,6 @@ static void STATS_tsfunc( double tzero, double tdelta ,
       }
       break ;
 
-      /* New methods, added by PDL, 17 July 2020 */
-
-      case METH_SKEWNESS:{
-
-        val[out_index] = getSkewness(ts, npts);
-      }
-      break;
-
-      case METH_KURTOSIS:{
-
-        val[out_index] = getKurtosis(ts, npts);
-     }
-      break;
-
     }
    }
 
@@ -1478,27 +1145,17 @@ static void autocorr( int npts, float in_ts[], int numVals, float outcoeff[] )
   int ii,nfft;
   double scaler;
   complex *cxar = NULL;
-  float tsmean ;
-  static int nfft_old = 0 ;
 
   /* Calculate size for FFT, including padding for eliminating overlap  */
   /* from circular convolution */
-  nfft = csfft_nextup_even(npts * 2 - 1);
-
-  if( nfft != nfft_old ){
-    nfft_old = nfft ;
-    INFO_message("FFT length = %d",nfft) ;
-  }
+  nfft = csfft_nextup_one35(npts * 2 - 1);
+/*  fprintf(stderr,"++ FFT length = %d\n",nfft) ; */
 
   cxar = (complex *) calloc( sizeof(complex) , nfft ) ;
 
-  /* compute mean of input */
-  for( tsmean=0.0f,ii=0 ; ii < npts ; ii++ ) tsmean += in_ts[ii] ;
-  tsmean /= npts ;
-
   /* Populate complex array with input (real-only) time series */
   for( ii=0 ; ii < npts ; ii++ ){
-    cxar[ii].r = in_ts[ii] - tsmean; cxar[ii].i = 0.0;
+    cxar[ii].r = in_ts[ii]; cxar[ii].i = 0.0;
   }
   /* Zero-pad input outside range of original time series */
   for( ii=npts ; ii < nfft ; ii++ ){ cxar[ii].r = cxar[ii].i = 0.0; }
@@ -1529,10 +1186,9 @@ static void autocorr( int npts, float in_ts[], int numVals, float outcoeff[] )
   /* The output coefficients are scaled by 1/(M-p) to   */
   /* provide an unbiased estimate, and also scaled by   */
   /* the final value of the zeroth coefficient.         */
-  scaler = cxar[0].r/npts; 
-  if( scaler != 0.0 ) scaler = 1.0 / scaler ;
+  scaler = cxar[0].r/npts;
   for (ii = 0 ; ii < numVals ; ii++ ) {
-    outcoeff[ii] = cxar[ii+1].r * ( scaler /(npts - (ii+1)) ) ;
+    outcoeff[ii] = cxar[ii+1].r/((npts - (ii+1)) * scaler);
   }
   free(cxar);
   cxar = NULL;
