@@ -3,13 +3,6 @@
      ***  14 Apr 2003 - RWCox.                                   ***
 --------------------------------------------------------------------------*/
 
-/*
-
-  [PT: Sep 9, 2019] add in opt: -disp_obl_xform_only
-                    + output transform between oblique coords.
-
-*/
-
 #include "mrilib.h"
 
 /*--------------------------------------------------------------------------*/
@@ -73,25 +66,12 @@ int main( int argc , char * argv[] )
    float     *matflar=NULL ;
 #endif
 
-   int DISP_OBL_XFORM_ONLY = 0 ;  // [PT: Sep 13, 2019] for getting oblique
-                            // transform matrix most easily
-
    /*-- help? --*/
 
    if( argc < 2 || strcmp(argv[1],"-help") == 0 ){
      printf("\n"
             "Usage: 3dWarp [options] dataset\n"
-            "Warp (spatially transform) one 3D dataset.\n"
-            "\n"
-            "* Here, the 'warp' is a 3x4 matrix = affine transform of space which\n"
-            "  the user supplies.\n"
-            "* Such a transformation can be computed by 3dWarpDrive or 3dAllineate,\n"
-            "  by matching one dataset to another.\n"
-            "* However, 3dAllineate can also transform a dataset given a matrix,\n"
-            "  so the usefulness of these older 3dWarp programs is now limited.\n"
-            "*****\n"
-            "***** For nonlinear spatial warping, see program 3dQwarp. *****\n"
-            "*****\n"
+            "Warp (spatially transform) a 3D dataset.\n"
             "--------------------------\n"
             "Transform Defining Options: [exactly one of these must be used]\n"
             "--------------------------\n"
@@ -136,8 +116,7 @@ int main( int argc , char * argv[] )
             "                input to 3dWarp should overlay properly with\n"
             "                the input to 3dWarpDrive that generated the\n"
             "                -matparent dataset).\n\n"
-  "  -card2oblique   obl_dset \n"
-  "       or \n"
+  "  -card2oblique obl_dset or \n"
   "  -oblique_parent obl_dset = Read in the oblique transformation matrix\n"
   "     from an oblique dataset and make cardinal dataset oblique to match.\n"
   "  -deoblique or\n"
@@ -146,25 +125,13 @@ int main( int argc , char * argv[] )
   "     output as specified with the -newgrid or -gridset options\n"
   "     or a new grid will be assigned based on the minimum voxel spacing\n"
   "    ** N.B.: EPI time series data should be time shifted with 3dTshift before"
-  "                rotating the volumes to a cardinal direction\n"
-  "\n"
-  "  -disp_obl_xform_only = (new opt) just display the obliquity transform\n"
-  "                         matrix that would be applied to make the output\n"
-  "                         dset;  very useful for moving between oblique\n"
-  "                         coords, such as with '-oblique_parent ..' or\n"
-  "                         '-deoblique'.  The result can be dumped into a\n"
-  "                         text file, e.g.:\n" 
-  "                              > textfile.aff12.1D\n"
-  "                         No dataset is created or changed.\n"
-  "\n"
+  "                rotating the volumes to a cardinal direction\n\n"
   "Sample usages:\n"
   " 3dWarpDrive -affine_general -base d1+orig -prefix d2WW -twopass"
     " -input d2+orig\n"
   " 3dWarp -matparent d2WW+orig -prefix epi2WW epi2+orig\n\n"
   " 3dWarp -card2oblique oblique_epi+orig -prefix oblique_anat card_anat+orig\n"
   " 3dWarp -oblique2card -prefix card_epi_tshift -newgrid 3.5 epi_tshift+orig\n"
-  " 3dWarp -card2oblique oblique_epi.nii -disp_obl_transf_only epi_tshift+orig\\\n"
-  "        > mat_obl_transform.aff12.1D\n"
   "\n"
   "Example of warping +tlrc results back to +orig space of some subject\n"
   "(get xform matrix, apply it, tell dataset it is not in orig space):\n"
@@ -174,51 +141,50 @@ int main( int argc , char * argv[] )
   "           -gridset subj1_epi+orig -cubic group_data+tlrc\n"
   "    3drefit -view orig group_warped+tlrc\n"
 #if 0
-  "\n"
-  "  -matfile mname  = Read in the file 'mname', which consists\n"
-  "                     of 12 ASCII-formatted numbers per line.\n"
-  "                     The i-th input line defines a 3x4 matrix\n"
-  "                     which is used to transform the i-th\n"
-  "                     sub-brick of the input dataset.\n"
+            "\n"
+            "  -matfile mname  = Read in the file 'mname', which consists\n"
+            "                     of 12 ASCII-formatted numbers per line.\n"
+            "                     The i-th input line defines a 3x4 matrix\n"
+            "                     which is used to transform the i-th\n"
+            "                     sub-brick of the input dataset.\n"
 #endif
-  "\n"
-  "-----------------------\n"
-  "Other Transform Options:\n"
-  "-----------------------\n"
-  "  -linear     }\n"
-  "  -cubic      } = Chooses spatial interpolation method.\n"
-  "  -NN         } =   [default = linear]\n"
-  "  -quintic    }\n"
-  "  -wsinc5     }\n"
-  "\n"
-  "  -fsl_matvec   = Indicates that the matrix file 'mmm' uses FSL\n"
-  "                    ordered coordinates ('LPI').  For use with\n"
-  "                    matrix files from FSL and SPM.\n"
-  "\n"
-  "  -newgrid ddd  = Tells program to compute new dataset on a\n"
-  "                    new 3D grid, with spacing of 'ddd' mmm.\n"
-  "                  * If this option is given, then the new\n"
-  "                    3D region of space covered by the grid\n"
-  "                    is computed by warping the 8 corners of\n"
-  "                    the input dataset, then laying down a\n"
-  "                    regular grid with spacing 'ddd'.\n"
-  "                  * If this option is NOT given, then the\n"
-  "                    new dataset is computed on the old\n"
-  "                    dataset's grid.\n"
-  "\n"
-  "  -gridset ggg  = Tells program to compute new dataset on the\n"
-  "                    same grid as dataset 'ggg'.\n"
-  "\n"
-  "  -zpad N       = Tells program to pad input dataset with 'N'\n"
-  "                    planes of zeros on all sides before doing\n"
-  "                    transformation.\n"
-  "---------------------\n"
-  "Miscellaneous Options:\n"
-  "---------------------\n"
-  "  -verb         = Print out some information along the way.\n"
-  "  -prefix ppp   = Sets the prefix of the output dataset.\n"
-  "\n"
-  ) ;
+            "\n"
+            "-----------------------\n"
+            "Other Transform Options:\n"
+            "-----------------------\n"
+            "  -linear     }\n"
+            "  -cubic      } = Chooses spatial interpolation method.\n"
+            "  -NN         } =   [default = linear]\n"
+            "  -quintic    }\n"
+            "\n"
+            "  -fsl_matvec   = Indicates that the matrix file 'mmm' uses FSL\n"
+            "                    ordered coordinates ('LPI').  For use with\n"
+            "                    matrix files from FSL and SPM.\n"
+            "\n"
+            "  -newgrid ddd  = Tells program to compute new dataset on a\n"
+            "                    new 3D grid, with spacing of 'ddd' mmm.\n"
+            "                  * If this option is given, then the new\n"
+            "                    3D region of space covered by the grid\n"
+            "                    is computed by warping the 8 corners of\n"
+            "                    the input dataset, then laying down a\n"
+            "                    regular grid with spacing 'ddd'.\n"
+            "                  * If this option is NOT given, then the\n"
+            "                    new dataset is computed on the old\n"
+            "                    dataset's grid.\n"
+            "\n"
+            "  -gridset ggg  = Tells program to compute new dataset on the\n"
+            "                    same grid as dataset 'ggg'.\n"
+            "\n"
+            "  -zpad N       = Tells program to pad input dataset with 'N'\n"
+            "                    planes of zeros on all sides before doing\n"
+            "                    transformation.\n"
+            "---------------------\n"
+            "Miscellaneous Options:\n"
+            "---------------------\n"
+            "  -verb         = Print out some information along the way.\n"
+            "  -prefix ppp   = Sets the prefix of the output dataset.\n"
+            "\n"
+           ) ;
      PRINT_COMPILE_DATE ; exit(0) ;
    }
 
@@ -375,11 +341,6 @@ int main( int argc , char * argv[] )
        mri_warp3D_method( MRI_QUINTIC ); nopt++ ; continue ;  /* 06 Aug 2003 */
      }
 
-     /* rcr - todo: move e.g. INTERP_methname to libmri and apply as generic */
-     if( strcmp(argv[nopt],"-wsinc5") == 0 ){  /* 8 Feb 2019 [rickr] */
-       mri_warp3D_method( MRI_WSINC5 ); nopt++ ; continue ;
-     }
-
      /*-----*/
 
      if( strcmp(argv[nopt],"-prefix") == 0 ){
@@ -428,16 +389,10 @@ int main( int argc , char * argv[] )
            ERROR_exit("-matvec file not a 3x4 matrix!\n");
          matar = MRI_FLOAT_PTR(matim) ;
        }
-       
-       if (!strcmp(argv[nopt-1],"-matvec_in2out")) {
-         use_matvec = MATVEC_FOR;  
-       } else if (!strcmp(argv[nopt-1],"-matvec_out2in")) {
-         use_matvec = MATVEC_BAC;  
-       } else {
-         ERROR_exit( "Your -matvec option must end with either \n"
-                     "_in2out or _out2in. You have %s\n",
-                     argv[nopt-1]+7);
-       }
+
+       use_matvec = (strstr(argv[nopt-1],"_in2out") != NULL) ? 
+                        MATVEC_FOR : MATVEC_BAC ;
+
        switch( use_matvec ){
 
          case MATVEC_FOR:
@@ -489,19 +444,11 @@ int main( int argc , char * argv[] )
         oblique_flag = 1; matdefined = 1; nopt++ ; continue ;
      }
 
-     // [PT: Sep 13, 2019] show transform and exit
-     if((strncmp(argv[nopt],"-disp_obl_xform_only",20) == 0 )){
-        DISP_OBL_XFORM_ONLY = 1; nopt++ ; continue ;
-     }
-
      /*-----*/
 
-     ERROR_message("Unknown option %s\n",argv[nopt]) ;
-     suggest_best_prog_option(argv[0], argv[nopt]);
-     exit(1);
-   } /* end of loop over options */
+     ERROR_exit("Unknown option %s\n",argv[nopt]) ;
 
-   // ===============================================================
+   } /* end of loop over options */
 
    /*-- check to see if we have a warp specified --*/
 
@@ -667,12 +614,8 @@ DUMP_MAT44("Twcombined", Tw);
       }
 
       /* show overall oblique/deoblique transformation */
-      if(oblique_flag)
-         if(DISP_OBL_XFORM_ONLY || oblique_flag )
-            DUMP_MAT44("Obliquity Transformation :", Tw);
-      
-      if( DISP_OBL_XFORM_ONLY )
-         exit(0);
+      if(verb && oblique_flag)
+         DUMP_MAT44("Obliquity Transformation :", Tw);
 
       LOAD_MAT  ( dicom_in2out.mm, matar[0],matar[1],matar[2],
                                    matar[4],matar[5],matar[6],
@@ -734,9 +677,15 @@ DUMP_MAT44("Twcombined", Tw);
    }
 #endif
 
-   /* lose obliquity if using 3dWarp for any transformation */
-   /* recompute Tc (Cardinal transformation matrix for new grid output */
-   THD_make_cardinal(outset);
+   if(oblique_flag) {
+      /* recompute Tc (Cardinal transformation matrix for new grid output */
+      THD_dicom_card_xform(outset, &tmat, &tvec); 
+      LOAD_MAT44(Tc, 
+          tmat.mat[0][0], tmat.mat[0][1], tmat.mat[0][2], tvec.xyz[0],
+          tmat.mat[1][0], tmat.mat[1][1], tmat.mat[1][2], tvec.xyz[1],
+          tmat.mat[2][0], tmat.mat[2][1], tmat.mat[2][2], tvec.xyz[2]);
+      outset->daxes->ijk_to_dicom_real = Tc;
+   }
 
    tross_Copy_History( inset , outset ) ;
    tross_Make_History( "3dWarp" , argc,argv , outset ) ;
