@@ -6,6 +6,10 @@
   -- RWCox - 08 Aug 2001
 ----------------------------------------------------------------------------*/
 
+#ifndef myXtFree
+#   define myXtFree(xp) (XtFree((char *)(xp)) , (xp)=NULL)
+#endif
+
 /*-------------------------- global data --------------------------*/
 
 static THD_3dim_dataset_array * ZCAT_dsar  = NULL ;  /* input datasets */
@@ -22,8 +26,8 @@ static int                      ZCAT_frugal = 0 ;    /* 05 Apr 2006 */
 #define DSUB(id) DSET_IN_3DARR(ZCAT_dsar,(id))
 
 static char ZCAT_output_prefix[THD_MAX_PREFIX] = "zcat" ;
-static RwcBoolean write_output = False;  /* 21 Jun 2006 [dg] -force rewrite as in 3drefit by rickr */
-static RwcBoolean NIFTI_mode = False;    /* saving NIFTI output */
+static Boolean write_output = False;  /* 21 Jun 2006 [dg] -force rewrite as in 3drefit by rickr */
+static Boolean NIFTI_mode = False;    /* saving NIFTI output */
 static int cmode = COMPRESS_NOFILE;   /* check compression mode for NIFTI separately */
 
 /*--------------------------- prototypes ---------------------------*/
@@ -134,7 +138,6 @@ void ZCAT_read_opts( int argc , char * argv[] )
          ERROR_exit("Can't open dataset %s\n",argv[nopt-1]) ;
       }
       THD_force_malloc_type( dset->dblk , DATABLOCK_MEM_MALLOC ) ;
-      THD_make_cardinal(dset);    /* deoblique    21 Oct, 2011 [rickr] */
 
       if( ZCAT_type < 0 ) ZCAT_type = dset->type ;
 
@@ -217,13 +220,13 @@ void ZCAT_Syntax(void)
 int main( int argc , char * argv[] )
 {
    int ninp , ids , iv ,kz,new_nz, nx,ny,nz,nxy,nxyz ;
-   THD_3dim_dataset * new_dset=NULL , * dset=NULL ;
+   THD_3dim_dataset * new_dset=NULL , * dset ;
    THD_ivec3 iv_nxyz ;
    float * fvol , *ffac ;
    void  * svol ;
    int fscale ; FILE * data_file = NULL ;
    MRI_IMAGE *svol_im;
-   MRI_IMARR *im_array=NULL;
+   MRI_IMARR *im_array;
 
    /*** read input options ***/
 
@@ -282,8 +285,8 @@ int main( int argc , char * argv[] )
 
    /*-- open output BRIK file --*/
    /* default cmode is COMPRESS_NOFILE  unless nifti.gzip output (.nii.gz) */
-   if (cmode == COMPRESS_NOFILE) { /* ignore compression for NIFTI - do in write
-                                      automatically later */
+   if ((cmode == COMPRESS_NOFILE)) { /* ignore compression for NIFTI - do in write
+   automatically later */
       cmode = THD_get_write_compression() ; /* check env. variable for compression*/
 #if 0
       if(NIFTI_mode && (cmode!=0)) /* have to compress this NIFTI data, add .gz to prefix */
