@@ -1,76 +1,4 @@
 #include "mrilib.h"
-void usage_3dZeropad(int detail)
-{
-         printf("Usage: 3dZeropad [options] dataset ~1~\n"
- "** Adds planes of zeros to a dataset (i.e., pads it out).\n"
- "** A negative 'add' count means to cut a dataset down in size.\n"
- "   [Remember 3rd grade arithmetic, please.]\n"
- "\n"
- "Options: ~2~\n"
- "  -I n = adds 'n' planes of zero at the Inferior edge\n"
- "  -S n = adds 'n' planes of zero at the Superior edge\n"
- "  -A n = adds 'n' planes of zero at the Anterior edge\n"
- "  -P n = adds 'n' planes of zero at the Posterior edge\n"
- "  -L n = adds 'n' planes of zero at the Left edge\n"
- "  -R n = adds 'n' planes of zero at the Right edge\n"
- "  -z n = adds 'n' planes of zeros on EACH of the\n"
- "          dataset z-axis (slice-direction) faces\n"
- "\n"
- " -RL a = These options specify that planes should be added/cut\n"
- " -AP b = symmetrically to make the resulting volume have\n"
- " -IS c = 'a', 'b', and 'c' slices in the respective directions.\n"
- "\n"
- " -pad2odds = add 0 or 1 plane in each of the R/A/S directions,\n"
- "              giving each axis an odd number of slices\n"
- " -pad2evens = add 0 or 1 plane in each of the R/A/S directions,\n"
- "              giving each axis an even number of slices\n"
- " -pad2mult N = add planes in each of the R/A/S directions,\n"
- "              making each number of planes a multiple of N\n"
- "\n"
- " -mm   = pad counts 'n' are in mm instead of slices:\n"
- "         * each 'n' is an integer\n"
- "         * at least 'n' mm of slices will be added/removed:\n"
- "            n =  3 and slice thickness = 2.5 mm ==> 2 slices added\n"
- "            n = -6 and slice thickness = 2.5 mm ==> 3 slices removed\n"
- "\n"
- " -master mset = match the volume described in dataset 'mset':\n"
- "                * mset must have the same orientation and grid\n"
- "                   spacing as dataset to be padded\n"
- "                * the goal of -master is to make the output dataset\n"
- "                   from 3dZeropad match the spatial 'extents' of\n"
- "                   mset (cf. 3dinfo output) as much as possible,\n"
- "                   by adding/subtracting slices as needed.\n"
- "                * you can't use -I,-S,..., or -mm with -master\n"
- "\n"
- " -prefix ppp = write result into dataset with prefix 'ppp'\n"
- "                 [default = 'zeropad']\n"
- "\n"
- "Nota Bene: ~1~\n"
- " * You can use negative values of n to cut planes off the edges\n"
- "     of a dataset.  At least one plane must be added/removed\n"
- "     or the program won't do anything.\n"
- " * Anat parent and Talairach markers are NOT preserved in the\n"
- "     new dataset.\n"
-#if 0
- " * If the old dataset has z-slice-dependent time offsets, and\n"
- "     if new z-planes are added, all the slice-dependent time\n"
- "     offsets will be removed.\n"
-#else
- " * If the old dataset has z-slice-dependent time offsets, and\n"
- "     if new (zero filled) z-planes are added, the time offsets\n"
- "     of the new slices will be set to zero.\n"
-#endif
- " * You can use program '3dinfo' to find out how many planes\n"
- "     a dataset has in each direction.\n"
- " * Program works for byte-, short-, float-, and complex-valued\n"
- "     datasets.\n"
- " * You can use a sub-brick selector on the input dataset.\n"
- "\n"
- " Author: RWCox - July 2000\n"
-           ) ;
-      PRINT_COMPILE_DATE ; return ;
-
-}
 
 int main( int argc , char * argv[] )
 {
@@ -78,9 +6,6 @@ int main( int argc , char * argv[] )
    THD_3dim_dataset *inset , *outset ;
    int add_I=0 , add_S=0 , add_A=0 , add_P=0 , add_L=0 , add_R=0 ;
    int RLsiz=0, APsiz=0, ISsiz=0 ; /* 23 Mar 2004 */
-   int add_any=0 ;
-   /* was pad2evens, now allow none, evens, odds, mult_N = 0,1,2,3... */
-   int pad2mult=0; /* 18 Jan 2024 [rickr] */
    char * prefix="zeropad" ;
 
    int add_z=0 ;   /* 07 Feb 2001 */
@@ -90,20 +15,78 @@ int main( int argc , char * argv[] )
    THD_3dim_dataset *mset=NULL ; /* 14 May 2002 */
 
    /*-- help? --*/
+
+   if( argc < 2 || strcmp(argv[1],"-help") == 0 ){
+      printf("Usage: 3dZeropad [options] dataset\n"
+             "Adds planes of zeros to a dataset (i.e., pads it out).\n"
+             "\n"
+             "Options:\n"
+             "  -I n = adds 'n' planes of zero at the Inferior edge\n"
+             "  -S n = adds 'n' planes of zero at the Superior edge\n"
+             "  -A n = adds 'n' planes of zero at the Anterior edge\n"
+             "  -P n = adds 'n' planes of zero at the Posterior edge\n"
+             "  -L n = adds 'n' planes of zero at the Left edge\n"
+             "  -R n = adds 'n' planes of zero at the Right edge\n"
+             "  -z n = adds 'n' planes of zeros on EACH of the\n"
+             "          dataset z-axis (slice-direction) faces\n"
+             "\n"
+             " -RL a = These options specify that planes should be added/cut\n"
+             " -AP b = symmetrically to make the resulting volume have\n"
+             " -IS c = 'a', 'b', and 'c' slices in the respective directions.\n"
+             "\n"
+             " -mm   = pad counts 'n' are in mm instead of slices:\n"
+             "         * each 'n' is an integer\n"
+             "         * at least 'n' mm of slices will be added/removed:\n"
+             "            n =  3 and slice thickness = 2.5 mm ==> 2 slices added\n"
+             "            n = -6 and slice thickness = 2.5 mm ==> 3 slices removed\n"
+             "\n"
+             " -master mset = match the volume described in dataset 'mset':\n"
+             "                * mset must have the same orientation and grid\n"
+             "                   spacing as dataset to be padded\n"
+             "                * the goal of -master is to make the output dataset\n"
+             "                   from 3dZeropad match the spatial 'extents' of\n"
+             "                   mset (cf. 3dinfo output) as much as possible,\n"
+             "                   by adding/subtracting slices as needed.\n"
+             "                * you can't use -I,-S,..., or -mm with -master\n"
+             "\n"
+             " -prefix ppp = write result into dataset with prefix 'ppp'\n"
+             "                 [default = 'zeropad']\n"
+             "\n"
+             "Nota Bene:\n"
+             " * You can use negative values of n to cut planes off the edges\n"
+             "     of a dataset.  At least one plane must be added/removed\n"
+             "     or the program won't do anything.\n"
+             " * Anat parent and Talairach markers are NOT preserved in the\n"
+             "     new dataset.\n"
+#if 0
+             " * If the old dataset has z-slice-dependent time offsets, and\n"
+             "     if new z-planes are added, all the slice-dependent time\n"
+             "     offsets will be removed.\n"
+#else
+             " * If the old dataset has z-slice-dependent time offsets, and\n"
+             "     if new (zero filled) z-planes are added, the time offsets\n"
+             "     of the new slices will be set to zero.\n"
+#endif
+             " * You can use program '3dinfo' to find out how many planes\n"
+             "     a dataset has in each direction.\n"
+             " * Program works for byte-, short-, float-, and complex-valued\n"
+             "     datasets.\n"
+             " * You can use a sub-brick selector on the input dataset.\n"
+             " * 3dZeropad won't overwrite an existing dataset (I hope).\n"
+             "\n"
+             " Author: RWCox - July 2000\n"
+           ) ;
+      PRINT_COMPILE_DATE ; exit(0) ;
+   }
+
    mainENTRY("3dZeropad main"); machdep(); AFNI_logger("3dZeropad",argc,argv);
    PRINT_VERSION("3dZeropad") ;
 
    /*-- read command line options --*/
-   if( argc == 1){ usage_3dZeropad(1); exit(0); } /* Bob's help shortcut */
 
    iarg = 1 ;
    while( iarg < argc && argv[iarg][0] == '-' ){
 
-      if( strcmp(argv[iarg],"-help") == 0 || strcmp(argv[iarg],"-h") == 0){
-         usage_3dZeropad(strlen(argv[iarg])>3 ? 2:1);
-         exit(0);
-      }
-
       /*- -I, -S, etc. -*/
 
       if( strlen(argv[iarg]) == 2 ){
@@ -184,27 +167,6 @@ int main( int argc , char * argv[] )
          iarg++ ; continue ;
       }
 
-      /*- -pad2* - handle many versions of this [18 Jan 2024 rickr] -*/
-      /* todo: add -pad2mult N */
-
-      if( strcmp(argv[iarg],"-pad2odds") == 0 ){
-         pad2mult = 1 ;
-         iarg++ ; continue ;
-      }
-      if( strcmp(argv[iarg],"-pad2evens") == 0 ){
-         pad2mult = 2 ;
-         iarg++ ; continue ;
-      }
-      if( strcmp(argv[iarg],"-pad2mult") == 0 ){
-         int pad=0;
-         pad = (int)strtod(argv[++iarg],NULL) ;
-         if( pad <= 0 )
-            ERROR_exit("illegal pad2mult %d (from %s)", pad, argv[iarg]);
-	
-         pad2mult = pad ;
-         iarg++ ; continue ;
-      }
-
       /*- -prefix -*/
 
       if( strcmp(argv[iarg],"-prefix") == 0 ){
@@ -233,33 +195,23 @@ int main( int argc , char * argv[] )
         if( !ISVALID_DSET(mset) ){
           fprintf(stderr,"** 3dZeropad: Can't open -master %s\n",argv[iarg]); exit(1);
         }
-        THD_make_cardinal(mset);    /* deoblique    21 Oct, 2011 [rickr] */
          iarg++ ; continue ;
       }
 
       /*- what the hell? -*/
 
-      fprintf(stderr,"** 3dZeropad: Illegal option: %s\n",argv[iarg]) ;
-      suggest_best_prog_option(argv[0], argv[iarg]);
-      exit(1) ;
-   }
-
-   if (iarg < 2) {
-      ERROR_message("Too few options, try %s -help for details\n",argv[0]);
-      exit(1);
+      fprintf(stderr,"** 3dZeropad: Illegal option: %s\n",argv[iarg]) ; exit(1) ;
    }
 
    /*- check to see if the user asked for something, anything -*/
 
-   add_any =  add_I || add_S || add_P || add_A || add_L || add_R
-                    || add_z || RLsiz || APsiz || ISsiz ;
+   if( mset == NULL ){
+    if( add_I==0 && add_S==0 && add_P==0 &&
+        add_A==0 && add_L==0 && add_R==0 && add_z==0 &&
+        RLsiz==0 && APsiz==0 && ISsiz==0               ){
 
-   /* pad2mult should be used alone */
-   if( pad2mult && (add_any || mset) )
-      ERROR_exit("Cannot combine -pad2* with other padding or master") ;
-
-   if( mset == NULL && add_any == 0 && pad2mult == 0 ) {
       fprintf(stderr,"++ 3dZeropad: All inputs are zero? Making a copy!\n") ;
+    }
    }
 
    /* check for conflicts [23 Mar 2004] */
@@ -290,7 +242,6 @@ int main( int argc , char * argv[] )
    if( inset == NULL ){
       fprintf(stderr,"** 3dZeropad: Can't open dataset %s\n",argv[iarg]); exit(1);
    }
-   THD_make_cardinal(inset);    /* deoblique    21 Oct, 2011 [rickr] */
 
 #if 0
    if( DSET_IS_MASTERED(inset) ){
@@ -298,36 +249,6 @@ int main( int argc , char * argv[] )
    }
 #endif
 
-   /*-- if pad2mult, decide on padding         [23 Oct 2019 rickr] --*/
-   /* do not worry about nx,ny,nz, focus on RL/AP,IS                 */
-   if( pad2mult ) {
-      THD_dataxes * iax = inset->daxes ;
-      int           ndr, nda, ndi ;
-      ndr = DAXES_NUM(iax,ORI_R2L_TYPE) ;
-      nda = DAXES_NUM(iax,ORI_A2P_TYPE) ;
-      ndi = DAXES_NUM(iax,ORI_I2S_TYPE) ;
-
-      /* pad to odd */
-      if( pad2mult == 1 ) {
-         add_R = 1-(ndr % 2) ; /* same as 2even, but "negate" */
-         add_A = 1-(nda % 2) ;
-         add_I = 1-(ndi % 2) ;
-      } else if ( pad2mult == 2 ) {
-         add_R = ndr % 2 ; /* add 1 if odd */
-         add_A = nda % 2 ;
-         add_I = ndi % 2 ;
-      } else {
-         /* otherwise, we want to add the negative mod nvoxels
-            (but -v1 % m is negative, grrrrrr...) */
-         add_R = (pad2mult - (ndr % pad2mult)) % pad2mult;
-         add_A = (pad2mult - (nda % pad2mult)) % pad2mult;
-         add_I = (pad2mult - (ndi % pad2mult)) % pad2mult;
-      }
-
-      INFO_message("pad2mult %d: applying -R %d -A %d -I %d\n",
-                   pad2mult, add_R, add_A, add_I);
-   }
-
    /*-- 14 May 2002: use master dataset now? --*/
 
    if( mset != NULL ){
@@ -344,9 +265,7 @@ int main( int argc , char * argv[] )
          max->yyorient != iax->yyorient ||
          max->zzorient != iax->zzorient   ){
 
-       fprintf(stderr,
-   "** 3dZeropad: Master (%s) and Input (%s) dataset not oriented the same!\n",
-               DSET_PREFIX(mset), DSET_PREFIX(inset));
+       fprintf(stderr,"** 3dZeropad: Master and Input datasets not oriented the same!\n");
        nerr++ ;
      }
 
@@ -524,5 +443,5 @@ int main( int argc , char * argv[] )
               "** 3dZeropad: Failed to write output!\n" ) ;
       exit(1) ;
    }
-
+   
 }
