@@ -28,12 +28,17 @@
 
 /*---------------------------------------------------------------------------*/
 
+
 #include "mrilib.h"
 
+#ifndef myXtFree
+#   define myXtFree(xp) (XtFree((char *)(xp)) , (xp)=NULL)
+#endif
+
 /*-------------------------- global data --------------------------*/
 
 static THD_3dim_dataset_array * B2F_dsar  = NULL ;
-static RwcPointer_array        * B2F_subv  = NULL ;
+static XtPointer_array        * B2F_subv  = NULL ;
 static int                      B2F_nvox  = -1 ;
 static int                      B2F_verb  = 0 ;
 static int                      B2F_func_type  = -1;
@@ -163,7 +168,7 @@ int * B2F_get_subv( int nvals , char * str )
    /* No selection list ==> select it all */
 
    if( str == NULL || str[0] == '\0' ){
-      subv = (int *) RwcMalloc( sizeof(int) * (nvals+1) ) ;
+      subv = (int *) XtMalloc( sizeof(int) * (nvals+1) ) ;
       subv[0] = nvals ;
       for( ii=0 ; ii < nvals ; ii++ ) subv[ii+1] = ii ;
       return subv ;
@@ -171,7 +176,7 @@ int * B2F_get_subv( int nvals , char * str )
 
    /* skip initial '[' */
 
-   subv    = (int *) RwcMalloc( sizeof(int) * 2 ) ;
+   subv    = (int *) XtMalloc( sizeof(int) * 2 ) ;
    subv[0] = nout = 0 ;
 
    ipos = 0 ;
@@ -188,10 +193,10 @@ int * B2F_get_subv( int nvals , char * str )
          ibot = nvals-1 ; ipos++ ;
       } else {                 /* decode an integer */
          ibot = strtol( str+ipos , &cpt , 10 ) ;
-         if( ibot < 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( ibot < 0 ){ myXtFree(subv) ; return NULL ; }
          if( ibot >= nvals ) ibot = nvals-1 ;
          nused = (cpt-(str+ipos)) ;
-         if( ibot == 0 && nused == 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( ibot == 0 && nused == 0 ){ myXtFree(subv) ; return NULL ; }
          ipos += nused ;
       }
 
@@ -199,7 +204,7 @@ int * B2F_get_subv( int nvals , char * str )
 
       if( str[ipos] == ',' || str[ipos] == '\0' || str[ipos] == ']' ){
          nout++ ;
-         subv = (int *) RwcRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
+         subv = (int *) XtRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
          subv[0]    = nout ;
          subv[nout] = ibot ;
          ipos++ ; continue ;  /* re-start loop at next sub-selector */
@@ -212,7 +217,7 @@ int * B2F_get_subv( int nvals , char * str )
       } else if( str[ipos] == '.' && str[ipos+1] == '.' ){
          ipos++ ; ipos++ ;
       } else {
-         myRwcFree(subv) ; return NULL ;
+         myXtFree(subv) ; return NULL ;
       }
 
       /** get ending value for loop now **/
@@ -221,10 +226,10 @@ int * B2F_get_subv( int nvals , char * str )
          itop = nvals-1 ; ipos++ ;
       } else {                 /* decode an integer */
          itop = strtol( str+ipos , &cpt , 10 ) ;
-         if( itop < 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( itop < 0 ){ myXtFree(subv) ; return NULL ; }
          if( itop >= nvals ) itop = nvals-1 ;
          nused = (cpt-(str+ipos)) ;
-         if( itop == 0 && nused == 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( itop == 0 && nused == 0 ){ myXtFree(subv) ; return NULL ; }
          ipos += nused ;
       }
 
@@ -237,7 +242,7 @@ int * B2F_get_subv( int nvals , char * str )
       if( str[ipos] == '(' ){  /* decode an integer */
          ipos++ ;
          istep = strtol( str+ipos , &cpt , 10 ) ;
-         if( istep == 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( istep == 0 ){ myXtFree(subv) ; return NULL ; }
          nused = (cpt-(str+ipos)) ;
          ipos += nused ;
          if( str[ipos] == ')' ) ipos++ ;
@@ -247,7 +252,7 @@ int * B2F_get_subv( int nvals , char * str )
 
       for( ii=ibot ; (ii-itop)*istep <= 0 ; ii += istep ){
          nout++ ;
-         subv = (int *) RwcRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
+         subv = (int *) XtRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
          subv[0]    = nout ;
          subv[nout] = ii ;
       }
@@ -340,7 +345,6 @@ int main( int argc , char * argv[] )
   printf ("\n");
 #endif
 
-WARNING_message("This program (3dbuc2fim) is old, not maintained, and probably useless!") ;
 
    /*** read input options ***/
 
@@ -402,7 +406,7 @@ WARNING_message("This program (3dbuc2fim) is old, not maintained, and probably u
 
    /*** loop over input datasets ***/
 
-   if( ninp > 1 ) myRwcFree( new_dset->keywords ) ;
+   if( ninp > 1 ) myXtFree( new_dset->keywords ) ;
 
    ivout = 0 ;
    for( ids=0 ; ids < ninp ; ids++ ){
