@@ -36,10 +36,14 @@
 
 #include "mrilib.h"
 
+#ifndef myXtFree
+#   define myXtFree(xp) (XtFree((char *)(xp)) , (xp)=NULL)
+#endif
+
 /*-------------------------- global data --------------------------*/
 
 static THD_3dim_dataset_array * BUCK_dsar  = NULL ;
-static RwcPointer_array        * BUCK_subv  = NULL ;
+static XtPointer_array        * BUCK_subv  = NULL ;
 static int                      BUCK_nvox  = -1 ;
 static int                      BUCK_dry   = 0 ;
 static int                      BUCK_verb  = 0 ;
@@ -57,7 +61,7 @@ static char BUCK_session[THD_MAX_NAME]         = "./"   ;
 /*--------------------------- prototypes ---------------------------*/
 
 void BUCK_read_opts( int , char ** ) ;
-void BUCK_Syntax(int) ;
+void BUCK_Syntax(void) ;
 int * BUCK_get_subv( int , char * ) ;
 
 /*--------------------------------------------------------------------
@@ -79,11 +83,7 @@ void BUCK_read_opts( int argc , char * argv[] )
    INIT_XTARR(BUCK_subv) ;
 
    while( nopt < argc ){
-      if( strcmp(argv[nopt],"-help") == 0 ||
-          strcmp(argv[nopt],"-h") == 0) {
-            BUCK_Syntax(strlen(argv[nopt])>3?2:1) ;
-         exit(0);
-      }
+
       /**** -prefix prefix ****/
 
       if( strncmp(argv[nopt],"-prefix",6) == 0 ||
@@ -150,7 +150,7 @@ void BUCK_read_opts( int argc , char * argv[] )
          }
          nopt++ ;
          if( nopt >= argc ){
-            fprintf(stderr,"need argument after -glueto or -aglueto!\n") ;
+            fprintf(stderr,"need argument after -glueto or -aglueto!\n") ; 
             exit(1) ;
          }
          if (strncmp(argv[nopt-1],"-aglueto",5) == 0) { /* ZSS April 16 2010 */
@@ -285,21 +285,15 @@ void BUCK_read_opts( int argc , char * argv[] )
 	    /*----- Note: no "continue" statement here.  File name will now
 	      be processed as an input dataset -----*/
       }
-
+      
       if( argv[nopt][0] == '-' ){
-         fprintf(stderr,"Unknown option: %s\n",argv[nopt]) ;
-         suggest_best_prog_option(argv[0], argv[nopt]);
-         exit(1) ;
+         fprintf(stderr,"Unknown option: %s\n",argv[nopt]) ; exit(1) ;
       }
 
       /**** read dataset ****/
 
       cpt = strstr(argv[nopt],"[") ;
       if( cpt == NULL ){
-         if (strlen(argv[nopt]) > THD_MAX_NAME-1) {
-            ERROR_exit( "Too long a filename for '%s'\n"
-                           "Maximum limit is %d\n", argv[nopt], THD_MAX_NAME-1);
-         }
          strcpy(dname,argv[nopt]) ;
          subv[0] = '\0' ;  /* make sure subv is reset ZSS Nov. 2010*/
       } else if( cpt == argv[nopt] ){
@@ -307,32 +301,12 @@ void BUCK_read_opts( int argc , char * argv[] )
          exit(1) ;
       } else {
          ii = cpt - argv[nopt] ;
-         if (ii > THD_MAX_NAME-1) {
-            ERROR_exit( "Too long a filename for '%s'\n"
-                        "Maximum character limit is %d, have %d\\n",
-                        argv[nopt], THD_MAX_NAME-1, ii);
-         }
-         if (strlen(argv[nopt])-ii > THD_MAX_NAME-1) {
-            ERROR_exit( "Too long a sub-brick selection for '%s'\n"
-                        "Maximum limit is %d, have %d\n"
-                  "Consider using '[1dcat FF.1D]' or '[count_afni ...]' methods\n"
-                  "for sub-brick selection. See 3dTcat -help for details.\n",
-                        argv[nopt], THD_MAX_NAME-1, strlen(argv[nopt])-ii);
-         }
          memcpy(dname,argv[nopt],ii) ; dname[ii] = '\0' ;
          strcpy(subv,cpt) ;
       }
       nopt++ ;
 
       dset = THD_open_one_dataset( dname ) ;
-      /* akin to 3dTcat, handle failure in open_one
-         (todo: remove open_one from these programs)    18 Apr 2016 [rickr] */
-      if ( dset == NULL ) {
-         dset = THD_open_dataset( argv[nopt-1] ) ;
-         subv[0] = '\0'; /* use selectors via THD_O_D */
-         if( dset && BUCK_verb )
-            INFO_message("failure w/open_one_dset, success w/open_dset");
-      }
       if( dset == NULL ){
          fprintf(stderr,"can't open dataset %s\n",dname) ; exit(1) ;
       }
@@ -340,8 +314,7 @@ void BUCK_read_opts( int argc , char * argv[] )
 
       if( BUCK_type < 0 ) BUCK_type = dset->type ;
 
-      BUCK_ccode = COMPRESS_filecode(dset->dblk->diskptr->brick_name) ;
-         /* 16 Mar 2010 */
+      BUCK_ccode = COMPRESS_filecode(dset->dblk->diskptr->brick_name) ; /* 16 Mar 2010 */
 
       ii = dset->daxes->nxx * dset->daxes->nyy * dset->daxes->nzz ;
       if( BUCK_nvox < 0 ){
@@ -365,11 +338,6 @@ void BUCK_read_opts( int argc , char * argv[] )
 
    }  /* end of loop over command line arguments */
 
-   if( argc < 2) {
-      ERROR_message("Too few options");
-      BUCK_Syntax(0) ;
-      exit(1);
-   }
    return ;
 }
 
@@ -389,7 +357,7 @@ int * BUCK_get_subv( int nvals , char * str )
    /* No selection list ==> select it all */
 
    if( str == NULL || str[0] == '\0' ){
-      subv = (int *) RwcMalloc( sizeof(int) * (nvals+1) ) ;
+      subv = (int *) XtMalloc( sizeof(int) * (nvals+1) ) ;
       subv[0] = nvals ;
       for( ii=0 ; ii < nvals ; ii++ ) subv[ii+1] = ii ;
       return subv ;
@@ -397,7 +365,7 @@ int * BUCK_get_subv( int nvals , char * str )
 
    /* skip initial '[' */
 
-   subv    = (int *) RwcMalloc( sizeof(int) * 2 ) ;
+   subv    = (int *) XtMalloc( sizeof(int) * 2 ) ;
    subv[0] = nout = 0 ;
 
    ipos = 0 ;
@@ -414,10 +382,10 @@ int * BUCK_get_subv( int nvals , char * str )
          ibot = nvals-1 ; ipos++ ;
       } else {                 /* decode an integer */
          ibot = strtol( str+ipos , &cpt , 10 ) ;
-         if( ibot < 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( ibot < 0 ){ myXtFree(subv) ; return NULL ; }
          if( ibot >= nvals ) ibot = nvals-1 ;
          nused = (cpt-(str+ipos)) ;
-         if( ibot == 0 && nused == 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( ibot == 0 && nused == 0 ){ myXtFree(subv) ; return NULL ; }
          ipos += nused ;
       }
 
@@ -425,7 +393,7 @@ int * BUCK_get_subv( int nvals , char * str )
 
       if( str[ipos] == ',' || str[ipos] == '\0' || str[ipos] == ']' ){
          nout++ ;
-         subv = (int *) RwcRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
+         subv = (int *) XtRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
          subv[0]    = nout ;
          subv[nout] = ibot ;
          ipos++ ; continue ;  /* re-start loop at next sub-selector */
@@ -438,7 +406,7 @@ int * BUCK_get_subv( int nvals , char * str )
       } else if( str[ipos] == '.' && str[ipos+1] == '.' ){
          ipos++ ; ipos++ ;
       } else {
-         myRwcFree(subv) ; return NULL ;
+         myXtFree(subv) ; return NULL ;
       }
 
       /** get ending value for loop now **/
@@ -447,10 +415,10 @@ int * BUCK_get_subv( int nvals , char * str )
          itop = nvals-1 ; ipos++ ;
       } else {                 /* decode an integer */
          itop = strtol( str+ipos , &cpt , 10 ) ;
-         if( itop < 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( itop < 0 ){ myXtFree(subv) ; return NULL ; }
          if( itop >= nvals ) itop = nvals-1 ;
          nused = (cpt-(str+ipos)) ;
-         if( itop == 0 && nused == 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( itop == 0 && nused == 0 ){ myXtFree(subv) ; return NULL ; }
          ipos += nused ;
       }
 
@@ -463,7 +431,7 @@ int * BUCK_get_subv( int nvals , char * str )
       if( str[ipos] == '(' ){  /* decode an integer */
          ipos++ ;
          istep = strtol( str+ipos , &cpt , 10 ) ;
-         if( istep == 0 ){ myRwcFree(subv) ; return NULL ; }
+         if( istep == 0 ){ myXtFree(subv) ; return NULL ; }
          nused = (cpt-(str+ipos)) ;
          ipos += nused ;
          if( str[ipos] == ')' ) ipos++ ;
@@ -473,7 +441,7 @@ int * BUCK_get_subv( int nvals , char * str )
 
       for( ii=ibot ; (ii-itop)*istep <= 0 ; ii += istep ){
          nout++ ;
-         subv = (int *) RwcRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
+         subv = (int *) XtRealloc( (char *)subv , sizeof(int) * (nout+1) ) ;
          subv[0]    = nout ;
          subv[nout] = ii ;
       }
@@ -489,12 +457,13 @@ int * BUCK_get_subv( int nvals , char * str )
 
 /*------------------------------------------------------------------*/
 
-void BUCK_Syntax(int detail)
+void BUCK_Syntax(void)
 {
    printf(
-    "Concatenate sub-bricks from input datasets into one big 'bucket' dataset. ~1~\n"
+    "Concatenate sub-bricks from input datasets into one big\n"
+    "'bucket' dataset.\n"
     "Usage: 3dbucket options\n"
-    "where the options are: ~1~\n"
+    "where the options are:\n"
    ) ;
 
    printf(
@@ -540,7 +509,6 @@ void BUCK_Syntax(int detail)
  "can select every third sub-brick by using the selection list\n"
  "  fred+orig[0..$(3)]\n"
  "\n"
- "Notes: ~1~\n"
  "N.B.: The sub-bricks are output in the order specified, which may\n"
  " not be the order in the original datasets.  For example, using\n"
  "  fred+orig[0..$(2),1..$(2)]\n"
@@ -567,15 +535,14 @@ void BUCK_Syntax(int detail)
  " calling the output dataset C, you would type\n"
  "    3dbucket -prefix C -fbuc 'A+orig[0]' -fbuc 'B+orig[1]'\n"
  "\n"
- "WARNING: ~1~\n"
- "         Using this program, it is possible to create a dataset that\n"
+ "WARNING: using this program, it is possible to create a dataset that\n"
  "         has different basic datum types for different sub-bricks\n"
  "         (e.g., shorts for brick 0, floats for brick 1).\n"
  "         Do NOT do this!  Very few AFNI programs will work correctly\n"
  "         with such datasets!\n"
    ) ;
 
-   PRINT_COMPILE_DATE ; return ;
+   PRINT_COMPILE_DATE ; exit(0) ;
 }
 
 /*------------------------------------------------------------------*/
@@ -585,7 +552,6 @@ int main( int argc , char * argv[] )
    int ninp , ids , nv , iv,jv,kv , ivout , new_nvals , have_fdr = 0, nfdr = 0 ;
    THD_3dim_dataset * new_dset=NULL , * dset ;
    char buf[256] ;
-   double angle;
 
    /*----- identify program -----*/
 #if 0
@@ -595,9 +561,9 @@ int main( int argc , char * argv[] )
 
    /*** read input options ***/
 
+   if( argc < 2 || strncmp(argv[1],"-help",4) == 0 ) BUCK_Syntax() ;
 
    mainENTRY("3dbucket main"); machdep(); PRINT_VERSION("3dbucket") ;
-   set_obliquity_report(0); /* silence obliquity */
 
    /*-- 20 Apr 2001: addto the arglist, if user wants to [RWCox] --*/
 
@@ -632,14 +598,6 @@ int main( int argc , char * argv[] )
        fprintf(stderr,"++ WARNING: %s grid mismatch with %s\n",
                DSET_BRIKNAME(DSUB(0)) , DSET_BRIKNAME(DSUB(iv)) ) ;
      if( DSUB(iv)->dblk->brick_fdrcurve ) have_fdr = 1 ;
-     /* allow for small angle differences   22 May 2015 [rickr] */
-     angle = dset_obliquity_angle_diff(new_dset, DSUB(iv), OBLIQ_ANGLE_THRESH);
-     if (angle > 0.0) {
-       WARNING_message(
-          "dataset %s has an obliquity difference of %f degrees with %s\n",
-          new_dset ,
-          angle, DSUB(iv) );
-     }
    }
 
    /*  if( ninp == 1 ) */   tross_Copy_History( DSUB(0) , new_dset ) ;
@@ -687,7 +645,7 @@ int main( int argc , char * argv[] )
 
    /*** loop over input datasets ***/
 
-   if( ninp > 1 ) myRwcFree( new_dset->keywords ) ;
+   if( ninp > 1 ) myXtFree( new_dset->keywords ) ;
 
    ivout = 0 ;
    for( ids=0 ; ids < ninp ; ids++ ){
@@ -697,6 +655,7 @@ int main( int argc , char * argv[] )
       if( ! BUCK_dry ){
          DSET_load(dset) ;  CHECK_LOAD_ERROR(dset) ;
       }
+
       /** loop over sub-bricks to output **/
 
       for( iv=0 ; iv < nv ; iv++ ){
@@ -707,7 +666,7 @@ int main( int argc , char * argv[] )
                                    DSET_BRICK_TYPE(dset,jv) , DSET_ARRAY(dset,jv) ) ;
 
             /*----- preserve label when one exists --- Modified March 2010 ZSS*/
-            if (DSET_HAS_LABEL(dset, jv) )
+            if (DSET_HAS_LABEL(dset, jv) ) 
               sprintf (buf, "%s", DSET_BRICK_LABEL(dset,jv));
             else
               sprintf(buf,"%.12s[%d]",DSET_PREFIX(dset),jv) ;
@@ -833,8 +792,7 @@ int main( int argc , char * argv[] )
       if( BUCK_glue ) putenv("AFNI_DECONFLICT=OVERWRITE") ;
       if( BUCK_glue && BUCK_ccode >= 0 )
         THD_set_write_compression(BUCK_ccode) ; /* 16 Mar 2010 */
-      if ( ! THD_write_3dim_dataset( NULL,NULL , new_dset , True ) )
-         exit(1) ;
+      THD_write_3dim_dataset( NULL,NULL , new_dset , True ) ;
       if( BUCK_verb ) fprintf(stderr,"-verb: wrote output: %s\n",DSET_BRIKNAME(new_dset)) ;
    }
 
