@@ -46,6 +46,7 @@
 
 #define SO_BIG 33333
 
+#include "afni.h"
 #include "mrilib.h"
 #include "ts.h"
 #include "afni_pcor.c"
@@ -64,9 +65,9 @@ THD_3dim_dataset * fim3d_fimmer_compute ( THD_3dim_dataset * dset_time ,
    float max_percent        /* 19 May 1997 */ ) 
 {
    THD_3dim_dataset * new_dset ;
-   int ifim , it,iv , nvox=0 , ngood_ref , ntime , it1 , dtyp , nxyz;
+   int ifim , it,iv , nvox , ngood_ref , ntime , it1 , dtyp , nxyz;
    float * vval , * tsar , * aval , * rbest , * abest ;
-   int   * indx=NULL ;
+   int   * indx ;
    short * bar ;
    void  * ptr ;
    float stataux[MAX_STAT_AUX];
@@ -76,7 +77,7 @@ THD_3dim_dataset * fim3d_fimmer_compute ( THD_3dim_dataset * dset_time ,
    PCOR_voxel_corr ** pc_vc ;
    int save_resam ;
 
-   int fim_nref , nx_ort , ny_ort=0 , internal_ort ;    /* 10 Dec 1996 */
+   int fim_nref , nx_ort , ny_ort , internal_ort ;    /* 10 Dec 1996 */
    static float * ref_vec = NULL ;
    static int    nref_vec = -666 ;
 
@@ -708,6 +709,7 @@ void get_line_opt( int argc , char *argv[] , line_opt *opt )
    time_series *ideal;
    time_series *ort;
    char err_note[128];
+   Boolean ok;
    char input_filename[THD_MAX_NAME];
 
 
@@ -861,9 +863,8 @@ void get_line_opt( int argc , char *argv[] , line_opt *opt )
          opt->dset = THD_open_one_dataset( argv[nopt] ) ;
          if( opt->dset == NULL ) 
          {
-            fprintf(stderr, "\n** Unable to open 3d+time data file: %s\n",
-                    argv[nopt]);
-            Syntax ("input dataset open failure");
+            sprintf (err_note, "Unable to open 3d+time data file: %s", argv[nopt]);
+            Syntax (err_note); 
          }
          continue ;
       }
@@ -973,7 +974,7 @@ int main( int argc , char *argv[] )
 {
    line_opt  opt ;               /* holds data constructed from command line */
    THD_3dim_dataset * new_dset;  /* functional data set to be calculated */
-   RwcBoolean ok;                   /* true if 3d write is successful */
+   Boolean ok;                   /* true if 3d write is successful */
    
 
    /*----- Identify software -----*/
@@ -989,8 +990,6 @@ int main( int argc , char *argv[] )
    PRINT_VERSION("3dfim") ; AUTHOR(PROGRAM_AUTHOR) ;
    mainENTRY("3dfim main") ; machdep() ;
 
-WARNING_message("This program (3dfim) is very old, may not be useful, and will not be maintained.") ;
-
    /*-- 20 Apr 2001: addto the arglist, if user wants to [RWCox] --*/
 
    { int new_argc ; char ** new_argv ;
