@@ -16,7 +16,7 @@ static int mpv_sign_meth = 0 ;
 int main( int argc , char *argv[] )
 {
    THD_3dim_dataset *inset=NULL ;
-   byte *mask=NULL ; int mask_nx=0,mask_ny=0,mask_nz=0 , automask=0 , masknum=0 ;
+   byte *mask=NULL ; int mask_nx,mask_ny,mask_nz , automask=0 , masknum ;
    int iarg=1 , verb=1 , ntype=0 , nev,kk,ii,nxyz,nt ;
    float na,nb,nc , dx,dy,dz ;
    MRI_IMARR *imar=NULL ; int *ivox ; MRI_IMAGE *pim ;
@@ -85,7 +85,7 @@ int main( int argc , char *argv[] )
        " a csh shell script like the one below:\n"
        "\n"
        " # Compute the individual SVD vectors\n"
-       " foreach mm ( `count_afni 1 77` )\n"
+       " foreach mm ( `count 1 77` )\n"
        "   3dmaskSVD -vnorm -mask mymask+orig\"<${mm}..${mm}>\" epi+orig > qvec${mm}.1D\n"
        " end\n"
        " # Glue them together into 1 big file, then delete the individual files\n"
@@ -139,10 +139,8 @@ int main( int argc , char *argv[] )
      }
 
      if( strcmp(argv[iarg],"-polort") == 0 ){
-       char *qpt ;
        if( ++iarg >= argc ) ERROR_exit("Need argument after '-polort'") ;
-       polort = (int)strtod(argv[iarg],&qpt) ;
-       if( *qpt != '\0' ) WARNING_message("Illegal non-numeric value after -polort") ;
+       polort = (int)strtod(argv[iarg],NULL) ;
        iarg++ ; continue ;
      }
 
