@@ -27,136 +27,6 @@ static float max_float( int n , float *x )   /* 24 Feb 2005 */
    for( i=1 ; i < n ; i++ ) if( m < x[i] ) m = x[i] ;
    return m ;
 }
-void usage_3dmaskave(int detail) {
-        printf(
-"Usage: 3dmaskave [options] inputdataset\n"
-"\n"
-"Computes average of all voxels in the input dataset\n"
-"which satisfy the criterion in the options list.\n"
-"If no options are given, then all voxels are included.\n"
-"\n"                         /* examples: 13 Mar 2006 [rickr] */
-"----------------------------------------------------------------\n"
-"Examples:\n"
-"\n"
-"1. compute the average timeseries in epi_r1+orig, over voxels\n"
-"   that are set (any non-zero value) in the dataset, ROI+orig:\n"
-"\n"
-"    3dmaskave -mask ROI+orig epi_r1+orig\n"
-"\n"
-"2. restrict the ROI to values of 3 or 4, and save (redirect)\n"
-"   the output to the text file run1_roi_34.txt:\n"
-"\n"
-"    3dmaskave -mask ROI+orig -quiet -mrange 3 4   \\\n"
-"              epi_r1+orig > run1_roi_34.txt\n"
-"\n"
-"3. Extract the time series from a single voxel with given\n"
-"   spatial indexes (e.g., for use with 3dTcorr1D):\n"
-"\n"
-"    3dmaskave -quiet -ibox 40 30 20 epi_r1+orig > r1_40_30_20.1D\n"
-"----------------------------------------------------------------\n"
-"\n"
-"Options:\n"
-"  -mask mset   Means to use the dataset 'mset' as a mask:\n"
-"                 Only voxels with nonzero values in 'mset'\n"
-"                 will be averaged from 'dataset'.  Note\n"
-"                 that the mask dataset and the input dataset\n"
-"                 must have the same number of voxels.\n"
-"               SPECIAL CASE: If 'mset' is the string 'SELF',\n"
-"                             then the input dataset will be\n"
-"                             used to mask itself.  That is,\n"
-"                             only nonzero voxels from the\n"
-"                             #miv sub-brick will be used.\n"
-"\n"
-"  -mindex miv  Means to use sub-brick #'miv' from the mask\n"
-"                 dataset.  If not given, miv=0.\n"
-"  -mrange a b  Means to further restrict the voxels from\n"
-"                 'mset' so that only those mask values\n"
-"                 between 'a' and 'b' (inclusive) will\n"
-"                 be used.  If this option is not given,\n"
-"                 all nonzero values from 'mset' are used.\n"
-"                 Note that if a voxel is zero in 'mset', then\n"
-"                 it won't be included, even if a < 0 < b.\n"
-"                   [-mindex and -mrange are old options that predate]\n"
-"                   [the introduction of the sub-brick selector '[]' ]\n"
-"                   [and the sub-range value selector '<>' to AFNI.  ]\n"
-"\n"
-"  -xbox x y z     } These options are the same as in\n"
-"  -dbox x y z     } program 3dmaskdump:\n"
-"  -nbox x y z     } They create a mask by putting down boxes\n"
-"  -ibox x y z     } or balls (filled spheres) at the specified\n"
-"  -xball x y z r  } locations.  See the output of\n"
-"  -dball x y z r  }   3dmaskdump -help\n"
-"  -nball x y z r  } for the gruesome and tedious details.\n"
-"   https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dmaskdump.html\n"
-"\n"
-"  -dindex div  Means to use sub-brick #'div' from the inputdataset.\n"
-"                 If not given, all sub-bricks will be processed.\n"
-"  -drange a b  Means to only include voxels from the inputdataset whose\n"
-"                 values fall in the range 'a' to 'b' (inclusive).\n"
-"                 Otherwise, all voxel values are included.\n"
-"                   [-dindex and -drange are old options that predate]\n"
-"                   [the introduction of the sub-brick selector '[]' ]\n"
-"                   [and the sub-range value selector '<>' to AFNI.  ]\n"
-"\n"
-"  -slices p q  Means to only included voxels from the inputdataset\n"
-"                 whose slice numbers are in the range 'p' to 'q'\n"
-"                 (inclusive).  Slice numbers range from 0 to\n"
-"                 NZ-1, where NZ can be determined from the output\n"
-"                 of program 3dinfo.  The default is to include\n"
-"                 data from all slices.\n"
-"                   [There is no provision for geometrical voxel]\n"
-"                   [selection except in the slice (z) direction]\n"
-"\n"
-"  -sigma       Means to compute the standard deviation in addition\n"
-"                 to the mean.\n"
-"  -sum         Means to compute the sum instead of the mean.\n"
-"  -sumsq       Means to compute the sum of squares instead of the mean.\n"
-"  -enorm       Means to compute the Euclidean norm instead of the mean.\n"
-"               This is the sqrt() of the sumsq result.\n"
-"  -median      Means to compute the median instead of the mean.\n"
-"  -max         Means to compute the max instead of the mean.\n"
-"  -min         Means to compute the min instead of the mean.\n"
-"                 [-sigma is ignored with -sum, -median, -max, or -min.]\n"
-"                 [the last given of -sum, -median, -max, or -min wins.]\n"
-"  -perc XX     Means to compute the XX-th percentile value (min=0 max=100).\n"
-"               XX should be an integer from 0 to 100.\n"
-"  -dump        Means to print out all the voxel values that\n"
-"                 go into the result.\n"
-"  -udump       Means to print out all the voxel values that\n"
-"                 go into the average, UNSCALED by any internal\n"
-"                 factors.\n"
-"                 N.B.: the scale factors for a sub-brick\n"
-"                       can be found using program 3dinfo.\n"
-"  -indump      Means to print out the voxel indexes (i,j,k) for\n"
-"                 each dumped voxel.  Has no effect if -dump\n"
-"                 or -udump is not also used.\n"
-"                 N.B.: if nx,ny,nz are the number of voxels in\n"
-"                       each direction, then the array offset\n"
-"                       in the brick corresponding to (i,j,k)\n"
-"                       is i+j*nx+k*nx*ny.\n"
-" -q     or\n"
-" -quiet        Means to print only the minimal numerical result(s).\n"
-"               This is useful if you want to create a *.1D file,\n"
-"               without any extra text; for example:\n"
-"                 533.814 [18908 voxels]   ==   'normal' output\n"
-"                 533.814                  ==   'quiet' output\n"
-"\n"
-"The output is printed to stdout (the terminal), and can be\n"
-"saved to a file using the usual redirection operation '>'.\n"
-"\n"
-"Or you can do fun stuff like\n"
-"  3dmaskave -q -mask Mfile+orig timefile+orig | 1dplot -stdin -nopush\n"
-"to pipe the output of 3dmaskave into 1dplot for graphing.\n"
-"\n"
-"-- Author: RWCox\n"
-            ) ;
-
-      printf("\n" MASTER_SHORTHELP_STRING ) ;
-
-      PRINT_COMPILE_DATE ; 
-   
-   return;
-}
 
 /*-----------------------------------------------------------------------
   A quickie.  (Not so quick any more, with all the options added.)
@@ -173,15 +43,12 @@ int main( int argc , char * argv[] )
    int div = -1 , div_bot,div_top , drange=0; /* 16 Sep 1998 */
    float data_bot=666.0 , data_top=-666.0 ;
    int indump = 0 ;                           /* 19 Aug 1999 */
-   int pslice=-1 , qslice=-1 , nxy=0,nz=0 ;       /* 15 Sep 1999 */
+   int pslice=-1 , qslice=-1 , nxy,nz ;       /* 15 Sep 1999 */
    int quiet=0 ;                              /* 23 Nov 1999 */
 
    int medianit = 0 ;                         /* 06 Jul 2003 */
    int maxit    = 0 ;                         /* 24 Feb 2005 */
    int minit    = 0 ;                         /* 25 Feb 2005 */
-   int sumit    = 0 ;                         /* 15 Jun 2011 */
-   int sumsqit  = 0 , enormit  = 0 ;          /* 16 Apr 2013 */
-   int percit   = 0 ; float perc = 0.0f ;     /* 21 Jun 2016 */
    float *exar ;                              /* 06 Jul 2003 */
    char *sname = "Average" ;                  /* 06 Jul 2003 */
    int self_mask = 0 ;                        /* 06 Dec 2004 */
@@ -189,17 +56,113 @@ int main( int argc , char * argv[] )
    int    boxball_num=0 ;                     /* 09 Sep 2009 */
    float *boxball_dat=NULL ;
 
+   if( argc < 2 || strcmp(argv[1],"-help") == 0 ){
+      printf("Usage: 3dmaskave [options] dataset\n"
+             "\n"
+             "Computes average of all voxels in the input dataset\n"
+             "which satisfy the criterion in the options list.\n"
+             "If no options are given, then all voxels are included.\n"
+             "\n"                         /* examples: 13 Mar 2006 [rickr] */
+             "------------------------------------------------------------\n"
+             "Examples:\n"
+             "\n"
+             "1. compute the average timeseries in epi_r1+orig, over voxels\n"
+             "   that are set (any non-zero value) in the dataset, ROI+orig:\n"
+             "\n"
+             "    3dmaskave -mask ROI+orig epi_r1+orig\n"
+             "\n"
+             "2. restrict the ROI to values of 3 or 4, and save (redirect)\n"
+             "   the output to the text file run1_roi_34.txt:\n"
+             "\n"
+             "    3dmaskave -mask ROI+orig -quiet -mrange 3 4   \\\n"
+             "              epi_r1+orig > run1_roi_34.txt\n"
+             "------------------------------------------------------------\n"
+             "\n"
+             "Options:\n"
+             "  -mask mset   Means to use the dataset 'mset' as a mask:\n"
+             "                 Only voxels with nonzero values in 'mset'\n"
+             "                 will be averaged from 'dataset'.  Note\n"
+             "                 that the mask dataset and the input dataset\n"
+             "                 must have the same number of voxels.\n"
+             "               SPECIAL CASE: If 'mset' is the string 'SELF',\n"
+             "                             then the input dataset will be\n"
+             "                             used to mask itself.  That is,\n"
+             "                             only nonzero voxels from the\n"
+             "                             #miv sub-brick will be used.\n"
+             "  -mindex miv  Means to use sub-brick #'miv' from the mask\n"
+             "                 dataset.  If not given, miv=0.\n"
+             "  -mrange a b  Means to further restrict the voxels from\n"
+             "                 'mset' so that only those mask values\n"
+             "                 between 'a' and 'b' (inclusive) will\n"
+             "                 be used.  If this option is not given,\n"
+             "                 all nonzero values from 'mset' are used.\n"
+             "                 Note that if a voxel is zero in 'mset', then\n"
+             "                 it won't be included, even if a < 0 < b.\n"
+             "\n"
+             "  -xbox x y z     } These options are the same as in\n"
+             "  -dbox x y z     } program 3dmaskdump:\n"
+             "  -nbox x y z     } They create a mask by putting down boxes\n"
+             "  -ibox x y z     } or balls (filled spheres) at the specified\n"
+             "  -xball x y z r  } locations.  See the output of\n"
+             "  -dball x y z r  }   3dmaskdump -help\n"
+             "  -nball x y z r  } for the gruesome and tedious details.\n"
+             "   http://afni.nimh.nih.gov/pub/dist/doc/program_help/3dmaskdump.html\n"
+             "\n"
+             "  -dindex div  Means to use sub-brick #'div' from the dataset.\n"
+             "                 If not given, all sub-bricks will be processed.\n"
+             "  -drange a b  Means to only include voxels from the dataset whose\n"
+             "                 values fall in the range 'a' to 'b' (inclusive).\n"
+             "                 Otherwise, all voxel values are included.\n"
+             "\n"
+             "  -slices p q  Means to only included voxels from the dataset\n"
+             "                 whose slice numbers are in the range 'p' to 'q'\n"
+             "                 (inclusive).  Slice numbers range from 0 to\n"
+             "                 NZ-1, where NZ can be determined from the output\n"
+             "                 of program 3dinfo.  The default is to include\n"
+             "                 data from all slices.\n"
+             "                 [There is no provision for geometrical voxel]\n"
+             "                 [selection except in the slice (z) direction]\n"
+             "\n"
+             "  -sigma       Means to compute the standard deviation as well\n"
+             "                 as the mean.\n"
+             "  -median      Means to compute the median instead of the mean.\n"
+             "  -max         Means to compute the max instead of the mean.\n"
+             "  -min         Means to compute the min instead of the mean.\n"
+             "                 (-sigma is ignored with -median, -max, or -min)\n"
+             "  -dump        Means to print out all the voxel values that\n"
+             "                 go into the average.\n"
+             "  -udump       Means to print out all the voxel values that\n"
+             "                 go into the average, UNSCALED by any internal\n"
+             "                 factors.\n"
+             "                 N.B.: the scale factors for a sub-brick\n"
+             "                       can be found using program 3dinfo.\n"
+             "  -indump      Means to print out the voxel indexes (i,j,k) for\n"
+             "                 each dumped voxel.  Has no effect if -dump\n"
+             "                 or -udump is not also used.\n"
+             "                 N.B.: if nx,ny,nz are the number of voxels in\n"
+             "                       each direction, then the array offset\n"
+             "                       in the brick corresponding to (i,j,k)\n"
+             "                       is i+j*nx+k*nx*ny.\n"
+             " -q     or\n"
+             " -quiet        Means to print only the minimal results.\n"
+             "               This is useful if you want to create a *.1D file.\n"
+             "\n"
+             "The output is printed to stdout (the terminal), and can be\n"
+             "saved to a file using the usual redirection operation '>'.\n"
+            ) ;
+
+      printf("\n" MASTER_SHORTHELP_STRING ) ;
+
+      PRINT_COMPILE_DATE ; exit(0) ;
+   }
+
    mainENTRY("3dmaskave main"); machdep(); AFNI_logger("3dmaskave",argc,argv);
    PRINT_VERSION("3dmaskave") ;
 
    /* scan argument list */
-   if (argc == 1) { usage_3dmaskave(1); exit(0); } /* Bob's help shortcut */
+
    narg = 1 ;
    while( narg < argc && argv[narg][0] == '-' ){
-      if (strcmp(argv[narg], "-h") == 0 || strcmp(argv[narg], "-help") == 0) {
-         usage_3dmaskave(strlen(argv[narg]) > 3 ? 2:1);
-         exit(0);
-      }
 
       if( strcmp(argv[narg]+2,"box")  == 0 ||    /* 09 Sep 2009 */
           strcmp(argv[narg]+2,"ball") == 0   ){
@@ -330,83 +293,26 @@ int main( int argc , char * argv[] )
       }
 
       if( strncmp(argv[narg],"-median",5) == 0 ){
-         medianit = 1 ; maxit = 0 ; minit = 0 ; sumit = 0 ;
-                        sumsqit = 0 ; enormit = 0 ; percit = 0 ;
+         medianit = 1 ; maxit = 0 ; minit = 0 ;
          narg++ ; continue ;
       }
 
-      if( strncmp(argv[narg],"-perc",5) == 0 ){
-        if( narg+1 > argc ) ERROR_exit("need argument after '-perc'") ;
-        perc = (float)strtod(argv[++narg],NULL) ;
-        if( perc < 0.0f || perc > 100.0f )
-          ERROR_exit("'-perc %s' is not legal [range is 0..100]",argv[narg]) ;
-        if( perc == 0.0f ){
-          WARNING_message("'-perc 0' is the same as '-min'") ;
-          maxit = 0 ; medianit = 0 ; minit = 1 ; sumit = 0 ;
-                      sumsqit = 0 ; enormit = 0 ; percit = 0 ;
-        } else if( perc == 100.0f ){
-          WARNING_message("'-perc 100' is the same as '-max'") ;
-          maxit = 1 ; medianit = 0 ; minit = 0 ; sumit = 0 ;
-                      sumsqit = 0 ; enormit = 0 ; percit = 0 ;
-        } else if( perc == 50.0f ){
-          WARNING_message("'-perc 50' is the same as '-median'") ;
-          maxit = 0 ; medianit = 1 ; minit = 0 ; sumit = 0 ;
-                      sumsqit = 0 ; enormit = 0 ; percit = 0 ;
-        } else {
-          maxit = 0 ; medianit = 0 ; minit = 0 ; sumit = 0 ;
-                      sumsqit = 0 ; enormit = 0 ;
-          percit = 1 ;
-        }
-        narg++ ; continue ;
-      }
-
       if( strncmp(argv[narg],"-max",4) == 0 ){  /* 24 Feb 2005 */
-         maxit = 1 ; medianit = 0 ; minit = 0 ; sumit = 0 ;
-                     sumsqit = 0 ; enormit = 0 ; percit = 0 ;
+         maxit = 1 ; medianit = 0 ; minit = 0 ;
          narg++ ; continue ;
       }
 
-      if( strcmp(argv[narg],"-sum") == 0 ){  /* 15 Jun 2011, P.S. no strncmp */
-        sumit = 1 ; maxit = medianit = minit = 0 ; percit = 0 ;
-        narg++ ; continue ;
-      }
-
-      if( strcmp(argv[narg],"-sumsq") == 0 ){  /* 16 Apr 2013 [rickr] */
-        sumsqit = 1 ; sumit = maxit = medianit = minit = 0 ; percit = 0 ;
-        narg++ ; continue ;
-      }
-
-      if( strcmp(argv[narg],"-enorm") == 0 ){  /* 16 Apr 2013 [rickr] */
-        /* enorm implies sumsq, since enorm just takes sqrt */
-        enormit = sumsqit = 1 ; sumit = maxit = medianit = minit = 0 ; percit = 0 ;
-        narg++ ; continue ;
-      }
-
       if( strncmp(argv[narg],"-min",4) == 0 ){  /* 25 Feb 2005 */
-         maxit = 0 ; medianit = 0 ; minit = 1 ; sumit = 0 ;
-                     sumsqit = 0 ; enormit = 0 ; percit = 0 ;
+         maxit = 0 ; medianit = 0 ; minit = 1 ;
          narg++ ; continue ;
       }
 
-      fprintf(stderr,"*** Unknown option: %s\n",argv[narg]) ; 
-      suggest_best_prog_option(argv[0], argv[narg]);
-      exit(1) ;
+      fprintf(stderr,"*** Unknown option: %s\n",argv[narg]) ; exit(1) ;
    }
-   
-   if (argc < 2) {
-      ERROR_message("Too few options, use -help option for details");
-      exit(1);
-   }
-   
+
    if( medianit ){ sigmait = 0; sname = "Median"; }
    if( maxit    ){ sigmait = 0; sname = "Max"   ; } /* 24 Feb 2005 */
    if( minit    ){ sigmait = 0; sname = "Min"   ; } /* 25 Feb 2005 */
-   if( sumit    ){ sigmait = 0; sname = "Sum"   ; } /* 15 Jun 2011 */
-   if( sumsqit  ){ sigmait = 0; sname = "Sumsq" ; } /* 16 Apr 2013 */
-   if( enormit  ){ sigmait = 0; sname = "Enorm" ; } /* 16 Apr 2013 */
-   if( percit   ){ sigmait = 0;
-                   sname   = (char *)malloc(sizeof(char)*16) ;
-                   sprintf(sname,"Perc%02d",(int)rintf(perc)) ; }
 
    /* should have one more argument */
 
@@ -469,13 +375,6 @@ int main( int argc , char * argv[] )
    }
 
    if( mask_dset != NULL ){
-      if( !EQUIV_GRIDS(mask_dset,input_dset) )
-         WARNING_message("Input dataset %s grid mismatch from mask.\n"
-             "Try the following command for grid comparison:\n"
-             " 3dinfo -header_line -prefix -same_all_grid %s %s\n"
-             ,argv[narg], 
-             DSET_HEADNAME(mask_dset), DSET_HEADNAME(input_dset)) ;
-
       if( DSET_NVOX(mask_dset) != nvox ){
         fprintf(stderr,"*** Input and mask datasets are not same dimensions!\n") ;
         exit(1) ;
@@ -520,8 +419,7 @@ int main( int argc , char * argv[] )
             }
           } else {
             mbot = 0 ;
-            // [PT: Dec 22, 2020] Thanks for the fix here, C Rorden!
-            mtop = (byte) MRI_TYPE_maxval[MRI_byte] ; 
+            mtop = (byte) MRI_TYPE_maxval[MRI_short] ;
           }
           for( mcount=0,ii=0 ; ii < nvox ; ii++ )
             if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 ){ mmm[ii] = 1 ; mcount++ ; }
@@ -655,34 +553,18 @@ int main( int argc , char * argv[] )
             }
 
             for( ii=mc=0 ; ii < nvox ; ii++ )
-               if( GOOD(ii) ){
-                  if( sumsqit ) sum += bar[ii]*bar[ii] ;
-                  else          sum += bar[ii] ;
-                  exar[mc++] = bar[ii] ;
-               }
+               if( GOOD(ii) ){ sum += bar[ii] ; exar[mc++] = bar[ii] ; }
             if( mc > 0 ) sum = sum / mc ;
 
             if( sigmait && mc > 1 ){
                for( ii=0 ; ii < nvox ; ii++ ) if( GOOD(ii) ) sigma += SQR(bar[ii]-sum) ;
                sigma = mfac * sqrt( sigma/(mc-1) ) ;
             }
-
                  if( medianit ) sum = qmed_float( mc , exar ) ;
             else if( maxit    ) sum = max_float ( mc , exar ) ;
             else if( minit    ) sum = min_float ( mc , exar ) ;
-            else if( sumit    ) sum *= mc ;
-            else if( sumsqit  ) sum *= mc*mfac ; /* and include extra mfac */
-            else if( percit   ){
-              float *qar=(float *)malloc(sizeof(float)*mc) ; int iq ;
-              memcpy(qar,exar,sizeof(float)*mc) ;
-              qsort_float(mc,qar) ;
-              iq = (int)rintf(0.01f*perc*mc) ; sum = qar[iq] ; free(qar) ;
-            }
-
             sum = mfac * sum ;
 
-            if( enormit ) sum = sqrt( sum ) ;
-
             if( dumpit ) printf("+++ %s = %g",sname,sum) ;
             else         printf("%g",sum) ;
 
@@ -718,11 +600,7 @@ int main( int argc , char * argv[] )
             }
 
             for( ii=mc=0 ; ii < nvox ; ii++ )
-               if( GOOD(ii) ){
-                  if( sumsqit ) sum += bar[ii]*bar[ii] ;
-                  else          sum += bar[ii] ;
-                  exar[mc++] = bar[ii] ;
-               }
+               if( GOOD(ii) ){ sum += bar[ii] ; exar[mc++] = bar[ii] ; }
             if( mc > 0 ) sum = sum / mc ;
 
             if( sigmait && mc > 1 ){
@@ -732,18 +610,8 @@ int main( int argc , char * argv[] )
                  if( medianit ) sum = qmed_float( mc , exar ) ;
             else if( maxit    ) sum = max_float ( mc , exar ) ;
             else if( minit    ) sum = min_float ( mc , exar ) ;
-            else if( sumit    ) sum *= mc ;
-            else if( sumsqit  ) sum *= mc*mfac ; /* and include extra mfac */
-            else if( percit   ){
-              float *qar=(float *)malloc(sizeof(float)*mc) ; int iq ;
-              memcpy(qar,exar,sizeof(float)*mc) ;
-              qsort_float(mc,qar) ;
-              iq = (int)rintf(0.01f*perc*mc) ; sum = qar[iq] ; free(qar) ;
-            }
             sum = mfac * sum ;
 
-            if( enormit ) sum = sqrt( sum ) ;
-
             if( dumpit ) printf("+++ %s = %g",sname,sum) ;
             else         printf("%g",sum) ;
 
@@ -779,11 +647,7 @@ int main( int argc , char * argv[] )
             }
 
             for( ii=mc=0 ; ii < nvox ; ii++ )
-               if( GOOD(ii) ){
-                  if( sumsqit ) sum += bar[ii]*bar[ii] ;
-                  else          sum += bar[ii] ;
-                  exar[mc++] = bar[ii] ;
-               }
+               if( GOOD(ii) ){ sum += bar[ii] ; exar[mc++] = bar[ii] ; }
             if( mc > 0 ) sum = sum / mc ;
 
             if( sigmait && mc > 1 ){
@@ -793,18 +657,8 @@ int main( int argc , char * argv[] )
                  if( medianit ) sum = qmed_float( mc , exar ) ;
             else if( maxit    ) sum = max_float ( mc , exar ) ;
             else if( minit    ) sum = min_float ( mc , exar ) ;
-            else if( sumit    ) sum *= mc ;
-            else if( sumsqit  ) sum *= mc*mfac ; /* and include extra mfac */
-            else if( percit   ){
-              float *qar=(float *)malloc(sizeof(float)*mc) ; int iq ;
-              memcpy(qar,exar,sizeof(float)*mc) ;
-              qsort_float(mc,qar) ;
-              iq = (int)rintf(0.01f*perc*mc) ; sum = qar[iq] ; free(qar) ;
-            }
             sum = mfac * sum ;
 
-            if( enormit ) sum = sqrt( sum ) ;
-
             if( dumpit ) printf("+++ %s = %g",sname,sum) ;
             else         printf("%g",sum) ;
 
