@@ -37,6 +37,10 @@
 #define MAIN
 #define MEGA  1048576  /* 2^20 */
 
+#ifndef myXtFree
+#define myXtFree(xp) (XtFree((char *)(xp)) , (xp)=NULL)
+#endif
+
 #define ALLOW_SUBV  /* 21 Feb 2001 */
 
 #ifdef ALLOW_SUBV
@@ -80,7 +84,6 @@ static int   MRG_be_quiet     = 0 ;
 static int   MRG_cflag_gthr   = THFLAG_NONE ;  /* 29 Aug 1996 */
 static int   MRG_doall        = 0;             /* 02 Feb 1998 */
 static int   MRG_verbose      = 0;             /* 29 Jul 2003 */
-static int   MRG_nozero       = 0;             /* 18 Jan 2017 */
 
 static char  MRG_output_session[THD_MAX_NAME]   = "./" ;
 static char  MRG_output_prefix [THD_MAX_PREFIX] = "mrg" ;
@@ -134,12 +137,6 @@ int MRG_read_opts( int argc , char * argv[] )
          continue ;
       }
 
-      /*** 18 Jan 2017: -nozero ***/
-
-      if( strcasecmp(argv[nopt],"-nozero") == 0 ){
-        MRG_nozero = 1 ; nopt++ ; continue ;
-      }
-
       /*** 29 Jul 2003: -verbose ***/
 
       if( strncmp(argv[nopt],"-verb",5) == 0 ){
@@ -164,7 +161,7 @@ int MRG_read_opts( int argc , char * argv[] )
          MRG_ivthr = MRG_edopt.iv_thr = (int) strtod( argv[nopt++] , NULL ) ;
          continue ;
       }
-
+      
       if( strncmp(argv[nopt],"-1rank", 5) == 0) {
          MRG_rank = MRG_edopt.rank = 1;
          nopt++ ; continue;
@@ -544,9 +541,7 @@ DUMP1 ;
 
       /**** unknown switch ****/
 
-      ERROR_message("unrecognized option %s",argv[nopt]) ;
-      suggest_best_prog_option(argv[0], argv[nopt]);
-      exit(1);
+      ERROR_exit("unrecognized option %s",argv[nopt]) ;
 
    }  /* end of loop over options */
 
@@ -557,28 +552,28 @@ DUMP1 ;
       MCW_strncpy( MRG_output_label , MRG_output_prefix , THD_MAX_LABEL ) ;
    }
 #endif
-
+   
    /* if -1rank is used, pass the prefix */
    if (MRG_rank) {
       char prefix[THD_MAX_PREFIX];
       FILENAME_TO_PREFIX(MRG_output_prefix, prefix);
       if (prefix[0] == '\0') strcpy(prefix, MRG_output_prefix);
-      /*fprintf(stderr,"Prefix >>>%s<<< >>>%s<<<\n",
+      /*fprintf(stderr,"Prefix >>>%s<<< >>>%s<<<\n", 
                        MRG_output_prefix, prefix); */
       if (PREFIX_IS_NIFTI(prefix)) {
-         char *p2=NULL;
+         char *p2=NULL; 
          if (STRING_HAS_SUFFIX( prefix,".nii")) {
-            p2 = strstr( prefix, ".nii");
+            p2 = strstr( prefix, ".nii"); 
             prefix[p2- prefix]='\0';
          } else if (STRING_HAS_SUFFIX( prefix,".nii.gz")) {
             p2 = strstr( prefix, ".nii.gz");
             prefix[p2- prefix]='\0';
-         }
-      }
-      sprintf(MRG_edopt.rankmapname,"%s/%s.rankmap.1D",
+         } 
+      } 
+      sprintf(MRG_edopt.rankmapname,"%s/%s.rankmap.1D", 
                                  MRG_output_session, prefix);
    }
-
+   
    return( nopt );
 }
 
@@ -666,14 +661,11 @@ void MRG_Syntax(void)
 
    printf(
     "OTHER OPTIONS:\n"
-    "  -nozero     = Do NOT write the output dataset if it would be all zero.\n"
-    "\n"
     "  -datum type = Coerce the output data to be stored as the given type,\n"
     "                  which may be byte, short, or float.\n"
     "          N.B.: Byte data cannot be negative.  If this datum type is chosen,\n"
     "                  any negative values in the edited and/or merged dataset\n"
     "                  will be set to zero.\n"
-    "\n"
     "  -keepthr    = When using 3dmerge to edit exactly one dataset of a\n"
     "                  functional type with a threshold statistic attached,\n"
     "                  normally the resulting dataset is of the 'fim'\n"
@@ -699,8 +691,6 @@ void MRG_Syntax(void)
     "                  are appropriate.  Note that sub-brick auxiliary data \n"
     "                  can be modified using program 3drefit. \n"
     "\n"
-    "  -quiet      = Reduce the number of messages shown\n"
-    "\n"
     "  -1dindex j  = Uses sub-brick #j as the data source , and uses sub-brick\n"
     "  -1tindex k  = #k as the threshold source.  With these, you can operate\n"
     "                  on any given sub-brick of the inputs dataset(s) to produce\n"
@@ -835,7 +825,7 @@ void MRG_Syntax(void)
     "     of integral data types. 'float' values are typecast to 'int' \n"
     "     before being ranked.\n"
     "\n"
-    "     See also program 3dRank\n"
+    "     See also program 3dRank\n" 
     "\n"
     "MERGING OPTIONS APPLIED TO FORM THE OUTPUT DATASET:\n"
     " [That is, different ways to combine results. The]\n"
@@ -851,7 +841,7 @@ void MRG_Syntax(void)
     "  -gsmax     = Combine datasets by taking max signed intensity\n"
     "                 (e.g., -7 and 2 combine to -7)\n"
     "  -gcount    = Combine datasets by counting number of 'hits' in\n"
-    "                  each voxel (see below for definition of 'hit')\n"
+    "                  each voxel (see below for defintion of 'hit')\n"
     "  -gorder    = Combine datasets in order of input:\n"
     "                * If a voxel is nonzero in dataset #1, then\n"
     "                    that value goes into the voxel.\n"
@@ -1197,24 +1187,20 @@ int main( int argc , char * argv[] )
   /*----- Iterate over sub-bricks -----*/
   for (iv = iv_bot;  iv < iv_top;  iv++)
     {
-      /* show if requested */
-      if ((MRG_verbose) && MRG_doall) printf ("Editing sub-brick %d\n", iv);
+      if ((!MRG_be_quiet) && MRG_doall) printf ("Editing sub-brick %d\n", iv);
 
       MRG_edopt.iv_fim = iv;
       EDIT_one_dataset( dset , &MRG_edopt ) ;  /* all the real work */
 
-      if( !MRG_be_quiet && !MRG_verbose ) { printf(".") ; fflush(stdout) ; }
+      if( !MRG_be_quiet && !MRG_doall ){ printf(".") ; fflush(stdout) ; }
 
     }  /* end of loop over sub-bricks */
 
-    /* newline after the pacifier dots */
-    if( !MRG_be_quiet && !MRG_verbose ) { printf("\n") ; fflush(stdout) ; }
-
     if( MRG_edopt.nfmask > 0 ){
       free(MRG_edopt.fmask) ; MRG_edopt.fmask = NULL ; MRG_edopt.nfmask = 0 ;
     }
 
-    if( !MRG_be_quiet ) printf("\n") ;
+    if( !MRG_be_quiet && !MRG_doall ) printf("\n") ;
 
       /** 17 Sep 1998: NOW create the new dataset **/
 
@@ -1345,7 +1331,7 @@ int main( int argc , char * argv[] )
             }
 
             efim = DSET_ARRAY(dset,ival) ;
-            dfim = (void *) RwcMalloc( mri_datum_size(output_thdatum) * nxyz ) ;
+            dfim = (void *) XtMalloc( mri_datum_size(output_thdatum) * nxyz ) ;
 
             switch( output_thdatum ){
                default: fprintf(stderr,"** illegal output_thdatum = %d\n",
@@ -1405,11 +1391,6 @@ int main( int argc , char * argv[] )
     }  /* iv    End of iteration over sub-bricks */
 
 
-      if( MRG_nozero && THD_count_nonzero_bricks(new_dset) == 0 ){ /* 17 Jan 2017 */
-        INFO_message("output dataset is all zero ==> not writing because of -allzero") ;
-        exit(0) ;
-      }
-
       THD_load_statistics( new_dset ) ;
       THD_write_3dim_dataset( NULL,NULL , new_dset , True ) ;
       if( ! MRG_be_quiet )
@@ -1487,17 +1468,17 @@ int main( int argc , char * argv[] )
 
    /* make space for the merger computations */
 
-   tfim = (float *) RwcMalloc( sizeof(float) * nxyz ) ;  /* dataset copy */
-   gfim = (float *) RwcMalloc( sizeof(float) * nxyz ) ;  /* results */
-   gnum = (short *) RwcMalloc( sizeof(short) * nxyz ) ;  /* counts */
+   tfim = (float *) XtMalloc( sizeof(float) * nxyz ) ;  /* dataset copy */
+   gfim = (float *) XtMalloc( sizeof(float) * nxyz ) ;  /* results */
+   gnum = (short *) XtMalloc( sizeof(short) * nxyz ) ;  /* counts */
    for( ii=0 ; ii < nxyz ; ii++ ) gfim[ii] = 0.0 ;      /* initialize */
    for( ii=0 ; ii < nxyz ; ii++ ) gnum[ii] = 0 ;
 
    /* 29 Aug 1996: make space for merger of thresholds, if desired */
 
    if( MRG_cflag_gthr != THFLAG_NONE ){
-      ttfim = (float *) RwcMalloc( sizeof(float) * nxyz ) ;  /* thresh copy */
-      ggfim = (float *) RwcMalloc( sizeof(float) * nxyz ) ;  /* thresh results */
+      ttfim = (float *) XtMalloc( sizeof(float) * nxyz ) ;  /* thresh copy */
+      ggfim = (float *) XtMalloc( sizeof(float) * nxyz ) ;  /* thresh results */
       for( ii=0 ; ii < nxyz ; ii++ ) ggfim[ii] = 0.0 ;      /* initialize */
 
       for( ii=0 ; ii < MAX_STAT_AUX ; ii++ ) thr_stataux[ii] = 0 ;
@@ -1721,8 +1702,8 @@ int main( int argc , char * argv[] )
       num_dset++ ;
    }  /* end of combiner loop over datasets */
 
-   myRwcFree(tfim) ;                      /* not needed any more */
-   if( ttfim != NULL ) myRwcFree(ttfim) ;
+   myXtFree(tfim) ;                      /* not needed any more */
+   if( ttfim != NULL ) myXtFree(ttfim) ;
 
    if( MRG_edopt.nfmask > 0 ){
      free(MRG_edopt.fmask) ; MRG_edopt.fmask = NULL ; MRG_edopt.nfmask = 0 ;
@@ -1800,7 +1781,7 @@ int main( int argc , char * argv[] )
    /**** at this point, don't need the count brick "gnum" anymore;
          "gfim" contains the results we'll eventually write to disk ****/
 
-   myRwcFree( gnum ) ;
+   myXtFree( gnum ) ;
 
    /*** if desired, edit the result for cluster size ***/
 
@@ -1812,7 +1793,8 @@ int main( int argc , char * argv[] )
    if( (rmm >= dx || rmm >= dy || rmm >= dz) && ptmin > 1 ){
       if( ! MRG_be_quiet ) printf("-- editing merger for cluster size\n") ;
 
-      clar  = MCW_find_clusters( nx,ny,nz , dx,dy,dz , MRI_float,gfim , rmm) ;
+      
+      clar  = MCW_find_clusters( nx,ny,nz , dx,dy,dz , MRI_float,gfim , rmm) ;   
       nclu  = 0 ;
       if( clar != NULL ){
          for( iclu=0 ; iclu < clar->num_clu ; iclu++ ){
@@ -1856,9 +1838,9 @@ int main( int argc , char * argv[] )
 
       case MRI_complex:{
          void * dfim ;
-         dfim = (void *) RwcMalloc( sizeof(complex) * nxyz ) ;
+         dfim = (void *) XtMalloc( sizeof(complex) * nxyz ) ;
          EDIT_coerce_type( nxyz , MRI_float,gfim , MRI_complex,dfim ) ;
-         myRwcFree( gfim ) ;
+         myXtFree( gfim ) ;
          EDIT_substitute_brick( new_dset , ivout , MRI_complex , dfim ) ;
          DSET_BRICK_FACTOR(new_dset,ivout) = 0.0 ;
       }
@@ -1886,9 +1868,9 @@ int main( int argc , char * argv[] )
             fimfac = MRI_TYPE_maxval[output_datum] / gtop ;
          }
 
-         dfim = (void *) RwcMalloc( mri_datum_size(output_datum) * nxyz ) ;
+         dfim = (void *) XtMalloc( mri_datum_size(output_datum) * nxyz ) ;
          EDIT_coerce_scale_type( nxyz,fimfac , MRI_float,gfim , output_datum,dfim ) ;
-         myRwcFree( gfim ) ;
+         myXtFree( gfim ) ;
          EDIT_substitute_brick( new_dset , ivout , output_datum , dfim ) ;
          DSET_BRICK_FACTOR(new_dset,ivout) = (fimfac != 0.0) ? 1.0/fimfac : 0.0 ;
       }
@@ -1900,10 +1882,10 @@ int main( int argc , char * argv[] )
    if( MRG_cflag_gthr != THFLAG_NONE ){
       short * dfim ;
 
-      dfim   = (short *) RwcMalloc( sizeof(short) * nxyz ) ;
+      dfim   = (short *) XtMalloc( sizeof(short) * nxyz ) ;
       thrfac = FUNC_COR_SCALE_SHORT ;
       EDIT_coerce_scale_type( nxyz,thrfac , MRI_float,ggfim , MRI_short,dfim ) ;
-      myRwcFree( ggfim ) ;
+      myXtFree( ggfim ) ;
       EDIT_substitute_brick( new_dset , DSET_THRESH_VALUE(new_dset) ,
                              MRI_short , dfim ) ;
       DSET_BRICK_FACTOR(new_dset,1) = 1.0/thrfac ;
@@ -1928,11 +1910,6 @@ int main( int argc , char * argv[] )
 
    /*** write to disk!!! ***/
 
-   if( MRG_nozero && THD_count_nonzero_bricks(new_dset) == 0 ){ /* 17 Jan 2017 */
-     INFO_message("output dataset is all zero ==> not writing because of -allzero") ;
-     exit(0) ;
-   }
-
    tross_Make_History( "3dmerge" , argc , argv , new_dset ) ;
    THD_load_statistics( new_dset ) ;
    THD_write_3dim_dataset( NULL,NULL , new_dset , True ) ;
