@@ -25,11 +25,11 @@ Computer Generation, Inc.,
 gary@compgen.com
 www.compgen.com/widgets
 
-Thanks to Contributors:
+Thanks to Contributers:
 J Satchell, Eric Marttila 
 */
 /* Revision History:
-$Log$
+$Log: LiteClue.c,v $
 Revision 1.18  2009/03/05 21:55:24  rickr
 Cput
 
@@ -125,8 +125,6 @@ extern void RWC_xineramize( Display *,int,int,int,int,int *,int *) ;
 
 #include <stdio.h>
 
-extern void RWC_sleep( int msec ) ;
-
 #if 0
 #define CheckWidgetClass(routine) \
 	if (XtClass(w) != xcgLiteClueWidgetClass) \
@@ -299,42 +297,6 @@ The font_information is derived
 
 #if XtSpecificationRelease >= 5
 /* R5 and above code */
-
-#if 0
-void RWC_fixup_fontset(Widget cww,Widget www) /* 08 Jan 2021 -- does not work */
-{
-   char **missing_charset=NULL , *def_string=NULL ;
-   int    missing_charset_count = 0 ;
-   XcgLiteClueWidget cw = (XcgLiteClueWidget)cww ;
-
-   if( cw == NULL || cw->liteClue.fontset != NULL ) return ;
-
-   cw->liteClue.fontset = XCreateFontSet( XtDisplay(cw) ,
-                                          "9x15bold" ,
-                                          &missing_charset , &missing_charset_count , &def_string ) ;
-
-   if( cw->liteClue.fontset != NULL ) return ;
-
-   if( www != (Widget)NULL ){
-     XFontSet xfset ;
-     XtVaGetValues( www , XtNfontSet , &xfset , NULL ) ;
-     if( xfset != (XFontSet)NULL ) cw->liteClue.fontset = xfset ;
-   }
-
-   return ;
-}
-#endif
-
-/*------------------------------------------------------------------*/
-/* Check widget for integrity and honor */
-
-int RWC_liteclue_has_fontset( Widget cww ) /* 10 Jan 2021 */
-{
-   XcgLiteClueWidget cw = (XcgLiteClueWidget)cww ;
-   return ( (cw != NULL) && (cw->liteClue.fontset != NULL) ) ;
-}
-/*------------------------------------------------------------------*/
-
 static void compute_font_info(XcgLiteClueWidget cw)
 {
 	XRectangle ink;
@@ -538,7 +500,6 @@ static void timeout_event( XtPointer client_data, XtIntervalId *id)
 	logical.width = oret.width;
 	}
 #else
-   if( cw->liteClue.fontset == NULL ) return ;  /* If fontset not found [RWC - 08 Jan 2021] */
 	XmbTextExtents(cw->liteClue.fontset, obj->text , obj->text_size ,&ink, &logical);
 #endif
 
@@ -607,16 +568,12 @@ static void Enter_event(Widget w, XtPointer client_data, XEvent * xevent, Boolea
 	if(event->mode != NotifyNormal)
 		return;
 
-	/* if a help was recently popped down, don't delay in popping up
+	/* if a help was recently popped down, don't delay in poping up
 	   help for next watched widget
 	*/
 	if ((event->time -  cw->liteClue.HelpPopDownTime) > 
 			cw->liteClue.cancelWaitPeriod ) 
-#if 0
-/* old typo in original? */
 		current_waitPeriod = cw->liteClue.waitPeriod,timeout_event;
-#endif
-		current_waitPeriod = cw->liteClue.waitPeriod;
 	else
 		current_waitPeriod = 0;
 
@@ -692,7 +649,6 @@ void XcgLiteClueAddWidget(Widget w, Widget watch,  char * text, int size, int op
 
 	CheckWidgetClass(ROUTINE);	/* make sure we are called with a LiteClue widget */
 
-   if( cw->liteClue.fontset == NULL ) return ;  /* If fontset not found [RWC - 08 Jan 2021] */
 	obj = find_watched_widget(cw, watch);
 	if (obj)
 	{
@@ -885,7 +841,7 @@ Func:	This function may be used to enable clues for insensitive
 	watched widgets. Normally, XtAppMainLoop (which calls
 	XtDispatchEvent) will not deliver EnterNotify and LeaveNotify
 	events to widgets that are not sensitive (XtSetSensitive). This
-	prevents clues from popping up for these widgets. To bypass this
+	prevents clues from poping up for these widgets. To bypass this
 	limitation, you can break out XtAppMainLoop and add a call to
 	XcgLiteClueDispatchEvent ass follows:
 
