@@ -2,19 +2,22 @@ print("#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 print("          ================== Welcome to 1dSVAR.R ==================          ")
 print("AFNI Structural Vector Auto-Regressive (SVAR) Modeling Package!")
 print("#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
-print("Version 0.0.3,  June 21, 2011")
+print("Version 0.0.2,  April. 28, 2011")
 print("Author: Gang Chen (gangchen@mail.nih.gov)")
-print("Website: https://afni.nimh.nih.gov/sscc/gangc/SVAR.html")
+print("Website: http://afni.nimh.nih.gov/sscc/gangc/SVAR.html")
 print("SSCC/NIMH, National Institutes of Health, Bethesda MD 20892")
 print("#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
 
-first.in.path <- function(file) {
-   ff <- paste(strsplit(Sys.getenv('PATH'),':')[[1]],'/', file, sep='')
-   ff<-ff[lapply(ff,file.exists)==TRUE];
-   #cat('Using ', ff[1],'\n');
-   return(gsub('//','/',ff[1], fixed=TRUE))
+libLoad <- function(myLib) {
+   sucLoad <- FALSE
+   sucCheck <- FALSE
+   try(sucLoad <- library(myLib, character.only = TRUE, logical.return = TRUE))
+   if (sucLoad) {print(sprintf("Package %s successfully loaded!", myLib)); sucCheck <- TRUE} else {
+	  	try(install.packages(myLib))
+      try(sucLoad <- library(myLib, character.only = TRUE, logical.return = TRUE))
+      if (sucLoad) print(sprintf("Package %s successfully loaded...", myLib)) 
+   	}
 }
-source(first.in.path('AFNIio.R'))
 
 # header assumed for multi-column files, but not for one-column ones
 # readMultiFiles <- function(nFiles, dim, inData) { 
@@ -374,11 +377,11 @@ rma <- function(yi, vi, mods=NULL, method="REML", addint=TRUE, ci=95, digits=4,
 
 
 
+libLoad("network")  # network drawing
 #libLoad('tcltk')    # for graphics
-pkgLoad('network')
 
 print("~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~")
-print("Visit https://afni.nimh.nih.gov/sscc/gangc/SVAR.html and makse sure")
+print("Visit http://afni.nimh.nih.gov/sscc/gangc/SVAR.html and makse sure")
 print("you've acquired the data for the analysis in desirable data format.")
 print("~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~")
 
@@ -395,9 +398,8 @@ print("Use CNTL-C on Unix or ESC on GUI version of R to stop at any moment.")
 anaType <- as.integer(readline("Analysis type (0: quit; 1: individual; 2: group)? "))
 
 if (anaType==1) {
-#libLoad("gsl")      # Legendre polynomials
-#libLoad("vars")     # VAR modeling 
-pkgLoad(c('gsl', 'vars'))
+libLoad("gsl")      # Legendre polynomials
+libLoad("vars")     # VAR modeling 
 
 anotherAna <- 1
 while (anotherAna==1) {
@@ -585,7 +587,7 @@ qualityCheck <- as.integer(readline("Want to run a few quality check tests (0: n
 if (qualityCheck) {
 # the modulus of the eigenvalues (presumably less than 1 as stable condition) in the reverse characteristic polynomial; stable process is stationary, but the converse is not true
 #print("Quality check of the model:")
-if (prod(roots(fm)<1)) print("Eigenvalues of the companion coefficient matrix indicate that the VAR(p) process is stable and thus stationary") else print("The VAR(p) process seems unstable and thus is not stationary")
+if (prod(roots(fm)<1)) print("Eigenvalues of the companion coefficient matrix indciate that the VAR(p) process is stable and thus stationary") else print("The VAR(p) process seems unstable and thus is not stationary")
 print("-----------------")
 print("Normality testing of the residuals")
 print(normality.test(fm))
@@ -665,25 +667,25 @@ for (ii in 1:nROIs) for (jj in 1:nROIs) for (kk in 1:nLags)  { # ii: target, jj:
 	netMatT[kk,jj,ii] <- coef(fm)[[ii]][jj+nROIs*(kk-1), 3]  # t values
 }
 				
-for (ii in 1:nLags) {
-   print(sprintf("Path coefficient matrix with a lag of %i (direction goes from row to column):", ii))
-   print(matrix(netMatR[ii,,], nrow = nROIs, ncol = nROIs, dimnames = list(names(myData), names(myData))))
-   saveMat <- as.integer(readline("Save above path matrix for group analysis (0: no; 1: yes)? "))
-   if (saveMat) {
-      matName <- as.character(readline("File name prefix (e.g., PathLag1Subj1)? "))
-      write.table(netMatR[ii,,], file=sprintf("%s.1D", matName), append=FALSE, row.names=names(myData), col.names=names(myData))
-   }   	
-   print("-----------------")
-	print(sprintf("Matrix of t values with a lag of %i (direction goes from row to column):", ii))
-   print(matrix(netMatT[ii,,], nrow = nROIs, ncol = nROIs, dimnames = list(names(myData), names(myData))))
-	print(sprintf("DFs = %i for null hypothesis H_0: a path coefficient = 0.", summary(fm)$varresult[[1]]$df[2]))
-	saveMatT <- as.integer(readline("Save matrix of t values for group analysis (0: no; 1: yes)? "))
-   if (saveMatT) {
-      matName <- as.character(readline("File name prefix (e.g., TLag1Subj1)? "))
-      write.table(netMatT[ii,,], file=sprintf("%s.1D", matName), append=FALSE, row.names=names(myData), col.names=names(myData))
-   }   	
-   print("-----------------")
-}
+#for (ii in 1:nLags) {
+#   print(sprintf("Path coefficient matrix with a lag of %i (direction goes from row to column):", ii))
+#   print(matrix(netMatR[ii,,], nrow = nROIs, ncol = nROIs, dimnames = list(names(myData), names(myData))))
+#   saveMat <- as.integer(readline("Save above path matrix for group analysis (0: no; 1: yes)? "))
+#   if (saveMat) {
+#      matName <- as.character(readline("File name prefix (e.g., PathLag1Subj1)? "))
+#      write.table(netMatR[ii,,], file=sprintf("%s.1D", matName), append=FALSE, row.names=names(myData), col.names=names(myData))
+#   }   	
+#   print("-----------------")
+#	print(sprintf("Matrix of t values with a lag of %i (direction goes from row to column):", ii))
+#   print(matrix(netMatT[ii,,], nrow = nROIs, ncol = nROIs, dimnames = list(names(myData), names(myData))))
+#	print(sprintf("DFs = %i for null hypothesis H_0: a path coefficient = 0.", summary(fm)$varresult[[1]]$df[2]))
+#	saveMatT <- as.integer(readline("Save matrix of t values for group analysis (0: no; 1: yes)? "))
+#   if (saveMatT) {
+#      matName <- as.character(readline("File name prefix (e.g., TLag1Subj1)? "))
+#      write.table(netMatT[ii,,], file=sprintf("%s.1D", matName), append=FALSE, row.names=names(myData), col.names=names(myData))
+#   }   	
+#   print("-----------------")
+#}
 
 #if (nLags>1) { # overall network with all lags collapsed
 #   libLoad("car")  # for linear.hypothesis
@@ -844,10 +846,10 @@ cat("\tROI names should be provided for both column and row.\n")
 cat("\tThe diagonals should be 0, and each of the off-diagonals\n")
 cat("\tindicates a connection from row to column, specified with\n")
 cat("\teither 0 (not connected), NA (to be estimated), or a known\n")
-cat("\tvalue (prior knowledge of path strength).\n\n")
+cat("\tvalue (prior knowledge of path stength).\n\n")
 
 
-instMat <- readMultiFiles(1, 2, "specification matrix for instantaneous effects") # both row and column names assumed
+instMat <- readMultiFiles(1, 2, "specification matrix for instantaneous effectss") # both row and column names assumed
 instMat <- diag(nROIs)-t(as.matrix(instMat[[1]])) # A0
 
 #readMultiFiles(1, 1, "instantaneous effects matrix")
@@ -856,15 +858,9 @@ instMat <- diag(nROIs)-t(as.matrix(instMat[[1]])) # A0
 # is the opposite to the one in our convention
 #aa <- as.matrix(read.table("../sem.1D", header = FALSE))
 #vv <- SVAR(x = fm, estmethod = "scoring", Amat = aa, Bmat = NULL, max.iter = 100, maxls = 1000, conv.crit = 1.0e-6)
-bb <- diag(nROIs); diag(bb) <- NA  # make B as a diagonal matrix with unknown elements
+bb <- diag(nROIs); diag(bb) <- NA  # make B as a diagonal matrix with unknown elments
 
-cat("\nThe following two options are for numerical algorithm. Choose first")
-cat("\n'Iterative', switch to 'Direct' if the iterative approach fails.\n\n")
-
-estMeth <- as.integer(readline("Numerical scheme (0: Iterative; 1: Direct)? "))
-
-if(estMeth==0) fm2 <- SVAR(x = fm, estmethod = "scoring", Amat = instMat, Bmat = bb, max.iter = 100, maxls = 1000, conv.crit = 1.0e-6)
-if(estMeth==1) fm2 <- SVAR(x = fm, estmethod = "direct", Amat = instMat, Bmat = bb, max.iter = 100, maxls = 1000, conv.crit = 1.0e-6)
+fm2 <- SVAR(x = fm, estmethod = "scoring", Amat = instMat, Bmat = bb, max.iter = 100, maxls = 1000, conv.crit = 1.0e-6)
 
 #vv <- SVAR(x = fm, estmethod = "scoring", Amat = aa, Bmat = bb, max.iter = 100, maxls = 1000, conv.crit = 1.0e-6)
 #(vv$A[abs(vv$Ase)>1e-6])/(vv$As[abs(vv$Ase)>1e-6])
@@ -959,7 +955,7 @@ nSubjs <- as.integer(readline("Number of subjects (e.g., 12)? "))     # number o
 #gfn <- vector('list', nSubjs)
 pathList <- vector('list', nSubjs)
 
-if (grpType==1) {  # Fisher transformation not done since it doesn't seem to matter much in testing
+if (grpType==1) {  # Fisher tranformation not done since it doesn't seem to matter much in testing
    print("Provide path coef files first:")
    print("-----------------")
    pathList <- readMultiFiles(nSubjs, 2, "subject path coef matrix")  #2: with header
@@ -977,7 +973,7 @@ if (grpType==1) {  # Fisher transformation not done since it doesn't seem to mat
    runMeta <- TRUE
 }
 
-if (grpType==2) {  # Fisher transformation not done since it doesn't seem to matter much in testing
+if (grpType==2) {  # Fisher tranformation not done since it doesn't seem to matter much in testing
    pathList <- readMultiFiles(nSubjs, 2, "subject path coef matrix")  #2: with header
    zMat <- do.call(rbind, lapply(lapply(pathList, as.matrix), c))  # convert to matrix
    runMeta <- FALSE
@@ -1112,7 +1108,7 @@ zMat <- vector('list', nGrp)
 zSEMat <- vector('list', nGrp)
 DF <- vector('list', nGrp)
 
-for (ii in 1:nGrp) {  # Fisher transformation not done since it doesn't seem to matter much in testing
+for (ii in 1:nGrp) {  # Fisher tranformation not done since it doesn't seem to matter much in testing
 	nSubjs[ii] <- as.integer(readline(sprintf("Number of subjects in group %s (e.g., 12)? ", ii)))
    pathList[[ii]] <- vector('list', nSubjs[ii])
 	if (grpType==1 ) {   
@@ -1136,7 +1132,7 @@ for (ii in 1:nGrp) {  # Fisher transformation not done since it doesn't seem to
 #      DF[[ii]] <- as.integer(readline(sprintf("Degrees of freedom for the t-statistics in group %s? ", ii)))
       print("-----------------")
    }
-   if (grpType==2) {  # Fisher transformation not done here since it doesn't seem to matter much in testing
+   if (grpType==2) {  # Fisher tranformation not done here since it doesn't seem to matter much in testing
       pathList[[ii]] <- readMultiFiles(nSubjs[ii], 2, "subject path coef matrix")  #2: with header
       zMat[[ii]] <- do.call(rbind, lapply(lapply(pathList[[ii]], as.matrix), c))  # convert to matrix
       runMeta <- FALSE
@@ -1159,7 +1155,7 @@ for (ii in 1:nGrp) {  # Fisher transformation not done since it doesn't seem to
 	nROIsG[ii] <- dim(pathList[[ii]][[1]])[1]
 	if (ii>1) for (jj in 1:ii) if (nROIsG[jj]!=nROIsG[1]) {sprintf("Group %i has %i ROIs while group 1 has %i", jj, nROIsG[jj], nROIsG[1]); break}
 	roiNames[[ii]] <- names(pathList[[ii]][[1]])
-	if (ii>1) for (jj in 1:ii) if (!identical(roiNames[[ii]], roiNames[[1]])) {sprintf("Group %i has different ROI names with group 1", jj, roiNames[[ii]]); break}
+	if (ii>1) for (jj in 1:ii) if (!identical(roiNames[[ii]], roiNames[[1]])) {sprintf("Group %i has different ROI namess with group 1", jj, roiNames[[ii]]); break}
 #	if (pthType==0) zList[[ii]] <- lapply(pathList[[ii]], fisherz) # sapply(pathList[[ii]], fisherz, simplify = FALSE)
 #  if (pthType==1) zList[[ii]] <- lapply(pathList[[ii]], function(x) log(x^2))
 #  if (pthType==2) zList[[ii]] <- lapply(pathList[[ii]], log)
