@@ -3,114 +3,31 @@
 
 typedef enum { SUMA_3dSS_NO_PAUSE = 0, SUMA_3dSS_DEMO_PAUSE, SUMA_3dSS_INTERACTIVE } SUMA_3DSS_MODES;
 
-typedef struct {
-   int id; /* 1D voxel index */
-   int ii, jj, kk; /* The regular indices */
-   float d2; /* square distance from center */
-   float ca; /* cosine of angle with wedge axis */
-} WegdeNeighbData;
-
-
-void SUMA_setBrainWrap_NodeDbg(int n);
-int  SUMA_getBrainWrap_NodeDbg(void);
-float SUMA_LoadPrepInVol (SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, 
-                          SUMA_SurfaceObject **SOhull);
-int SUMA_Find_IminImax (float *xyz, float *dir, 
-            SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, int ni, 
-            float *MinMax, float *MinMax_dist , 
-            float *MinMax_over, float *MinMax_over_dist,
-            float *Means, float *undershish, float *overshish, 
-            int *fvecind_under, int *fvecind_over, 
-            float d1, float d4, int ShishMax);
-int SUMA_Find_IminImax_2 (float *xyz, float *dir, 
-                        THD_3dim_dataset *in_vol, float **fvecp,
-                        float travstp, 
-                        float under_dist, float over_dist, 
-                        float stop_avg_thr,  int verb, 
-                        float *MinMax, float *MinMax_dist , 
-                        float *MinMax_over, float *MinMax_over_dist,
-                        float *Means, 
-                        float *undershish, float *overshish, 
-                        int *fvecind_under, int *fvecind_over
-                        );
-int SUMA_THD_WedgeNeighborhood(THD_3dim_dataset *dset, byte *mask,
-                               byte **examinedp,
-                               float *P, float *C,
-                               float t, float adeg,
-                               DList **Hoodu);
-int SUMA_THD_Radial_Avgs( THD_3dim_dataset  *dset, float *ufin,
-                           byte *cmask, float *ucm,
-                           byte zeropad, 
-                           float under, float over, int trvoff[2],
-                           float **umu, float **umo);
-int SUMA_THD_Radial_Stats( THD_3dim_dataset  *dset,
-                           byte *cmask, float *ucm,
-                           THD_3dim_dataset **osetp, byte zeropad, 
-                           float under, float over , int avgwin);
-int SUMA_Vox_Radial_Stats (float *fvec, int nxx, int nyy, int nzz, 
-                        float *xyz_ijk, float *cen_ijk, 
-                        int *voxtrav, int *trvoff,
-                        float *Means, 
-                        float *undershish, float *overshish, 
-                        int *fvecind_under, int *fvecind_over, 
-                        byte zeropad);
-int SUMA_Vox_Radial_Samples (float *fvec, int nxx, int nyy, int nzz, 
-                        float *xyz_ijk, float *cen_ijk, 
-                        float *undershish, 
-                        int *fvecind_under);
-int SUMA_THD_Radial_HeadBoundary( THD_3dim_dataset  *dset, float uthr,
-                           byte *cmask, float *ucm,
-                           THD_3dim_dataset **osetp,
-                           byte zeropad, 
-                           float under, float over, 
-                           float avgwin, int arcfill,
-                           float *Rcmstats, float *Rnzstats);
-int SUMA_CrudeNonHeadMask(THD_3dim_dataset *dset,
-                            float *cm_dicom, byte **cmask,
-                            float *mean, float *stdv);
-int SUMA_SkullMask (SUMA_SurfaceObject *SO, 
-                    SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, SUMA_COMM_STRUCT *cs);
-int SUMA_StretchToFitLeCerveau (SUMA_SurfaceObject *SO, 
-               SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, SUMA_COMM_STRUCT *cs);
-short *SUMA_FindVoxelsInSurface_SLOW (SUMA_SurfaceObject *SO, 
-                        SUMA_VOLPAR *VolPar, int *N_inp, int box_only) ;
-short *SUMA_SurfGridIntersect (SUMA_SurfaceObject *SO, float *NodeIJKlist, 
-                               SUMA_VOLPAR *VolPar, int *N_inp, int fillhole, 
-                               THD_3dim_dataset *fillholeset);
-
-short *SUMA_FindVoxelsInSurface (SUMA_SurfaceObject *SO, SUMA_VOLPAR *VolPar, 
-                  int *N_inpnt, int  fillhole, THD_3dim_dataset *fillholeset) ;
-int SUMA_PushToEdge(SUMA_SurfaceObject *SO, 
-                    SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, float limtouch, 
-                    SUMA_COMM_STRUCT *cs, int aggressive) ;
-int SUMA_PushToOuterSkull(SUMA_SurfaceObject *SO, 
-                          SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, 
-                          float limtouch, SUMA_COMM_STRUCT *cs, int N_itermax) ;
-int SUMA_PushToInnerSkull(SUMA_SurfaceObject *SO, 
-               SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, 
-               float limtouch, SUMA_COMM_STRUCT *cs) ;
-int SUMA_Reposition_Touchup(SUMA_SurfaceObject *SO, 
-                            SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, 
-                            float limtouch, SUMA_COMM_STRUCT *cs) ;
-float *SUMA_Suggest_Touchup(SUMA_SurfaceObject *SO, 
-                            SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, 
-                            float limtouch, SUMA_COMM_STRUCT *cs, int *N_touch);
-float *SUMA_Suggest_Touchup_Grad(SUMA_SurfaceObject *SO, 
-                                 SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, 
-                                 float limtouch, SUMA_COMM_STRUCT *cs, 
-                                 int *N_touch);
+float SUMA_LoadPrepInVol (SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, SUMA_SurfaceObject **SOhull);
+int SUMA_Find_IminImax (float *xyz, float *dir, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, int ni, 
+                        float *MinMax, float *MinMax_dist , float *MinMax_over, float *MinMax_over_dist,
+                        float *Means, float *undershish, float *overshish, int *fvecind_under, int *fvecind_over, 
+                        float d1, float d4, int ShishMax);
+int SUMA_SkullMask (SUMA_SurfaceObject *SO, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, SUMA_COMM_STRUCT *cs);
+int SUMA_StretchToFitLeCerveau (SUMA_SurfaceObject *SO, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, SUMA_COMM_STRUCT *cs);
+byte *SUMA_FindVoxelsInSurface_SLOW (SUMA_SurfaceObject *SO, SUMA_VOLPAR *VolPar, int *N_inp, int fillhole) ;
+short *SUMA_SurfGridIntersect (SUMA_SurfaceObject *SO, float *NodeIJKlist, SUMA_VOLPAR *VolPar, int *N_inp, int fillhole, THD_3dim_dataset *fillholeset);
+short *SUMA_FindVoxelsInSurface (SUMA_SurfaceObject *SO, SUMA_VOLPAR *VolPar, int *N_inpnt, int  fillhole, THD_3dim_dataset *fillholeset) ;
+int SUMA_PushToEdge(SUMA_SurfaceObject *SO, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, float limtouch, SUMA_COMM_STRUCT *cs, int agressive) ;
+int SUMA_PushToOuterSkull(SUMA_SurfaceObject *SO, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, float limtouch, SUMA_COMM_STRUCT *cs, int N_itermax) ;
+int SUMA_PushToInnerSkull(SUMA_SurfaceObject *SO, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, float limtouch, SUMA_COMM_STRUCT *cs) ;
+int SUMA_Reposition_Touchup(SUMA_SurfaceObject *SO, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, float limtouch, SUMA_COMM_STRUCT *cs) ;
+float *SUMA_Suggest_Touchup(SUMA_SurfaceObject *SO, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, float limtouch, SUMA_COMM_STRUCT *cs, int *N_touch);
+float *SUMA_Suggest_Touchup_Grad(SUMA_SurfaceObject *SO, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, float limtouch, SUMA_COMM_STRUCT *cs, int *N_touch);
 float *SUMA_Suggest_Touchup_PushEdge(SUMA_SurfaceObject *SO, 
                                     SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, 
-                                    float limtouch, SUMA_COMM_STRUCT *cs, 
-                                    int *N_touch);
+                                    float limtouch, SUMA_COMM_STRUCT *cs, int *N_touch);
 float *SUMA_Suggest_Touchup_PushOuterSkull(SUMA_SurfaceObject *SO, 
                                     SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, 
-                                    float limtouch, SUMA_COMM_STRUCT *cs, 
-                                    int *N_touch, int priorityatnode);
+                                    float limtouch, SUMA_COMM_STRUCT *cs, int *N_touch, int priorityatnode);
 float *SUMA_Suggest_Touchup_PushInnerSkull(SUMA_SurfaceObject *SO, 
                                     SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, 
-                                    float limtouch, SUMA_COMM_STRUCT *cs, 
-                                    int *N_touch);
+                                    float limtouch, SUMA_COMM_STRUCT *cs, int *N_touch);
 SUMA_Boolean SUMA_LimitCoordToVolume(float *NewCoord,          
                                      THD_3dim_dataset *in_volp,
                                      int units,
@@ -118,8 +35,7 @@ SUMA_Boolean SUMA_LimitCoordToVolume(float *NewCoord,
 int SUMA_DidUserQuit(void);
 EDIT_options *SUMA_BlankAfniEditOptions(void);
 void *SUMA_Push_Nodes_To_Hull(SUMA_SurfaceObject *SO, SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt, SUMA_COMM_STRUCT *cs, int N_itermax);
-SUMA_Boolean SUMA_3dedge3(THD_3dim_dataset *inset, float *emask, 
-                          THD_3dim_dataset **poutsetp);
+SUMA_Boolean SUMA_3dedge3(THD_3dim_dataset *inset, float *emask, THD_3dim_dataset **poutsetp);
 
 /*!
    SUMA_WRAP_BRAIN_SMOOTH(niter, bufp1, bufp2);
