@@ -3,9 +3,7 @@
 #include "Decompose.c"           /* For testing, put it in library if you'll be using it */
 #endif
 
-/* store the special names used for xmats */
-static char special_xmats[] = {"RandShift, RandRigid, RandAffine, Scale, NegXY"}; 
-void usage_SUMA_ConvertSurface (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
+void usage_SUMA_ConvertSurface (SUMA_GENERIC_ARGV_PARSE *ps)
    
   {/*Usage*/
           static char FuncName[]={"usage_SUMA_ConvertSurface"};
@@ -22,9 +20,6 @@ void usage_SUMA_ConvertSurface (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "    reads in a surface and writes it out in another format.\n"
 "    Note: This is a not a general utility conversion program. \n"
 "    Only fields pertinent to SUMA are preserved.\n"
-"\n%s", detail ? "":"use -h or -help for more help detail.\n");
-   if (detail) {
-      printf ( 
 "%s"
 "\n"
 "  Alternate GIFTI output qualifiers:\n"
@@ -35,6 +30,40 @@ void usage_SUMA_ConvertSurface (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "     If AFNI_NIML_TEXT_DATA environment variable is set to YES, the\n"
 "     the default is -xml_ascii, otherwise it is -xml_b64\n" 
 "\n"
+/*                  "    -i_TYPE inSurf specifies the input surface, TYPE is one of the following:\n"
+"       fs: FreeSurfer surface. \n"
+"           If surface name has .asc it is assumed to be\n"
+"           in ASCII format. Otherwise it is assumed to be\n"
+"           in BINARY_BE (Big Endian) format.\n"
+"           Patches in Binary format cannot be read at the moment.\n"
+"       sf: SureFit surface. \n"
+"           You must specify the .coord followed by the .topo file.\n"
+"       vec (or 1d): Simple ascii matrix format. \n"
+"            You must specify the NodeList file followed by the FaceSetList file.\n"
+"            NodeList contains 3 floats per line, representing X Y Z vertex coordinates.\n"
+"            FaceSetList contains 3 ints per line, representing v1 v2 v3 triangle vertices.\n"
+"       ply: PLY format, ascii or binary.\n"
+"            Only vertex and triangulation info is preserved.\n"
+"       bv: BrainVoyager format. \n"
+"           Only vertex and triangulation info is preserved.\n"
+"    -ipar_TYPE ParentSurf specifies the parent surface. Only used\n"
+"            when -o_fsp is used, see below.\n"
+"    -o_TYPE outSurf specifies the output surface, TYPE is one of the following:\n"
+"       fs: FreeSurfer ascii surface. \n"
+"       fsp: FeeSurfer ascii patch surface. \n" 
+"            In addition to outSurf, you need to specify\n"
+"            the name of the parent surface for the patch.\n"
+"            using the -ipar_TYPE option\n"
+"       sf: SureFit surface. \n"
+"           You must specify the .coord followed by the .topo file.\n"
+"       vec (or 1D): Simple ascii matrix format. \n"
+"            see help for vec under -i_TYPE options for format specifications.\n"
+"       ply: PLY format, ascii or binary.\n"
+"    -sv SurfaceVolume [VolParam for sf surfaces]\n"
+"       This option must not come before the -i_TYPE option.\n"
+"       If you supply a surface volume, the coordinates of the input surface.\n"
+"        are modified to SUMA's convention and aligned with SurfaceVolume.\n"
+"        You must also specify a VolParam file for SureFit surfaces.\n" */
 "    -orient_out STR: Output coordinates in STR coordinate system. \n"
 "                      STR is a three character string following AFNI's \n"
 "                      naming convention. The program assumes that the   \n"
@@ -52,7 +81,6 @@ void usage_SUMA_ConvertSurface (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "                      winding). This option will write out a new surface \n"
 "                      even if the mesh was consistent.\n"
 "                      See SurfQual -help for mesh checks.\n"
-"    -flip_orient: Flip the winding of the triangles\n"
 "    -radial_to_sphere rad: Push each node along the center-->node direction\n"
 "                           until |center-->node| = rad.\n"
 "    -acpc: Apply acpc transform (which must be in acpc version of \n"
@@ -79,48 +107,7 @@ void usage_SUMA_ConvertSurface (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "                 where all the nodes in nodelist are used in the mesh.\n"
 "                 Note that node indices will no longer correspond between\n"
 "                 the input patch and the output surface.\n"
-"    -merge_surfs: Merge multitudes of surfaces on the command line into one\n"
-"                  big surface before doing anything else to the surface.\n"
-"                  This is for the moment the only option for which you \n"
-"                  should specify more than one input surface on the command\n"
-"                  line. For example:\n"
-"            ConvertSurface -i lh.smoothwm.gii -i rh.smoothwm.gii \\\n"
-"                           -merge_surfs       -o_gii lrh.smoothwm.gii\n"
-"\n"
-#if 1
-"   Options for coordinate projections:\n"
-"   -node_depth DEPTHPREF: Project all coordinates onto the principal \n"
-"                          direction and output of depth/height of each\n"
-"                          node relative to the outlying projection point.\n"
-"                          This option is processed right before -pc_proj, \n"
-"                          should that option also be requested.\n"
-"                          This option outputs file DEPTHPREF.pcdepth.1D.dset\n"
-"                          which contains node index, followed by depth, then \n"
-"                          height of node. See also same option in SurfPatch\n"
-"\n" 
-"    -pc_proj ONTO PREFIX: Project coordinates onto ONTO, where ONTO is one \n"
-"                   of the parameters listed below.\n"
-"              ONTO values for plane projections along various normals:\n"
-"                       PC0_plane = normal is 1st principal vector\n"
-"                       PC1_plane = normal is  2nd principal vector\n"
-"                       PC2_plane = normal is  3rd principal vector\n"
-"                       PCZ_plane = normal is  component closest to Z axis\n"
-"                       PCY_plane = normal is  component closest to Y axis\n"
-"                       PCX_plane = normal is  component closest to X axis\n"
-"              ONTO values for line projections:\n"
-"                       PC0_dir   = project along 1st principal vector\n"
-"                       PC1_dir   = project along 2nd principal vector\n"
-"                       PC2_dir   = project along 3rd principal vector\n"
-"                       PCZ_dir   = project along component closest to Z axis\n"
-"                       PCY_dir   = project along component closest to Y axis\n"
-"                       PCX_dir   = project along component closest to X axis\n"
-"              PREFIX is used to form the name of the output file containing \n"
-"                       the projected coordinates. File PREFIX.xyzp.1D.coord\n"
-"                       contains the projected coordinates.\n"
-"    Note: This is the last operation to be performed by this program, \n"
-"          and no surfaces are written out in the end.\n"
-"\n"
-#endif                
+"\n"                 
 "    Options for applying arbitrary affine transform:\n"
 "    [xyz_new] = [Mr] * [xyz_old - cen] + D + cen\n"
 "    -xmat_1D mat: Apply transformation specified in 1D file mat.1D.\n"
@@ -132,18 +119,13 @@ void usage_SUMA_ConvertSurface (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "                  or\n"
 "                  r11 r12 r13 D1 r21 r22 r23 D2 r31 r32 r33 D3\n"
 "    -ixmat_1D mat: Same as xmat_1D except that mat is replaced by inv(mat)\n"
+"    -ixmat_1D mat: Same as xmat_1D except that mat is replaced by inv(mat)\n"
 "        NOTE: For both -xmat_1D and -ixmat_1D, you can replace mat with \n"
 "              one of the special strings:\n"
 "              'RandShift', 'RandRigid', or 'RandAffine' which would create\n"
 "              a transform on the fly. \n"
-"              You can also use 'NegXY' to flip the sign of X and Y \n"
-"              coordinates.\n"
 "    -seed SEED: Use SEED to seed the random number generator for random\n"
 "                matrix generation\n"
-"    -XYZscale sX sY sZ: Scale the coordinates by sX sY sZ.\n"
-"                        This option essentially turns sX sY sZ.\n"
-"                        into a -xmat_1D option. So you cannot mix\n"
-"                        and match.\n"
 "    -xcenter x y z: Use vector cen = [x y z]' for rotation center.\n"
 "                    Default is cen = [0 0 0]'\n"
 "    -polar_decomp: Apply polar decomposition to mat and preserve\n"
@@ -152,24 +134,19 @@ void usage_SUMA_ConvertSurface (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "                   This option can only be used in conjunction with\n"
 "                   -xmat_1D\n"
 "\n"
-"%s"
-"\n", (detail > 1) ? sio : "Use -help for I/O and miscellaneous options." , 
-      (detail > 1) ? s : "");
-  }/*Usage*/
-       if (sio) SUMA_free(sio); s = NULL;        
-       if (s) SUMA_free(s); s = NULL;        
-       if (detail) {
+"%s\n"
+                  , sio, s); SUMA_free(sio); sio = NULL; SUMA_free(s); s = NULL; 
           s = SUMA_New_Additions(0, 1); printf("%s\n", s);SUMA_free(s); s = NULL; 
-          printf ("\t\t Ziad S. Saad SSCC/NIMH/NIH saadz@mail.nih.gov \n");
-      }
-   return;
-}   
+          printf ("\t\t Ziad S. Saad SSCC/NIMH/NIH saadz@mail.nih.gov \t Wed Jan  8 13:44:29 EST 2003 \n");
+          exit (0);
+  }/*Usage*/
+   
 int main (int argc,char *argv[])
 {/* Main */
    static char FuncName[]={"ConvertSurface"}; 
-	int kar, volexists, i, Doinv, randseed, Domergesurfs=0, pciref;
-   float DoR2S, *pcxyzref;
-   double xcen[3], sc[3];
+	int kar, volexists, i, Doinv, randseed;
+   float DoR2S;
+   double xcen[3];
    double xform[4][4];
    char  *if_name = NULL, *of_name = NULL, *if_name2 = NULL, 
          *of_name2 = NULL, *sv_name = NULL, *vp_name = NULL,
@@ -182,16 +159,15 @@ int main (int argc,char *argv[])
    SUMA_SO_File_Format iForm = SUMA_FF_NOT_SPECIFIED, 
                         iparForm = SUMA_FF_NOT_SPECIFIED, 
                         oFormat = SUMA_FF_NOT_SPECIFIED;
-   SUMA_SurfaceObject *SO = NULL, *SOpar = NULL;
+   SUMA_SurfaceObject *SO = NULL, *SOpar = NULL, *SOsurf = NULL;
    SUMA_PARSED_NAME *of_name_strip = NULL, *of_name2_strip = NULL;
    SUMA_SFname *SF_name = NULL;
    void *SO_name = NULL;
-   char orsurf[6], orcode[6], *PCprojpref=NULL, *NodeDepthpref=NULL;
+   char orsurf[6], orcode[6];
    THD_warp *warp=NULL ;
    THD_3dim_dataset *aset=NULL;
-   SUMA_Boolean brk, Do_tlrc, Do_mni_RAI, Do_mni_LPI, Do_acpc, Docen, Do_flip;
-   SUMA_Boolean Doxmat, Do_wind, Do_p2s, Do_native, Do_PolDec;
-   int Do_PCproj, Do_PCrot, Do_NodeDepth;
+   SUMA_Boolean brk, Do_tlrc, Do_mni_RAI, Do_mni_LPI, Do_acpc, Docen;
+   SUMA_Boolean Doxmat, Do_wind, Do_p2s, onemore, Do_native, Do_PolDec;
    SUMA_GENERIC_ARGV_PARSE *ps=NULL;
    SUMA_Boolean exists;
    SUMA_Boolean LocalHead = NOPE;
@@ -203,6 +179,12 @@ int main (int argc,char *argv[])
 	SUMAg_DOv = SUMA_Alloc_DisplayObject_Struct (SUMA_MAX_DISPLAYABLE_OBJECTS);
    ps = SUMA_Parse_IO_Args(argc, argv, "-o;-i;-sv;-ipar;");
    
+   if (argc < 4)
+       {
+          usage_SUMA_ConvertSurface (ps);
+          exit (1);
+       }
+   
    
    kar = 1;
    xmat_name = NULL;
@@ -218,24 +200,16 @@ int main (int argc,char *argv[])
    Do_mni_LPI = NOPE;
    Do_acpc = NOPE;
    Do_wind = NOPE;
-   Do_flip = NOPE;
    Do_p2s = NOPE;
    Do_native = NOPE;
    DoR2S = 0.0;
    Do_PolDec = NOPE;
-   Do_PCproj = NO_PRJ;
-   Do_PCrot = NO_ROT;
-   pciref = -1;
-   pcxyzref = NULL;
-   PCprojpref = NULL;
-   NodeDepthpref = NULL;
-   Do_NodeDepth = 0;
    Doinv = 0;
-   Domergesurfs = 0;
-	while (kar < argc) { /* loop across command line options */
+   onemore = NOPE;
+	while (kar < argc) { /* loop accross command ine options */
 		/*fprintf(stdout, "%s verbose: Parsing command line...\n", FuncName);*/
 		if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
-			 usage_SUMA_ConvertSurface(ps, strlen(argv[kar]) > 3 ? 2:1);
+			 usage_SUMA_ConvertSurface(ps);
           exit (0);
 		}
 		
@@ -252,21 +226,6 @@ int main (int argc,char *argv[])
 			randseed = atoi(argv[kar]); 
 			brk = YUP;
 		}
-
-      if (!brk && (strcmp(argv[kar], "-xyzscale") == 0)) {
-         kar ++;
-			if (kar+2 >= argc)  {
-		  		fprintf (SUMA_STDERR, "need 3 values after -XYZscale\n");
-				exit (1);
-			}
-			sc[0] = strtod(argv[kar], NULL); kar ++; 
-			sc[1] = strtod(argv[kar], NULL); kar ++; 
-         sc[2] = strtod(argv[kar], NULL);
-			xmat_name = "Scale";
-         Doxmat = YUP;
-         Doinv = 0;
-         brk = YUP;
-		}
       
       if (!brk && ( (strcmp(argv[kar], "-xmat_1d") == 0) || 
                     (strcmp(argv[kar], "-xmat_1D") == 0) ) ) {
@@ -280,7 +239,6 @@ int main (int argc,char *argv[])
          Doinv = 0;
 			brk = YUP;
 		}
-      
       if (!brk && ( (strcmp(argv[kar], "-ixmat_1d") == 0) || 
                     (strcmp(argv[kar], "-ixmat_1D") == 0) ) ) {
          kar ++;
@@ -293,78 +251,16 @@ int main (int argc,char *argv[])
          Doinv = 1;
 			brk = YUP;
 		}
-      
       if (!brk && (strcmp(argv[kar], "-polar_decomp") == 0)) {
          Do_PolDec = YUP;
 			brk = YUP;
 		}
       
-      if (!brk && (strcmp(argv[kar], "-merge_surfs") == 0)) {
-         Domergesurfs = 1;
-			brk = YUP;
-		}
-      
-      if (!brk && (strcmp(argv[kar], "-pc_proj") == 0)) {
-         kar ++;
-			if (kar+1 >= argc)  {
-		  		fprintf (SUMA_STDERR, "need 2 argument after -pc_proj\n");
-				exit (1);
-			}
-              if (!strcmp(argv[kar],"PC0_plane")) Do_PCproj = E1_PLN_PRJ;
-         else if (!strcmp(argv[kar],"PC1_plane")) Do_PCproj = E2_PLN_PRJ;
-         else if (!strcmp(argv[kar],"PC2_plane")) Do_PCproj = E3_PLN_PRJ;
-         else if (!strcmp(argv[kar],"PCZ_plane")) Do_PCproj = EZ_PLN_PRJ;
-         else if (!strcmp(argv[kar],"PCY_plane")) Do_PCproj = EY_PLN_PRJ;
-         else if (!strcmp(argv[kar],"PCX_plane")) Do_PCproj = EX_PLN_PRJ;
-         else if (!strcmp(argv[kar],"PC0_dir"))   Do_PCproj = E1_DIR_PRJ;
-         else if (!strcmp(argv[kar],"PC1_dir"))   Do_PCproj = E2_DIR_PRJ;
-         else if (!strcmp(argv[kar],"PC2_dir"))   Do_PCproj = E3_DIR_PRJ;
-         else if (!strcmp(argv[kar],"PCZ_dir"))   Do_PCproj = EZ_DIR_PRJ;
-         else if (!strcmp(argv[kar],"PCY_dir"))   Do_PCproj = EY_DIR_PRJ;
-         else if (!strcmp(argv[kar],"PCX_dir"))   Do_PCproj = EX_DIR_PRJ;
-         else {
-            SUMA_S_Err("Bad value of %s for -pca_proj", argv[kar]);
-            exit(1);
-         }
-         ++kar;
-         if (argv[kar][0] == '-') {
-            SUMA_S_Err("Prefix for -pc_proj should not start with '-'.\n"
-                       "Could it be that %s is another option and \n"
-                       "the prefix was forgtotten?", argv[kar]);
-            exit(1);
-         }
-         PCprojpref = argv[kar];
-			
-         brk = YUP;
-		}
-      
-      if (!brk && (strcmp(argv[kar], "-node_depth") == 0)) {
-         kar ++;
-			if (kar >= argc)  {
-		  		fprintf (SUMA_STDERR, "need a prefix argument after -node_depth\n");
-				exit (1);
-			}
-         Do_NodeDepth = 1;
-         if (argv[kar][0] == '-') {
-            SUMA_S_Err("Prefix for -node_depth should not start with '-'.\n"
-                       "Could it be that %s is another option and \n"
-                       "the prefix was forgtotten?", argv[kar]);
-            exit(1);
-         }
-         NodeDepthpref = argv[kar];
-         
-         brk = YUP;
-      }
       
       if (!brk && (strcmp(argv[kar], "-make_consistent") == 0)) {
          Do_wind = YUP;
 			brk = YUP;
 		}
-
-      if (!brk && (strcmp(argv[kar], "-flip_orient") == 0)) {
-         Do_flip = YUP;
-			brk = YUP;
-		}
       
       if (!brk && (strcmp(argv[kar], "-xcenter") == 0)) {
          kar ++;
@@ -450,19 +346,12 @@ int main (int argc,char *argv[])
 			fprintf (SUMA_STDERR,
                   "Error %s: Option %s not understood. Try -help for usage\n", 
                   FuncName, argv[kar]);
-			suggest_best_prog_option(argv[0], argv[kar]);
-         exit (1);
+			exit (1);
 		} else {	
 			brk = NOPE;
 			kar ++;
 		}
    }
-   if (argc < 3) {
-        SUMA_S_Err("Too few options");
-        usage_SUMA_ConvertSurface (ps, 0);
-        exit (1);
-   }
-   
    /* transfer info from ps structure (backward compat) */
 
    if (ps->o_N_surfnames) {
@@ -496,123 +385,118 @@ int main (int argc,char *argv[])
    }
    
    if (Do_mni_LPI && Do_mni_RAI) {
-      SUMA_S_Err("\nCombining -MNI_lpi and -MNI_rai options.\nNot good.");
+      fprintf (SUMA_STDERR,"Error %s:\nCombining -MNI_lpi and -MNI_rai options.\nNot good.", FuncName);
       exit(1);
    }
    
    if (!if_name) {
-      SUMA_S_Err("input surface not specified.\n");
+      fprintf (SUMA_STDERR,"Error %s: input surface not specified.\n", FuncName);
       exit(1);
    }
-   if (!of_name && (Do_PCproj < 0 && !Do_NodeDepth) ) {
-      SUMA_S_Err("output surface or projection PREFIX not specified.\n");
+   if (!of_name) {
+      fprintf (SUMA_STDERR,"Error %s: output surface not specified.\n", FuncName);
       exit(1);
    }
    if (iType == SUMA_FT_NOT_SPECIFIED) {
-      SUMA_S_Err("input type not recognized.\n");
+      fprintf (SUMA_STDERR,"Error %s: input type not recognized.\n", FuncName);
       exit(1);
    }
-   if (oType == SUMA_FT_NOT_SPECIFIED && (Do_PCproj < 0 && !Do_NodeDepth) ) {
-      SUMA_S_Err("output type not recognized.\n");
+   if (oType == SUMA_FT_NOT_SPECIFIED) {
+      fprintf (SUMA_STDERR,"Error %s: output type not recognized.\n", FuncName);
       exit(1);
    }
    if (  oType != SUMA_GIFTI && 
          oFormat >= SUMA_XML_SURF && 
-         oFormat <= SUMA_XML_B64GZ_SURF &&
-         (Do_PCproj < 0 && !Do_NodeDepth) ){
-      SUMA_S_Err("XML output options only valid with -o_gii\n");
+         oFormat <= SUMA_XML_B64GZ_SURF){
+      fprintf (SUMA_STDERR,
+               "Error %s: XML output options only valid with -o_gii\n", 
+               FuncName);
       exit(1);
    }
    if (iType == SUMA_SUREFIT) {
       if (!if_name2) {
-         SUMA_S_Err("input SureFit surface incorrectly specified.\n");
+         fprintf (SUMA_STDERR,
+                  "Error %s: input SureFit surface incorrectly specified.\n", 
+                  FuncName);
          exit(1);
       }
       if (sv_name && !vp_name) {
-         SUMA_S_Err("VolParent needs the -sv option for SureFit surfaces.");
+         fprintf (SUMA_STDERR,
+                  "Error %s: VolParent must specified with -sv potion for SureFit surfaces. \n", 
+                  FuncName);
          exit(1);
       }
    }
    if (iType == SUMA_VEC) {
       if (!if_name2) {
-         SUMA_S_Err("Input vec surface incorrectly specified.\n");
+         fprintf (SUMA_STDERR,"Error %s: input vec surface incorrectly specified.\n", FuncName);
          exit(1);
       }
    }
 
    if (( Do_mni_RAI || Do_mni_LPI) && !Do_tlrc) {
-      SUMA_SL_Warn ( "I hope you know what you're doing.\n"
-                     "The MNI transform should only be applied to a\n"
-                     "Surface in the AFNI tlrc coordinate space.\n");
+      SUMA_SL_Warn ("I hope you know what you're doing.\nThe MNI transform should only be applied to a\nSurface in the AFNI tlrc coordinate space.\n");
    }
    
    if (Do_acpc && Do_tlrc) {
-      SUMA_S_Err("You can't do -tlrc and -acpc simultaneously.");
+      fprintf (SUMA_STDERR,"Error %s: You can't do -tlrc and -acpc simultaneously.\n", FuncName);
       exit(1);
    }
    
    if ((Doxmat || Docen) && (Do_acpc || Do_tlrc)) {
-      SUMA_S_Err("You can't do -tlrc or -acpc with -xmat_1D and -xcenter.\n");
+      fprintf (SUMA_STDERR,"Error %s: You can't do -tlrc or -acpc with -xmat_1D and -xcenter.\n", FuncName);
       exit(1);
    }
    
    if ((!Doxmat && Docen)) {
-      SUMA_S_Err("You can't use -xcenter without -xmat_1D.\n");
+      fprintf (SUMA_STDERR,"Error %s: You can't use -xcenter without -xmat_1D.\n", FuncName);
       exit(1);
    }
    if (oType == SUMA_SUREFIT) {
       if (!of_name2) {
-       SUMA_S_Err("output SureFit surface incorrectly specified. \n");
+       fprintf (SUMA_STDERR,"Error %s: output SureFit surface incorrectly specified. \n", FuncName);
        exit(1);
       }
    }
    
    if (oType == SUMA_VEC) {
       if (!of_name2) {
-       SUMA_S_Err("output vec surface incorrectly specified. \n");
+       fprintf (SUMA_STDERR,"Error %s: output vec surface incorrectly specified. \n", FuncName);
        exit(1);
       }
    }
    
-   if ( ps->i_N_surfnames > 1 && !Domergesurfs) {
-      SUMA_S_Err("Multiple surfaces specified without -merge_surfs option\n"
-                 "Nothing to do for such an input\n");
-      exit(1);
-   }
-   
    
    /* test for existence of input files */
-   
-   if (!SUMA_is_predefined_SO_name(if_name, NULL, NULL, NULL, NULL) &&
-       !SUMA_filexists(if_name)) {
-      SUMA_S_Errv("if_name %s not found.\n", if_name);
+   if (!SUMA_filexists(if_name)) {
+      fprintf (SUMA_STDERR,"Error %s: %s not found.\n", FuncName, if_name);
       exit(1);
    }
    
    if (if_name2) {
       if (!SUMA_filexists(if_name2)) {
-         SUMA_S_Errv("if_name2 %s not found.\n", if_name2);
+         fprintf (SUMA_STDERR,"Error %s: %s not found.\n", FuncName, if_name2);
          exit(1);
       }
    }
 
    if (ifpar_name2) {
       if (!SUMA_filexists(ifpar_name2)) {
-         SUMA_S_Errv("ifpar_name2 %s not found.\n", ifpar_name2);
+         fprintf (SUMA_STDERR,"Error %s: %s not found.\n", FuncName, ifpar_name2);
          exit(1);
       }
    }
    
    if (ifpar_name) {
       if (!SUMA_filexists(ifpar_name)) {
-         SUMA_S_Errv("ifpar_name %s not found.\n", ifpar_name);
+         fprintf (SUMA_STDERR,"Error %s: %s not found.\n", FuncName, ifpar_name);
          exit(1);
       }
    }
    
    if (xmat_name) {
-      if (!strstr(special_xmats,xmat_name) && !SUMA_filexists(xmat_name)) {
-         SUMA_S_Errv("xmat file %s not found.\n", xmat_name);
+      if (!SUMA_filexists(xmat_name)) {
+         fprintf (SUMA_STDERR,"Error %s: %s not found.\n", FuncName, xmat_name);
          exit(1);
       }
    } else {
@@ -625,7 +509,7 @@ int main (int argc,char *argv[])
    if (sv_name) {
       char *head = NULL, view[10];
       head = SUMA_AfniPrefix(sv_name, view, NULL, &volexists);
-      if (!SUMA_AfniExistsView(volexists, view) && !SUMA_filexists(sv_name)) {
+      if (!SUMA_AfniExistsView(volexists, view)) {
          fprintf (SUMA_STDERR,
                   "Error %s: volume %s not found.\n", FuncName, head);
          exit(1);
@@ -649,32 +533,30 @@ int main (int argc,char *argv[])
    }
 
    /* check for existence of output files */
-   if ((Do_PCproj < 0 && !Do_NodeDepth) ) {
-      if (of_name2) {
-         SUMA_SFname *SFname;
+   if (of_name2) {
+      SUMA_SFname *SFname;
 
-         SO_name = SUMA_2Prefix2SurfaceName (of_name, of_name2, NULL, 
-                                             vp_name, oType, &exists);
-         SFname = (SUMA_SFname *)SO_name;
-         OF_name2 = SUMA_copy_string(SFname->name_topo);
-         OF_name = SUMA_copy_string(SFname->name_coord);
-      } else {
-         SO_name = SUMA_Prefix2SurfaceName (of_name, NULL, vp_name, 
-                                            oType, &exists);
-         OF_name = SUMA_copy_string((char *) SO_name);
-      }
-
-      if (exists && !THD_ok_overwrite()) {
-         if (OF_name2) 
-            fprintf (SUMA_STDERR,
-                     "Error %s: output file(s) %s and/or %s exist already.\n", 
-                     FuncName, OF_name, OF_name2);
-         else fprintf ( SUMA_STDERR,
-                        "Error %s: output file %s exists already.\n", 
-                        FuncName, OF_name);
-         exit(1);
-      }
-   }   
+      SO_name = SUMA_2Prefix2SurfaceName (of_name, of_name2, NULL, 
+                                          vp_name, oType, &exists);
+      SFname = (SUMA_SFname *)SO_name;
+      OF_name2 = SUMA_copy_string(SFname->name_topo);
+      OF_name = SUMA_copy_string(SFname->name_coord);
+   } else {
+      SO_name = SUMA_Prefix2SurfaceName (of_name, NULL, vp_name, oType, &exists);
+      OF_name = SUMA_copy_string((char *) SO_name);
+   }
+   
+   if (exists && !THD_ok_overwrite()) {
+      if (OF_name2) 
+         fprintf (SUMA_STDERR,
+                  "Error %s: output file(s) %s and/or %s exist already.\n", 
+                  FuncName, OF_name, OF_name2);
+      else fprintf ( SUMA_STDERR,
+                     "Error %s: output file %s exists already.\n", 
+                     FuncName, OF_name);
+      exit(1);
+   }
+      
    /* now for the real work */
    if (Doxmat) {
       MRI_IMAGE *im = NULL;
@@ -686,10 +568,6 @@ int main (int argc,char *argv[])
          SUMA_FillRandXform(xform, randseed, 3);
       } else if (!strcmp(xmat_name,"RandShift")) {
          SUMA_FillRandXform(xform, randseed, 1);
-      } else if (!strcmp(xmat_name,"Scale")) {
-         SUMA_FillScaleXform(xform, sc);
-      } else if (!strcmp(xmat_name,"NegXY")) {
-         SUMA_FillXYnegXform(xform);
       } else {
          im = mri_read_double_1D (xmat_name);
 
@@ -855,61 +733,28 @@ int main (int argc,char *argv[])
          #endif 
       }
    }
-   
-   if ( ps->i_N_surfnames ==  1) {
-      /* load that one surface */
-      SO = SUMA_Load_Surface_Object_Wrapper ( if_name, if_name2, vp_name, 
-                                              iType, iForm, sv_name, 1);
-      if (!SO) {
-         SUMA_S_Err("Failed to read input surface.\n");
-         exit (1);
-      }
-   } else if ( ps->i_N_surfnames > 1 && Domergesurfs) {
-      SUMA_SurfaceObject **SOar=NULL;
-      int ii;
-      SUMA_S_Notev("Merging %d surfaces into 1\n", ps->i_N_surfnames);
-      SOar = (SUMA_SurfaceObject **)
-                  SUMA_calloc(ps->i_N_surfnames, sizeof(SUMA_SurfaceObject *));
-      if (ps->N_sv > 1 || ps->N_vp > 1) {
-         SUMA_S_Errv("Cannot handle multiple (%d) -sv or multiple (%d) -vp\n",
-                     ps->N_sv, ps->N_vp);
-         exit(1);
-      }
-      for (ii = 0; ii<ps->i_N_surfnames; ++ii) {
-         SOar[ii] = SUMA_Load_Surface_Object_Wrapper(ps->i_surfnames[ii], 
-                                                     ps->i_surftopo[ii],
-                                                     vp_name, 
-                                                     ps->i_FT[0], ps->i_FF[0], 
-                                                     sv_name, 1);
-      }
-      if (!(SO = SUMA_MergeSurfs(SOar, ps->i_N_surfnames))) {
-         SUMA_S_Err("Failed to merge");
-         exit(1);
-      }
-      for (ii = 0; ii<ps->i_N_surfnames; ++ii) {
-         SUMA_Free_Surface_Object(SOar[ii]);
-         SOar[ii]=NULL;
-      } SUMA_free(SOar); SOar=NULL;
+   /* prepare the name of the surface object to read*/
+   SO = SUMA_Load_Surface_Object_Wrapper ( if_name, if_name2, vp_name, iType, iForm, sv_name, 1);
+   if (!SO) {
+      fprintf (SUMA_STDERR,"Error %s: Failed to read input surface.\n", FuncName);
+      exit (1);
    }
-   
+
    if (DoR2S > 0.0000001) {
       if (!SUMA_ProjectSurfaceToSphere(SO, NULL , DoR2S , NULL)) {
          SUMA_S_Err("Failed to project to surface");
          exit(1);
       }
    }
-   
-   
+
    if (ifpar_name) {
-      SOpar = SUMA_Load_Surface_Object_Wrapper ( ifpar_name, ifpar_name2,
-                                 vp_name, iparType, iparForm, sv_name, 1);
+      SOpar = SUMA_Load_Surface_Object_Wrapper ( ifpar_name, ifpar_name2, vp_name, iparType, iparForm, sv_name, 1);
       if (!SOpar) {
-         SUMA_S_Err("Failed to read input parent surface.\n");
+         fprintf (SUMA_STDERR,"Error %s: Failed to read input parent surface.\n", FuncName);
          exit (1);
       }
       /* need edge list */
-      if (!SUMA_SurfaceMetrics_eng (SOpar,"EdgeList", NULL, 0, 
-                                    SUMAg_CF->DsetList)) {
+      if (!SUMA_SurfaceMetrics_eng (SOpar,"EdgeList", NULL, 0, SUMAg_CF->DsetList)) {
          SUMA_SL_Err("Failed to create edgelist for parent");
          exit(1);
       }
@@ -918,32 +763,21 @@ int main (int argc,char *argv[])
    
    /* if Do_wind */
    if (Do_wind) {
-      fprintf (SUMA_STDOUT,
-         "Checking and repairing mesh's winding consistency...\n");
+      fprintf (SUMA_STDOUT,"Checking and repairing mesh's winding consistency...\n");
       /* check the winding, but that won't fix the normals, 
       you'll have to recalculate those things, if need be ... */
-      if (!SUMA_SurfaceMetrics_eng (SO, "CheckWind", NULL, 0, 
-                                    SUMAg_CF->DsetList)) {
-         SUMA_S_Err("Failed in SUMA_SurfaceMetrics.\n");
+      if (!SUMA_SurfaceMetrics_eng (SO, "CheckWind", NULL, 0, SUMAg_CF->DsetList)) {
+         fprintf (SUMA_STDERR,"Error %s: Failed in SUMA_SurfaceMetrics.\n", FuncName);
          exit(1);
       }   
    }
-
-   if (Do_flip) {
-      fprintf (SUMA_STDOUT,
-         "Flipping triangle winding...\n");
-      SUMA_FlipSOTriangles(SO);   
-   }
    
    if (Do_tlrc) {
       fprintf (SUMA_STDOUT,"Performing talairach transform...\n");
 
       /* form the tlrc version of the surface volume */
-      tlrc_name = (char *) SUMA_calloc (strlen(SO->VolPar->dirname)+
-                                        strlen(SO->VolPar->prefix)+60, 
-                                        sizeof(char));
-      sprintf (tlrc_name, "%s%s+tlrc.HEAD", 
-                           SO->VolPar->dirname, SO->VolPar->prefix);
+      tlrc_name = (char *) SUMA_calloc (strlen(SO->VolPar->dirname)+strlen(SO->VolPar->prefix)+60, sizeof(char));
+      sprintf (tlrc_name, "%s%s+tlrc.HEAD", SO->VolPar->dirname, SO->VolPar->prefix);
       if (!SUMA_filexists(tlrc_name)) {
          fprintf (SUMA_STDERR,"Error %s: %s not found.\n", FuncName, tlrc_name);
          exit(1);
@@ -952,11 +786,11 @@ int main (int argc,char *argv[])
       /* read the tlrc header */
       aset = THD_open_dataset(tlrc_name) ;
       if( !ISVALID_DSET(aset) ){
-         SUMA_S_Err("%s is not a valid data set.\n", tlrc_name) ;
+         fprintf (SUMA_STDERR,"Error %s: %s is not a valid data set.\n", FuncName, tlrc_name) ;
          exit(1);
       }
       if( aset->warp == NULL ){
-         SUMA_S_Err("tlrc_name does not contain a talairach transform.\n");
+         fprintf (SUMA_STDERR,"Error %s: tlrc_name does not contain a talairach transform.\n", FuncName);
          exit(1);
       }
       
@@ -964,7 +798,7 @@ int main (int argc,char *argv[])
       
       /* now warp the coordinates, one node at a time */
       if (!SUMA_AFNI_forward_warp_xyz(warp, SO->NodeList, SO->N_Node)) {
-         SUMA_S_Err("Failed in SUMA_AFNI_forward_warp_xyz.\n");
+         fprintf (SUMA_STDERR,"Error %s: Failed in SUMA_AFNI_forward_warp_xyz.\n", FuncName);
          exit(1);
       }
 
@@ -1055,23 +889,20 @@ int main (int argc,char *argv[])
             SUMA_SL_Err("Failed to xform coordinates"); exit(1); 
          }
       }
-      SUMA_Blank_AfniSO_Coord_System(SO->aSO);
    }
    
    if (orcode[0] != '\0') {
-      SUMA_LHv("Changing coordinates from %s to %s\n", orsurf, orcode);
+      if (LocalHead) fprintf (SUMA_STDERR,"%s: Changing coordinates from %s to %s\n", FuncName, orsurf, orcode);
       if (!SUMA_CoordChange(orsurf, orcode, SO->NodeList, SO->N_Node)) {
          SUMA_S_Err("Failed to change coords.");
          exit(1);
       }
-      SUMA_Blank_AfniSO_Coord_System(SO->aSO);
    }
    
    if (Do_p2s) {
       SUMA_SurfaceObject *SOold = SO;
-      SUMA_LH("Changing patch to surface...");
-      SO = SUMA_Patch2Surf(SOold->NodeList, SOold->N_Node, 
-                           SO->FaceSetList, SO->N_FaceSet, 3);
+      if (LocalHead) fprintf (SUMA_STDERR,"%s: Changing patch to surface...\n", FuncName);
+      SO = SUMA_Patch2Surf(SOold->NodeList, SOold->N_Node, SO->FaceSetList, SO->N_FaceSet, 3);
       if (!SO) {
          SUMA_S_Err("Failed to change patch to surface.");
          exit(1);
@@ -1088,55 +919,18 @@ int main (int argc,char *argv[])
       }
    }
    
-   if (Do_NodeDepth) {
-      float *dpth=NULL, mx=0.0;
-      SUMA_PC_XYZ_PROJ *pcp=NULL;
-      if (SUMA_NodeDepth(SO->NodeList, SO->N_Node, E1_DIR_PRJ, &dpth, 
-                     0.0, NULL, &mx, &pcp) < 0) {
-         SUMA_S_Err("Failed to compute node depth");
-         exit(1);
-      } else {
-         if (!SUMA_WriteNodeDepth(NodeDepthpref,pcp,dpth, mx)) {
-            SUMA_S_Err("Failed to write node depth");
-            exit(1);
-         } 
-      }
-      SUMA_ifree(dpth);
-      pcp = SUMA_Free_PC_XYZ_Proj(pcp);
-   }
+   if (LocalHead) SUMA_Print_Surface_Object (SO, stderr);
    
-   if (Do_PCproj > NO_PRJ) {
-      SUMA_PC_XYZ_PROJ *pcp=NULL;
-      pciref = 0; pcxyzref = NULL;
-      if (!(pcp = SUMA_Project_Coords_PCA(SO->NodeList, SO->N_Node,
-                                  pciref, pcxyzref, Do_PCproj, Do_PCrot, 1))) {
-         SUMA_S_Err("Failed to project");
-         exit(1);
-      } else {
-         if (!SUMA_Write_PC_XYZ_Proj(pcp, PCprojpref)) {
-            SUMA_S_Err("Failed to write out projections");
-            exit(1);
-         } else {
-           pcp = SUMA_Free_PC_XYZ_Proj(pcp);
-         }  
-         
-         exit(0);
-      }
-   }
-
+   fprintf (SUMA_STDOUT,"Writing surface...\n");
    
    
    /* write the surface object */
-   if (SO_name) {
-      if (LocalHead) SUMA_Print_Surface_Object (SO, stderr);
-      fprintf (SUMA_STDOUT,"Writing surface...\n");
-      if (!(SUMA_Save_Surface_Object ( SO_name,
+   if (!(SUMA_Save_Surface_Object ( SO_name,
                                     SO, oType, oFormat, SOpar))) {
          fprintf (SUMA_STDERR,
                   "Error %s: Failed to write surface object.\n", 
                   FuncName);
          exit (1);
-      }
    } 
    
    
