@@ -30,11 +30,11 @@ void SUMA_MapIcosahedron_usage ()
 "              inspec   -LRmerge std.LH_SPEC.spec std.RH_SPEC.spec \\\n"
 "                       -prefix std.BOTH_SPEC.spec\n"
 "\n"
-"   -rd recDepth: recursive (binary) tessellation depth for icosahedron.\n"
+"   -rd recDepth: recursive (binary) tesselation depth for icosahedron.\n"
 "        (optional, default:3) See CreateIcosahedron for more info.\n"
 "\n"
-"   -ld linDepth: number of edge divides for linear icosahedron tessellation \n"
-"        (optional, default uses binary tessellation).\n"
+"   -ld linDepth: number of edge divides for linear icosahedron tesselation \n"
+"        (optional, default uses binary tesselation).\n"
 "        See CreateIcosahedron -help for more info.\n"
 "\n"
 "   *Note: Enter -1 for recDepth or linDepth to let program \n"
@@ -95,7 +95,7 @@ void SUMA_MapIcosahedron_usage ()
 "                     \n"
 "   ----------------------------------------------------------------\n"
 "\n"
-"   -it numIt: number of smoothing iterations \n"
+"   -it numIt: number of smoothing interations \n"
 "        (optional, default none).\n"
 "\n"
 "   -prefix FOUT: prefix for output files.\n"
@@ -138,7 +138,7 @@ void SUMA_MapIcosahedron_usage ()
 "                   three nodes in the original mesh.\n"
 "                   The file is named by the prefix of the output\n"
 "                   spec file and suffixed by MI.1D\n"
-"  NOTE I: This option is useful for understanding what contributed\n"
+"  NOTE: This option is useful for understanding what contributed\n"
 "        to a node's position in the standard meshes (STD_M).\n"
 "        Say a triangle on the  STD_M version of the white matter\n"
 "        surface (STD_WM) looks fishy, such as being large and \n"
@@ -151,35 +151,8 @@ void SUMA_MapIcosahedron_usage ()
 "        (or N0 or N2) on the original sphere.reg and examine the\n"
 "        mesh there, which is best seen in mesh view mode ('p' button).\n"
 "        It will most likely be the case that the sphere.reg mesh\n"
-"        there would be highly distorted (quite compressed).\n"
-"  NOTE II: The program also outputs a new mapping file in the format\n"
-"        that SurfToSurf  likes. This format has the extension .niml.M2M\n"
-"        This way you can use SurfToSurf to map a new dataset from original\n"
-"        to standard meshes in the same way that MapIcosahedron would have\n"
-"        carried out the mapping.\n"
-"        For example, the following command creates standard meshes and\n"
-"        also maps thickness data onto the new meshes:\n"
-"            MapIcosahedron -spec rh.spec -ld 60 \\\n"
-"                           -dset_map rh.thickness.gii.dset \\\n"
-"                           -prefix std.60.\n"
-"        Say you want to map another (SOMEDSET) dataset defined on the\n"
-"        original mesh onto the std.60 mesh and use the same mapping derived \n"
-"        by MapIcosahedron. The command for that would be:\n"
-"            SurfToSurf -i_fs std.60.rh.smoothwm.asc \\\n"
-"                       -i_fs rh.smoothwm.asc \\\n"
-"                       -prefix std.60. \\\n"
-"                       -mapfile std.60.rh.niml.M2M \\\n"
-"                       -dset rh.SOMEDSET.gii.dset\n"
+"        there would be highly distorted (quite compressed).\n"    
 "   -no_nodemap: Opposite of write_nodemap\n"
-"   -write_dist PREFIX: write distortions to PREFIX.LABEL\n"
-"        The mapping for 0,0,0-centered surfaces was previously distorted.\n"
-"        Write a file containing the node-wise distortion vectors.\n"
-"        One could then summarize that file using 1d_tool.py, as in:\n"
-"            1d_tool.py -collapse_cols euclidean_norm -show_mmms \\\n"
-"                       -infile PREFIX.LABEL.txt\n"
-"        or simply write out the euclidean norms for suma display:\n"
-"            1d_tool.py -collapse_cols euclidean_norm \\\n"
-"                       -infile PREFIX.LABEL.txt -write PREFIX.enorm.1D\n"
 "\n"
 "NOTE 1: The algorithm used by this program is applicable\n"
 "      to any surfaces warped to a spherical coordinate\n"
@@ -223,9 +196,7 @@ int main (int argc, char *argv[])
    static char FuncName[]={"MapIcosahedron"};
    SUMA_Boolean brk, smooth=NOPE, verb=NOPE, all_surfs_spec=NOPE;
    char fout[SUMA_MAX_FILENAME_LENGTH];
-   char * dist_prefix=NULL;
-   char icoFileNm[SUMA_MAX_FILENAME_LENGTH], 
-        outSpecFileNm[SUMA_MAX_FILENAME_LENGTH];
+   char icoFileNm[SUMA_MAX_FILENAME_LENGTH], outSpecFileNm[SUMA_MAX_FILENAME_LENGTH];
    char bin[SUMA_MAX_FILENAME_LENGTH], *histnote=NULL;
    int numTriBin=0, numTriLin=0, numIt=0;
 
@@ -303,7 +274,7 @@ int main (int argc, char *argv[])
    WriteMI = YUP;
    N_in_name = 0;
    oform = SUMA_ASCII_NIML;
-   while (kar < argc) { /* loop across command line options */
+   while (kar < argc) { /* loop accross command line options */
       if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
          SUMA_MapIcosahedron_usage ();
          exit (1);
@@ -311,12 +282,12 @@ int main (int argc, char *argv[])
       
       SUMA_SKIP_COMMON_OPTIONS(brk, kar);
 
-      if (!brk && (strcmp(argv[kar], "-iodbg") == 0)) {
-          fprintf( SUMA_STDOUT,
-                "Warning %s: SUMA running in in/out debug mode.\n", FuncName);
-          SUMA_INOUT_NOTIFY_ON;
-          brk = YUP;
-      }
+		if (!brk && (strcmp(argv[kar], "-iodbg") == 0)) {
+			fprintf( SUMA_STDOUT,
+                  "Warning %s: SUMA running in in/out debug mode.\n", FuncName);
+			SUMA_INOUT_NOTIFY_ON;
+			brk = YUP;
+		}
       if (!brk && (strcmp(argv[kar], "-memdbg") == 0)) {
          fprintf( SUMA_STDOUT,
                   "Warning %s: SUMA running in memory trace mode.\n", FuncName);
@@ -362,7 +333,7 @@ int main (int argc, char *argv[])
                               "Warning %s:\n"
                               " Using sphere's center of mass as a\n"
                               " geometric center. This is only for\n"
-                              " compulsive backward compatibility.\n"
+                              " compulsive backward comaptibility.\n"
                               " It is better NOT to use this option.\n", 
                               FuncName);
          UseCOM = YUP;
@@ -528,22 +499,10 @@ int main (int argc, char *argv[])
             brk = YUP;
          }   
       
-      if (!brk && strcmp(argv[kar], "-write_dist") == 0)
-         {
-            kar ++;
-            if (kar >= argc)  {
-               fprintf (SUMA_STDERR, "need argument after -write_dist");
-               exit (1);
-            }
-            dist_prefix = argv[kar];
-            brk = YUP;
-         }   
-      
       if (!brk) {
          fprintf (SUMA_STDERR,
                   "Error %s: Option %s not understood. Try -help for usage\n", 
                   FuncName, argv[kar]);
-         suggest_best_prog_option(argv[0], argv[kar]);
          exit (1);
       } 
       else {   
@@ -551,7 +510,7 @@ int main (int argc, char *argv[])
          kar ++;
       }
       
-   }/* loop across command line options */
+   }/* loop accross command line options */
 
    /* check on output file name */
    if (!THD_ok_overwrite()) {
@@ -575,7 +534,7 @@ int main (int argc, char *argv[])
    sprintf (outSpecFileNm, "%s%s", 
             fout, SUMA_FnameGet(brainSpecFile,"f", SUMAg_CF->cwd));
    
-   if (LocalHead && !UseCOM && UserCenter == -1) {/* Enough already. Dec 2011 */
+   if (!UseCOM && UserCenter == -1) {
       SUMA_S_Note("\n"
                   "---------------------------------------------------\n"
                   "The program now uses the estimated geometric center\n"
@@ -594,7 +553,7 @@ int main (int argc, char *argv[])
    }
    if (LocalHead) 
       fprintf (SUMA_STDERR, 
-               "%s: %s contains surfaces, tessellation depth is %d.\n", 
+               "%s: %s contains surfaces, tesselation depth is %d.\n", 
                FuncName, brainSpecFile, depth);
    if (brainSpecFile == NULL) {
       fprintf (SUMA_STDERR,"Error %s: No spec file specified.\n", FuncName);
@@ -612,11 +571,7 @@ int main (int argc, char *argv[])
                FuncName, brainSpecFile);
       exit(1);
    }
-   /* Remove some states that are certainly of no use here 
-      ZSS. Aug 06 2013                                              */
-   SUMA_RemoveSpecState(&brainSpec, "pial-outer-smoothed", 1, "SAME");     
-   
-   /* scan through spec file and make sure there is one and only one
+   /* scan trough spec file and make sure there is one and only one
       LocalDomainParent. Otherwise issue a warning */
    found = 0;
    for (i=0; i<brainSpec.N_Surfs; ++i) {
@@ -856,7 +811,7 @@ int main (int argc, char *argv[])
             ++found; 
             if (!(SO_morph = SUMA_findSOp_inDOv (brainSpec.IDcode[i], 
                                                  SUMAg_DOv, SUMAg_N_DOv))) {
-               SUMA_S_Err("Could not locate surface!");
+               SUMA_S_Err("Could not locate suface!");
                exit(1);
             }
          }
@@ -880,7 +835,7 @@ int main (int argc, char *argv[])
                      "%s\n", morph_surf, brainSpec.State[i]);
             if (!(SO_morph = SUMA_findSOp_inDOv (brainSpec.IDcode[i], 
                                                  SUMAg_DOv, SUMAg_N_DOv))) {
-               SUMA_S_Err("Could not locate surface!");
+               SUMA_S_Err("Could not locate suface!");
                exit(1);
             }
          }
@@ -910,7 +865,7 @@ int main (int argc, char *argv[])
             found = 1;
             if (!(SO_morph = SUMA_findSOp_inDOv (brainSpec.IDcode[i], 
                                                  SUMAg_DOv, SUMAg_N_DOv))) {
-               SUMA_S_Err("Could not locate surface!");
+               SUMA_S_Err("Could not locate suface!");
                exit(1);
             }
          }
@@ -928,9 +883,8 @@ int main (int argc, char *argv[])
    if (SO_morph->MF==NULL) 
       SUMA_SurfaceMetrics_eng(SO_morph, "MemberFace", NULL, 
                               0, SUMAg_CF->DsetList);    
-   if (!SO_morph->Label && !
-       (SO_morph->Label =  SUMA_SurfaceFileName(SO_morph, NOPE))){
-       SO_morph->Label = SUMA_copy_string("LeMorphometre");
+   if (!SO_morph->Label) {
+      SO_morph->Label =  SUMA_SurfaceFileName(SO_morph, NOPE);
    }
    if (!(SUMA_SetSphereParams(SO_morph, 0.1))) {
       SUMA_S_Err("Failed to set sphere parameters");
@@ -962,9 +916,9 @@ int main (int argc, char *argv[])
       Cx = SUMA_Convexity_Engine ( SO_morph->NodeList, 
                                    SO_morph->N_Node, 
                                    SO_morph->NodeNormList, 
-                                   SO_morph->FN, OutName, NULL);
+                                   SO_morph->FN, OutName);
       if (Cx) SUMA_free(Cx); Cx = NULL;
-      SUMA_SphereQuality (SO_morph, SO_morph->Label, NULL, NULL, NULL);
+      SUMA_SphereQuality (SO_morph, SO_morph->Label, NULL);
       fprintf( SUMA_STDERR, 
                "%s:\nExiting after SUMA_SphereQuality\n", FuncName);
 
@@ -1198,7 +1152,7 @@ int main (int argc, char *argv[])
       SO_morph->isSphere = SUMA_GEOM_NOT_SET;
    }
    
-   MI = SUMA_MapSurface( icoSurf, SO_morph, verb, dist_prefix ) ;
+   MI = SUMA_MapSurface( icoSurf, SO_morph, verb ) ;
    if (!MI) {
       fprintf (SUMA_STDERR, 
                "Error %s: Failed in SUMA_MapIcosahedron.\n", FuncName);
@@ -1249,16 +1203,6 @@ int main (int argc, char *argv[])
          SUMA_S_Err("Failed to create M2M");
          exit(1);
       }
-      if (WriteMI) {
-         char *fname =  SUMA_copy_string(outSpecFileNm);
-         fname = SUMA_append_replace_string( SUMA_CropExtension(fname,".spec"),
-                           "","",1);
-         if (!(SUMA_Save_M2M(fname, M2M))) {
-            SUMA_S_Err("Failed to save M2M");
-            exit(1);
-         }
-         SUMA_free(fname); fname=NULL; 
-      }
       for (i=0; i<N_in_name; ++i) {
          if (verb) SUMA_S_Notev("Processing dset %s\n", in_name[i]);
          iform = SUMA_NO_DSET_FORMAT;
@@ -1272,7 +1216,7 @@ int main (int argc, char *argv[])
          }
          uname = SUMA_append_replace_string(
                SUMA_FnameGet(in_name[i],"pa", SUMAg_CF->cwd), 
-                             SUMA_FnameGet(in_name[i],"l",SUMAg_CF->cwd), 
+                             SUMA_FnameGet(in_name[i],"f",SUMAg_CF->cwd), 
                              fout, 0);
          oname = SUMA_WriteDset_s (uname, dseto, SUMA_ASCII_NIML, 1, 1); 
          if (verb) SUMA_S_Notev("Wrote %s\n", oname);
@@ -1548,6 +1492,7 @@ int main (int argc, char *argv[])
    
    SCRUBIT;   
 
+
    SUMA_RETURN(0);
    
 }/* main SUMA_MapIcosahedron*/
