@@ -86,7 +86,7 @@ SUMA_GENERIC_PROG_OPTIONS_STRUCT *SUMA_NikoMap_ParseInput(char *argv[], int argc
    Opt->NodeDbg = -1;
    kar = 1;
    brk = NOPE;
-	while (kar < argc) { /* loop across command line options */
+	while (kar < argc) { /* loop accross command ine options */
 		/*fprintf(stdout, "%s verbose: Parsing command line...\n", FuncName);*/
 		if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
 			 usage_NikoMap(ps);
