@@ -1,6 +1,6 @@
 #include "SUMA_suma.h"
 
-void usage_ROI2dataset_Main (int detail)
+void usage_ROI2dataset_Main ()
    
   {/*Usage*/
       static char FuncName[]={"usage_ROI2dataset_Main"};
@@ -11,6 +11,7 @@ void usage_ROI2dataset_Main (int detail)
 "   ROI2dataset <-prefix dsetname> [...] <-input ROI1 ROI2 ...>\n"
 "               [<-of ni_bi|ni_as|1D>] \n"
 "               [<-dom_par_id idcode>] \n"
+/* "   [<-dom_par domain> NOT IMPLEMENTED YET] \n" */
 "    This program transforms a series of ROI files\n"
 "    to a node dataset. This data set will contain\n"
 "    the node indices in the first column and their\n"
@@ -24,7 +25,6 @@ void usage_ROI2dataset_Main (int detail)
 "                          Program will not overwrite existing\n"
 "                          datasets.\n"
 "                          See also -label_dset alternate below.\n"
-"    -keep_separate: Output one column (sub-brick) for each ROI value\n"
 "\n"      
 " and/or\n"
 "    -nodelist        NL: Prefix for a set of .1D files\n"
@@ -39,20 +39,11 @@ void usage_ROI2dataset_Main (int detail)
 "                         encountered in an ROI file and across ROI files.\n"
 "                         If you want duplicate node entries removed, then\n"
 "                         use -nodelist.nodups instead.\n"
-"                   For example, say you traced an ROI that consisted of some \n"
-"                   arbitrary curved path and you want to get the nodes \n"
-"                   forming the path in the order traversed while drawing.\n"
-"                   First save the path drawn, say to trace.niml.roi, \n"
-"                   then use the following command:\n"
-"                         ROI2dataset -nodelist.nodups TRACE \\\n"
-"                                     -input trace.niml.roi\n"
 "                   Note: You can use the output of -nodelist as input to \n"
 "                         ConvertDset's -node_select_1D option. \n"
-"                         This is not the case for -nodelist because\n"
-"                         ConvertDset's -node_select_1D does not allow for \n"
+"                         This is not the case for -nodelist.nodups because\n"
+"                         ConvertDset's -node_select_1D does allow for \n"
 "                         duplicate node entries. \n"
-"    -nodelist_with_ROIval: Also add the ROIval as a second column in .1D\n"
-"                           files output by -nodelist.\n"
 "    -input ROI1 ROI2....: ROI files to turn into a \n"
 "                          data set. This parameter MUST\n"
 "                          be the last one on command line.\n"
@@ -62,9 +53,6 @@ void usage_ROI2dataset_Main (int detail)
 "\n"
 "    -label_dset dsetname: Write a label dataset, instead of a simple dataset.\n"
 "                          Labeled datasets are treated differently in SUMA.\n"   "                          This option also sets the output format to NIML.\n"
-"                    Note: Using -keep_separate with this option is legal, but\n"
-"                          makes little sense. You can't view more than one \n"
-"                          sub-brick in SUMA for Labeled datasets.\n"
 "    -h | -help: This help message\n"
 "    -of FORMAT: Output format of dataset. FORMAT is one of:\n"
 "                ni_bi: NIML binary\n"
@@ -87,9 +75,7 @@ void usage_ROI2dataset_Main (int detail)
 "                            specify your own padding label.\n"
 "    -pad_label padding_label: Use padding_label (an integer) to\n"
 "                            label nodes that do not belong\n"
-"                            to any ROI. Default is 0.\n"
-"                         This padding value is also used in the multi-column\n"
-"                            format of option -keep_separate.\n" 
+"                            to any ROI. Default is 0.\n" 
 "\n");
          s = SUMA_New_Additions(0, 1); printf("%s\n", s);SUMA_free(s); s = NULL;
          fprintf(SUMA_STDOUT, 
@@ -110,20 +96,24 @@ int main (int argc,char *argv[])
    NI_stream ns;
    SUMA_DSET_FORMAT Out_Format = SUMA_ASCII_NIML;
    SUMA_DRAWN_ROI ** ROIv = NULL, **tROIv = NULL;
-   SUMA_Boolean AddThis = NOPE;
+	SUMA_Boolean AddThis = NOPE;
    SUMA_ROI_EXTRACT *dd=NULL;
    DList *ddl=NULL;
    DListElmt *el=NULL;
-   int nodups=0, olabel = 0, withflag = 0, keepsep=0;
+   int nodups=0, olabel = 0;
    SUMA_COLOR_MAP *cmap=NULL;
    SUMA_Boolean LocalHead = NOPE;
-   
+	
    SUMA_STANDALONE_INIT;
    SUMA_mainENTRY;
+	
+   if (argc < 4) {
+      usage_ROI2dataset_Main ();
+   }
    
    /* parse the command line */
    kar = 1;
-   brk = NOPE;
+	brk = NOPE;
    prefix_name = NULL;
    input_name_v = NULL;
    N_input_name = 0;
@@ -132,37 +122,35 @@ int main (int argc,char *argv[])
    pad_to = -1;
    pad_val = 0;
    nodelist=NULL;
-   withflag = 0;
    olabel = 0;
-   keepsep = 0;
    nodups = 0;
-   while (kar < argc) { /* loop across command line options */
-      /* SUMA_LH("Parsing command line..."); */
+   while (kar < argc) { /* loop accross command ine options */
+		/* SUMA_LH("Parsing command line..."); */
       
-      if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
-          usage_ROI2dataset_Main(strlen(argv[kar]) > 3 ? 2:1);
+		if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
+			 usage_ROI2dataset_Main();
           exit (1);
-      }
+		}
       
       SUMA_SKIP_COMMON_OPTIONS(brk, kar);
       
       if (!brk && (strcmp(argv[kar], "-prefix") == 0)) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need argument after -prefix ");
-            exit (1);
-         }
-         prefix_name = argv[kar];
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -prefix ");
+				exit (1);
+			}
+			prefix_name = argv[kar];
          brk = YUP;
-      }
+		}
       
       if (!brk && (strcmp(argv[kar], "-label_dset") == 0)) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need argument after -label_dset ");
-            exit (1);
-         }
-         prefix_name = argv[kar];
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -label_dset ");
+				exit (1);
+			}
+			prefix_name = argv[kar];
          if (Out_Format != SUMA_NO_DSET_FORMAT &&
              Out_Format != SUMA_ASCII_NIML &&
              Out_Format != SUMA_BINARY_NIML) {
@@ -174,42 +162,28 @@ int main (int argc,char *argv[])
          else Out_Format = SUMA_BINARY_NIML;
          olabel = 1;
          brk = YUP;
-      }
+		}
       
       if (  !brk && 
-            (strcmp(argv[kar], "-keep_separate") == 0) ) {
-         keepsep = 1;
-         brk = YUP;     
-      }
-      
-      
-      if (  !brk && 
-            (strcmp(argv[kar], "-nodelist") == 0 || 
-             strcmp(argv[kar], "-nodelist.nodups") == 0) ) {
-         if (strlen(argv[kar])> 10) nodups = 1;
+            (strncmp(argv[kar], "-nodelist", 9) == 0) ) {
+         if (strcmp(argv[kar], "-nodelist.nodups") == 0) nodups = 1;
          else nodups = 0;
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need argument after -nodelist* options ");
-            exit (1);
-         }
-         nodelist = argv[kar];
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -nodelist* options ");
+				exit (1);
+			}
+			nodelist = argv[kar];
          
          brk = YUP;
-      }
-      
-      if (  !brk && 
-            (strcmp(argv[kar], "-nodelist_with_ROIval") == 0) ) {
-         withflag = 1;
-         brk = YUP;     
-      }
+		}
       
       if (!brk && (strcmp(argv[kar], "-of") == 0)) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need argument after -of ");
-            exit (1);
-         }
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -of ");
+				exit (1);
+			}
          
          Out_Format = SUMA_NO_DSET_FORMAT;
                      /* Can't use isOutputFormatFromArg because -of is not part
@@ -217,7 +191,7 @@ int main (int argc,char *argv[])
          if (!SUMA_isFormatFromArg(argv[kar], &Out_Format)) {
             fprintf (SUMA_STDERR, 
                      "%s not a valid option with -of.\n", argv[kar]);
-            exit (1);
+				exit (1);
          }
          if (olabel && 
              Out_Format != SUMA_ASCII_NIML &&
@@ -227,24 +201,24 @@ int main (int argc,char *argv[])
          } 
          
          brk = YUP;
-      }
+		}
       
       if (!brk && (strcmp(argv[kar], "-dom_par_id") == 0)) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need argument after -dom_par_id");
-            exit (1);
-         }
-         Parent_idcode_str = SUMA_copy_string(argv[kar]);
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -dom_par_id");
+				exit (1);
+			}
+			Parent_idcode_str = SUMA_copy_string(argv[kar]);
          brk = YUP;
       }
       
       if (!brk && (strcmp(argv[kar], "-input") == 0)) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need at least one argument after -input ");
-            exit (1);
-         }
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need at least one argument after -input ");
+				exit (1);
+			}
          input_name_v = (char **)SUMA_malloc((argc-kar+1)*sizeof(char *));
          
          cnt = 0;
@@ -256,34 +230,39 @@ int main (int argc,char *argv[])
          brk = YUP;
       }
       
+      #if 0   /* now handled in main_ENTRY() */
+      if (!brk && (strcmp(argv[kar], "-pad_to_node") == 0)) {
+         kar ++;
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -pad_to_node");
+				exit (1);
+			}
+			pad_to = atoi(argv[kar]);
+         brk = YUP;
+      }
+      #endif
       if (!brk && ( (strcmp(argv[kar], "-pad_label") == 0) || 
                      (strcmp(argv[kar], "-pad_val") == 0) )) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need argument after -pad_label");
-            exit (1);
-         }
-         pad_val = atoi(argv[kar]);
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -pad_label");
+				exit (1);
+			}
+			pad_val = atoi(argv[kar]);
          brk = YUP;
       }
       
       if (!brk) {
-         fprintf (SUMA_STDERR,
+			fprintf (SUMA_STDERR,
                   "Error %s: Option %s not understood. Try -help for usage\n", 
                   FuncName, argv[kar]);
-         suggest_best_prog_option(argv[0], argv[kar]);
-         exit (1);
-      } else { 
-         brk = NOPE;
-         kar ++;
-      }   
+			exit (1);
+		} else {	
+			brk = NOPE;
+			kar ++;
+		}   
    }   
    
-   if (argc < 4) {
-      SUMA_S_Err("Too few options");
-      usage_ROI2dataset_Main (1);
-   }
-   
    if (MRILIB_DomainMaxNodeIndex >= 0) pad_to = MRILIB_DomainMaxNodeIndex;
 
    if (!prefix_name && !nodelist) {
@@ -318,7 +297,7 @@ int main (int argc,char *argv[])
             break;
       }
       #endif
-      SUMA_LH ("%s",out_name);
+      SUMA_LH (out_name);
 
       /* check for existence of out_name */
       if (SUMA_filexists(out_name) && !THD_ok_overwrite()) {
@@ -371,7 +350,7 @@ int main (int argc,char *argv[])
          exit(1);
       }
 
-      /* Now go throughout the ROIs and load them if possible into ROIv */
+      /* Now go throught the ROIs and load them if possible into ROIv */
       SUMA_LHv("Cycling over %d rois\n", N_tROI);
       for (ii=0; ii < N_tROI; ++ii) {
          if (!Parent_idcode_str) {
@@ -433,7 +412,7 @@ int main (int argc,char *argv[])
       el = dlist_head(ddl);
       while (el) {
          dd = (SUMA_ROI_EXTRACT *)el->data;
-         sprintf(cbuf, ".%03d.1D", dd->label);
+         sprintf(cbuf, ".%0d.1D", dd->label);
          outlist_name = SUMA_append_string(nodelist, cbuf);
          /* check for existence of outlist_name */
          if (SUMA_filexists(outlist_name) && !THD_ok_overwrite()) {
@@ -442,12 +421,7 @@ int main (int argc,char *argv[])
             exit(1); 
          }
          
-         if (withflag) {
-            SUMA_WRITE_INT_ARRAY_AND_FLAG_1D(dd->vals, dd->N_vals, 1, 
-                                             outlist_name, dd->label);
-         } else {
-            SUMA_WRITE_INT_ARRAY_1D(dd->vals, dd->N_vals, 1, outlist_name);
-         }
+         SUMA_WRITE_INT_ARRAY_1D(dd->vals, dd->N_vals, 1, outlist_name);
          SUMA_free(outlist_name); outlist_name = NULL;
          el = dlist_next(el);
       } 
@@ -455,23 +429,14 @@ int main (int argc,char *argv[])
    }
    
    if (out_name) { /* output dset required */
-      if (!keepsep) {
-         if (!(dset = SUMA_ROIv2Grpdataset ( ROIv, N_ROIv, 
-                                             Parent_idcode_str, 
-                                             pad_to, pad_val, 
-                                             &cmap))) {
-            SUMA_SL_Err("Failed in SUMA_ROIv2Grpdataset");
-            exit(1);
-         }
-      } else {
-         if (!(dset = SUMA_ROIv2MultiDset ( ROIv, N_ROIv, 
-                                             Parent_idcode_str, 
-                                             pad_to, pad_val, 
-                                             &cmap))) {
-            SUMA_SL_Err("Failed in SUMA_ROIv2MultiDset");
-            exit(1);
-         }
+      if (!(dset = SUMA_ROIv2Grpdataset ( ROIv, N_ROIv, 
+                                          Parent_idcode_str, 
+                                          pad_to, pad_val, 
+                                          &cmap))) {
+         SUMA_SL_Err("Failed in SUMA_ROIv2Grpdataset");
+         exit(1);
       }
+
       if (LocalHead) {
          fprintf (SUMA_STDERR,"%s: Adding history\n",
                            FuncName);
