@@ -8,88 +8,61 @@ void usage_ROIgrow (SUMA_GENERIC_ARGV_PARSE *ps)
       int i;
       s = SUMA_help_basics();
       sio  = SUMA_help_IO_Args(ps);
-      printf ( 
-"\n"
-"Usage: ROIgrow <-i_TYPE SURF> <-roi_nodes ROI.1D> <-lim LIM>\n"
-"               [-prefix PREFIX]\n"
-"       A program to expand an ROI on the surface.\n"
-"       The roi is grown from each node by a user-determined\n"
-"       distance (geodesic, measured along the mesh).\n"
-"\n"
-"  Mandatory Parameters:\n"
-"     -i_TYPE SURF: Specify input surface.\n"
-"             You can also use -t* and -spec and -surf\n"
-"             methods to input surfaces. See below\n"
-"             for more details.\n"
-"     -roi_labels ROI_LABELS: Data column containing\n"
-"                             integer labels of ROIs.\n"
-"                             Each integer label gets\n"
-"                             grown separately.\n"
-"                             If ROI_LABELS is a dataset in niml\n"
-"                             format, then you need not\n"
-"                             use -roi_nodes because node \n"
-"                             indices are stored with the \n"
-"                             labels.\n"
-"        Notice: With this option, an output is created for\n"
-"                each label. The output contains two columns:\n"
-"                One with node indices and one with the label.\n"
-"                When this option is not used, you get one\n"
-"                column out containing node indices only.\n"
-"\n"
-"        You can also use the key word PER_NODE (i.e. -roi_labels PER_NODE)\n"
-"        to tell the program to consider each node to be a separate ROI.\n"
-"        If you do not use the option -roi_nodes (see below), then each node\n"
-"        forming the surface is considered to be an ROI on its own and a \n"
-"        region will be grown around it accordingly. Under this scenario you \n"
-"        would get as many files out as you have nodes in the surface.\n"
-"        If you do specify the option -roi_nodes, then growth is done \n"
-"        separately from each node index found in ROI_INDICES below.\n"
-"        PER_NODE is likely to produce lots of files unless restricted to a \n"
-"        few node indices. You could hide them by using a prefix beginning\n"
-"        with '.', such as -prefix .HIDDEN_FILES \n"
-"        \n"
-"        Example: ROIgrow -i ld20 -roi_labels PER_NODE -prefix toy -lim 10\n"
-"\n"
-"                 #launch suma with:\n"
-"                 suma -i ld20 &\n"
-"                 #Visualize grown neighborhood around node 1484 for example.\n"
-"                 DriveSuma -com surf_cont -load_dset toy.1484.1D -I_sb 1\n"
-"\n"
-"     -full_list: Output a row for each node on the surface.\n"
-"                 Nodes not in the grown ROI, receive a 0 for\n"
-"                 a label. This option is ONLY for use with\n"
-"                 -roi_labels. This way you can combine \n"
-"                 multiple grown ROIs with, say, 3dcalc.\n"
-"                 For such operations, you are better off \n"
-"                 using powers of 2 for integer labels.\n"
-"     -roi_nodes ROI_INDICES: Data column containing\n"
-"                     node indices of ROI. \n"
-"                     Use the [] column\n"
-"                     specifier if you have more than\n"
-"                     one column in the data file.\n"
-"                     To get node indices from a niml dset\n"
-"                     use the '[i]' selector.\n"
-"     -grow_from_edge: Grow ROIs from their edges rather than\n"
-"                      the brute force default. This might \n"
-"                      make the program faster on large ROIs  \n"
-"                      and large surfaces.\n"
-"     -lim LIM: Distance to cover from each node.\n"
-"               The units of LIM are those of the surface's\n"
-"               node coordinates. Distances are calculated\n"
-"               along the surface's mesh.\n"
-"     -insphere DIA: Instead of growing along the surface, \n"
-"                    just add nodes that are inside a sphere of\n"
-"                    diameter DIA around the ROI node.\n"
-"                    Option -grow_from_edge is useless in this mode.\n"
-"     -inbox E1 E2 E3: Like -isinsphere, but use a box of edge widths\n"
-"                        E1 E2 E3 instead of DIA.\n"
-"\n"
-"  Optional Parameters:\n"
-"     -prefix PREFIX: Prefix of 1D output dataset.\n"
-"                     Default is ROIgrow\n"
-" \n"
-"%s"
-"%s"
+      printf ( "\n"
+               "Usage: ROIgrow <-i_TYPE SURF> <-roi_nodes ROI.1D> <-lim LIM>\n"
+               "               [-prefix PREFIX]\n"
+               "       A program to expand an ROI on the surface.\n"
+               "       The roi is grown from each node by a user-determined\n"
+               "       distance (geodesic, measured along the mesh).\n"
+               "\n"
+               "  Mandatory Parameters:\n"
+               "     -i_TYPE SURF: Specify input surface.\n"
+               "             You can also use -t* and -spec and -surf\n"
+               "             methods to input surfaces. See below\n"
+               "             for more details.\n"
+               "     -roi_labels ROI_LABELS: Data column containing\n"
+               "                             integer labels of ROIs.\n"
+               "                             Each integer label gets\n"
+               "                             grown separately.\n"
+               "                             If ROI_LABELS is in niml\n"
+               "                             format, then you need not\n"
+               "                             use -roi_nodes because node \n"
+               "                             indices are stored with the \n"
+               "                             labels.\n"
+               "        Notice: With this option, an output is created for\n"
+               "                each label. The output contains two columns:\n"
+               "                One with node indices and one with the label.\n"
+               "                When this option is not used, you get one\n"
+               "                column out containing node indices only.\n"
+               "     -full_list: Output a row for each node on the surface.\n"
+               "                 Nodes not in the grown ROI, receive a 0 for\n"
+               "                 a label. This option is ONLY for use with\n"
+               "                 -roi_labels. This way you can combine \n"
+               "                 multiple grown ROIs with, say, 3dcalc.\n"
+               "                 For such operations, you are better off \n"
+               "                 using powers of 2 for integer labels.\n"
+               "     -roi_nodes ROI_INDICES: Data column containing\n"
+               "                     node indices of ROI. \n"
+               "                     Use the [] column\n"
+               "                     specifier if you have more than\n"
+               "                     one column in the data file.\n"
+               "                     To get node indices from a niml dset\n"
+               "                     use the '[i]' selector.\n"
+               "     -grow_from_edge: Grow ROIs from their edges rather than\n"
+               "                      the brute force default. This might \n"
+               "                      make the program faster on large ROIs  \n"
+               "                      and large surfaces.\n"
+               "     -lim LIM: Distance to cover from each node.\n"
+               "               The units of LIM are those of the surface's\n"
+               "               node coordinates. Distances are calculated\n"
+               "               along the surface's mesh."
+               "\n"
+               "  Optional Parameters:\n"
+               "     -prefix PREFIX: Prefix of 1D output dataset.\n"
+               "                     Default is ROIgrow\n"
+               " \n"
+               "%s"
+               "%s"
                "\n", sio,  s);
       SUMA_free(s); s = NULL; SUMA_free(st); st = NULL; SUMA_free(sio); sio = NULL;       
       s = SUMA_New_Additions(0, 1); printf("%s\n", s);SUMA_free(s); s = NULL;
@@ -100,7 +73,7 @@ void usage_ROIgrow (SUMA_GENERIC_ARGV_PARSE *ps)
 SUMA_GENERIC_PROG_OPTIONS_STRUCT *SUMA_ROIgrow_ParseInput(
                char *argv[], int argc, SUMA_GENERIC_ARGV_PARSE *ps)
 {
-   static char FuncName[]={"SUMA_ROIgrow_ParseInput"}; 
+   static char FuncName[]={"SUMA_BrainWrap_ParseInput"}; 
    SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt=NULL;
    int kar;
    SUMA_Boolean brk;
@@ -110,21 +83,21 @@ SUMA_GENERIC_PROG_OPTIONS_STRUCT *SUMA_ROIgrow_ParseInput(
    
    Opt = SUMA_Alloc_Generic_Prog_Options_Struct();
    Opt->out_prefix = NULL;
+   Opt->d1 = -1;
    Opt->in_nodeindices = NULL;
    Opt->in_name = NULL;
    Opt->PushToEdge = 0;
-   Opt->b1 = 0; Opt->b2 = 0;
-   Opt->cog[0]=-1; Opt->cog[1]=0.0; Opt->cog[2]=0.0;
+   Opt->b1 = 0;
    kar = 1;
    brk = NOPE;
-   while (kar < argc) { /* loop across command line options */
-      /*fprintf(stdout, "%s verbose: Parsing command line...\n", FuncName);*/
-      if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
-          usage_ROIgrow(ps);
+	while (kar < argc) { /* loop accross command ine options */
+		/*fprintf(stdout, "%s verbose: Parsing command line...\n", FuncName);*/
+		if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
+			 usage_ROIgrow(ps);
           exit (0);
-      }
-      
-      SUMA_SKIP_COMMON_OPTIONS(brk, kar);
+		}
+		
+		SUMA_SKIP_COMMON_OPTIONS(brk, kar);
       
       if (!brk && (strcmp(argv[kar], "-debug") == 0))
       {
@@ -182,36 +155,7 @@ SUMA_GENERIC_PROG_OPTIONS_STRUCT *SUMA_ROIgrow_ParseInput(
             exit (1);
          }
          
-         Opt->b2 = 0;
-         Opt->cog[0] = atof(argv[++kar]);
-         brk = YUP;
-      }
-      
-      if (!brk && (strcmp(argv[kar], "-insphere") == 0))
-      {
-         if (kar+1 >= argc)
-         {
-            fprintf (SUMA_STDERR, "need a parameter after -insphere \n");
-            exit (1);
-         }
-         
-         Opt->b2 = 1;
-         Opt->cog[0] = atof(argv[++kar]);
-         brk = YUP;
-      }
-      
-      if (!brk && (strcmp(argv[kar], "-inbox") == 0))
-      {
-         if (kar+3 >= argc)
-         {
-            fprintf (SUMA_STDERR, "need 3 parameters after -inbox \n");
-            exit (1);
-         }
-         
-         Opt->b2 = 2;
-         Opt->cog[0] = atof(argv[++kar]);
-         Opt->cog[1] = atof(argv[++kar]);
-         Opt->cog[2] = atof(argv[++kar]);
+         Opt->d1 = atof(argv[++kar]);
          brk = YUP;
       }
       
@@ -226,19 +170,18 @@ SUMA_GENERIC_PROG_OPTIONS_STRUCT *SUMA_ROIgrow_ParseInput(
          brk = YUP;
       }
       if (!brk && !ps->arg_checked[kar]) {
-         fprintf (SUMA_STDERR,
+			fprintf (SUMA_STDERR,
                   "Error %s:\nOption %s not understood.\n"
                   "Try -help for usage\n", FuncName, argv[kar]);
-         suggest_best_prog_option(argv[0], argv[kar]);
-         exit (1);
-      } else { 
-         brk = NOPE;
-         kar ++;
-      }
+			exit (1);
+		} else {	
+			brk = NOPE;
+			kar ++;
+		}
    }
    
    if (!Opt->out_prefix) Opt->out_prefix = SUMA_copy_string("ROIgrow"); 
-   if (Opt->cog[0] < 0) {
+   if (Opt->d1 < 0) {
       fprintf (SUMA_STDERR,"-lim option not specified.");
       exit (1);
    }
@@ -399,20 +342,18 @@ int main (int argc,char *argv[])
    SUMA_SurfSpecFile *Spec = NULL;
    int N_Spec=0, *nodeind = NULL, N_nodeind, i, cnt, j;
    int *nodeind_tmp=NULL, N_nodeind_tmp, free_nodeind = 1;
-   int  *nodelabels = NULL, N_nodelabels, *lbls=NULL, N_lbls=0;
-   int  per_node=0;  /* if PER_NODE, accept label==0  [27 Nov 2019 rickr] */
+	int  *nodelabels = NULL, N_nodelabels, *lbls=NULL, N_lbls=0;
    char *outname = NULL;
    SUMA_DSET *inds_dset=NULL, *lbls_dset=NULL;
    SUMA_SurfaceObject *SO = NULL;
-   float *cent=NULL;
    SUMA_Boolean LocalHead = NOPE;
 
    SUMA_STANDALONE_INIT;
-   SUMA_mainENTRY;
+	SUMA_mainENTRY;
 
    /* Allocate space for DO structure */
-   SUMAg_DOv = SUMA_Alloc_DisplayObject_Struct (SUMA_MAX_DISPLAYABLE_OBJECTS);
-   ps = SUMA_Parse_IO_Args(argc, argv, "-i;-spec;-t;-s;");
+	SUMAg_DOv = SUMA_Alloc_DisplayObject_Struct (SUMA_MAX_DISPLAYABLE_OBJECTS);
+   ps = SUMA_Parse_IO_Args(argc, argv, "-i;");
    
    if (argc < 2) {
       usage_ROIgrow(ps);
@@ -494,49 +435,24 @@ int main (int argc,char *argv[])
    nodelabels = NULL; N_nodelabels = 0;
    if (Opt->in_name) {
       SUMA_DSET_FORMAT form=SUMA_NO_DSET_FORMAT;
-      if (!strcmp(Opt->in_name,"PER_NODE")) {
-         per_node = 1;
-         if (nodeind) {
-            /* user already specified the nodes */
-            SUMA_S_Note("Will grow each of %d nodes from %s\n",
-                        N_nodeind, Opt->in_nodeindices);
-            nodelabels = (int *)SUMA_calloc(N_nodeind, sizeof(int));
-            memcpy(nodelabels, nodeind, N_nodeind*sizeof(int));
-            N_nodelabels = N_nodeind;
-         } else {
-            /* Get all nodes of surface */
-            SUMA_S_Note("Will grow each of %d nodes forming the surface\n",
-                        SO->N_Node);
-            N_nodelabels = N_nodeind = SO->N_Node;
-            nodelabels = (int *)SUMA_calloc(N_nodeind, sizeof(int));
-            nodeind = (int *)SUMA_calloc(N_nodeind, sizeof(int));
-            for (i=0;i<N_nodeind;++i) {
-               nodelabels[i] = nodeind[i] = i;
-            } 
-         }
-      } else {  
-         if (!(lbls_dset = SUMA_LoadDset_s(Opt->in_name, &form, 0))) {
-            SUMA_S_Errv("Failed to load -roi_labels %s\n", Opt->in_name);
+      lbls_dset = SUMA_LoadDset_s(Opt->in_name, &form, 0);
+      if (SDSET_VECNUM(lbls_dset) != 1) {
+         SUMA_S_Errv(
+            "Node labels dset (%s) has more than one column.\n",
+            Opt->in_name);
+         exit(1);   
+      }
+      if (!(nodelabels = SUMA_DsetCol2Int(lbls_dset, 0, 1))) {
+         SUMA_S_Err("Failed to extract nodelabels");
+         exit(1);
+      }
+      N_nodelabels = SDSET_VECFILLED(lbls_dset);
+      if (!nodeind) {/* node indices are from the node index of the dset */
+         if (!(nodeind = SUMA_GetNodeDef(lbls_dset))) {
+            SUMA_S_Err("No node indices to go with node labels!");
             exit(1);
          }
-         if (SDSET_VECNUM(lbls_dset) != 1) {
-            SUMA_S_Errv(
-               "Node labels dset (%s) has more than one column.\n",
-               Opt->in_name);
-            exit(1);   
-         }
-         if (!(nodelabels = SUMA_DsetCol2Int(lbls_dset, 0, 1))) {
-            SUMA_S_Err("Failed to extract nodelabels");
-            exit(1);
-         }
-         N_nodelabels = SDSET_VECFILLED(lbls_dset);
-         if (!nodeind) {/* node indices are from the node index of the dset */
-            if (!(nodeind = SUMA_GetNodeDef(lbls_dset))) {
-               SUMA_S_Err("No node indices to go with node labels!");
-               exit(1);
-            }
-            N_nodeind = SDSET_VECFILLED(lbls_dset); free_nodeind = 0;
-         }
+         N_nodeind = SDSET_VECFILLED(lbls_dset); free_nodeind = 0;
       }
    }
    
@@ -554,8 +470,7 @@ int main (int argc,char *argv[])
       SUMA_LHv("Have %d unique labels...\n", N_lbls);
       /* Now do the deeds */
       for (i=0; i<N_lbls; ++i) {
-         /* if per_node, process label 0  [27 Nov 2019 rickr] */
-         if (lbls[i] || per_node ) {
+         if (lbls[i]) {
             /* make a copy of nodeind */
             if (!(nodeind_tmp = 
                   (int *)SUMA_calloc(N_nodelabels, sizeof(int)))) {
@@ -570,51 +485,13 @@ int main (int argc,char *argv[])
                }
             }
             N_nodeind_tmp = cnt;
-            switch (Opt->b2) {
-               case 0:
-                  SUMA_LHv("Processing label %d, %d nodes, growing mode %f.\n",
-                           lbls[i], N_nodeind_tmp, Opt->cog[0]);
-                  if (!(nmask = SUMA_ROIgrow(SO, nodeind_tmp, 
-                                             N_nodeind_tmp, Opt->cog[0],
-                                             Opt->PushToEdge))) {
-                     SUMA_S_Err("Failed in SUMA_ROIgrow");
-                     exit(1);
-                  }
-                  break;
-               case 1:
-                  if (nmask) SUMA_free(nmask); nmask=NULL;
-                  SUMA_LHv("Processing label %d, %d nodes, "
-                           "isinsphere mode diameter %f.\n",
-                           lbls[i], N_nodeind_tmp, Opt->cog[0]);
-                  for (j=0; j<N_nodeind_tmp; ++j) {
-                     cent = SO->NodeList+(SO->NodeDim*nodeind_tmp[j]);
-                     if (!(nmask = 
-                              SUMA_nodesinsphere2_bm(SO->NodeList, SO->N_Node,
-                                             cent, Opt->cog[0]/2.0, nmask))) {
-                        SUMA_S_Err("Failed in SUMA_nodesinsphere2_bm");
-                        exit(1);
-                     }
-                  }
-                  break;
-               case 2:
-                  if (nmask) SUMA_free(nmask); nmask=NULL;
-                  SUMA_LHv("Processing label %d, %d nodes, "
-                           "isinbox mode edges %f %f %f.\n",
-                           lbls[i], N_nodeind_tmp, 
-                           Opt->cog[0], Opt->cog[1],Opt->cog[2]);
-                  for (j=0; j<N_nodeind_tmp; ++j) {
-                     cent = SO->NodeList+(SO->NodeDim*nodeind_tmp[j]);
-                     if (!(nmask = 
-                              SUMA_nodesinbox2_bm(SO->NodeList, SO->N_Node,
-                                                  cent, Opt->cog, nmask))) {
-                        SUMA_S_Err("Failed in SUMA_nodesinbox2_bm");
-                        exit(1);
-                     }
-                  }
-                  break;
-               default:
-                  SUMA_S_Errv("Groing mode of %d not good.\n", Opt->b2);
-                  exit(1);             
+            SUMA_LHv("Processing label %d, %d nodes...\n",
+                     lbls[i], N_nodeind_tmp);
+            if (!(nmask = SUMA_ROIgrow(SO, nodeind_tmp, 
+                                       N_nodeind_tmp, Opt->d1,
+                                       Opt->PushToEdge))) {
+               SUMA_S_Err("Failed in SUMA_ROIgrow");
+               exit(1);
             }
             SUMA_WRITE_GROWN_MASK(lbls[i]);
             SUMA_free(nmask); nmask=NULL; 
@@ -623,40 +500,11 @@ int main (int argc,char *argv[])
       }
       SUMA_free(lbls); lbls = NULL;
    } else {
-      switch (Opt->b2) {
-         case 0:
-            if (!(nmask = SUMA_ROIgrow(SO, nodeind,
-                                       N_nodeind, Opt->cog[0], 
-                                       Opt->PushToEdge))) {
-               SUMA_S_Err("Failed in SUMA_ROIgrow");
-               exit(1);
-            }
-            break;
-         case 1:
-           for (j=0; j<N_nodeind; ++j) {
-               cent = SO->NodeList+(SO->NodeDim*nodeind[j]);
-               if (!(nmask = SUMA_nodesinsphere2_bm(
-                                    SO->NodeList, SO->N_Node,
-                                    cent, Opt->cog[0]/2.0, nmask))) {
-                  SUMA_S_Err("Failed in SUMA_nodesinsphere2_bm");
-                  exit(1);
-               }
-            }
-            break;
-         case 2:
-            for (j=0; j<N_nodeind; ++j) {
-               cent = SO->NodeList+(SO->NodeDim*nodeind[j]);
-               if (!(nmask = 
-                        SUMA_nodesinbox2_bm(SO->NodeList, SO->N_Node,
-                                            cent, Opt->cog, nmask))) {
-                  SUMA_S_Err("Failed in SUMA_nodesinbox2_bm");
-                  exit(1);
-               }
-            }
-            break;
-         default:
-            SUMA_S_Errv("Groing mode of %d not good.\n", Opt->b2);
-            exit(1);         
+      if (!(nmask = SUMA_ROIgrow(SO, nodeind,
+                                 N_nodeind, Opt->d1, 
+                                 Opt->PushToEdge))) {
+         SUMA_S_Err("Failed in SUMA_ROIgrow");
+         exit(1);
       }
       SUMA_WRITE_GROWN_MASK(-1);  
    }
