@@ -1,6 +1,7 @@
 #ifndef SUMA_SEGFUNC_INCLUDED
 #define SUMA_SEGFUNC_INCLUDED
 
+#define IN_MASK(mm,k) ( (!(mm) || (mm)[k]) )
 
 /*!
    Swap a column between two dsets.
@@ -112,19 +113,6 @@
    }  \
 }
 
-#define NEW_SHORTYV(par,nsb,nm,pb,view){  \
-   NEW_SHORTY(par,nsb,nm,pb); \
-   if (view) {\
-            if (!strstr(view,"orig")) \
-         EDIT_dset_items( pb ,ADN_view_type , VIEW_ORIGINAL_TYPE ,ADN_none ) ; \
-      else  if (!strstr(view,"acpc")) \
-         EDIT_dset_items( pb ,ADN_view_type, VIEW_ACPCALIGNED_TYPE ,ADN_none ); \
-      else  if (!strstr(view,"tlrc")) \
-         EDIT_dset_items( pb ,ADN_view_type, VIEW_TALAIRACH_TYPE ,ADN_none ) ; \
-      else SUMA_S_Errv("In NEW_SHORTYV; View of %s is rubbish", view);   \
-   }  \
-}
-
 #define NEW_SHORTY(par,nsb,nm,pb){  \
    int m_i;   \
    pb = EDIT_empty_copy(par); \
@@ -133,19 +121,14 @@
                     ADN_nvals, nsb, \
                     ADN_ntt, nsb, \
                     ADN_malloc_type , DATABLOCK_MEM_MALLOC ,   \
+                    ADN_view_type   , VIEW_ORIGINAL_TYPE ,  \
                     ADN_type        , HEAD_ANAT_TYPE ,   \
                     ADN_func_type   , ANAT_BUCK_TYPE ,   \
                     ADN_none ) ; \
-               /* ADN_view_type   , VIEW_ORIGINAL_TYPE ,  ZSS Sep 28 2012 */   \
    for(m_i=0;m_i<nsb;++m_i) EDIT_substitute_brick( pb, m_i, MRI_short, NULL ) ; \
    tross_Copy_History( par , pb ) ; \
 }
 
-#define SET_ALL_BRICK_FACTORS(pb, fac) {\
-   int m_i; \
-   for(m_i=0;m_i<DSET_NVALS(pb);++m_i) EDIT_BRICK_FACTOR(pb, m_i, (fac)); \
-}
-
 #define NEW_FLOATY(par,nsb,nm,pb){  \
    int m_i;   \
    pb = EDIT_empty_copy(par); \
@@ -154,6 +137,7 @@
                     ADN_nvals, nsb, \
                     ADN_ntt, nsb, \
                     ADN_malloc_type , DATABLOCK_MEM_MALLOC ,   \
+                    ADN_view_type   , VIEW_ORIGINAL_TYPE ,  \
                     ADN_type        , HEAD_ANAT_TYPE ,   \
                     ADN_func_type   , ANAT_BUCK_TYPE ,   \
                     ADN_none ) ; \
@@ -161,23 +145,6 @@
    tross_Copy_History( par , pb ) ; \
 }
 
-#define NEW_FLOATYV(par,nsb,nm,pb,fv){  \
-   int m_i; \
-   pb = EDIT_empty_copy(par); \
-   EDIT_dset_items( pb ,   \
-                    ADN_prefix , nm ,  \
-                    ADN_nvals, nsb, \
-                    ADN_ntt, nsb, \
-                    ADN_malloc_type , DATABLOCK_MEM_MALLOC ,   \
-                    ADN_type        , HEAD_ANAT_TYPE ,   \
-                    ADN_func_type   , ANAT_BUCK_TYPE ,   \
-                    ADN_none ) ; \
-   for(m_i=0;m_i<nsb;++m_i) \
-      EDIT_substitute_brick( pb, m_i, MRI_float, (m_i==0 && (fv))?(fv):NULL); \
-   tross_Copy_History( par , pb ) ; \
-}
-
-
 #define EPS 0.000001
 #define MINP 0.01   /* I tried 0.05, 0.01, and 0.001: See
                         results of @Run.PROB.12class.1 (at 0.01)
@@ -271,30 +238,6 @@
    IJK[1] = ((IJK[1]) / (ni)); \
 }
 
-/*Macros to go from 1D to 4D ubyte indexing. 
-  For SUMA_COLID_N2RGBA, you will need to pass ints for r g b a
-  even though ubyte is needed for final storage */
-#define SUMA_COLID_N2RGBA(n,r,g,b,a) { \
-   (b) = (n) & (16777215); /* x % 2^24 = x & (2^n-1) */ \
-   (a) = (n) >> 24; /* divide by 2^24 (256x256x256) */  \
-   (g) = (b) & (65535); \
-   (b) = (b) >> 16; \
-   (r) = (g) & (255); \
-   (g) = (g) >> 8;   \
-}
-#define SUMA_COLID_N2RGBA_slow(n,r,g,b,a) { \
-   (b) = (n) % (16777216); /* x % 2^24 = x & (2^n-1) */ \
-   (a) = (n) /  16777216; /* divide by 2^24 (256x256x256) */  \
-   (g) = (b) % (65536); \
-   (b) = (b) / 65536; \
-   (r) = (g) % (256); \
-   (g) = (g) / 256;  \
-}
-#define SUMA_COLID_RGBA2N(r,g,b,a,n) { \
-   (n) = ((a) << 24) + ((b) << 16) + ((g) << 8) + (r);  \
-}
-
-
 #define GET_NEIGHBS_IN_MASK(cmask, ijk, ni, nj, nk, nij, ijkn_vec){  \
    static int m_IJK[3];   \
    m_IJK[2] = ((ijk) / (nij)); \
@@ -369,6 +312,30 @@
       SUMA_free(opref); SUMA_free(oid);\
    }  \
 }      
+      
+#define SUMA_SEG_WRITE_DSET_KILLME(proot, pref, dset, iter, hh) {\
+   char m_pref[512], *m_proot = (char *)proot, *m_hh = (char*)hh; int ovw;   \
+   char *opref = SUMA_copy_string(DSET_PREFIX(dset)); \
+   char *oid = SUMA_copy_string(DSET_IDCODE_STR(dset));   \
+   char *ohist = tross_Get_History(dset); \
+   if (m_proot != NULL) {\
+      if (iter >=0) { snprintf(m_pref, 500, "%s/%s.%s.%d", \
+                                       m_proot, m_proot,pref, iter); }\
+      else { snprintf(m_pref, 500, "%s/%s.%s", m_proot, m_proot, pref); }\
+   } else { \
+      if (iter >=0) snprintf(m_pref, 500, "%s/%s.%d", m_proot, pref, iter); \
+      else snprintf(m_pref, 500, "%s%s", m_proot, pref); \
+   }  \
+   SUMA_S_Notev("Writing %s\n", m_pref);   \
+   EDIT_dset_items(  dset , ADN_prefix  , m_pref, ADN_none);  \
+   UNIQ_idcode_fill(DSET_IDCODE_STR(dset));/* new id */   \
+   if (m_hh) tross_Append_History(dset, m_hh);/*add history*/   \
+   DSET_quiet_overwrite(dset);   \
+   EDIT_dset_items(  dset , ADN_prefix  , opref, ADN_none);  \
+   strcpy(DSET_IDCODE_STR(dset), oid); \
+   if (ohist) tross_Replace_History(dset, ohist); \
+   SUMA_free(opref); SUMA_free(oid); free(ohist); ohist=NULL;\
+}
 
 #define GRID_MISMATCH(a,b) (   (DSET_NX(a) != DSET_NX(b)) \
                             || (DSET_NY(a) != DSET_NY(b)) \
@@ -384,72 +351,6 @@
 #define SUMA_knegBOUND  32
 #define SUMA_K_HOLE     48
 
-/* A macro for SUMA_hist_freq(), requires 
-int m_i0;
-float m_a;
-If you change this macro, be sure to reflect
-the changes in function SUMA_hist_freq()
-*/
-#define SUMA_HIST_FREQ(hh, val, fr) {  \
-   m_a = ((val-hh->b[0])/hh->W);   \
-   m_i0 = (int)m_a;   \
-   if (m_i0<0) { fr = hh->cn[0]; } \
-   else if (m_i0>=hh->K) { fr = hh->cn[hh->K-1]; } \
-   else { m_a = m_a-m_i0; fr = m_a*hh->cn[m_i0+1]+(1.0-m_a)*hh->cn[m_i0]; }  \
-}
-
-
-SUMA_HIST *SUMA_hist(float *v, int n, int Ku, float Wu, 
-                     float *range, char *label, int ignoreout);
-SUMA_HIST *SUMA_hist_opt(float *v, int n, int Ku, float Wu, float *range, 
-                     char *label, int ignoreout, 
-                     float oscfrqthr, char *methods);
-SUMA_HIST *SUMA_dset_hist(THD_3dim_dataset *dset, int ia, 
-                          byte *cmask, char *label, SUMA_HIST *href,
-                          int ignoreout, float oscifreq, char *methods);
-int SUMA_hist_smooth( SUMA_HIST *hh, int N_iter ); 
-float SUMA_hist_oscillation( SUMA_HIST *hh, 
-                             float minmaxfrac, float oscfracthr, int *N_osci);
-SUMA_HIST *SUMA_Free_hist(SUMA_HIST *hh);
-void SUMA_Show_hist(SUMA_HIST *hh, int norm, FILE *out);
-void SUMA_Show_dist(SUMA_FEAT_DIST *FD, FILE *out);
-void SUMA_Show_dists(SUMA_FEAT_DISTS *FDV, FILE *out, int level);
-char *SUMA_dist_info(SUMA_FEAT_DIST *FD, int level);
-char *SUMA_dists_info(SUMA_FEAT_DISTS *FDV, int level);
-float SUMA_hist_freq(SUMA_HIST *hh, float vv);
-double SUMA_hist_value(SUMA_HIST *hh, double vv, char *what);
-float SUMA_hist_perc_freq(SUMA_HIST *nn, float perc, int norm, int *iperc, 
-                          float minfreq);
-double SUMA_val_at_count(SUMA_HIST *hh, double count, int norm, int from_top);
-char *SUMA_hist_variable(SUMA_HIST *hh);
-char *SUMA_hist_conditional(SUMA_HIST *hh);
-char *SUMA_dist_variable(SUMA_FEAT_DIST *hh);
-char *SUMA_dist_conditional(SUMA_FEAT_DIST *hh);
-char *SUMA_label_variable(char *label, char c);
-char *SUMA_label_conditional(char *label, char c);
-NI_str_array * SUMA_dists_featureset(SUMA_FEAT_DISTS *FDV);
-NI_str_array * SUMA_dists_classset(SUMA_FEAT_DISTS *FDV);
-char *SUMA_hist_fname(char *proot, char *variable, char *conditional, 
-                      int withext);
-char *SUMA_corrmat_fname(char *proot, char *conditional, int withext);
-SUMA_FEAT_DIST *SUMA_find_feature_dist(SUMA_FEAT_DISTS *FDV, 
-                                       char *label, char *feature, char *class,
-                                       int *ifind);
-SUMA_FEAT_DISTS *SUMA_grow_feature_dists(SUMA_FEAT_DISTS *FDV);
-SUMA_FEAT_DIST *SUMA_free_dist(SUMA_FEAT_DIST *FD);
-SUMA_FEAT_DISTS *SUMA_free_dists(SUMA_FEAT_DISTS *FDV);
-SUMA_FEAT_DISTS *SUMA_add_feature_dist(SUMA_FEAT_DISTS *FDV, 
-                                       SUMA_FEAT_DIST **FDp,
-                                       int append);
-SUMA_FEAT_DIST *SUMA_hist_To_dist(SUMA_HIST **hhp, char *thislabel);
-SUMA_FEAT_DISTS *SUMA_TRAIN_DISTS_To_dists(SUMA_FEAT_DISTS *FDV, 
-                                           NI_element *ndist);
-SUMA_FEAT_DISTS *SUMA_get_all_dists(char *where);
-NI_group *SUMA_hist_To_NIhist(SUMA_HIST *hh);
-SUMA_HIST *SUMA_NIhist_To_hist(NI_group *ngr);
-int SUMA_write_hist(SUMA_HIST *hh, char *name);
-SUMA_HIST *SUMA_read_hist(char *name);
-
 int SUMA_Seg_Write_Dset(char *proot, char *prefi, THD_3dim_dataset *dset, 
                         int iter, char *hh);
 int SUMA_KeyofLabel_Dtable(Dtable *vl_dtable, char *label);
@@ -466,11 +367,7 @@ int p_cv_GIV_afu (SEG_OPTS *Opt, char *feat,
                   char *cls, double *d);
 int p_cv_GIV_A (SEG_OPTS *Opt, char *cls, double *dr);
 int normalize_p(SEG_OPTS *Opt, THD_3dim_dataset *pout);
-int is_shorty(THD_3dim_dataset *pset);
-int set_p_floor(THD_3dim_dataset *pset, float pfl, byte *cmask);
-SUMA_Boolean SUMA_set_Stat_mix_floor(SUMA_CLASS_STAT *cs, float floor);
 THD_3dim_dataset *p_C_GIV_A (SEG_OPTS *Opt);
-THD_3dim_dataset *p_C_GIV_A_omp (SEG_OPTS *Opt);
 int SUMA_LabelToGroupedIndex(char *cls_str, char **group_clss_lbls, int N_lbls);
 int SUMA_LabelToGroupedKey(char *cls_str, char **group_clss_lbls, int N_lbls, 
                            int *group_keys);
@@ -534,7 +431,6 @@ int SUMA_set_Stat(SUMA_CLASS_STAT *cs, char *label, char *pname, double val);
 double SUMA_get_Stat(SUMA_CLASS_STAT *cs, char *label, char *pname);
 double *SUMA_get_Stats(SUMA_CLASS_STAT *cs,  char *pname);
 int SUMA_MixFrac_from_ClassStat(SUMA_CLASS_STAT *cs, float *mf);
-int SUMA_ZeroSamp_from_ClassStat(SUMA_CLASS_STAT *cs);
 int SUMA_Stat_position (SUMA_CLASS_STAT *cs, char *label, char *pname, int pp[]);
 SUMA_CLASS_STAT *SUMA_Free_Class_Stat(SUMA_CLASS_STAT *cs);
 SUMA_CLASS_STAT *SUMA_New_Class_Stat(char **clsl, int N_clsl, int *keys, 
@@ -545,7 +441,7 @@ int SUMA_Class_stats(THD_3dim_dataset *aset,
                      THD_3dim_dataset *wset,
                      THD_3dim_dataset *pC, 
                      THD_3dim_dataset *gold,
-                     SUMA_CLASS_STAT *cs, float mix_frac_floor);
+                     SUMA_CLASS_STAT *cs);
 double SUMA_mixopt_2_mixfrac(char *mixopt, char *label, int key, int N_clss,
                              byte *cmask, THD_3dim_dataset *cset);
 double pdfnorm(double x, double mean, double stdv);
@@ -569,45 +465,19 @@ int SUMA_pst_C_giv_ALL(THD_3dim_dataset *aset,
 int SUMA_CompareSegDsets(THD_3dim_dataset *base, THD_3dim_dataset *seg,
                          byte *cmask, byte mask_by_base,
                          SUMA_CLASS_STAT *cs );
-int SUMA_ray_k(int n1D, int ni, int nij, int nk, float *av, byte *ba, 
-               float ta[], int da[]);
-int SUMA_ray_j(int n1D, int ni, int nij, int nj, float *av, byte *ba, 
-               float ta[], int da[]);
-int SUMA_ray_i(int n1D, int ni, int nij, float *av, byte *ba, 
-               float ta[], int da[]);
-int SUMA_ray_unplug_k(int n1D, int ni, int nij, int nk, 
-                      float *av, byte *ba, int side);
-int SUMA_ray_unplug_j(int n1D, int ni, int nij, int nj, 
-                      float *av, byte *ba, int side);
-int SUMA_ray_unplug_i(int n1D, int ni, int nij, 
-                      float *av, byte *ba, int side);
 int SUMA_VolumeInFill(THD_3dim_dataset *aset,
                       THD_3dim_dataset **filledp,
-                      int method, int integ, int MxIter,
-                      int minhits, int erode, int dilate, float val,
-                      byte *mask);
-int SUMA_Volume_RadFill(THD_3dim_dataset *aset, float *ufv, byte *ucmask,
-                      float *ucm, THD_3dim_dataset **filledp,
-                      int nplug, int nlin, int fitord, float smooth, int N_off);
+                      int method);
 int SUMA_mri_volume_infill(MRI_IMAGE *imin);
-int SUMA_mri_volume_infill_zoom(MRI_IMAGE *imin, byte thorough, 
-                                 int integ, int mxiter);
-int SUMA_mri_volume_infill_solid(MRI_IMAGE *imin, int minhits, 
-                                 int mxiter, int unholize,
-                                 byte *mask);
+int SUMA_mri_volume_infill_zoom(MRI_IMAGE *imin, byte thorough);
 int SUMA_VolumeBlurInMask(THD_3dim_dataset *aset,
                                      byte *cmask,
                                      THD_3dim_dataset **blrdp,
-                                     float FWHM, float unifac,
-                                     int speed);
-int SUMA_VolumeBlur(THD_3dim_dataset *aset,
-                   byte *cmask,
-                   THD_3dim_dataset **blurredp,
-                   float FWHM);
+                                     float FWHM, float unifac);
 int SUMA_VolumeLSBlurInMask(THD_3dim_dataset *aset ,
                                      byte *cmask,
                                      THD_3dim_dataset **blurredp,
-                                     float FWHM, float mxvx);
+                                     float FWHM);
 double SUMA_EdgeEnergy(short *a, float af, short *b, float bf,
                       int Ni, int Nj, int Nk,
                       short *c, short c1, short c2, 
@@ -667,44 +537,5 @@ int SUMA_Split_Classes(char **Glbls, int N_Glbls, int *Gkeys, int *Split,
                        SEG_OPTS *Opt);
 int SUMA_SetDsetLabeltable(THD_3dim_dataset *dset, char **labels, 
                            int N_labels, int *keys);
-
-SUMA_SurfaceObject *SUMA_Mask_Skin(THD_3dim_dataset *iset, int ld,
-                       int smooth_final, int shrink_mode, SUMA_COMM_STRUCT *cs);
-SUMA_SurfaceObject *SUMA_Dset_ConvexHull(THD_3dim_dataset *dset, int isb,
-                                        float th, byte *umask);
-SUMA_SurfaceObject *SUMA_ExtractHead_hull(THD_3dim_dataset *iset,
-                                     float hullvolthr, SUMA_COMM_STRUCT *cs);
-SUMA_SurfaceObject *SUMA_ExtractHead(THD_3dim_dataset *iset,
-                                     float hullvolthr, SUMA_COMM_STRUCT *cs);
-SUMA_SurfaceObject *SUMA_ExtractHead_RS(THD_3dim_dataset *iset,
-                               THD_3dim_dataset **urset, SUMA_COMM_STRUCT *cs);
-SUMA_Boolean SUMA_ShrinkSkullHull2Mask(SUMA_SurfaceObject *SO, 
-                             THD_3dim_dataset *iset, float thr,
-                             int smooth_final, float *under_over_mm,
-                             int zero_attractor, 
-                             SUMA_COMM_STRUCT *cs);
-SUMA_Boolean SUMA_ShrinkSkullHull(SUMA_SurfaceObject *SO, 
-                             THD_3dim_dataset *iset, float thr,
-                             int use_rs, SUMA_COMM_STRUCT *cs);                  
-SUMA_Boolean SUMA_ShrinkHeadSurf(SUMA_SurfaceObject *SO, 
-                             THD_3dim_dataset *aset, 
-                             THD_3dim_dataset *arset,
-                             float *ucm,
-                             SUMA_COMM_STRUCT *cs);
-SUMA_Boolean SUMA_ShrinkSkullHull_RS(SUMA_SurfaceObject *SO, 
-                             THD_3dim_dataset *aset, 
-                             THD_3dim_dataset *arset, float thr,
-                             SUMA_COMM_STRUCT *cs) ;
-SUMA_Boolean SUMA_ShrinkHeadSurf_RS(SUMA_SurfaceObject *SO, 
-                             THD_3dim_dataset *aset, 
-                             THD_3dim_dataset *arset,
-                             float *ucm,
-                             SUMA_COMM_STRUCT *cs);
-THD_3dim_dataset *SUMA_Dset_FindVoxelsInSurface(
-                     SUMA_SurfaceObject *SO, THD_3dim_dataset *iset, 
-                     SUMA_VOLPAR *vp, char *vpname,
-                     char *prefix, int meth, int maskonly);          
-THD_3dim_dataset *SUMA_dset_hist_equalize(THD_3dim_dataset *din, 
-                                          int sb, byte *cmask, SUMA_HIST *hh);
-
+                     
 #endif
