@@ -26,7 +26,7 @@ Usage :
    RetStrct =   SUMA_SurfNorm (NodeList, N_NodeList, FaceSetList,  N_FaceSetList );
    
    
-Input parameters : 
+Input paramters : 
 \param  NodeList (float *): N_NodeList x 3 vector containing the XYZ coordinates of each node
 \param  N_NodeList (int): number of nodes in NodeList
 \param  FaceSetList (int *): [N_FaceSetList x 3] vector (matrix prior to SUMA 1.2) of node indices forming each triangular facet (FaceSets). 
@@ -51,7 +51,7 @@ Side effects :
    if (RetStrct.NodeNormList) SUMA_free(RetStrct.NodeNormList);
 
 The node normals are obtained by averaging the normals of the surrounding facesets (ie facesets containing the node).
-This is an approximation and in special cases like a cube with a particular tessellation, the normals could be biased 
+This is an approximation and in special cases like a cube with a particular tesselation, the normals could be biased 
 in direction if the node is a member of more triangles on one side of the object than the other sides. 
 See Lab-book NIH-2, page 142 for an illustration or this miserable ascii rendition. 
                
@@ -70,10 +70,7 @@ See Lab-book NIH-2, page 142 for an illustration or this miserable ascii renditi
        |              ## | *
        ------------------     
 ***/
-static int surf_norm_quiet = 0;
-void set_surf_norm_quiet(int v) { surf_norm_quiet=v; }
-SUMA_SURF_NORM SUMA_SurfNorm (float *NodeList, int N_NodeList, 
-                              int *FaceSetList, int N_FaceSetList )
+SUMA_SURF_NORM SUMA_SurfNorm (float *NodeList, int N_NodeList, int *FaceSetList, int N_FaceSetList )
 {/*SUMA_SurfNorm*/
    static char stmp[200], FuncName[]={"SUMA_SurfNorm"}; 
    float d1[3], d2[3], d, nrm;
@@ -89,10 +86,8 @@ SUMA_SURF_NORM SUMA_SurfNorm (float *NodeList, int N_NodeList,
    RetStrct.N_Face = N_FaceSetList;
 
    /* allocate space */
-   if (LocalHead) 
-      fprintf(SUMA_STDERR,"%s: %d %d\n", FuncName, N_NodeList, N_FaceSetList);
-   RetStrct.FaceNormList = 
-               (float *)SUMA_calloc (N_FaceSetList * NP, sizeof(float));
+   if (LocalHead) fprintf(SUMA_STDERR,"%s: %d %d\n", FuncName, N_NodeList, N_FaceSetList);
+   RetStrct.FaceNormList = (float *)SUMA_calloc (N_FaceSetList * NP, sizeof(float));
    RetStrct.NodeNormList = (float *)SUMA_calloc (N_NodeList * ND, sizeof(float));
    Index = (int *)SUMA_calloc (N_NodeList, sizeof(int));
    N_Memb = (int *)SUMA_calloc (N_NodeList, sizeof(int));
@@ -107,27 +102,22 @@ SUMA_SURF_NORM SUMA_SurfNorm (float *NodeList, int N_NodeList,
    for (i=0; i < N_FaceSetList; i++) {
       ip = NP * i;
       for (j=0; j < 3; j++) {
-         d1[j] =  NodeList[(ND*FaceSetList[ip])+j] - 
-                  NodeList[(ND*FaceSetList[ip+1])+j];
-         d2[j] =  NodeList[(ND*FaceSetList[ip+1])+j] - 
-                  NodeList[(ND*FaceSetList[ip+2])+j];
+         d1[j] = NodeList[(ND*FaceSetList[ip])+j] - NodeList[(ND*FaceSetList[ip+1])+j];
+         d2[j] = NodeList[(ND*FaceSetList[ip+1])+j] - NodeList[(ND*FaceSetList[ip+2])+j];
       }
       RetStrct.FaceNormList[ip  ] = d1[1]*d2[2] - d1[2]*d2[1];
       RetStrct.FaceNormList[ip+1] = d1[2]*d2[0] - d1[0]*d2[2];
       RetStrct.FaceNormList[ip+2] = d1[0]*d2[1] - d1[1]*d2[0];
-      d = sqrt(RetStrct.FaceNormList[ip]*RetStrct.FaceNormList[ip]+
-               RetStrct.FaceNormList[ip+1]*RetStrct.FaceNormList[ip+1]+
-               RetStrct.FaceNormList[ip+2]*RetStrct.FaceNormList[ip+2]);
+      d = sqrt(RetStrct.FaceNormList[ip]*RetStrct.FaceNormList[ip]+RetStrct.FaceNormList[ip+1]*RetStrct.FaceNormList[ip+1]+RetStrct.FaceNormList[ip+2]*RetStrct.FaceNormList[ip+2]);
       if (d == 0.0) {
-         /* I used to return here with a nasty message, 
-         but it seems that FreeSurfer surfaces contain such conditions 
+         /* I used to return here with a nasty message, but it seems that FreeSurfer surfaces contain such conditions 
          So, now I just set the normal to 1.0 in that case */
          /*SUMA_error_message (FuncName,"Zero length vector, returning",1);
          if (RetStrct.FaceNormList) SUMA_free(RetStrct.FaceNormList);
          if (RetStrct.NodeNormList) SUMA_free(RetStrct.NodeNormList);
          if (Index) SUMA_free(Index);
          if (N_Memb) SUMA_free(N_Memb);
-         SUMA_RETURN (RetStrct); */
+         SUMA_RETURN (RetStrct);*/
          RetStrct.FaceNormList[ip] = 1.0;
          RetStrct.FaceNormList[ip+1] = 1.0;
          RetStrct.FaceNormList[ip+2] = 1.0;
@@ -219,14 +209,14 @@ SUMA_SURF_NORM SUMA_SurfNorm (float *NodeList, int N_NodeList,
                      RetStrct.NodeNormList[id+2] = 1.0;
             }
          }
-      if (NotMember && !surf_norm_quiet) {
+      if (NotMember) {
          sprintf (stmp, "(IGNORE for surfaces with cuts\n"
                         "%d nodes (%f%% of total) are\n"
                         "not members of any FaceSets.\n"
                         "Their normals are set to the\n"
                         "unit vector.\n", 
                         NotMember, (float)NotMember/(float)N_NodeList*100.0);
-         SUMA_SL_Note("%s",stmp);
+         SUMA_SL_Note(stmp);
       }
       
    if (N_Memb) SUMA_free(N_Memb);
@@ -300,7 +290,7 @@ Purpose :
 Usage : 
    RetStruct = SUMA_MemberFaceSets (int Nind, int * FaceSetList, int nFace, int FaceSetDim);
    
-Input parameters : 
+Input paramters : 
 \param  Nind (int) : Total number of nodes in Index. ( No value (node index) in FaceSetList can be > Nind-1 )
 \param  FaceSetList (int *) : The FaceSetList vector (used to be matrix, prior to SUMA 1.2), [nFace x FaceSetDim] 
 \param  nFace (int) : number of FaceSets in FaceSetList 
@@ -362,13 +352,9 @@ SUMA_MEMBER_FACE_SETS *SUMA_MemberFaceSets (int Nind, int * FaceSetList,
    SUMA_MEMBER_FACE_SETS *RetStrct;
    int **tmpMember;
    int i, inode, iface, ip , NP;
-   byte *filled=NULL;
-   SUMA_Boolean LocalHead = NOPE;
    
    SUMA_ENTRY;
 
-   SUMA_LHv("Nind=%d, nFr=%d, FaceDim=%d\n", Nind, nFr, FaceDim);
-   
    NP = FaceDim;
    RetStrct = (SUMA_MEMBER_FACE_SETS *)
                   SUMA_malloc(sizeof(SUMA_MEMBER_FACE_SETS));
@@ -378,20 +364,18 @@ SUMA_MEMBER_FACE_SETS *SUMA_MemberFaceSets (int Nind, int * FaceSetList,
    if (ownerid) sprintf(RetStrct->owner_id, "%s", ownerid);
    else RetStrct->owner_id[0] = '\0';
    RetStrct->LinkedPtrType = SUMA_LINKED_MEMB_FACE_TYPE;
-   RetStrct->do_type = not_DO_type;
    
    RetStrct->N_Memb_max = RetStrct->Nnode = 0;
    RetStrct->N_Memb = NULL;
    RetStrct->NodeMemberOfFaceSet = NULL;
    
    /* Allocate return variables */
-   tmpMember = (int **) SUMA_allocate2D (Nind, 
-                           SUMA_MAX_MEMBER_FACE_SETS ,sizeof(int));
+   tmpMember = (int **) SUMA_allocate2D (Nind, SUMA_MAX_MEMBER_FACE_SETS ,sizeof(int));
    RetStrct->N_Memb = (int *) SUMA_calloc (Nind, sizeof(int));
-   filled = (byte *)SUMA_calloc(Nind, sizeof(int));
+   
    if (!tmpMember || !RetStrct->N_Memb)
       {
-         SUMA_S_Err("Failed to allocate for tmpMember or RetStrct->N_Memb");
+         fprintf (SUMA_STDERR,"Error %s: Failed to allocate for tmpMember or RetStrct->N_Memb\n", FuncName);
          SUMA_RETURN (RetStrct);
       }
    
@@ -402,38 +386,30 @@ SUMA_MEMBER_FACE_SETS *SUMA_MemberFaceSets (int Nind, int * FaceSetList,
       do {
          inode = FaceSetList[ip + i];
          if (inode > Nind) {
-            SUMA_S_Err("FaceSetList contains node indices >= Nind");
+            fprintf (SUMA_STDERR,"Error %s: FaceSetList contains node indices >= Nind\n", FuncName);
             SUMA_RETURN (RetStrct);
          }
+         tmpMember[inode][RetStrct->N_Memb[inode]] = iface; 
+         ++RetStrct->N_Memb[inode];
          if (RetStrct->N_Memb[inode] >= SUMA_MAX_MEMBER_FACE_SETS) {
-            if (!filled[inode]){
-               SUMA_S_Errv("Node %d is member of (%d FaceSets) more than"
-                        " SUMA_MAX_MEMBER_FACE_SETS (%d)\n"
-                        "Skipping remaining facets\n",
-                  inode, RetStrct->N_Memb[inode], SUMA_MAX_MEMBER_FACE_SETS);
-            }
-            filled[inode]=1;
-         } else {
-            tmpMember[inode][RetStrct->N_Memb[inode]] = iface; 
-            ++RetStrct->N_Memb[inode];
+            fprintf (SUMA_STDERR,"Error %s: Node %d is member of (%d FaceSets) more than SUMA_MAX_MEMBER_FACE_SETS (%d)\n",\
+                FuncName, inode, RetStrct->N_Memb[inode], SUMA_MAX_MEMBER_FACE_SETS);
+            SUMA_RETURN (RetStrct);
          }
-         if (RetStrct->N_Memb[inode] > RetStrct->N_Memb_max) 
-            RetStrct->N_Memb_max = RetStrct->N_Memb[inode];
+         if (RetStrct->N_Memb[inode] > RetStrct->N_Memb_max) RetStrct->N_Memb_max = RetStrct->N_Memb[inode];
          ++i;
       } while (i < FaceDim);
    }
    
    /*allocate just enough for returning variables */
-   RetStrct->NodeMemberOfFaceSet = 
-      (int **) SUMA_allocate2D (Nind, RetStrct->N_Memb_max ,sizeof(int));
+   RetStrct->NodeMemberOfFaceSet = (int **) SUMA_allocate2D (Nind, RetStrct->N_Memb_max ,sizeof(int));
    if (!RetStrct->NodeMemberOfFaceSet)
       {
-         SUMA_S_Err("Failed to allocate for RetStrct->NodeMemberOfFaceSet\n");
+         fprintf(SUMA_STDERR,"Error %s: Failed to allocate for RetStrct->NodeMemberOfFaceSet\n", FuncName);
          SUMA_RETURN (RetStrct);
       }
 
-   /* loop through all nodes, 
-      cp results into RetStrct->NodeMemberOfFaceSet and seal with -1 */
+   /* loop through all nodes, cp results into RetStrct->NodeMemberOfFaceSet and seal with -1 */
    for (inode = 0; inode < Nind; ++inode) {
       i = 0;
       while (i < RetStrct->N_Memb[inode]) {
@@ -441,13 +417,11 @@ SUMA_MEMBER_FACE_SETS *SUMA_MemberFaceSets (int Nind, int * FaceSetList,
          ++i;
       }
       /*seal with -1 */
-      if (RetStrct->N_Memb[inode] < RetStrct->N_Memb_max) 
-               RetStrct->NodeMemberOfFaceSet[inode][i] = -1;
+      if (RetStrct->N_Memb[inode] < RetStrct->N_Memb_max) RetStrct->NodeMemberOfFaceSet[inode][i] = -1;
    }
 
    /* Clean up time */
    if (tmpMember) SUMA_free2D((char **)tmpMember, Nind);
-   if (filled) SUMA_free(filled); filled = NULL;
    
    RetStrct->Nnode = Nind;
    SUMA_RETURN (RetStrct);
