@@ -101,7 +101,7 @@ SUMA_Boolean Set_up_Control_Curve( MyCircleOpt *opt, SUMA_MX_VEC *ControlCurve )
    for (j=0; j<opt->N_ctrl_points; ++j) {
       j3 = 3*j;
    
-      /* Store initial location of control point. */
+      /* Store intial location of control point. */
       k=0; 
       dp = mxvdp3(ControlCurve, i, j, k);
       dp[0] = opt->CtrlPts_i[j3  ];
@@ -196,11 +196,9 @@ SUMA_SegmentDO *SUMA_Perturbation2SDO(SUMA_MX_VEC *ControlCurve, SUMA_MX_VEC *Pe
             }
          }                            
          if (p==0) {
-            colv[4*kcc+0] = 1.0; 
-            colv[4*kcc+1] = colv[4*kcc+2] = colv[4*kcc+3] = 0.0;  
+            colv[4*kcc+0] = 1.0; colv[4*kcc+1] = colv[4*kcc+2] = colv[4*kcc+3] = 0.0;  
          } else{
-            colv[4*kcc+1] = 1.0; 
-            colv[4*kcc+0] = colv[4*kcc+2] = colv[4*kcc+3] = 0.0;  
+            colv[4*kcc+1] = 1.0; colv[4*kcc+0] = colv[4*kcc+2] = colv[4*kcc+3] = 0.0;  
          }
          thickv[kcc] = 2;   
          ++kcc;
@@ -210,10 +208,10 @@ SUMA_SegmentDO *SUMA_Perturbation2SDO(SUMA_MX_VEC *ControlCurve, SUMA_MX_VEC *Pe
 
    SDO = SUMA_CreateSegmentDO( N_n, oriented, NodeBased, Stipple,
                                Label, idcode_str, Parent_idcode_str,
-                               NOT_SET_type, NULL,
                                LineWidth, LineCol,
                                NodeId, NULL, n0, n1,
-                               colv, thickv );
+                               colv, thickv 
+                              );
 
    if (idcode_str) SUMA_free(idcode_str); idcode_str = NULL;
    if (n0) SUMA_free(n0); n0 = NULL;
@@ -352,7 +350,7 @@ SUMA_Boolean Perturbations(   MyCircleOpt *opt, SUMA_MX_VEC *ControlCurve,
          ps->cs->talk_suma = NOPE;
       }
       SUMA_free_SegmentDO(sdo); sdo = NULL;
-      NI_free_element(ngr); ngr = NULL; 
+      NI_free(ngr); ngr = NULL; 
       /* again for direction 2 */
       sdo = SUMA_Perturbation2SDO(opt->ControlCurve, Perturb_Vec, "PV1", 1, 5.0);
       /* change that thing to NIML */
@@ -368,7 +366,7 @@ SUMA_Boolean Perturbations(   MyCircleOpt *opt, SUMA_MX_VEC *ControlCurve,
          ps->cs->talk_suma = NOPE;
       }
       SUMA_free_SegmentDO(sdo); sdo = NULL;
-      NI_free_element(ngr); ngr = NULL; 
+      NI_free(ngr); ngr = NULL; 
       if (  opt->pause > 1) {
             SUMA_PAUSE_PROMPT("Pausing after perturbation directions\nDo something to proceed.\n");
       }
@@ -687,7 +685,7 @@ SUMA_Boolean Change_in_Energy(   MyCircleOpt *opt, SUMA_MX_VEC *ControlCurve, SU
                   fprintf(SUMA_STDERR, "del_SF = %f\n", del_SF.elts[0]);
                }
                
-               if(LocalHead) fprintf(SUMA_STDERR, "CHECK THE INDICES!!!i = %d, m = %d, q = %d, p = %d\n", i, m, q, p);
+               if(LocalHead) fprintf(SUMA_STDERR, "CHECK THE INDICIES!!!i = %d, m = %d, q = %d, p = %d\n", i, m, q, p);
                mxvd4(Del_S, i, m, q, p) = del_SF.elts[0]; 
                if(LocalHead) fprintf(SUMA_STDERR, "del_SF = %11.8f\n", del_SF.elts[0]);
                matrix_destroy(&B);
@@ -833,7 +831,7 @@ double S_energy( MyCircleOpt *opt, SUMA_MX_VEC *VecX , SUMA_GENERIC_ARGV_PARSE *
          }
          
          /* SUMA_free_SegmentDO(sdo); sdo = NULL;
-         NI_free_element(ngr); ngr = NULL; 
+         NI_free(ngr); ngr = NULL; 
          if (  opt->pause > 1) {
                SUMA_PAUSE_PROMPT("Pausing after Sm trial\nDo something to proceed.\n");
          }*/
@@ -923,10 +921,10 @@ SUMA_SegmentDO *SUMA_G2SDO(vector G, SUMA_MX_VEC *ControlCurve,
 
    SDO = SUMA_CreateSegmentDO( N_n, oriented, NodeBased, Stipple,
                                Label, idcode_str, Parent_idcode_str,
-                               NOT_SET_type, NULL,
                                LineWidth, LineCol,
                                NodeId, NULL, n0, n1,
-                               colv, thickv);
+                               colv, thickv 
+                              );
 
    if (idcode_str) SUMA_free(idcode_str); idcode_str = NULL;
    if (n0) SUMA_free(n0); n0 = NULL;
@@ -1103,7 +1101,7 @@ double Find_Lamda( MyCircleOpt *opt, SUMA_MX_VEC *ControlCurve, SUMA_MX_VEC *Max
          ps->cs->talk_suma = NOPE;
       }
       SUMA_free_SegmentDO(sdo); sdo = NULL;
-      NI_free_element(ngr); ngr = NULL; 
+      NI_free(ngr); ngr = NULL; 
    }
 
    if(LocalHead){
@@ -1416,7 +1414,7 @@ SUMA_Boolean FindSplineWeights (MyCircle *C, MyCircleOpt *opt, FILE *condition_n
    if (LocalHead) {
       fprintf(SUMA_STDERR, "%s:\n"
                            "Number of control points: %d\n", 
-                            FuncName, opt->N_ctrl_points);
+                     	    FuncName, opt->N_ctrl_points);
    }
    
    if (opt->dim !=2 && opt->dim != 3) {
@@ -1447,7 +1445,7 @@ SUMA_Boolean FindSplineWeights (MyCircle *C, MyCircleOpt *opt, FILE *condition_n
          else { idm = opt->dim*i; }
       i3 = 3*i;
       /* Distance between control point and desired destination of control point */ 
-      /* nrm is the axis of rotation from initial control point location to final. */       
+      /* nrm is the axis of rotation from intial control point location to final. */       
       /* BEWARE: USING _NC HERE, MEANING NO CENTER.  WILL THE CENTER ALWAYS BE THE ORIGIN? */
       SUMA_ANGLE_DIST_NC((&(opt->CtrlPts_f[i3])), (&(opt->CtrlPts[i3])), opt->Dtheta[i], (&(opt->Nrm[i3])) );
 
