@@ -6,8 +6,8 @@
    #define DO_SCALE 319.7   /*!< scale node coordinates by specified factor. Useful for tesscon coordinate system in iv files*/
 #endif
 
-void usage_SUMA_SurfaceMetrics (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
-{
+void usage_SUMA_SurfaceMetrics (SUMA_GENERIC_ARGV_PARSE *ps)
+   {
       static char FuncName[]={"usage_SUMA_SurfaceMetrics"};
       char * s = NULL, *sio=NULL;
       s = SUMA_help_basics();
@@ -17,9 +17,7 @@ void usage_SUMA_SurfaceMetrics (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "Usage: SurfaceMetrics <-Metric1> [[-Metric2] ...] \n"
 "                  <-SURF_1> \n"
 "                  [-tlrc] [<-prefix prefix>]\n"
-"\n%s", detail ? "":"use -h or -help for more help detail.\n");
-   if (detail) {
-      printf ( 
+"\n"
 "Outputs information about a surface's mesh\n"
 "\n"
 "   -Metric1: Replace -Metric1 with the following:\n"
@@ -35,7 +33,7 @@ void usage_SUMA_SurfaceMetrics (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "            the result is incorrect. \n"
 "            Volume is calculated using Gauss's theorem,\n"
 "            see [Hughes, S.W. et al. 'Application of a new \n"
-"            discrete form of Gauss's theorem for measuring \n"
+"            discreet form of Gauss's theorem for measuring \n"
 "            volume' in Phys. Med. Biol. 1996].\n"
 "      -conv: output surface convexity at each node.\n"
 "         Output file is prefix.conv. Results in two columns:\n"
@@ -45,8 +43,6 @@ void usage_SUMA_SurfaceMetrics (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "         C[i] = Sum(dj/dij) over all neighbors j of i\n"
 "         dj is the distance of neighboring node j to the tangent plane at i\n"
 "         dij is the length of the segment ij\n"
-"         Note: This option produces a .1D file, and a NIML dataset with \n"
-"         similar content.\n"
 "      -closest_node XYZ_LIST.1D: Find the closest node on the surface\n"
 "                              to each XYZ triplet in XYZ_LIST.1D\n"
 "                              Note that it is assumed that the XYZ\n"
@@ -91,14 +87,9 @@ void usage_SUMA_SurfaceMetrics (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "         Col.4-6: vector of 2nd principal direction of surface\n"
 "         Col.7: Curvature along T1\n"
 "         Col.8: Curvature along T2\n"
-"         Col.9: Curvature magnitude sqrt(c7*c7+c8*c8)\n"
 "         Curvature algorithm by G. Taubin from: \n"
 "         'Estimating the tensor of curvature of surface \n"
 "         from a polyhedral approximation.'\n"
-"         Note: This option produces a .1D file, a NIML dataset with similar\n"
-"         content, and Displayable Objects (DO) file containing \n"
-"         the principal directions at each node. You can load these objects\n"
-"         with SUMA's 'Alt+Ctrl+s' option.\n"
 "      -edges: outputs info on each edge. \n"
 "         Output file is prefix.edges. Results in five columns:\n"
 "         Col.0: Edge Index (into a SUMA structure).\n"
@@ -110,9 +101,6 @@ void usage_SUMA_SurfaceMetrics (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "                     Segments begin at node and have a default\n"
 "                     magnitude of 1. See option 'Alt+Ctrl+s' in \n"
 "                     SUMA for visualization.\n"
-"         Note: This option produces a .1D file and a Displayable Objects \n"
-"         file containing  the principal directions at each node. \n"
-"         You can load these objects with SUMA's 'Alt+Ctrl+s' option.\n"
 "      -face_normals: Outputs segments along triangle normals.\n"
 "                     Segments begin at centroid of triangles and \n"
 "                     have a default magnitude of 1. See option \n"
@@ -189,24 +177,18 @@ void usage_SUMA_SurfaceMetrics (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "                   For more information, see cat_matvec's -P option.\n"
 "                   This option can only be used in conjunction with\n"
 "                   -xmat_1D\n"
-"    -h: Show most of the options\n"
-"    -help: Show all of the options\n"
 "\n"
 "%s"
 "\n"
 "%s"
-"\n", 
-   (detail > 1) ? sio : "Use -help for I/O and miscellaneous options." , 
-   (detail > 1) ? s : "" );
+"\n", sio, s);
+      SUMA_free(s); s = NULL;
+      SUMA_free(sio); sio = NULL;
+      s = SUMA_New_Additions(0, 1); printf("%s\n", s);SUMA_free(s); s = NULL;
+      printf ( "       Ziad S. Saad SSCC/NIMH/NIH saadz@mail.nih.gov \n"
+               "       Mon May 19 15:41:12 EDT 2003\n"
+               "\n");   
    }
-      if (s) SUMA_free(s); s = NULL;
-      if (sio) SUMA_free(sio); sio = NULL;
-      if (detail) {
-         s = SUMA_New_Additions(0, 1); printf("%s\n", s);SUMA_free(s); s = NULL;
-         printf ( "       Ziad S. Saad SSCC/NIMH/NIH saadz@mail.nih.gov \n");   
-      }
-   return;
-}
 #define SURFACEMETRICS_MAX_SURF 10
 
 int main (int argc,char *argv[])
@@ -232,7 +214,7 @@ int main (int argc,char *argv[])
    char *surf_names[SURFACEMETRICS_MAX_SURF];
    char *spec_file, *histnote;
    char *closest_to_xyz = NULL;
-   int insurf_method = 0, ind = 0, quiet=0, randseed;
+   int insurf_method = 0, N_surf = 0, ind = 0, quiet=0, randseed;
    SUMA_Boolean   brk, Do_tlrc, Do_conv, Do_curv, 
                   Do_area, Do_edges, Do_vol, Do_sph, NewCent, 
                   Do_cord, Do_TriNorm, Do_TriSine, Do_TriCosine,
@@ -240,22 +222,26 @@ int main (int argc,char *argv[])
                   Do_NodeAngles, Do_cen, Do_xmat, Do_inv,
                   Do_NodeNorm, Do_en, Do_in, Do_et; 
    SUMA_Boolean   LocalHead = NOPE;  
-   SUMA_DSET *ndset=NULL;
-   char *oname=NULL;
    SUMA_GENERIC_ARGV_PARSE *ps=NULL;
    
-   SUMA_STANDALONE_INIT;
+	SUMA_STANDALONE_INIT;
    SUMA_mainENTRY;
    
    ps = SUMA_Parse_IO_Args(argc, argv, "-i;-t;-spec;-s;-sv;");
    
-   /* Allocate space for DO structure */
-   SUMAg_DOv = SUMA_Alloc_DisplayObject_Struct (SUMA_MAX_DISPLAYABLE_OBJECTS);
+	/* Allocate space for DO structure */
+	SUMAg_DOv = SUMA_Alloc_DisplayObject_Struct (SUMA_MAX_DISPLAYABLE_OBJECTS);
 
+   if (argc > 1 && argc < 4)
+       {
+          SUMA_S_Err("Too few parameters");
+          usage_SUMA_SurfaceMetrics (ps);
+          exit (1);
+       }
    
    MetricList = SUMA_StringAppend (NULL, NULL);
    kar = 1;
-   brk = NOPE;
+	brk = NOPE;
    xmat_name = NULL;
    xcen[0] = 0.0; xcen[1] = 0.0; xcen[2] = 0.0;
    Do_cen = NOPE;
@@ -289,152 +275,152 @@ int main (int argc,char *argv[])
    for (i=0; i<SURFACEMETRICS_MAX_SURF; ++i) { surf_names[i] = NULL; }   
    spec_file = NULL;
 
-   while (kar < argc) { /* loop across command line options */
-      /* fprintf(stdout, "%s verbose: Parsing command line...\n", FuncName); */
-      if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
-          usage_SUMA_SurfaceMetrics(ps, strlen(argv[kar]) > 3 ? 2:1);
-          exit (0);
-      }
-      
+	while (kar < argc) { /* loop accross command ine options */
+		/* fprintf(stdout, "%s verbose: Parsing command line...\n", FuncName); */
+		if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
+			 usage_SUMA_SurfaceMetrics(ps);
+          exit (1);
+		}
+		
       SUMA_SKIP_COMMON_OPTIONS(brk, kar);
       
       if (!brk && (strcmp(argv[kar], "-sph_coords_center") == 0)) {
          kar ++;
-         if (kar+2 >= argc)  {
-            fprintf (SUMA_STDERR, 
+			if (kar+2 >= argc)  {
+		  		fprintf (SUMA_STDERR, 
                      "need 3 arguments after -sph_coords_center \n");
-            exit (1);
-         }
-         sph_center[0] = atof(argv[kar]); kar ++;
+				exit (1);
+			}
+			sph_center[0] = atof(argv[kar]); kar ++;
          sph_center[1] = atof(argv[kar]); kar ++;
          sph_center[2] = atof(argv[kar]);
          NewCent = YUP;
          Do_sph = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       
       if (!brk && (strcmp(argv[kar], "-seed") == 0)) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need 1 integer after -seed\n");
-            exit (1);
-         }
-         randseed = atoi(argv[kar]); 
-         brk = YUP;
-      }
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need 1 integer after -seed\n");
+				exit (1);
+			}
+			randseed = atoi(argv[kar]); 
+			brk = YUP;
+		}
       if (!brk && ( (strcmp(argv[kar], "-xmat_1d") == 0) ||
                     (strcmp(argv[kar], "-xmat_1D") == 0) ) ) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need 1 argument after -xmat_1D\n");
-            exit (1);
-         }
-         xmat_name = argv[kar]; 
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need 1 argument after -xmat_1D\n");
+				exit (1);
+			}
+			xmat_name = argv[kar]; 
          Do_xmat = YUP;
          Do_inv = 0;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       if (!brk && ( (strcmp(argv[kar], "-ixmat_1d") == 0) ||
                     (strcmp(argv[kar], "-ixmat_1D") == 0) ) ) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need 1 argument after -ixmat_1D\n");
-            exit (1);
-         }
-         xmat_name = argv[kar]; 
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need 1 argument after -ixmat_1D\n");
+				exit (1);
+			}
+			xmat_name = argv[kar]; 
          Do_xmat = YUP;
          Do_inv = 1;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       if (!brk && (strcmp(argv[kar], "-polar_decomp") == 0)) {
          Do_PolDec = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       
       if (!brk && (strcmp(argv[kar], "-xcenter") == 0)) {
          kar ++;
-         if (kar+2>= argc)  {
-            fprintf (SUMA_STDERR, "need 3 arguments after -xcenter\n");
-            exit (1);
-         }
-         xcen[0] = atof(argv[kar]); ++kar;
-         xcen[1] = atof(argv[kar]); ++kar;
-         xcen[2] = atof(argv[kar]); 
+			if (kar+2>= argc)  {
+		  		fprintf (SUMA_STDERR, "need 3 arguments after -xcenter\n");
+				exit (1);
+			}
+			xcen[0] = atof(argv[kar]); ++kar;
+			xcen[1] = atof(argv[kar]); ++kar;
+			xcen[2] = atof(argv[kar]); 
          Do_cen = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
 
       if (!brk && (strcmp(argv[kar], "-quiet") == 0)) {
          quiet = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       
       if (!brk && (strcmp(argv[kar], "-tri_sines") == 0)) {
          Do_TriSine = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       if (!brk && (strcmp(argv[kar], "-tri_angles") == 0)) {
          Do_TriAngles = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       if (!brk && (strcmp(argv[kar], "-node_angles") == 0)) {
          Do_NodeAngles = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       if (!brk && (strcmp(argv[kar], "-tri_cosines") == 0)) {
          Do_TriCosine = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       if (!brk && (strcmp(argv[kar], "-tri_CoSines") == 0)) {
          Do_TriCoSine = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       
       if (!brk && (strcmp(argv[kar], "-sph_coords") == 0)) {
          Do_sph = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       
       if (!brk && (strcmp(argv[kar], "-coords") == 0)) {
          Do_cord = YUP;
-         brk = YUP;
-      }
+			brk = YUP;
+		}
       
       if (!brk && (strcmp(argv[kar], "-prefix") == 0)) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need argument after -prefix ");
-            exit (1);
-         }
-         OutPrefix = SUMA_copy_string(argv[kar]);
-         brk = YUP;
-      }
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -prefix ");
+				exit (1);
+			}
+			OutPrefix = SUMA_copy_string(argv[kar]);
+			brk = YUP;
+		}
       
       if (!brk && (strcmp(argv[kar], "-sv") == 0)) {
          if (0 && iType == SUMA_FT_NOT_SPECIFIED) {
                               /* iType input no longer allowed */
             fprintf (SUMA_STDERR, 
-                     " -sv option must be preceded by -i_TYPE option.");
+                     " -sv option must be preceeded by -i_TYPE option.");
             exit(1);
          }
          kar ++;
-         if (iType == SUMA_SUREFIT) {
+			if (iType == SUMA_SUREFIT) {
             if (kar+1 >= argc)  {
-               fprintf (SUMA_STDERR, 
+		  		   fprintf (SUMA_STDERR, 
                   "need 2 argument after -sv (SurfaceVolume and VolumeParent)");
-               exit (1);
-            }
+				   exit (1);
+			   }
             sv_name = argv[kar]; kar ++;
             vp_name = argv[kar];
          } else {
             if (kar >= argc)  {
-               fprintf (SUMA_STDERR, "need argument after -sv ");
-               exit (1);
-            }
-            sv_name = argv[kar];
+		  		   fprintf (SUMA_STDERR, "need argument after -sv ");
+				   exit (1);
+			   }
+			   sv_name = argv[kar];
          }
-         brk = YUP;
-      }
+			brk = YUP;
+		}
 
       if (!brk && (strcmp(argv[kar], "-tlrc") == 0)) {
          Do_tlrc = YUP;
@@ -450,19 +436,19 @@ int main (int argc,char *argv[])
       }
       if (!brk && (strcmp(argv[kar], "-normals_scale") == 0)) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need argument after -normals_scale ");
-            exit (1);
-         }
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -normals_scale ");
+				exit (1);
+			}
          NormScale = atof(argv[kar]);
          brk = YUP;
       }
       if (!brk && (strcmp(argv[kar], "-closest_node") == 0)) {
          kar ++;
-         if (kar >= argc)  {
-            fprintf (SUMA_STDERR, "need argument after -closest_node ");
-            exit (1);
-         }
+			if (kar >= argc)  {
+		  		fprintf (SUMA_STDERR, "need argument after -closest_node ");
+				exit (1);
+			}
          closest_to_xyz = argv[kar];
          brk = YUP;
       }
@@ -512,23 +498,16 @@ int main (int argc,char *argv[])
       }
       
       if (!brk && !ps->arg_checked[kar]) {
-         fprintf (SUMA_STDERR,
+			fprintf (SUMA_STDERR,
                   "Error %s: Option %s not understood. Try -help for usage\n", 
                   FuncName, argv[kar]);
-         suggest_best_prog_option(argv[0], argv[kar]);
-         exit (1);
-      } else { 
-         brk = NOPE;
-         kar ++;
-      }
+			exit (1);
+		} else {	
+			brk = NOPE;
+			kar ++;
+		}
    }
-   if (argc < 4)
-    {
-       SUMA_S_Err("Too few parameters");
-       usage_SUMA_SurfaceMetrics (ps, 0);
-       exit (1);
-    }
-
+   
    /* clean MetricList */
    MetricList = SUMA_StringAppend (MetricList, NULL); 
    
@@ -821,16 +800,17 @@ int main (int argc,char *argv[])
    /* create the surface label*/
    SO->Label = SUMA_SurfaceFileName (SO, NOPE);
    if (!SO->Label) {
-      SO->Label = SUMA_copy_string("No_Decent_Label");
+      SUMA_S_Err("Failed to create Label");
+      exit(1);
    }
 
    if (LocalHead) SUMA_Print_Surface_Object (SO, stderr);
    
    /* Now do the deed */
-   SUMA_LH ("%s",MetricList->s);
+   SUMA_LH (MetricList->s);
    if (strlen(MetricList->s)) {
       if (!SUMA_SurfaceMetrics (SO, MetricList->s, NULL)) {
-         SUMA_S_Err("Failed in SUMA_SurfaceMetrics.");
+         fprintf (SUMA_STDERR,"Error %s: Failed in SUMA_SurfaceMetrics.\n", FuncName);
          exit(1);
       }
    }
@@ -903,46 +883,22 @@ int main (int argc,char *argv[])
       }
       
       fprintf (fout,"#Node normals.\n");
-      fprintf (fout,"#  Segments from node along the direction of the normal "
-                    "(of magnitude %f)\n", NormScale);
+      fprintf (fout,"#  Segments from node along the direction of the normal (of magnitude %f)\n", NormScale);
       fprintf (fout,"#  1st three columns are node's coordinates\n");
-      fprintf (fout,"#  2nd three columns are the coordinate of a second "
-                    "point along the normal\n");
+      fprintf (fout,"#  2nd three columns are the coordinate of a second point along the normal\n");
       if (histnote) fprintf (fout,"#History:%s\n", histnote);
       
       for (i=0; i<SO->N_Node; ++i) {
-         norm[0] = SO->NodeNormList[3*i]; 
-         norm[1] = SO->NodeNormList[3*i+1]; 
-         norm[2] = SO->NodeNormList[3*i+2];
+         norm[0] = SO->NodeNormList[3*i]; norm[1] = SO->NodeNormList[3*i+1]; norm[2] = SO->NodeNormList[3*i+2];
          /* normal is expected to be normalized...*/
          norm[0] *= NormScale; norm[1] *= NormScale; norm[2] *= NormScale;
          fprintf (fout,"%f %f %f \t%f %f %f\n", 
             SO->NodeList[3*i], SO->NodeList[3*i+1], SO->NodeList[3*i+2], 
-            SO->NodeList[3*i]+norm[0], SO->NodeList[3*i+1]+norm[1], 
-            SO->NodeList[3*i+2]+norm[2]);            
+            SO->NodeList[3*i]+norm[0], SO->NodeList[3*i+1]+norm[1], SO->NodeList[3*i+2]+norm[2]);            
       }
       
       fclose(fout); fout = NULL;
       
-      /* Also output a DO file*/
-      sprintf(OutName, "%s.NodeNorm.1D.do", OutPrefix);
-      if (!THD_ok_overwrite() && SUMA_filexists(OutName)) {
-         SUMA_S_Err("Curvature output dset exists.\nWill not overwrite.");
-         exit(1);
-      }
-      if (!(fout = fopen(OutName,"w"))) {
-         SUMA_S_Err( "Failed to open file for writing.\n"
-                     "Check your permissions.\n");
-         exit(1);
-      }
-      fprintf (fout,"#node-based_vectors\n");
-      for (i=0; i < SO->N_Node; ++i) {
-         fprintf (fout, "%d %f %f %f \n",
-                  i, SO->NodeNormList[3*i], 
-                     SO->NodeNormList[3*i+1], 
-                     SO->NodeNormList[3*i+2]);
-      }
-      fclose(fout); fout = NULL;
    }
    
    if (Do_TriNorm) {
@@ -959,17 +915,14 @@ int main (int argc,char *argv[])
       }
       fout = fopen(OutName,"w");
       if (!fout) {
-         SUMA_S_Err("Failed to open file for writing.\n"
-                    "Check your permissions.\n");
+         SUMA_S_Err("Failed to open file for writing.\nCheck your permissions.\n");
          exit(1);
       }
       
       fprintf (fout,"#Triangle normals.\n");
-      fprintf (fout,"#  Segments from centroid of triangle along the "
-                    "direction of the normal (of magnitude %f)\n", NormScale);
+      fprintf (fout,"#  Segments from centroid of triangle along the direction of the normal (of magnitude %f)\n", NormScale);
       fprintf (fout,"#  1st three columns are centroid's coordinates\n");
-      fprintf (fout,"#  2nd three columns are the coordinate of a second "
-                    "point along the normal\n");
+      fprintf (fout,"#  2nd three columns are the coordinate of a second point along the normal\n");
       if (histnote) fprintf (fout,"#History:%s\n", histnote);
       
       for (i=0; i<SO->N_FaceSet; ++i) {
@@ -1257,20 +1210,18 @@ int main (int argc,char *argv[])
    if (Do_cord) {
       sprintf(OutName, "%s.coord.1D.dset", OutPrefix);
       if (!THD_ok_overwrite() && SUMA_filexists(OutName)) {
-         SUMA_S_Err("Coord output file exists.\nWill not overwrite.");
+         SUMA_S_Err("Edge output file exists.\nWill not overwrite.");
          exit(1);
       }
       
       fout = fopen(OutName,"w");
       if (!fout) {
-         SUMA_S_Err("Failed to open file for writing.\n"
-                    "Check your permissions.\n");
+         SUMA_S_Err("Failed to open file for writing.\nCheck your permissions.\n");
          exit(1);
       }
       
       fprintf (fout,"#Cartesian coords, \n");
-      fprintf (fout,"#  Center is: [%f %f %f] \n", 
-                  SO->Center[0], SO->Center[1], SO->Center[2]);
+      fprintf (fout,"#  Center is: [%f %f %f] \n", SO->Center[0], SO->Center[1], SO->Center[2]);
       fprintf (fout,"#nI = Node Index\n");
       fprintf (fout,"#x  = X \n");
       fprintf (fout,"#y  = Y\n");
@@ -1303,8 +1254,7 @@ int main (int argc,char *argv[])
       
       fout = fopen(OutName,"w");
       if (!fout) {
-         SUMA_S_Err("Failed to open file for writing.\n"
-                    "Check your permissions.\n");
+         SUMA_S_Err("Failed to open file for writing.\nCheck your permissions.\n");
          exit(1);
       }
       
@@ -1324,12 +1274,9 @@ int main (int argc,char *argv[])
             nt = SO->EL->ELps[i][2];
             n1_3 = 3 * n1;
             n2_3 = 3 * n2;
-            edgeL2 = ( (SO->NodeList[n2_3] - SO->NodeList[n1_3]) * 
-                           (SO->NodeList[n2_3] - SO->NodeList[n1_3]) ) +
-                     ( (SO->NodeList[n2_3+1] - SO->NodeList[n1_3+1]) * 
-                           (SO->NodeList[n2_3+1] - SO->NodeList[n1_3+1]) ) +
-                     ( (SO->NodeList[n2_3+2] - SO->NodeList[n1_3+2]) * 
-                           (SO->NodeList[n2_3+2] - SO->NodeList[n1_3+2]) ); 
+            edgeL2 = ( (SO->NodeList[n2_3] - SO->NodeList[n1_3]) * (SO->NodeList[n2_3] - SO->NodeList[n1_3]) ) +
+                     ( (SO->NodeList[n2_3+1] - SO->NodeList[n1_3+1]) * (SO->NodeList[n2_3+1] - SO->NodeList[n1_3+1]) ) +
+                     ( (SO->NodeList[n2_3+2] - SO->NodeList[n1_3+2]) * (SO->NodeList[n2_3+2] - SO->NodeList[n1_3+2]) ); 
                      
             fprintf (fout,"%d\t%d\t%d\t%d\t%f\n",
                   i, n1, n2, nt, sqrt(edgeL2));
@@ -1356,8 +1303,7 @@ int main (int argc,char *argv[])
       
       fout = fopen(OutName,"w");
       if (!fout) {
-         SUMA_S_Err( "Failed to open file for writing.\n"
-                     "Check your permissions.\n");
+         SUMA_S_Err("Failed to open file for writing.\nCheck your permissions.\n");
          exit(1);
       }
       
@@ -1374,7 +1320,6 @@ int main (int argc,char *argv[])
    }
    
    if (Do_curv) {
-      
       SUMA_S_Note("Writing curvatures ...");
       
       if (!SO->SC) {
@@ -1388,66 +1333,28 @@ int main (int argc,char *argv[])
          exit(1);
       }
       
-      
-      if (!(fout = fopen(OutName,"w"))) {
-         SUMA_S_Err( "Failed to open file for writing.\n"
-                     "Check your permissions.\n");
+      fout = fopen(OutName,"w");
+      if (!fout) {
+         SUMA_S_Err("Failed to open file for writing.\nCheck your permissions.\n");
          exit(1);
       }  
       
       fprintf (fout,"#Curvature\n");
       fprintf (fout,"#nI = Node Index\n");
-      fprintf (fout,
-               "#T1 = 1 x 3 vector of 1st principal direction of surface\n");
-      fprintf (fout,
-               "#T2 = 1 x 3 vector of 2nd principal direction of surface\n");
+      fprintf (fout,"#T1 = 1 x 3 vector of 1st principal direction of surface\n");
+      fprintf (fout,"#T2 = 1 x 3 vector of 2nd principal direction of surface\n");
       fprintf (fout,"#Kp1 = curvature along T1\n");
       fprintf (fout,"#Kp2 = curvature along T2\n");
-      fprintf (fout,"#Kp = sqrt(Kp1*Kp1+Kp2*Kp2)\n");
-      fprintf (fout, "#nI\tT1[0]\tT1[1]\tT1[2]\tT2[0]\tT2[1]\tT2[2]"
-                     "\tKp1\tKp2\tKp\n\n");
+      fprintf (fout,"#nI\tT1[0]\tT1[1]\tT1[2]\tT2[0]\tT2[1]\tT2[2]\tKp1\tKp2\n\n");
       if (histnote) fprintf (fout,"#History:%s\n", histnote);
       
       for (i=0; i < SO->N_Node; ++i) {
-         fprintf (fout,"%d\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\n",
+         fprintf (fout,"%d\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\n",
             i, SO->SC->T1[i][0], SO->SC->T1[i][1], SO->SC->T1[i][2], 
             SO->SC->T2[i][0], SO->SC->T2[i][1], SO->SC->T2[i][2],
-            SO->SC->Kp1[i], SO->SC->Kp2[i], 
-            sqrt(SO->SC->Kp1[i]*SO->SC->Kp1[i]+
-                         SO->SC->Kp2[i]*SO->SC->Kp2[i]));
+            SO->SC->Kp1[i], SO->SC->Kp2[i] );
       }
-      fclose(fout); fout = NULL;
       
-      /* Also output nice dset*/
-      sprintf(OutName, "%s.curv.niml.dset", OutPrefix);
-      if (!THD_ok_overwrite() && SUMA_filexists(OutName)) {
-         SUMA_S_Err("Curvature output dset exists.\nWill not overwrite.");
-         exit(1);
-      }
-      ndset = SUMA_CurvatureToDset(SO->SC, OutName);
-      SUMA_AddNgrHist(ndset->ngr, "SurfaceMetrics", argc, argv);
-      oname = SUMA_WriteDset_s(OutName, ndset, SUMA_BINARY_NIML, 1, 1);
-      SUMA_free(oname); oname=NULL;
-      SUMA_FreeDset(ndset); ndset=NULL;
-   
-      /* And some niml DOs */
-      sprintf(OutName, "%s.curv.1D.do", OutPrefix);
-      if (!THD_ok_overwrite() && SUMA_filexists(OutName)) {
-         SUMA_S_Err("Curvature output DO file exists.\nWill not overwrite.");
-         exit(1);
-      }
-      if (!(fout = fopen(OutName,"w"))) {
-         SUMA_S_Err( "Failed to open file for writing.\n"
-                     "Check your permissions.\n");
-         exit(1);
-      }
-      fprintf (fout,"#node-based_vectors\n");
-      for (i=0; i < SO->N_Node; ++i) {
-         fprintf (fout, "%d %f %f %f 1 0 0 1\n"
-                        "%d %f %f %f 0 1 0 1\n",
-                        i, SO->SC->T1[i][0], SO->SC->T1[i][1], SO->SC->T1[i][2], 
-                        i, SO->SC->T2[i][0], SO->SC->T2[i][1], SO->SC->T2[i][2]);
-      }
       fclose(fout); fout = NULL;
    }
    
@@ -1483,32 +1390,6 @@ int main (int argc,char *argv[])
       }
       
       fclose(fout); fout = NULL;
-      
-      /* Also output nice dset*/
-      sprintf(OutName, "%s.conv.niml.dset", OutPrefix);
-      if (!THD_ok_overwrite() && SUMA_filexists(OutName)) {
-         SUMA_S_Err("Curvature output dset exists.\nWill not overwrite.");
-         exit(1);
-      }
-      if (!(ndset =  SUMA_CreateFullDsetPointer( 
-            OutPrefix, 
-            SUMA_NODE_BUCKET, 
-            NULL, 
-            NULL,
-            SO->N_Node ))) {
-         SUMA_S_Err("Failed to create dset");
-         exit(1);
-      }
-
-      if (!SUMA_AddDsetNelCol(ndset, "Convexity", SUMA_NODE_FLOAT, 
-                              (void *)Cx, NULL, 1)) {
-         SUMA_S_Err("Failed to add col Convexity");
-         exit(1);
-      } 
-      SUMA_AddNgrHist(ndset->ngr, "SurfaceMetrics", argc, argv);
-      oname = SUMA_WriteDset_s(OutName, ndset, SUMA_BINARY_NIML, 1, 1);
-      SUMA_free(oname); oname=NULL;
-      SUMA_FreeDset(ndset); ndset=NULL;
    }   
    
    if (Do_vol) {
@@ -1640,8 +1521,7 @@ int main (int argc,char *argv[])
       fclose(fout); fout = NULL;
    }
    
-   if (closest_to_xyz) { /* read xyz list, report closest node 
-                            (SLOW implementation...)*/
+   if (closest_to_xyz) { /* read xyz list, report closest node (SLOW implementation...)*/
       MRI_IMAGE *im = NULL;
       float *far=NULL, *p=NULL;
       int nx2, N_XYZ = 0,i, i3, *closest=NULL, n;
@@ -1650,20 +1530,17 @@ int main (int argc,char *argv[])
       /* load the 1D file */
       im = mri_read_1D (closest_to_xyz);
       if (!im) {
-         fprintf(SUMA_STDERR,"Error %s:\n Failed to read/find %s.\n", 
-                  FuncName, closest_to_xyz);
+         fprintf(SUMA_STDERR,"Error %s:\n Failed to read/find %s.\n", FuncName, closest_to_xyz);
          exit(1);
       }   
 
       far = MRI_FLOAT_PTR(im);
       if (im->nx == 0) {
-         fprintf(SUMA_STDERR,"Error %s:\n Empty file %s.\n", 
-                  FuncName, closest_to_xyz);
+         fprintf(SUMA_STDERR,"Error %s:\n Empty file %s.\n", FuncName, closest_to_xyz);
          exit(1);
       }
       if (im->ny != 3) {
-         fprintf(SUMA_STDERR,"Error %s:\n Found %d columns in %s. Expecting 3\n",
-                     FuncName, im->ny, closest_to_xyz);
+         fprintf(SUMA_STDERR,"Error %s:\n Found %d columns in %s. Expecting 3\n", FuncName, im->ny, closest_to_xyz);
          exit(1);
       }
 
@@ -1700,8 +1577,7 @@ int main (int argc,char *argv[])
 
       fout = fopen(OutName,"w");
       if (!fout) {
-         SUMA_S_Err( "Failed to open file for writing.\n"
-                     "Check your permissions.\n");
+         SUMA_S_Err("Failed to open file for writing.\nCheck your permissions.\n");
          exit(1);
       }  
 
@@ -1745,11 +1621,10 @@ int main (int argc,char *argv[])
    if (!SUMA_FreeSpecFields(pSpec)) {
       SUMA_S_Err("Failed to free Spec fields");
    } SUMA_free(pSpec); pSpec = NULL; 
-   if (ps) SUMA_FreeGenericArgParse(ps); ps = NULL;
+ 	if (ps) SUMA_FreeGenericArgParse(ps); ps = NULL;
    
    /* dset and its contents are freed in SUMA_Free_CommonFields */
-   if (!SUMA_Free_CommonFields(SUMAg_CF)) 
-      SUMA_error_message(FuncName,"SUMAg_CF Cleanup Failed!",1);
+   if (!SUMA_Free_CommonFields(SUMAg_CF)) SUMA_error_message(FuncName,"SUMAg_CF Cleanup Failed!",1);
 
    if (histnote) SUMA_free(histnote);
     
