@@ -242,7 +242,7 @@ void SUMA_DotXform_SetPending (NI_element *dotopts, int pending, char *id)
                strcat(stmp, cs);
                strcat(stmp, id);
                NI_set_attribute(dotopts, "pending", stmp);
-            } else {/* already pending */
+            } else {/* alread pending */
             }
          } else { /* nothing pending, add it */
             sprintf(stmp, "%s;", id);
@@ -350,7 +350,7 @@ SUMA_DSET *SUMA_GetDotPreprocessedDset(SUMA_DSET *in_dset,
          }
 
          if (!(child = SUMA_Fetch_OverlayPointerByDset (
-                              (SUMA_ALL_DO *)SO, pdset, &OverInd))) {
+                    SO->Overlays, SO->N_Overlays, pdset, &OverInd))) {
             /* need a new one */
             if (!(SDSET_LABEL(pdset))) SUMA_LabelDset(pdset,NULL);
             stmp = SUMA_append_string("dotprep.", SDSET_LABEL(pdset));         
@@ -363,7 +363,7 @@ SUMA_DSET *SUMA_GetDotPreprocessedDset(SUMA_DSET *in_dset,
             }
             SUMA_LH("Add overlay to SO");
             /* Add this plane to SO->Overlays */
-            if (!SUMA_AddNewPlane ( (SUMA_ALL_DO *)SO, child, 
+            if (!SUMA_AddNewPlane ( SO, child, 
                                     SUMAg_DOv, SUMAg_N_DOv, 0)) {
                SUMA_SL_Crit("Failed in SUMA_AddNewPlane");
                SUMA_FreeOverlayPointer(child);
@@ -383,11 +383,11 @@ SUMA_DSET *SUMA_GetDotPreprocessedDset(SUMA_DSET *in_dset,
             /*update the list widget if open */
             LW = SO->SurfCont->SwitchDsetlst;
             if (LW) {
-               if (!LW->isShaded) SUMA_RefreshDsetList ((SUMA_ALL_DO *)SO);  
+               if (!LW->isShaded) SUMA_RefreshDsetList (SO);  
             }  
 
             /* this chunk from SUMA_ColPlane_NewOrder */
-            if (!SUMA_MovePlaneDown((SUMA_ALL_DO *)SO, child->Name)) {
+            if (!SUMA_MovePlaneDown(SO, child->Name)) {
                SUMA_L_Err("Error in SUMA_MovePlaneUp.");
                goto BAIL;
             }
@@ -468,8 +468,7 @@ void SUMA_dot_product_CB( void *params)
    static char FuncName[]={"SUMA_dot_product_CB"};
 
    char *SO_idcode=NULL, *ts_dset_id=NULL, 
-         *dot_dset_id=NULL, stmp[300], ident[300], prefix[300], 
-         *p1=NULL, *p2=NULL, *Cside;
+         *dot_dset_id=NULL, stmp[300];
    SUMA_DSET *in_dset=NULL, *ts_src_dset=NULL; 
    double TR = 0;
    double *ts=NULL; 
@@ -486,7 +485,7 @@ void SUMA_dot_product_CB( void *params)
    
    SUMA_ENTRY;
    
-   if (LocalHead) {
+   if (0 && LocalHead) {
       SUMA_LH("Callbacks upon entering");
       SUMA_Show_Callbacks(SUMAg_CF->callbacks, SUMA_STDERR, 1);
    }
@@ -535,13 +534,11 @@ void SUMA_dot_product_CB( void *params)
    if (LocalHead) {
       int suc=0;
       sprintf(stmp,"file:%s.nelpars.1D", FuncName);
-      SUMA_LH("Writing %s", stmp);
       NEL_WRITE_1D(nelpars, stmp, suc);
    }
    if (LocalHead) {
       int suc=0;
       sprintf(stmp,"file:%s.dotopts.1D", FuncName);
-      SUMA_LH("Writing %s", stmp);
       NEL_WRITE_1D(dotopts, stmp, suc);
    }
       
@@ -583,18 +580,19 @@ void SUMA_dot_product_CB( void *params)
    }
    
    if (N_ts < 0) { /* try to get ts from a dset, based on where click happened */
-      if (!(SO = SUMA_findSOp_inDOv(NI_get_attribute(nelpars,"event.DO_idcode"),
+      if (!(SO = SUMA_findSOp_inDOv(NI_get_attribute(nelpars,"event.SO_idcode"),
                                     SUMAg_DOv, SUMAg_N_DOv))) {
          SUMA_S_Notev("Could not find event's SO (%s)\n"
                       "Use Shift+Ctrl+Right Click on the surface "
                       "to calculate correlation with new changes\n",
-                     NI_get_attribute(nelpars,"event.DO_idcode"));
-         /* SUMA_DUMP_TRACE("event.DO_idcode"); */
+                     NI_get_attribute(nelpars,"event.SO_idcode"));
+         /* SUMA_DUMP_TRACE("event.SO_idcode"); */
          SUMA_RETURNe;
       }
       /* find out which overlay was clicked on */
-      if (!(Sover = SUMA_Fetch_OverlayPointer((SUMA_ALL_DO*)SO,
-                        NI_get_attribute(nelpars,"event.overlay_name"),&jj))) {
+      if (!(Sover = SUMA_Fetch_OverlayPointer(SO->Overlays, SO->N_Overlays,
+                                 NI_get_attribute(nelpars,"event.overlay_name"),
+                                 &jj))) {
          SUMA_S_Err("Could not find event's overlay");
          SUMA_RETURNe;                          
       }
@@ -663,7 +661,6 @@ void SUMA_dot_product_CB( void *params)
          char stmp[1000];
          if (!SDSET_LABEL(in_dset)) SUMA_LabelDset(in_dset, NULL);
          sprintf(stmp,"%s.ts.%d.1D", SDSET_LABEL(in_dset), ts_node);
-         SUMA_LH("Writing %s", stmp);
          SUMA_WRITE_ARRAY_1D(ts, N_ts, 1, stmp);
       }
       SUMA_LHv("  Calculating dot for %d/%d: \n"
@@ -677,38 +674,6 @@ void SUMA_dot_product_CB( void *params)
          SUMA_S_Err("Failed to compute dot product");
          SUMA_RETURNe;
       }
-      
-      SUMA_LH("Now clearing overlay vecs");
-      /* Make sure color overlay datacopies get reset */
-      if (!SUMA_DSET_ClearOverlay_Vecs(out_dset)) {         
-         SUMA_S_Err("Failed to clear overlay copies");
-         SUMA_RETURNe;
-      }
-      
-	   snprintf(ident,298*sizeof(char), "filename:%s", SDSET_FILENAME(out_dset));
-      
-      SUMA_LH("Adding to save list");
-      {
-      	SUMA_PARSED_NAME *p1p, *p2p;
-      p1p = SUMA_ParseFname_eng(SDSET_FILENAME(in_dset), SUMAg_CF->cwd, 0);
-      p1 = SUMA_RemoveDsetExtension_s(p1p->FileName_NoExt,
-                                        SUMA_NO_DSET_FORMAT);
-      p2p = SUMA_ParseFname_eng(SDSET_FILENAME(ts_src_dset), SUMAg_CF->cwd, 0);
-      p2 = SUMA_RemoveDsetExtension_s(p2p->FileName_NoExt,
-                                        SUMA_NO_DSET_FORMAT);
-      SUMA_Free_Parsed_Name(p1p); p1p = NULL;
-      SUMA_Free_Parsed_Name(p2p); p2p = NULL;
-      }
-      
-      if (SO->Side == SUMA_LEFT) Cside = "L";
-      else if (SO->Side == SUMA_RIGHT) Cside = "R";
-      else Cside = "";
-      snprintf(prefix,298*sizeof(char),"seed_%d%s.DOT.%s", 
-                  ts_node, Cside, p1);
-      SUMA_free(p1); SUMA_free(p2);
-      if (!(SUMA_Add_to_SaveList(&SUMAg_CF->SaveList, "sdset", ident, prefix))) {
-         SUMA_S_Warnv("Failed to add to save list %s %s\n", ident, prefix);
-      }
    }
    
    if (ts) SUMA_free(ts); ts = NULL;
@@ -716,9 +681,8 @@ void SUMA_dot_product_CB( void *params)
    /* Now clear callback specific elements for caution 
       This way I'll know if this function 
       is being called repeatedly by mistake*/
-   SUMA_LH("Clearing callback specific elements");
    if (nelts) {
-      NI_remove_from_group(ngr, nelts); NI_free_element(nelts); nelts = NULL;
+      NI_remove_from_group(ngr, nelts); NI_free(nelts); nelts = NULL;
    }
    
    
@@ -756,7 +720,7 @@ SUMA_DSET *SUMA_DotDetrendDset(  SUMA_DSET *in_dset,
       SUMA_RETURN(NULL);  
    }
      
-   SUMA_LH("Bandpass/detrending phase");  
+  
    /* detrend */
    nnort = THD_bandpass_vectors (SDSET_VECNUM(in_dset), SDSET_VECLEN(in_dset), 
                                  fvec, (float)TR, fbot, ftop, qdet, nref, 
@@ -772,11 +736,9 @@ SUMA_DSET *SUMA_DotDetrendDset(  SUMA_DSET *in_dset,
       THD_normalize( SDSET_VECNUM(in_dset) , fvec[i] ) ;
    }
    
-   SUMA_LH("About to form output dset");
    /* make a copy of the input dset */
    o_dset = SUMA_MaskedCopyofDset(in_dset, NULL, NULL, 1, 0);
    
-   SUMA_LH("Now filling with output");
    /* Now fill it with fvec*/
    if (!SUMA_VecArray2Dset((void **)fvec, 
                             o_dset, 
@@ -988,10 +950,6 @@ SUMA_Boolean SUMA_dot_product(SUMA_DSET *in_dset,
             } 
          }
          break;
-      case SUMA_complex:
-         SUMA_S_Err("No support for complex type here");
-         SUMA_RETURN(NOPE);
-         break;
       default:
          SUMA_S_Err("What kind of numeric type is this?");
          SUMA_RETURN(NOPE);
@@ -1022,13 +980,12 @@ SUMA_Boolean SUMA_dot_product(SUMA_DSET *in_dset,
                      par[2] );
          par[2] = 2; /* something ... */
       }
-      SUMA_LH("Adding ort stuff");
       SUMA_AddColAtt_CompString( nelb, 0, 
                                  NI_stat_encode(NI_STAT_CORREL, 
                                                 par[0], par[1], par[2]),
                                  SUMA_NI_CSS, 0);
    }
-   SUMA_LH("Heading out");
+   
    if (0 && LocalHead) {
       ic = 0;
       for (ir=0; ir<SDSET_VECLEN(in_dset) && ic < 10; ++ir) {
@@ -1053,7 +1010,9 @@ SUMA_Boolean SUMA_dot_product(SUMA_DSET *in_dset,
       SUMA_free(s);
    }
    
+   
    SUMA_RETURN(YUP);
+   
 }
 
 /* *************************************************************************** */
@@ -1181,8 +1140,7 @@ SUMA_Boolean SUMA_GICOR_Dsets(SUMA_SurfaceObject *SOv[],
             ov[i]->OptScl->ThreshRange[1] = 0.0;
 
             /* Now add the overlay to SOv[i]->Overlays */
-            if (!SUMA_AddNewPlane ((SUMA_ALL_DO *)SOv[i], ov[i], 
-                                    SUMAg_DOv, SUMAg_N_DOv, 1)) {
+            if (!SUMA_AddNewPlane (SOv[i], ov[i], SUMAg_DOv, SUMAg_N_DOv, 0)) {
                SUMA_SL_Crit("Failed in SUMA_AddNewPlane");
                SUMA_FreeOverlayPointer(ov[i]);
                SUMA_free(dset_namev[i]); SUMA_free(targetv[i]);
@@ -1219,7 +1177,7 @@ SUMA_Boolean SUMA_GICOR_Dsets(SUMA_SurfaceObject *SOv[],
       for (i=0; i<2; ++i) {
          if (sdsetv[i]) {
             if (!(ov[i] = SUMA_Fetch_OverlayPointerByDset(
-                             (SUMA_ALL_DO *)SOv[i],
+                             SOv[i]->Overlays, SOv[i]->N_Overlays,
                              sdsetv[i], &ovind))) {
                SUMA_S_Err("Failed to find overlay pointer");
                SUMA_RETURN(NOPE);
@@ -1265,7 +1223,6 @@ SUMA_Boolean SUMA_GICOR_Surfaces(GICOR_setup *giset, SUMA_SurfaceObject *SOv[])
    SUMA_RETURN(YUP); 
 }
 
-
 /*!
    Function called from SUMA_niml, when GICorr sends a setup element 
    This function parallels AFNI's GICOR_setup_func
@@ -1274,15 +1231,16 @@ SUMA_Boolean SUMA_GICOR_setup_func( NI_stream nsg , NI_element *nel )
 {
    static char FuncName[]={"SUMA_GICOR_setup_func"};
    GICOR_setup *giset = NULL;
+   char *atr=NULL , *pre=NULL, *s=NULL;
    SUMA_DSET *sdsetv[2]={NULL, NULL};
    SUMA_OVERLAYS *ov[2]={NULL, NULL};
+   int nnode_dom[2]={0,0};
+   int nnode_mask[2]={0,0};
    SUMA_SurfaceObject *SOv[2]={NULL, NULL};
-   char *pre=NULL;
    SUMA_Boolean LocalHead = NOPE;
    
    SUMA_ENTRY;
    
-   
    /* fetch the giset struct */
    giset = SUMAg_CF->giset; 
    if( giset != NULL && giset->ready ) SUMA_RETURN(YUP) ;
@@ -1294,7 +1252,73 @@ SUMA_Boolean SUMA_GICOR_setup_func( NI_stream nsg , NI_element *nel )
      memset(giset,0, sizeof(GICOR_setup)) ;
    }
    
-   if (!SUMA_init_GISET_setup(nsg, nel, giset, 0)) SUMA_GIQUIT;
+   giset->ns    = nsg ;  /* save socket for I/O back to 3dGroupInCorr */
+   giset->ready = 0 ;    /* not ready yet */
+
+   /* set various parameters from the NIML header */
+
+   atr = NI_get_attribute( nel , "ndset_A" ) ; 
+      if( atr == NULL )        SUMA_GIQUIT;
+   giset->ndset_A = (int)strtod(atr,NULL) ;    
+      if( giset->ndset_A < 2 ) SUMA_GIQUIT;
+
+   atr = NI_get_attribute( nel , "ndset_B" ) ; 
+      if( atr == NULL )        SUMA_GIQUIT;
+   giset->ndset_B = (int)strtod(atr,NULL) ;
+
+   atr = NI_get_attribute( nel , "nvec" ) ;  
+      if( atr == NULL )        SUMA_GIQUIT;
+   giset->nvec = (int)strtod(atr,NULL) ;       
+      if( giset->nvec < 2 )    SUMA_GIQUIT;
+
+   atr = NI_get_attribute( nel , "seedrad" ) ;
+   if( atr != NULL ) giset->seedrad = (float)strtod(atr,NULL) ;
+
+   atr = NI_get_attribute( nel , "ttest_opcode" ) ;
+   if( atr != NULL ) giset->ttest_opcode = (int)strtod(atr,NULL) ;
+
+   /* create output dataset(s), to be filled in from 3dGroupInCorr data later */
+               
+   atr = NI_get_attribute( nel , "geometry_string" ); 
+      if( atr == NULL ) {
+         SUMA_S_Err("No geometry string");
+         SUMA_RETURN(NOPE);
+      }
+   pre = NI_get_attribute( nel , "target_name" ) ;
+   if( pre == NULL || *pre == '\0' ) pre = "GICorrelletto" ;
+   
+   /* How many dsets? */
+   SUMA_LHv("attr=%s\nval0=%s,val1=%s\n", 
+            NI_get_attribute(nel,"LRpair_nnode"),
+            SUMA_NI_get_ith_string(NI_get_attribute(nel,"LRpair_nnode"),",",0),
+            SUMA_NI_get_ith_string(NI_get_attribute(nel,"LRpair_nnode"),",",1));
+   if ((s=SUMA_NI_get_ith_string(
+               NI_get_attribute(nel,"LRpair_nnode"),",",0))) {
+      giset->nnode_domain[0] = (int)strtol(s, NULL, 10);
+      SUMA_free(s); s = NULL;
+      if ((s=SUMA_NI_get_ith_string(
+               NI_get_attribute(nel,"LRpair_nnode"),",",1))) {
+         giset->nnode_domain[1] = (int)strtol(s, NULL, 10);
+         SUMA_free(s); s = NULL;
+      }
+   } else {
+      giset->nnode_domain[0] = giset->nvec; 
+      giset->nnode_domain[1] = 0; 
+   }
+               
+   if ((s=SUMA_NI_get_ith_string(
+               NI_get_attribute(nel,"LRpair_ninmask"),",",0))) {
+      giset->nnode_mask[0] = (int)strtol(s, NULL, 10);
+      SUMA_free(s); s = NULL;
+      if ((s=SUMA_NI_get_ith_string(
+               NI_get_attribute(nel,"LRpair_ninmask"),",",1))) {
+         giset->nnode_mask[1] = (int)strtol(s, NULL, 10);
+         SUMA_free(s); s = NULL;
+      }
+   } else {
+      giset->nnode_mask[0] = giset->nnode_domain[0]; 
+      giset->nnode_mask[1] = giset->nnode_domain[1];
+   }
    
    /* Now find surfaces that can be the domain */
    if (!SUMA_GICOR_Surfaces(giset, SOv)) {
@@ -1303,14 +1327,25 @@ SUMA_Boolean SUMA_GICOR_setup_func( NI_stream nsg , NI_element *nel )
    }
    
    /* Now create appropriate dsets */
-   pre = NI_get_attribute( nel , "target_name" ) ;
-   if( pre == NULL || *pre == '\0' ) pre = "GICorrelletto" ;
    if (!SUMA_GICOR_Dsets(SOv, giset, pre, SUMAg_CF->DsetList, 
                          sdsetv, ov, nel)) {
       SUMA_S_Err("Failed to find/create dsets for giset");
       SUMA_RETURN(NOPE);
    }
 
+   giset->nvox = giset->nvec ;
+
+   /* list of voxels to expect from each 3dGroupInCorr data */
+   if( nel->vec_len == 0 || nel->vec_num == 0 || nel->vec == NULL ){  /* all */
+     giset->ivec = NULL ; giset->nivec = 0 ;
+      INFO_message("DEBUG: GICOR_setup_func has ivec=NULL") ; 
+   } else {                                     /* make index list of voxels */
+     int ii , nn , *iv=(int *)nel->vec[0] ;
+     giset->ivec = (int *)calloc(sizeof(int),giset->nvec) ;
+     nn = MIN(giset->nvec,nel->vec_len) ; giset->nivec = nn ;
+     for( ii=0 ; ii < nn ; ii++ ) giset->ivec[ii] = iv[ii] ;
+     INFO_message("DEBUG: GICOR_setup_func has ivec=int[%d]",nn) ; 
+   }
 
    giset->ready = 1 ;
    
@@ -1326,9 +1361,10 @@ SUMA_Boolean SUMA_GICOR_process_dataset( NI_element *nel  )
 {
    static char FuncName[]={"SUMA_GICOR_process_dataset"};
    GICOR_setup *giset = SUMAg_CF->giset ;
-   int vmul ; float thr ;
-   int id=0, ic=0;
-   char *seedstr=NULL, *Cside=NULL, ident[300]={""}, prefix[300]={""};
+   char *sbuf=NULL;
+   float *neldar , *nelzar , *dsdar , *dszar ;
+   int nvec,nn , vmul ; float thr ;
+   int id=0, ic=0, ipair=0;
    SUMA_SurfaceObject *SOv[2]={NULL,NULL};
    SUMA_DSET *sdsetv[2]={NULL, NULL};
    SUMA_OVERLAYS *ov[2]={NULL, NULL};
@@ -1372,54 +1408,107 @@ SUMA_Boolean SUMA_GICOR_process_dataset( NI_element *nel  )
 
    SUMA_LH("Populating the dset in question, redisplay, etc.");
    
-   if (!SUMA_PopulateDsetsFromGICORnel(nel, giset, sdsetv)) {
-      SUMA_S_Err("Failed to populate. Not fun.");
-      SUMA_RETURN(NOPE);
-   }  
-   
-   /* Add dsets to autosave list */
-   if (!(seedstr = NI_get_attribute(nel,"boomerang_msg"))) {
-      seedstr = "seed_XXXX";
-   }
-   for (id=0; id<2; ++id) {
-      if (sdsetv[id] && SOv[id]) {   
-         snprintf(ident,298*sizeof(char), "filename:%s", 
-                                          SDSET_FILENAME(sdsetv[id]));
-         if (SOv[id]->Side == SUMA_LEFT) Cside = ".lh";
-         else if (SOv[id]->Side == SUMA_RIGHT) Cside = ".rh";
-         else Cside = "";
-         snprintf(prefix,298*sizeof(char),"seed_%s.GIC%s", 
-                     seedstr, Cside);
-         if (!(SUMA_Add_to_SaveList(&SUMAg_CF->SaveList, "sdset", 
-                                    ident, prefix))) {
-            SUMA_S_Warnv("Failed to add to save list %s %s\n", ident, prefix);
-         }
-      }
+   for (id=0; id < 2; ++id) {
+      for (ipair=0; ipair < nel->vec_num/2; ++ipair) {
+         neldar = (float *)nel->vec[2*ipair+0] ;  /* delta array */
+         nelzar = (float *)nel->vec[2*ipair+1] ;  /* zscore array */
+         nvec   = nel->vec_len ;
+
+         if (giset->nnode_domain[id]) {
+            dsdar = (float *)SDSET_VEC(sdsetv[id],(2*ipair+0)) ;
+            dszar = (float *)SDSET_VEC(sdsetv[id],(2*ipair+1)) ;
+            if (LocalHead) {
+               sbuf=SUMA_ShowMeSome(dsdar,
+                           SUMA_float, SDSET_VECLEN(sdsetv[id]),10,"dsdar:\n");
+               SUMA_LHv("pre copy surf%d %s\n",id, sbuf); 
+               SUMA_free(sbuf); sbuf=NULL;
+            }
+
+            if( giset->ivec == NULL ){  /* all nodes */
+               if (giset->nvox != nvec) {
+                  SUMA_S_Errv( "nvox=%d, nvec=%d, ivec=NULL\n"
+                              "Did not expect that.\n",
+                              giset->nvox, nvec);
+                  SUMA_RETURN(NOPE) ;
+               }
+               if (id == 0) {
+                  nn = MAX(0, nvec-giset->nnode_domain[1]);
+                  SUMA_LHv("Copying %d values from neldar, surf%d\n", 
+                           nn, id);
+                  if (LocalHead) {   
+                     sbuf=SUMA_ShowMeSome(neldar,SUMA_float, nn,10,"neldar:\n");
+                     SUMA_LHv("from the tube surf%d: %s\n", id, sbuf); 
+                     SUMA_free(sbuf); sbuf=NULL;
+                  }
+                  memcpy(dsdar,neldar,sizeof(float)*nn) ;
+                  memcpy(dszar,nelzar,sizeof(float)*nn) ;
+               } else {
+                  nn = MAX(0, nvec-giset->nnode_domain[0]);
+                  SUMA_LHv("Copying %d values from neldar+%d, surf%d\n", 
+                           nn, giset->nnode_domain[0], id);
+                  if (LocalHead) {
+                     sbuf=SUMA_ShowMeSome((neldar+giset->nnode_domain[0]),
+                                          SUMA_float, nn, 10,"neldar:\n");
+                     SUMA_LHv("from the tube surf%d: %s\n", id, sbuf); 
+                     SUMA_free(sbuf); sbuf=NULL;
+                  }
+                  memcpy(dsdar,(neldar+giset->nnode_domain[0]),
+                           sizeof(float)*nn) ;
+                  memcpy(dszar,(nelzar+giset->nnode_domain[0]),
+                           sizeof(float)*nn) ;
+               }
+               if (LocalHead) {
+                  sbuf=SUMA_ShowMeSome(dsdar,SUMA_float, nn, 10,"dsdar:\n");
+                  SUMA_LHv("post copy surf%d %s\n", id, sbuf); 
+                  SUMA_free(sbuf); sbuf=NULL;
+               }
+            } else { /* Have index vector */
+               int *ivec=giset->ivec , kk ;
+               nn = MIN( giset->nnode_mask[id] , nvec ) ;
+               if (id == 0) {
+                  for( kk=0 ; kk < nn ; kk++ ){
+                     dsdar[ivec[kk]] = neldar[kk] ; 
+                     dszar[ivec[kk]] = nelzar[kk] ;
+                  }
+               } else {
+                  for( kk=0 ; kk < nn ; kk++ ){
+                     dsdar[ivec[kk]-giset->nnode_domain[0]] = neldar[kk] ; 
+                     dszar[ivec[kk]-giset->nnode_domain[0]] = nelzar[kk] ;
+                  }
+               }
+            }
+         } /* if (giset->nnode_domain[id]) */
+      } /* for (ipair ...) */
    }
 
    /* colorize and redisplay */
    for (id=0; id<2; ++id) {
       if (ov[id] && SOv[id]) {
          SOv[id]->SurfCont->curColPlane = ov[id];
-         if (!SUMA_OpenCloseSurfaceCont(NULL, (SUMA_ALL_DO*)SOv[id], NULL)) {
+         if (!SUMA_OpenCloseSurfaceCont(NULL, SOv[id], NULL)) {
             SUMA_SLP_Err("Cannot open Surface Controller!");
             SUMA_RETURN(NOPE);
          }
+         SUMA_LH("Updating range\n");
+         if (!SUMA_UpdateDsetColRange(sdsetv[id],-1)) {
+            SUMA_S_Err("Failed to update range");
+            SUMA_RETURN(NOPE);
+         }
          if ( SOv[id]->SurfCont->SwitchDsetlst && 
               !SOv[id]->SurfCont->SwitchDsetlst->isShaded ) {
-             SUMA_RefreshDsetList ((SUMA_ALL_DO*)SOv[id]);       
+             SUMA_RefreshDsetList (SOv[id]);       
          }
          SUMA_LHv("Colorizing %d\n", id);
          if (!SUMA_ColorizePlane (ov[id])) {
             SUMA_SLP_Err("Failed to colorize plane.\n");
             SUMA_RETURN(NOPE);
          }
-         if (!SUMA_Remixedisplay ((SUMA_ALL_DO*)SOv[id])) {
+         if (!SUMA_RemixRedisplay (SOv[id])) {
             SUMA_SLP_Err("Failed to remix redisplay.\n");
             SUMA_RETURN(NOPE);
          }
          SUMA_LHv("Initializing %d\n", id);
-         SUMA_UpdateColPlaneShellAsNeeded((SUMA_ALL_DO*)SOv[id]);
+         SUMA_UpdateColPlaneShellAsNeeded(SOv[id]);
       }
    }
 
@@ -1488,7 +1577,7 @@ int SUMA_AFNI_gicor_setref( SUMA_SurfaceObject *SO, int node )
 {
    static char FuncName[]={"SUMA_AFNI_gicor_setref"};
    NI_element *nel=NULL;
-   char buf[256]={"bise"}, boom[64]={""}, *cside=NULL;
+   char buf[256]={"bise"};
    GICOR_setup *giset = SUMAg_CF->giset ;
    THD_fvec3 iv,jv; THD_ivec3 kv; 
    int ijk=-1,ii=0;
@@ -1497,11 +1586,7 @@ int SUMA_AFNI_gicor_setref( SUMA_SurfaceObject *SO, int node )
    
    SUMA_ENTRY;
    
-   if (!SO) {
-      SUMA_S_Err("NULL input");
-      SUMA_RETURN(-1) ;
-   }
-     
+   
    if (node < 0) { /* OK, return */
       SUMA_LHv("node %d\n", node);
       SUMA_RETURN(0) ;
@@ -1518,22 +1603,16 @@ int SUMA_AFNI_gicor_setref( SUMA_SurfaceObject *SO, int node )
    /* change node index to proper ijk */
    if (!SUMA_GICOR_Surfaces(giset, SOv)) {
       SUMA_S_Err("Failed to find surfaces for giset");
-      SUMA_RETURN(-1);
+      SUMA_RETURN(NOPE);
    }
-   
-   if (SUMA_isRelated_SO(SO, SOv[0],1)) {
+   if (SUMA_isRelated(SO, SOv[0],1)) {
       ijk = node;
-   } else if (SUMA_isRelated_SO(SO, SOv[1],1)) {
+   } else if (SUMA_isRelated(SO, SOv[1],1)) {
       ijk = node+giset->nnode_domain[0]; 
    } else {
       SUMA_SLP_Warn("Cannot change node to ijk");
       SUMA_RETURN(-1);
    }  
-   
-   cside = "";
-   if (SO->Side == SUMA_LEFT) cside = "L";
-   else if (SO->Side == SUMA_RIGHT) cside = "R";
-   sprintf(boom,"%d%s", node, cside);
    SUMA_LHv("Node %d --> ijk %d\n", node, ijk);
 
    /* if socket has gone bad, we're done */
@@ -1553,14 +1632,13 @@ int SUMA_AFNI_gicor_setref( SUMA_SurfaceObject *SO, int node )
      ii = bsearch_int( ijk , giset->nvec , giset->ivec ) ;
      if( ii < 0 ){
        WARNING_message("GrpInCorr set point not in mask from 3dGroupInCorr") ;
-       SUMA_RETURN(0) ; /* don't return an error */
+       SUMA_RETURN(-1) ;
      }
    }
 
    /* send ijk node index to 3dGroupInCorr */
    nel = NI_new_data_element( "SETREF_ijk" , 0 ) ;
-   NI_set_attribute(nel, "boomerang_msg", boom);
-   
+
    sprintf( buf , "%d" , ijk ) ;
    NI_set_attribute( nel , "index" , buf ) ;
 
