@@ -151,10 +151,8 @@ extrudeSolidFromPolygon(GLfloat data[][2], unsigned int dataSize,
     tobj = gluNewTess();  /* create and initialize a GLU
                              polygon tessellation object */
     /* cast 3rd args as _GLUfuncptr for some machines   02 Aug 2004 [rickr] */
-    gluTessCallback(tobj, GLU_BEGIN,  (void *) glBegin);
-//    gluTessCallback(tobj, GLU_BEGIN, CAST_GLU_FUNCPTR glBegin);
-    gluTessCallback(tobj, GLU_VERTEX, (void *) glVertex2fv);/* tricky */
-//    gluTessCallback(tobj, GLU_VERTEX, CAST_GLU_FUNCPTR glVertex2fv);/* tricky */
+    gluTessCallback(tobj, GLU_BEGIN, CAST_GLU_FUNCPTR glBegin);
+    gluTessCallback(tobj, GLU_VERTEX, CAST_GLU_FUNCPTR glVertex2fv);/* tricky */
     gluTessCallback(tobj, GLU_END, CAST_GLU_FUNCPTR glEnd);
   }
   glNewList(side, GL_COMPILE);
@@ -210,7 +208,7 @@ GLfloat lightOneColor[] = {0.6, 0.3, 0.2, 1.0};  /* red-tinted */
 void
 contextInit(void)
 {
-  glEnable(GL_CULL_FACE);  /* Up to 50% better performance than no
+  glEnable(GL_CULL_FACE);  /* Up to 50% better perfomance than no
                               back-face culling. */
   glEnable(GL_DEPTH_TEST); /* Enable depth buffering. */
 
@@ -261,12 +259,6 @@ main(int argc, char **argv)
   int flags, x, y, width, height, lastX = 0, i;
   
   for (i = 1; i < argc; i++) {
-    if (!strcmp(argv[i], "-help")) {
-      fprintf(stdout,"A simple openGL test program using GLX.\n"
-                     "If it does not run, then SUMA certainly won't.\n"
-                     "Copyright (c) Mark J. Kilgard, 1996.\n" );
-      return(0); 
-    }
     if (!strcmp(argv[i], "-geometry")) {
       if (++i >= argc)
         fatalError("follow -geometry option with geometry parameter");
