@@ -16,7 +16,7 @@ void usage_path_optimize (SUMA_GENERIC_ARGV_PARSE *ps)
                "             [-talk_pause] [-debug DEBUG] [-ouput OUTPUT] [-M_time M_TIME]                     \n"
                "                                                                                               \n"
                "  -ctrl CTRLFILE:   Control nodes 1D file.                                                     \n"
-               "                    Each row is for one node's initial and final XYZ.                           \n" 
+               "                    Each row is for one node's intial and final XYZ.                           \n" 
                "  -dom_dim DOM_DIM: Set domain dimension. Default is 2, a circle.                              \n"
                "                    Must choose dom_dim = 3 for a sphere.                                      \n" 
                "  -dim DIM:         Set the dimension.  Default is 2D. Needed because of -dot option.          \n"
@@ -30,15 +30,15 @@ void usage_path_optimize (SUMA_GENERIC_ARGV_PARSE *ps)
                "                    Default is no adjustment.                                                  \n"  
                "  -sin_kern         Choose to use the expansion factor that includes the sine term.            \n"
                "                    Default is without the sine component of the kernel,  but the default      \n"
-               "                       doesn't work. This option is mandatory for successful deformations.     \n"
-               "  -dot:             Choose to use a dot product requirement when calculated the weights         \n"
+               "                       doesn't work. This option is manditory for successful deformations.     \n"
+               "  -dot:             Choose to use a dot product requirment when calculated the weights         \n"
                "                    to ensure tangency.                                                        \n"
                "  -neighb_check:    Will check at each iteration if the distance to each node's nearest        \n"
                "                    neighbor is smaller than the proposed step size.  Will print results       \n"
                "                    to file, but will not make any step size adjustment.                       \n"
                "  -neighb_adjust:   Checks neighbor distances and adjusts step size accordingly.               \n"
                "  -talk_pause:      For use with SUMA and -talk_suma option.  Will pause program after         \n"
-               "                    initial conditions are setting, allowing user to adjust viewing window      \n"
+               "                    intial conditions are setting, allowing user to adjust viewing window      \n"
                "                    before completing the rest of the iterations.                              \n"
                "                    Use -talk_pause -talk_pause (yes, twice) to a pause at each iteration      \n"
                "  -debug DEBUG:     Choose to turn debugging on.  Default is no debugging.                     \n"                        
@@ -432,9 +432,10 @@ SUMA_SegmentDO *SUMA_ControlCurve2SDO(SUMA_MX_VEC *ControlCurve, char *Label)
 
    SDO = SUMA_CreateSegmentDO( N_n, oriented, NodeBased, Stipple,
                                Label, idcode_str, Parent_idcode_str,
-                               NOT_SET_type, NULL, LineWidth, LineCol,
+                               LineWidth, LineCol,
                                NodeId, NULL, n0, n1,
-                               colv, thickv);
+                               colv, thickv 
+                              );
 
    if (idcode_str) SUMA_free(idcode_str); idcode_str = NULL;
    if (n0) SUMA_free(n0); n0 = NULL;
@@ -640,7 +641,7 @@ int SUMA_Optimize_Path(MyCircleOpt *opt, SUMA_GENERIC_ARGV_PARSE *ps)
             ps->cs->talk_suma = NOPE;
          }
          SUMA_free_SegmentDO(sdo); sdo = NULL;
-         NI_free_element(ngr); ngr = NULL; 
+         NI_free(ngr); ngr = NULL; 
          if ((!opt->iter_count && opt->pause) || opt->pause > 1) {
             SUMA_PAUSE_PROMPT("Initial surface in your face\nDo something to proceed.\n");
          }
@@ -823,6 +824,7 @@ int SUMA_Apply_Deformation(MyCircleOpt *opt, SUMA_GENERIC_ARGV_PARSE *ps)
    int nbad, close_neighb = 0, nbad_face, nbad_node;
    byte *RiskyTrigs=NULL;
    SUMA_Boolean exists;
+   SUMA_SPHERE_QUALITY SSQ;
    SUMA_Boolean LocalHead = NOPE;
    
    SUMA_ENTRY;
@@ -1168,7 +1170,8 @@ int SUMA_Apply_Deformation(MyCircleOpt *opt, SUMA_GENERIC_ARGV_PARSE *ps)
                SUMA_RECOMPUTE_NORMALS(opt->SO);
 
                shist = SUMA_HistString (FuncName, argc, argv, NULL);
-               SUMA_SphereQuality(opt->SO, outfile_SphereQuality, shist, NULL, &nbad);
+               SSQ = SUMA_SphereQuality(opt->SO, outfile_SphereQuality, shist);
+               nbad = SSQ.N_bad_facesets;
                SUMA_Save_Surface_Object(SO_name, opt->SO, SUMA_VEC, SUMA_ASCII, NULL);   */
             } else {
                if (LocalHead) fprintf(SUMA_STDERR,"iteration %d, %d bad facests: Nema Problema!\n", niter, nbad);
@@ -1208,7 +1211,7 @@ int SUMA_Apply_Deformation(MyCircleOpt *opt, SUMA_GENERIC_ARGV_PARSE *ps)
          } while( nbad > 0 );  /* Once there are no more bad facets, dt is small enough and can continue to next iteration. */
                   /* What will dt be now?  Back to original or stick with small dt?  Will need to see how 
                         this loop affects dt for rest of move. */
-                  /* For now, have dt changed permanently by the loop above.  Changed because facets were flipping. */
+                  /* For now, have dt changed permantly by the loop above.  Changed because facets were flipping. */
 
          if (opt->dbg_flag > 1) {
             /* Print Velocity Magnitudes to File. */   
@@ -1327,7 +1330,8 @@ int SUMA_Apply_Deformation(MyCircleOpt *opt, SUMA_GENERIC_ARGV_PARSE *ps)
          SO_name = SUMA_Prefix2SurfaceName (outfile_SphereQuality, NULL, NULL, SUMA_VEC, &exists);
          SUMA_RECOMPUTE_NORMALS(opt->SO);
 
-         SUMA_SphereQuality(opt->SO, outfile_SphereQuality , NULL, NULL, &nbad);
+         SSQ = SUMA_SphereQuality(opt->SO, outfile_SphereQuality , NULL);
+         nbad = SSQ.N_bad_facesets;
          SUMA_Save_Surface_Object(SO_name, opt->SO, SUMA_VEC, SUMA_ASCII, NULL);
       }
         
@@ -1407,7 +1411,7 @@ int SUMA_Apply_Deformation(MyCircleOpt *opt, SUMA_GENERIC_ARGV_PARSE *ps)
 /* Julia:
 This main started as a copy of SUMA_toy_circle and I added to it an example to show you how to use 
 the array functions.
-To compile this program, use:
+To comile this program, use:
  make path_optimize && mv path_optimize ~/abin       
 
 The functions should be put in SUMA_SurfWarp.c and function prototypes should be in SUMA_SurfWarp.h. Don't forget
@@ -1432,6 +1436,7 @@ int main (int argc,char *argv[])
    SUMA_GENERIC_PROG_OPTIONS_STRUCT *Opt;  
    SUMA_GENERIC_ARGV_PARSE *ps=NULL;
    MyCircleOpt myopt, *opt = NULL;
+   SUMA_SPHERE_QUALITY SSQ;
    vector Wv;
    int i, niter = 0, nbad_face, nbad_node, dims[50], N_dims, i3;
    FILE *SpheresAtNodes = NULL;
@@ -1633,7 +1638,9 @@ int main (int argc,char *argv[])
    SO_name = SUMA_Prefix2SurfaceName (opt->outfile, NULL, NULL, SUMA_VEC, &exists); 
    shist = SUMA_HistString (NULL, argc, argv, NULL);
    fprintf( SUMA_STDERR, "\nNITER = %d", niter );
-   SUMA_SphereQuality(opt->SO, opt->outfile , shist, &nbad_node, &nbad_face);   
+   SSQ = SUMA_SphereQuality(opt->SO, opt->outfile , shist);   
+   nbad_face = SSQ.N_bad_facesets;
+   nbad_node = SSQ.N_bad_nodes;
    
    if (nbad_face) {
       fprintf(SUMA_STDERR,"Shist %s!:\n you have %d bad facets!\n", FuncName, nbad_face);
