@@ -40,7 +40,7 @@
 #define PROGRAM_LATEST "15 August 2001"     /* date of last program revision */
 
 /*---------------------------------------------------------------------------*/
-#include "afni.h"
+
 #include "afni_warp.h"
 
 #define MAIN
@@ -149,18 +149,9 @@ void display_help_menu()
       "program provides a batch implementation of the interactive\n"
       "AFNI 'Write' buttons, one dataset at a time.\n"
       "\n"
-      "  Example: create dataset func+tlrc (.HEAD and .BRIK) by applying\n"
-      "           the orig->tlrc transformation from the anat.\n"
+      "  Example: adwarp -apar anat+tlrc -dpar func+orig\n"
       "\n"
-      "           adwarp -apar anat+tlrc -dpar func+orig\n"
-      "\n"
-      "  Example: in the case of a manual tlrc transformation, maybe the\n"
-      "           anat+tlrc.BRIK does not exist (just the .HEAD file does).\n"
-      "           In such a case on might apply the anat+tlrc transformation\n"
-      "           to the anat+orig dataset.  But since the anat+tlrc.HEAD\n"
-      "           file already exists, the -overwrite option is needed.\n"
-      "\n"
-      "           adwarp -apar anat+tlrc -dpar anat+orig -overwrite\n"
+      "  This will create dataset func+tlrc (.HEAD and .BRIK).\n"
       "\n"
       "Options (so to speak):\n"
       "----------------------\n"
@@ -175,7 +166,7 @@ void display_help_menu()
       "-prefix ppp = Set the prefix for the output dataset to 'ppp'.\n"
       "                The default is the prefix of 'dset'.\n"
       "\n"
-      "-dxyz ddd   = Set the grid spacing in the output dataset to\n"
+      "-dxyz ddd   = Set the grid spacing in the output datset to\n"
       "                'ddd' mm.  The default is 1 mm.\n"
       "\n"
       "-verbose    = Print out progress reports.\n"
@@ -271,8 +262,6 @@ void get_options
 	  option_data->aset = THD_open_one_dataset (argv[nopt]);
 	  if (! ISVALID_3DIM_DATASET(option_data->aset))
 	    AW_error ("Cannot read anat parent dataset.\n") ;
-          THD_make_cardinal(option_data->aset);   /* 21 Oct, 2011 [rickr] */
-
 	  nopt++;
 	  continue;
 	}
@@ -285,7 +274,6 @@ void get_options
 	  option_data->dset = THD_open_dataset (argv[nopt]);
 	  if (! ISVALID_3DIM_DATASET(option_data->dset))
 	    AW_error ("Cannot read data parent dataset.\n") ;
-          THD_make_cardinal(option_data->dset);   /* 21 Oct, 2011 [rickr] */
 	  nopt++;
 	  continue;
 	}
@@ -388,10 +376,7 @@ void get_options
 
       /*----- unknown command -----*/
       sprintf(message,"Unrecognized command line option: %s\n", argv[nopt]);
-      fprintf (stderr, "%s Error: %s \n", PROGRAM_NAME, message);
-      suggest_best_prog_option(argv[0], argv[nopt]);
-      exit(1);
-      
+      AW_error (message);
 
     }
 
@@ -653,7 +638,7 @@ ENTRY("adwarp_follower_dataset") ;
 */
 
 
-RwcBoolean adwarp_refashion_dataset
+Boolean adwarp_refashion_dataset
 (
   adwarp_options   *option_data,  /* adwarp program options */
   THD_3dim_dataset *dset,         /* new (output) dataset */
@@ -662,13 +647,13 @@ RwcBoolean adwarp_refashion_dataset
 {
   THD_datablock *dblk  = dset->dblk ;
   THD_diskptr   *dkptr = dset->dblk->diskptr ;
-  RwcBoolean good ;
+  Boolean good ;
   int npix , nx,ny,nz,nv , kk , ival , code , nzv , dsiz , isfunc , cmode ;
   MRI_IMAGE *im ;
   void *imar ;
   FILE *far ;
   float brfac_save ;
-  int resam_mode = 0;
+  int resam_mode;
 
   int native_order , save_order ;  /* 23 Nov 1999 */
 
@@ -833,7 +818,6 @@ STATUS("have new image") ;
         imar = mri_data_pointer(im) ;
          if( save_order != native_order ){                   /* 23 Nov 1999 */
             switch( im->kind ){
-               default:                                   break ;
                case MRI_short:   mri_swap2(  npix,imar) ; break ;
                case MRI_float:
                case MRI_int:     mri_swap4(  npix,imar) ; break ;
