@@ -37,7 +37,6 @@ ENTRY("AFNI_time_lock_change_CB") ;
 }
 
 /*------------------------------------------------------------------------*/
-/* Do the locking of time indexes */
 
 void AFNI_time_lock_carryout( Three_D_View *im3d )
 {
@@ -107,7 +106,7 @@ void AFNI_lock_enforce_CB( Widget w , XtPointer cd , XtPointer calld )
 
 ENTRY("AFNI_lock_enforce_CB") ;
    if( !IM3D_OPEN(im3d) ) EXRETURN ;
-   AFNI_space_lock_carryout( im3d ) ;
+   AFNI_lock_carryout( im3d ) ;
    AFNI_time_lock_carryout( im3d ) ;  /* 03 Nov 1998 */
    RESET_AFNI_QUIT(im3d) ;
    EXRETURN ;
@@ -162,21 +161,6 @@ ENTRY("AFNI_lock_clear_CB") ;
      if( IM3D_VALID(qq3d) )
        MCW_set_bbox( qq3d->vwid->dmode->lock_bbox , 0 ) ;
    }
-   if( w != (Widget)NULL ){
-    static int ncall = 0 ;
-    if( ncall == 0 )
-      (void)MCW_popup_message( w ,
-                                 " \n"
-                                 "*** WARNING:             ***\n"
-                                 "*** all AFNI controllers ***\n"
-                                 "*** have been unlocked!  ***\n"
-                                 "----------------------------\n"
-                                 "*** The 'Set All' button ***\n"
-                                 "*** can re-lock them :)  ***\n" ,
-                               MCW_USER_KILL | MCW_TIMER_KILL ) ;
-     ncall++ ;
-   }
-
    EXRETURN ;
 }
 
@@ -203,9 +187,8 @@ ENTRY("AFNI_lock_setall_CB") ;
 }
 
 /*------------------------------------------------------------------------*/
-/* Do the locking of spatial coordinates */
 
-void AFNI_space_lock_carryout( Three_D_View *im3d )
+void AFNI_lock_carryout( Three_D_View *im3d )
 {
    Three_D_View *qq3d ;
    int ii,jj,kk , cc , glock ;
@@ -214,7 +197,7 @@ void AFNI_space_lock_carryout( Three_D_View *im3d )
    THD_dataxes *qaxes , *daxes ;
    static int busy = 0 ;  /* !=0 if this routine is "busy" */
 
-ENTRY("AFNI_space_lock_carryout") ;
+ENTRY("AFNI_lock_carryout") ;
 
    /* first, determine if there is anything to do */
 
@@ -322,89 +305,13 @@ ENTRY("AFNI_ijk_lock_change_CB") ;
 
 /*------------------------------------------------------------------------*/
 
-int AFNI_bbox_thrlock_mask2val(int bval)
-{
-   int ii;
-   for (ii=0; ii<3; ++ii) {
-      if (bval & 1<<ii) {
-         return(ii);
-      }
-   }
-   return(0);
-}
-
-/*------------------------------------------------------------------------*/
-
-void AFNI_set_all_thrlock_bboxes(Three_D_View *im3d, int bval)
-{
-   int ii;
-   Three_D_View *qq3d ;
-
-   if (bval < 0) bval = 1<<AFNI_thresh_lock_env_val();
-
-   /* set all other controller lock boxes to the same value */
-   for( ii=0 ; ii < MAX_CONTROLLERS ; ii++ ){
-     qq3d = GLOBAL_library.controllers[ii] ;
-     if( qq3d == im3d || ! IM3D_VALID(qq3d) ) continue ;
-     MCW_set_bbox( qq3d->vwid->dmode->thr_lock_bbox , bval ) ;
-   }
-
-   GLOBAL_library.thr_lock = AFNI_bbox_thrlock_mask2val(bval);
-
-   return;
-}
-
-/*------------------------------------------------------------------------*/
-
-void AFNI_func_thrlock_change_CB( Widget w , XtPointer cd , XtPointer calld )
-{
-   Three_D_View *im3d = (Three_D_View *) cd ;
-   int           bval , bold ;
-
-ENTRY("AFNI_func_thrlock_change_CB") ;
-
-   if( ! IM3D_VALID(im3d) ) EXRETURN ;
-
-   bold = 1<<GLOBAL_library.thr_lock ;
-   bval = MCW_val_bbox( im3d->vwid->dmode->thr_lock_bbox ) ;
-
-   if( bval == bold ) EXRETURN ;                     /* same --> nothing to do */
-
-   /* new value --> save in global setting */
-
-   GLOBAL_library.thr_lock = AFNI_bbox_thrlock_mask2val(bval) ;
-
-   /* And apply it to other controllers */
-   AFNI_set_all_thrlock_bboxes(im3d, bval);
-
-   RESET_AFNI_QUIT(im3d) ;
-   EXRETURN ;
-}
-
-/*------------------------------------------------------------------------*/
-
-int AFNI_thresh_lock_env_val(void)
-{
-   int i=0;
-   char *eee=NULL;
-
-   eee = getenv( "AFNI_THRESH_LOCK" ) ;          /* determine how to lock */
-   if( eee == NULL ) return(0) ;
-   if(*eee == 'V' || *eee == 'v') return(1);
-   if(*eee == 'P' || *eee == 'p') return(2);
-   return(0);
-}
-
-/*------------------------------------------------------------------------*/
-/* Do the locking of thresholds */
-
 void AFNI_thresh_lock_carryout( Three_D_View *im3d )
 {
    Three_D_View *qq3d ;
    static int busy = 0 ;  /* !=0 if this routine is "busy" */
    int glock , cc,ii , dopval,dothresh ;
    float thresh , pval=0.0f , tval ;
-   char cmd[64] ;
+   char cmd[64] , *eee ;
 
 ENTRY("AFNI_thresh_lock_carryout") ;
 
@@ -416,9 +323,11 @@ ENTRY("AFNI_thresh_lock_carryout") ;
    if( glock == 0 )                   EXRETURN;  /* nothing to do */
    if( !IM3D_OPEN(im3d) )             EXRETURN;  /* bad input */
    if( GLOBAL_library.ignore_lock )   EXRETURN;  /* ordered not to do anything */
-   if (!GLOBAL_library.thr_lock)      EXRETURN;
-   dothresh = (GLOBAL_library.thr_lock == 1) ;
-   dopval   = (GLOBAL_library.thr_lock == 2) && im3d->fim_now != NULL ;
+
+   eee = getenv( "AFNI_THRESH_LOCK" ) ;          /* determine how to lock */
+   if( eee == NULL ) EXRETURN ;
+   dothresh = (*eee == 'V' || *eee == 'v') ;
+   dopval   = (*eee == 'P' || *eee == 'p') && im3d->fim_now != NULL ;
    if( !dothresh && !dopval ) EXRETURN ;         /* no command? */
 
    ii = AFNI_controller_index(im3d) ;           /* which one am I? */
@@ -432,7 +341,7 @@ ENTRY("AFNI_thresh_lock_carryout") ;
 
    /* get true threshold of this controller => all others get this value, too*/
 
-   thresh = get_3Dview_func_thresh(im3d,1) ;
+   thresh = im3d->vinfo->func_threshold * im3d->vinfo->func_thresh_top ;
 
    /* get p-value corresponding, if that is what's being locked */
 
@@ -485,8 +394,6 @@ ENTRY("AFNI_equate_pbars") ;
    lbar = lh3d->vwid->func->inten_pbar ;
    rbar = rh3d->vwid->func->inten_pbar ;
 
-   if( MCW_pbars_equivalent(lbar,rbar) ) EXRETURN ;  /* 07 Jul 2014 */
-
    cc = AFNI_controller_index(lh3d) ; if( cc < 0 ) EXRETURN ;
 
    if( !rbar->bigmode ){
@@ -497,34 +404,26 @@ ENTRY("AFNI_equate_pbars") ;
                AV_uformat_fval(rbar->pval[qq]) ,
                ovc->label_ov[rbar->ov_index[qq]] ) ;
    } else {
-     if( rbar->big31 == 0 )
-       sprintf(cmd,"SET_PBAR_ALL %c.%c%d %f %s\n" , 'A'+cc ,
-               (rbar->mode) ? '+' : '-' , 99 ,
-               rbar->bigtop , PBAR_get_bigmap(rbar) ) ;
-     else
-       sprintf(cmd,"SET_PBAR_ALL %c.%c%d %f::%f %s\n" , 'A'+cc ,
-               (rbar->mode) ? '+' : '-' , 99 ,
-               rbar->bigbot,rbar->bigtop , PBAR_get_bigmap(rbar) ) ;
+     sprintf(cmd,"SET_PBAR_ALL %c.%c%d %f %s\n" , 'A'+cc ,
+             (rbar->mode) ? '+' : '-' , 99 ,
+             rbar->bigtop , PBAR_get_bigmap(rbar) ) ;
      if( rbar->bigflip )
        sprintf(cmd+strlen(cmd)," FLIP") ;
      if( rbar->bigrota )
        sprintf(cmd+strlen(cmd)," ROTA=%d",rbar->bigrota) ;
-     lbar->big30 = rbar->big30 ;
-     lbar->big31 = rbar->big31 ;
-     lbar->big32 = rbar->big32 ;
    }
 
-   AFNI_driver(cmd) ; EXRETURN ;
+   AFNI_driver( cmd ) ; EXRETURN ;
 }
 
 /*---------------------------------------------------------------*/
-/* Do the locking of pbars */
 
 void AFNI_pbar_lock_carryout( Three_D_View *im3d )
 {
    Three_D_View *qq3d ;
    static int busy = 0 ;  /* !=0 if this routine is "busy" */
    int glock , cc,ii ;
+   char *eee ;
 
 ENTRY("AFNI_pbar_lock_carryout") ;
 
@@ -536,18 +435,16 @@ ENTRY("AFNI_pbar_lock_carryout") ;
    if( glock == 0 )                   EXRETURN;  /* nothing to do */
    if( !IM3D_OPEN(im3d) )             EXRETURN;  /* bad input */
    if( GLOBAL_library.ignore_lock )   EXRETURN;  /* ordered not to do anything */
-   if( !AFNI_check_pbar_lock() )      EXRETURN;  /* not locked? */
+
+   eee = getenv( "AFNI_PBAR_LOCK" ) ;            /* determine how to lock */
+   if( eee == NULL ) EXRETURN ;
+   if( *eee != 'Y' && *eee != 'y' ) EXRETURN ;
 
    ii = AFNI_controller_index(im3d) ;           /* which one am I? */
 
    if( ii < 0 ) EXRETURN ;                      /* nobody? bad input! */
    if( ((1<<ii) & glock) == 0 ) EXRETURN ;      /* input not locked */
 
-#if 0
-INFO_message("AFNI_pbar_lock_carryout( %d ) ******************* ",ii) ;
-TRACEBACK ;
-#endif
-
    /* something to do? */
 
    busy = 1 ;  /* don't let this routine be called recursively */
@@ -560,9 +457,7 @@ TRACEBACK ;
      qq3d = GLOBAL_library.controllers[cc] ; /* controller */
 
      if( IM3D_OPEN(qq3d) && qq3d != im3d && ((1<<cc) & glock) != 0 ){
-#if 0
-ININFO_message(" equate_pbars( %d )",cc) ;
-#endif
+
        AFNI_equate_pbars( qq3d , im3d ) ;
      }
    }
@@ -572,7 +467,6 @@ ININFO_message(" equate_pbars( %d )",cc) ;
 }
 
 /*------------------------------------------------------------------------*/
-/* Do the dynamic locking of dragging thresholds */
 
 void AFNI_thrdrag_lock_carryout( Three_D_View *im3d )
 {
@@ -580,6 +474,7 @@ void AFNI_thrdrag_lock_carryout( Three_D_View *im3d )
    static int busy = 0 ;  /* !=0 if this routine is "busy" */
    int glock , cc,ii , dothresh,dopval , ival , stop ;
    float thresh , pval=0.0f , tval ;
+   char *eee ;
 
 ENTRY("AFNI_thrdrag_lock_carryout") ;
 
@@ -592,9 +487,10 @@ ENTRY("AFNI_thrdrag_lock_carryout") ;
    if( !IM3D_OPEN(im3d) )             EXRETURN;  /* bad input */
    if( GLOBAL_library.ignore_lock )   EXRETURN;  /* ordered not to do anything */
 
-   if (!GLOBAL_library.thr_lock) EXRETURN;
-   dothresh = (GLOBAL_library.thr_lock == 1) ;
-   dopval   = (GLOBAL_library.thr_lock == 2) && im3d->fim_now != NULL ;
+   eee = getenv( "AFNI_THRESH_LOCK" ) ;          /* determine how to lock */
+   if( eee == NULL ) EXRETURN ;
+   dothresh = (*eee == 'V' || *eee == 'v') ;
+   dopval   = (*eee == 'P' || *eee == 'p') && im3d->fim_now != NULL ;
    if( !dothresh && !dopval ) EXRETURN ;         /* no command? */
 
    ii = AFNI_controller_index(im3d) ;           /* which one am I? */
@@ -607,7 +503,7 @@ ENTRY("AFNI_thrdrag_lock_carryout") ;
    busy = 1 ;  /* don't let this routine be called recursively */
 
    ival   = rint(im3d->vinfo->func_threshold/THR_factor) ;
-   thresh = get_3Dview_func_thresh(im3d,1) ;
+   thresh = im3d->vinfo->func_threshold * im3d->vinfo->func_thresh_top ;
    stop   = (int)( rint( pow(10.0,THR_top_expon) ) - 1.0 ) ;
 
    if( dopval ){
@@ -657,30 +553,13 @@ ENTRY("AFNI_thrdrag_lock_carryout") ;
 
 /*------------------------------------------------------------------------*/
 
-int AFNI_check_pbar_lock()
-{
-   return AFNI_yesenv("AFNI_PBAR_LOCK") ;
-}
-
-/*------------------------------------------------------------------------*/
-
-int AFNI_check_range_lock()
-{
-   if( AFNI_yesenv("AFNI_RANGE_LOCK")           ) return 1 ;
-   if( PBAR_FULLRANGE && AFNI_check_pbar_lock() ) return 1 ;
-   return 0 ;
-}
-
-/*------------------------------------------------------------------------*/
-/* Do the locking of OLay ranges */
-
 void AFNI_range_lock_carryout( Three_D_View *im3d )
 {
    Three_D_View *qq3d ;
    static int busy = 0 ;  /* !=0 if this routine is "busy" */
-   int glock , cc,ii,nn , qdone=0 ;
+   int glock , cc,ii,nn ;
    float val ;
-   char cmd[64] ;
+   char cmd[64] , *eee ;
 
 ENTRY("AFNI_range_lock_carryout") ;
 
@@ -692,7 +571,10 @@ ENTRY("AFNI_range_lock_carryout") ;
    if( glock == 0 )                   EXRETURN;  /* nothing to do */
    if( !IM3D_OPEN(im3d) )             EXRETURN;  /* bad input */
    if( GLOBAL_library.ignore_lock )   EXRETURN;  /* ordered not to do anything */
-   if( !AFNI_check_range_lock() )     EXRETURN;  /* not locked? */
+
+   eee = getenv( "AFNI_RANGE_LOCK" );            /* determine how to lock */
+   if( eee == NULL )                  EXRETURN;
+   if( *eee != 'Y' && *eee != 'y' )   EXRETURN;
 
    ii = AFNI_controller_index(im3d);             /* which one am I? */
 
@@ -704,8 +586,8 @@ ENTRY("AFNI_range_lock_carryout") ;
    val = im3d->vinfo->fim_range ;
    if( val <= 0.0 )                   EXRETURN;  /* shouldn't happen */
 
-   /* count how many OTHER controllers are are open and locked;
-      if none of them are, there is nothing to do [29 Apr 2005] */
+   /* count how OTHER controllers are are open and locked;
+      if none of them, there is nothing to do [29 Apr 2005] */
 
    for( nn=cc=0 ; cc < MAX_CONTROLLERS ; cc++ ){
      qq3d = GLOBAL_library.controllers[cc] ;
@@ -737,248 +619,3 @@ ENTRY("AFNI_range_lock_carryout") ;
    busy = 0 ;  /* OK, let this routine be activated again */
    EXRETURN ;
 }
-
-/*------------------------------------------------------------------------*/
-
-void AFNI_set_all_rnglock_bboxes(Three_D_View *im3d, int bval)
-{
-   int ii;
-   Three_D_View *qq3d ;
-
-   if( bval < 0 || bval > 1 )
-     bval = MCW_val_bbox( im3d->vwid->dmode->rng_lock_bbox ) ;
-
-   /* set all other controller lock boxes to the same value */
-
-   for( ii=0 ; ii < MAX_CONTROLLERS ; ii++ ){
-     qq3d = GLOBAL_library.controllers[ii] ;
-     if( qq3d == im3d || ! IM3D_VALID(qq3d) ) continue ;
-     MCW_set_bbox( qq3d->vwid->dmode->rng_lock_bbox , bval ) ;
-   }
-
-   if( AFNI_check_range_lock() != bval )
-     AFNI_setenv( bval ? "AFNI_RANGE_LOCK=YES" : "AFNI_RANGE_LOCK=NO" ) ;
-
-   return;
-}
-
-/*------------------------------------------------------------------------*/
-
-void AFNI_func_rnglock_change_CB( Widget w , XtPointer cd , XtPointer calld )
-{
-   Three_D_View *im3d = (Three_D_View *)cd ;
-   int           bval , bold ;
-
-ENTRY("AFNI_func_rnglock_change_CB") ;
-
-   if( ! IM3D_VALID(im3d) ) EXRETURN ;
-
-   bold = AFNI_check_range_lock() ;
-   bval = MCW_val_bbox( im3d->vwid->dmode->rng_lock_bbox ) ;
-
-   if( bval == bold ) EXRETURN ;                     /* same --> nothing to do */
-
-   /* New value ==> apply it to other controllers */
-
-   AFNI_set_all_rnglock_bboxes(im3d,bval);
-   AFNI_range_lock_carryout(im3d) ;
-
-   EXRETURN ;
-}
-
-/*------------------------------------------------------------------------*/
-
-void AFNI_set_all_pbarlock_bboxes(Three_D_View *im3d, int bval)
-{
-   int ii;
-   Three_D_View *qq3d ;
-
-   if( bval < 0 || bval > 1 )
-     bval = MCW_val_bbox( im3d->vwid->dmode->pbar_lock_bbox ) ;
-
-   /* set all other controller lock boxes to the same value */
-
-   for( ii=0 ; ii < MAX_CONTROLLERS ; ii++ ){
-     qq3d = GLOBAL_library.controllers[ii] ;
-     if( qq3d == im3d || ! IM3D_VALID(qq3d) ) continue ;
-     MCW_set_bbox( qq3d->vwid->dmode->pbar_lock_bbox , bval ) ;
-   }
-
-   if( AFNI_check_pbar_lock() != bval )
-     AFNI_setenv( bval ? "AFNI_PBAR_LOCK=YES" : "AFNI_PBAR_LOCK=NO" ) ;
-
-   return;
-}
-
-/*------------------------------------------------------------------------*/
-
-void AFNI_func_pbarlock_change_CB( Widget w , XtPointer cd , XtPointer calld )
-{
-   Three_D_View *im3d = (Three_D_View *)cd ;
-   int           bval , bold ;
-
-ENTRY("AFNI_func_pbarlock_change_CB") ;
-
-   if( ! IM3D_VALID(im3d) ) EXRETURN ;
-
-   bold = AFNI_check_pbar_lock() ;
-   bval = MCW_val_bbox( im3d->vwid->dmode->pbar_lock_bbox ) ;
-
-   if( bval == bold ) EXRETURN ;                     /* same --> nothing to do */
-
-   /* New value ==> apply it to other controllers */
-
-   AFNI_set_all_pbarlock_bboxes(im3d,bval);
-   AFNI_pbar_lock_carryout(im3d) ;
-
-   EXRETURN ;
-}
-
-/*-----------------------------------------------------------------------
-    10 Dec 2019: zoom/pan locking on or off
--------------------------------------------------------------------------*/
-
-void AFNI_zoompan_lock_change_CB( Widget w , XtPointer cd , XtPointer calld )
-{
-   Three_D_View *im3d = (Three_D_View *)cd ;
-   Three_D_View *qq3d ;
-   int           bval , ii , bold ;
-
-ENTRY("AFNI_zoompan_lock_change_CB") ;
-
-   if( ! IM3D_VALID(im3d) ) EXRETURN ;
-
-   /* get current global setting and compare to changed lock box */
-
-   bold = GLOBAL_library.zoompan_lock ;
-   bval = MCW_val_bbox( im3d->vwid->dmode->zoompan_lock_bbox ) ;
-   if( bval == bold ) EXRETURN ;                     /* same --> nothing to do */
-
-   /* new value --> save in global setting */
-
-   GLOBAL_library.zoompan_lock = bval ;
-
-   /* set all other controller lock boxes to the same value */
-
-   for( ii=0 ; ii < MAX_CONTROLLERS ; ii++ ){
-     qq3d = GLOBAL_library.controllers[ii] ;
-     if( qq3d == im3d || ! IM3D_VALID(qq3d) ) continue ;
-
-     MCW_set_bbox( qq3d->vwid->dmode->zoompan_lock_bbox , bval ) ;
-   }
-   RESET_AFNI_QUIT(im3d) ;
-   EXRETURN ;
-}
-
-/*------------------------------------------------------------------------*/
-/* Locking for the zoom+pan image viewers [10 Dec 2019] */
-
-void AFNI_zoompan_lock_carryout( Three_D_View *im3d )
-{
-   static int busy = 0 ;  /* !=0 if this routine is "busy" */
-   Three_D_View *qq3d ;
-   MCW_imseq *seq ;
-   int ii,jj,kk , cc , glock ;
-   int axi_zlev=0 ; float axi_poff[2] ;
-   int sag_zlev=0 ; float sag_poff[2] ;
-   int cor_zlev=0 ; float cor_poff[2] ;
-
-ENTRY("AFNI_zoompan_locks_carryout") ;
-
-   if( busy || !IM3D_VALID(im3d)    ) EXRETURN ;
-   if( GLOBAL_library.ignore_lock   ) EXRETURN ;
-   if( !GLOBAL_library.zoompan_lock ) EXRETURN ;
-   if( !IM3D_IMAGIZED(im3d)         ) EXRETURN ;
-
-   glock = GLOBAL_library.controller_lock ;      /* not a handgun */
-   if( glock == 0 )                   EXRETURN ; /* nothing to do */
-
-   ii = AFNI_controller_index(im3d) ;            /* which one am I? */
-
-   if( ii < 0 )                       EXRETURN ; /* nobody? bad input! */
-   if( ((1<<ii) & glock) == 0 )       EXRETURN ; /* input not locked */
-
-   /* something to do? */
-
-   busy = 1 ;  /* don't let this routine be called recursively */
-
-   /* find the zoom and pan parameters for the current image viewers */
-
-   seq = IM3D_AXIALIMAGE(im3d) ;
-   if( seq != NULL ){
-     drive_MCW_imseq( seq, isqDR_get_zoom  , &axi_zlev ) ;
-     drive_MCW_imseq( seq, isqDR_get_panoff, axi_poff  ) ;
-   }
-
-   seq = IM3D_SAGITTALIMAGE(im3d) ;
-   if( seq != NULL ){
-     drive_MCW_imseq( seq, isqDR_get_zoom  , &sag_zlev ) ;
-     drive_MCW_imseq( seq, isqDR_get_panoff, sag_poff  ) ;
-   }
-
-   seq = IM3D_CORONALIMAGE(im3d) ;
-   if( seq != NULL ){
-     drive_MCW_imseq( seq, isqDR_get_zoom  , &cor_zlev ) ;
-     drive_MCW_imseq( seq, isqDR_get_panoff, cor_poff  ) ;
-   }
-
-   /* loop through other controllers:
-        for those that ARE open, ARE NOT the current one,
-        and ARE locked, set zoom and pan to match
-        this controller's corresponding image viewers */
-
-   for( cc=0 ; cc < MAX_CONTROLLERS ; cc++ ){
-
-     qq3d = GLOBAL_library.controllers[cc] ; /* controller */
-
-     if( IM3D_OPEN(qq3d) && qq3d != im3d && ((1<<cc) & glock) != 0 ){
-
-       seq = IM3D_AXIALIMAGE(qq3d) ;
-       if( seq != NULL ){
-         drive_MCW_imseq( seq, isqDR_set_zoom  , &axi_zlev ) ;
-         drive_MCW_imseq( seq, isqDR_set_panoff, axi_poff  ) ;
-       }
-
-       seq = IM3D_SAGITTALIMAGE(qq3d) ;
-       if( seq != NULL ){
-         drive_MCW_imseq( seq, isqDR_set_zoom  , &sag_zlev ) ;
-         drive_MCW_imseq( seq, isqDR_set_panoff, sag_poff  ) ;
-       }
-
-       seq = IM3D_CORONALIMAGE(qq3d) ;
-       if( seq != NULL ){
-         drive_MCW_imseq( seq, isqDR_set_zoom  , &cor_zlev ) ;
-         drive_MCW_imseq( seq, isqDR_set_panoff, cor_poff  ) ;
-       }
-     }
-   }
-
-   busy = 0 ;  /* OK, let this routine be activated again */
-   EXRETURN ;
-}
-
-/*------------------------------------------------------------------------*/
-/* Enforce all locks at the same time [03 Jul 2014] */
-
-void AFNI_all_locks_carryout( Three_D_View *im3d )
-{
-   static int busy = 0 ;  /* !=0 if this routine is "busy" */
-
-ENTRY("AFNI_all_locks_carryout") ;
-
-   if( busy || !IM3D_VALID(im3d)  ) EXRETURN ;
-   if( GLOBAL_library.ignore_lock ) EXRETURN ;
-
-#if 0
-INFO_message("AFNI_all_locks_carryout: im3d index = %d",AFNI_controller_index(im3d)) ;
-#endif
-
-   AFNI_space_lock_carryout  ( im3d ) ;
-   AFNI_time_lock_carryout   ( im3d ) ;
-   AFNI_thresh_lock_carryout ( im3d ) ;
-   AFNI_pbar_lock_carryout   ( im3d ) ;
-   AFNI_range_lock_carryout  ( im3d ) ;
-   AFNI_zoompan_lock_carryout( im3d ) ; /* 10 Dec 2019 */
-
-   AFNI_sleep(1) ; busy = 0 ; EXRETURN ;
-}
