@@ -10,8 +10,6 @@
 void ENV_init(void){}
 #else
 
-extern void TTRR_resetup(void) ;
-
 /***********************************************************************
   Pseudo-plugin to set/show environment variables
 ************************************************************************/
@@ -79,6 +77,7 @@ static char *env_fixed[] = {
     "AFNI_DEFAULT_IMSAVE"       , "AFNI_IMAGE_ZEROCOLOR"  ,
     "AFNI_IMAGE_LABEL_MODE"     , "AFNI_IMAGE_LABEL_SIZE" ,
     "AFNI_GRAPH_BASELINE"       , "AFNI_GRAPH_GLOBALBASE" ,
+    "AFNI_MINC_DATASETS"        , "AFNI_MINC_FLOATIZE"    , "AFNI_MINC_SLICESCALE"  ,
     "AFNI_ANALYZE_DATASETS"     , "AFNI_ANALYZE_SCALE"    , "AFNI_ANALYZE_FLOATIZE" ,
     "AFNI_ANALYZE_ORIENT"       , "AFNI_ANALYZE_AUTOCENTER" ,
     "AFNI_MPEG_DATASETS"        , "AFNI_MPEG_GRAYIZE"     ,
@@ -87,6 +86,7 @@ static char *env_fixed[] = {
     "AFNI_GLOBAL_SESSION"       , "AFNI_NIML_START"       ,
     "AFNI_TTRR_SETUP"           , "AFNI_LOAD_PRINTSIZE"   ,
     "AFNI_VALUE_LABEL_DTABLE"   ,
+    "AFNI_VERSION_CHECK"        ,
     "AFNI_AGIF_DELAY"           , "AFNI_MPEG_FRAMERATE"   ,
     "AFNI_STARTUP_SCRIPT"       , "AFNI_STARTUP_WARNINGS" ,
     "AFNI_VERSION_CHECK"        , "AFNI_LOGO16"           ,
@@ -95,15 +95,7 @@ static char *env_fixed[] = {
 
 #define NUM_env_fixed (sizeof(env_fixed)/sizeof(char *))
 
-/*-------------------------------------------------------------------------*/
-
-char *angle_strings[] = { "120" , "180" , "240" , "300" , "360" } ;
-#define NUM_angle_strings (sizeof(angle_strings)/sizeof(char *)) /* 08 Nov 2011 */
-
-char *globalrange_strings[] = { "Slice" , "Volume" , "Dataset" } ; /* 29 Jan 2014 */
-#define NUM_globalrange_strings 3
-
-/*--------------------- strings for Coordinate format --------------------*/
+/*--------------------- strings for Cooordinate format --------------------*/
 
 #define NUM_cord_strings 50
 
@@ -118,22 +110,16 @@ static char *cord_strings[NUM_cord_strings] = {
 } ;
 
 static void ENV_coorder( char * ) ;
-static void ENV_angle_string( char * ) ;
-/*void ENV_globalrange( char * ) ;*/
-static void ENV_thresh_lock( char * ) ;
+static void ENV_globalrange( char * ) ;
 static void ENV_compressor( char * ) ;
 static void ENV_leftisleft( char * ) ;
-static void ENV_leftisposterior( char * ); /* 27 Mar 2017 */
 static void ENV_marksquality( char * ) ;
 static void ENV_trusthost( char * ) ;     /* 21 Feb 2001 */
 static void ENV_cwd( char * ) ;           /* 22 Feb 2001 */
 static void ENV_redraw_titles( char * );  /* 21 Dec 2004 */
 static void ENV_redisplay( char * );      /* 21 Mar 2005 */
 static void ENV_setjpegquality(char *);   /* 11 May 2006 */
-static void ENV_wami_maxrad(char *vname); /* 27 Jun 2011 */
-static void ENV_wami_maxfind(char *vname); /* 27 Jun 2011 */
-static void ENV_atlas_reset(char *atlas); /* 05 Jul 2011 */
-static void ENV_jumpspace_reset(char *spacename); /* 13 Jun 2014 */
+
 #ifdef USE_SESSTRAIL
 static void ENV_sesstrail( char * ) ;
 #endif
@@ -221,11 +207,9 @@ PLUGIN_interface * ENV_init(void)
      }
    }
 
-#if 0
    ENV_add_string( "AFNI_ENFORCE_ASPECT" ,
                    "To make AFNI enforce image window aspect ratio?" ,
                    NUM_yesno_list , yesno_list , NULL  ) ;
-#endif
 
    ENV_add_numeric( "AFNI_FIM_PERCENT_LIMIT" ,
                     "Upper limit on % Change in FIM" ,
@@ -236,13 +220,9 @@ PLUGIN_interface * ENV_init(void)
                     0,10,2,2 , NULL                 ) ;
 
    ENV_add_string( "AFNI_LEFT_IS_LEFT" ,
-                   "To show subject's left on image left (axial, coronal)?" ,
+                   "To show subject's left on image left?" ,
                    NUM_yesno_list , yesno_list , ENV_leftisleft  ) ;
 
-   ENV_add_string( "AFNI_LEFT_IS_POSTERIOR" ,
-                   "To show subject's posterior on image left (sagittal)?" ,
-                   NUM_yesno_list , yesno_list , ENV_leftisposterior  ) ;
-
    ENV_add_string( "AFNI_NO_SIDES_LABELS" ,
                    "Skip showing image window left-side label?" ,
                    NUM_yesno_list , yesno_list , NULL  ) ;
@@ -395,9 +375,8 @@ PLUGIN_interface * ENV_init(void)
                    NUM_yesno_list , yesno_list , ENV_redisplay  ) ;
 
    ENV_add_string( "AFNI_IMAGE_GLOBALRANGE" ,
-   "Set image viewers to use 3D global data range by slice, volume or dataset min-max?",
-              NUM_globalrange_strings , globalrange_strings , ENV_globalrange_view  ) ;
-
+                   "Set image viewers to use 3D global data range min-to-max?" ,
+                   NUM_yesno_list , yesno_list , ENV_globalrange  ) ;
 
    /* 19 Nov 2003 */
 
@@ -419,17 +398,15 @@ PLUGIN_interface * ENV_init(void)
 
    ENV_add_string( "AFNI_THRESH_LOCK" ,                           /* 06 Feb 2004 */
                    "Lock Threshold slider values together?" ,
-                   NUM_threshlock_list , threshlock_list , ENV_thresh_lock  ) ;
+                   NUM_threshlock_list , threshlock_list , NULL  ) ;
 
    ENV_add_string( "AFNI_GRAPH_CX2R" ,                            /* 18 Apr 2011 */
                    "Graph display of complex time series" ,
                    NUM_cx2r_list , cx2r_list , NULL  ) ;
 
-#if 0                                                     /* removed 11 Jan 2021 */
    ENV_add_string( "AFNI_GRAPH_BOXLAB" ,                          /* 18 Apr 2011 */
                    "Box graph display of brick labels" ,
                    NUM_boxlab_list , boxlab_list , NULL  ) ;
-#endif
 
    ENV_add_yesno( "AFNI_PBAR_LOCK" , "Lock Color Pbars together?" ) ; /* 07 Feb 2004 */
    ENV_add_yesno( "AFNI_RANGE_LOCK", "Lock OLay Ranges together?" ) ; /* 23 Feb 2004 */
@@ -438,13 +415,11 @@ PLUGIN_interface * ENV_init(void)
 
    /* 23 Feb 2004 [rickr] */
    ENV_add_yesno( "AFNI_IMAGE_ZOOM_NN" ,
-                  "Use Nearest Neighbor interpolation for image Zoom?" ) ;
+	           "Use Nearest Neighbor interpolation for image Zoom?" ) ;
 
    /* 22 Mar 2004 [RWCox] */
    ENV_add_yesno( "AFNI_SLAVE_FUNCTIME" , "Time Index affects functional overlay?" ) ;
-#if 0
    ENV_add_yesno( "AFNI_SLAVE_THRTIME"  , "Time Index affects threshold overlay?" ) ;
-#endif
 
    ENV_add_string( "AFNI_REALTIME_MP_HOST_PORT" ,     /* 31 Mar 2004 [rickr] */
                    "Supply host:port string for realtime motion parameters." ,
@@ -458,17 +433,10 @@ PLUGIN_interface * ENV_init(void)
                    "Use 'label2' field for window titles?" ,
                    NUM_yesno_list , yesno_list , ENV_redraw_titles ) ;
 
-#if 0
    /* 21 Mar 2005 [RWCox] */
    ENV_add_string( "AFNI_EDGIZE_OVERLAY" ,
-                   "Display color overlay as edges?" ,
+                   "Display color overlay as edges only?" ,
                    NUM_yesno_list , yesno_list , ENV_redisplay ) ;
-#endif
-
-   /* 11 Dec 2014 [RWCox] */
-   ENV_add_string( "AFNI_FUNC_BOXED_COLOR" ,
-                   "Name of color for Alpha+Boxed overlays." , /* 21 Sep 2001 */
-                   0,NULL , NULL ) ;
 
    /* 08 Apr 2005 [rickr] */
    ENV_add_numeric( "AFNI_NIFTI_DEBUG" ,
@@ -524,7 +492,7 @@ PLUGIN_interface * ENV_init(void)
 
    /* 04 Aug 2010 [RWCox] */
    ENV_add_numeric( "AFNI_CLUSTER_WAMIMAX" ,
-                    "Max clusters sent to 'whereami_afni'" ,
+                    "Max clusters sent to 'whereami'" ,
                     1,99,0,20 , NULL ) ;
 
    /* 28 Feb 2011 [RWCox] */
@@ -551,10 +519,6 @@ PLUGIN_interface * ENV_init(void)
    ENV_add_yesno( "AFNI_INSTACORR_FDR" ,
                   "Compute FDR curve for InstaCorr correlations?" ) ;
 
-   /* 24 Sep 2021 [RWCox] */
-   ENV_add_yesno( "AFNI_INSTACORR_JUMP" ,
-                  "Shift+Ctrl click jumps crosshairs before doing InstaCorr?") ;
-
    /* 27 Aug 2009 [RWCox] */
    ENV_add_numeric( "AFNI_IMAGE_CROPSTEP" ,
                     "Cropped image panning step size" ,
@@ -568,52 +532,6 @@ PLUGIN_interface * ENV_init(void)
                    "Colors for the FIM Ort in AFNI Graph viewer" ,
                    0,NULL , NULL ) ;
 
-   /* 27 Jun 2011 [DRG] */
-   ENV_add_numeric( "AFNI_WHEREAMI_DEC_PLACES" ,
-                    "Number of decimal places for whereami_afni output" ,
-                    0,4,0,0 , NULL ) ;
-   ENV_add_numeric( "AFNI_WHEREAMI_MAX_FIND" ,
-                    "Maximum limit for structures from an atlas for whereami_afni output" ,
-                    1,50,0,9 , ENV_wami_maxfind ) ;
-   ENV_add_string( "AFNI_WHEREAMI_MAX_SEARCH_RAD" ,
-                "Maximum radius for structures from an atlas for whereami_afni output" ,
-                 0, NULL, ENV_wami_maxrad ) ;
-   /* 01 Jul 2011 [DRG] */
-   ENV_add_string( "AFNI_ATLAS_COLORS" ,
-          "Atlas to use in Atlas colors, Draw Dataset,  Go to atlas location" ,
-                 0, NULL, ENV_atlas_reset ) ;
-
-   /* 08 Nov 2011 [RWC] */
-   ENV_add_string( "AFNI_IMAGE_COLORANGLE" ,
-                   "Image view color scale angle" ,
-                   NUM_angle_strings,angle_strings , ENV_angle_string ) ;
-
-   /* 23 Dec 2011 [RWC] */
-   ENV_add_string( "AFNI_IMAGE_LABEL_STRING" ,
-                   "Extra string for image view overlay labels" ,
-                   0,NULL , NULL ) ;
-
-   /* 21 Feb 2013 [RWC] */
-   ENV_add_yesno( "AFNI_HISTOG_CUMULATIVE" ,
-                  "Show cumulative histogram in plugins?" ) ;
-
-   /* 25 Jun 2013 [RWC] */
-   ENV_add_numeric( "AFNI_PBAR_TICK" ,
-                    "Number of tick marks for colorscale" ,
-                    0,63,0,9 , NULL ) ;
-
-   /* 23 Jul 2013 [RWC] */
-   ENV_add_yesno( "AFNI_RECENTER_VIEWING" ,
-                  "Re-center xhairs when switching UnderLay?" ) ;
-
-   ENV_add_string( "AFNI_JUMPTO_SPACE" ,
-          "Space name to use in Jump to (spacename)" ,
-                 0, NULL, ENV_jumpspace_reset ) ;
-
-   /* 28 Feb 2017 [RWC] */
-   ENV_add_yesno( "AFNI_IMAGE_LABEL_IJK" ,
-                  "Plot image overlay label as slice index?" ) ;
-
    /*--------- Sort list of variables [21 Feb 2007]  -----------*/
 
    if( !AFNI_yesenv("AFNI_DONT_SORT_ENVIRONMENT") )
@@ -817,14 +735,12 @@ void ENV_add_string( char *vname , char *vhint ,
 static char * ENV_main( PLUGIN_interface *plint )
 {
    char *tag ;
-   int ii,kk , ndone=0 , skip ;
-
-ENTRY("ENV_main") ;
+   int ii,kk , ndone=0 ;
 
    /*--------- loop over input lines ---------*/
 
    while(1){
-      tag = PLUTO_get_optiontag(plint) ; skip = 0 ;
+      tag = PLUTO_get_optiontag(plint) ;
       if( tag == NULL ) break ;
 
       /* find which variable */
@@ -833,12 +749,12 @@ ENTRY("ENV_main") ;
          if( strcmp(tag,env_var[ii].vname) == 0 ) break ;
 
       if( ii == NUM_env_var )
-        RETURN( "** ENV_main: table corruption! **" );  /* should not happen */
+        return "** ENV_main: table corruption! **" ;  /* should not happen */
 
       switch( env_var[ii].vtype ){  /* set vvalue for each type */
 
          default:
-           RETURN( "** ENV_main: table corruption! **" );  /* should not happen */
+           return "** ENV_main: table corruption! **" ;  /* should not happen */
 
          /* write a numeric value into the environment */
 
@@ -846,7 +762,7 @@ ENTRY("ENV_main") ;
          case ENV_NUMBER_EDITABLE:{
             float val = PLUTO_get_number(plint) ;
             sprintf(env_var[ii].vvalue,"%s=%s" ,
-                    env_var[ii].vname , AV_uformat_fval(val) ) ;
+                    env_var[ii].vname , AV_format_fval(val) ) ;
          }
          break ;
 
@@ -855,22 +771,18 @@ ENTRY("ENV_main") ;
          case ENV_STRING:{
             char *str = PLUTO_get_string(plint) ; int jj ;
 
-            if( str == NULL || *str == '\0' ){
-              skip = 1 ;
+            if( env_var[ii].vcount > 0 ){
+               jj = PLUTO_string_index( str , env_var[ii].vcount ,
+                                              env_var[ii].vlist   ) ;
+               if( jj >= 0 )
+                  sprintf(env_var[ii].vvalue,"%s=%s" ,
+                          env_var[ii].vname , str     ) ;
+               else
+                  sprintf(env_var[ii].vvalue,"%s=" , env_var[ii].vname ) ;
             } else {
-              if( env_var[ii].vcount > 0 ){
-                 jj = PLUTO_string_index( str , env_var[ii].vcount ,
-                                                env_var[ii].vlist   ) ;
-                 if( jj >= 0 )
-                    sprintf(env_var[ii].vvalue,"%s=%s" ,
-                            env_var[ii].vname , str     ) ;
-                 else
-                    sprintf(env_var[ii].vvalue,"%s=" , env_var[ii].vname ) ;
-              } else {
-                 sprintf(env_var[ii].vvalue,"%s=%s" ,
-                         env_var[ii].vname , str     ) ;
-              }
-           }
+               sprintf(env_var[ii].vvalue,"%s=%s" ,
+                       env_var[ii].vname , str     ) ;
+            }
          }
          break ;
 
@@ -878,19 +790,16 @@ ENTRY("ENV_main") ;
 
       /* actually set environment variable */
 
-      if( !skip ){
+      putenv(env_var[ii].vvalue) ;
 
-        putenv(env_var[ii].vvalue) ;
-
-        /* call callback, if there is one */
+      /* call callback, if there is one */
 
 #if 0
-        if( env_var[ii].vfunc != NULL ) env_var[ii].vfunc( env_var[ii].vname ) ;
+      if( env_var[ii].vfunc != NULL ) env_var[ii].vfunc( env_var[ii].vname ) ;
 #else
-        if( env_var[ii].vfunc != NULL )
-          AFNI_CALL_VOID_1ARG( env_var[ii].vfunc , char *, env_var[ii].vname ) ;
+      if( env_var[ii].vfunc != NULL )
+        AFNI_CALL_VOID_1ARG( env_var[ii].vfunc , char *, env_var[ii].vname ) ;
 #endif
-      }
 
       /* turn this option off (for the user's convenience) */
 
@@ -906,20 +815,37 @@ ENTRY("ENV_main") ;
 
    /*--------- finished -------*/
 
-   if( ndone == 0 ) RETURN( " \n*** Don't you want to do anything? ***\n ") ;
+   if( ndone == 0 ) return " \n*** Don't you want to do anything? ***\n " ;
 
-   RETURN( NULL );
+   return NULL ;
 }
 
-
 /*-----------------------------------------------------------------------*/
 
-static void ENV_thresh_lock( char *vname )
+static void ENV_globalrange( char *vname )
 {
-   /* initialize viewers with new env value */
-   AFNI_set_all_thrlock_bboxes(NULL, -1);
-   return;
+   Three_D_View *im3d ;
+   int ii , gbr=AFNI_yesenv("AFNI_IMAGE_GLOBALRANGE") ;
+
+   for( ii=0 ; ii < MAX_CONTROLLERS ; ii++ ){
+     im3d = GLOBAL_library.controllers[ii] ;
+     if( ! IM3D_OPEN(im3d) ) continue ;
+     if( gbr ){
+       AFNI_range_setter( im3d , im3d->s123 ) ;
+       AFNI_range_setter( im3d , im3d->s231 ) ;
+       AFNI_range_setter( im3d , im3d->s312 ) ;
+       drive_MCW_imseq( im3d->s123 , isqDR_display , (XtPointer)(-1) ) ;
+       drive_MCW_imseq( im3d->s231 , isqDR_display , (XtPointer)(-1) ) ;
+       drive_MCW_imseq( im3d->s312 , isqDR_display , (XtPointer)(-1) ) ;
+     } else {
+       drive_MCW_imseq( im3d->s123 , isqDR_setrange , (XtPointer)NULL ) ;
+       drive_MCW_imseq( im3d->s231 , isqDR_setrange , (XtPointer)NULL ) ;
+       drive_MCW_imseq( im3d->s312 , isqDR_setrange , (XtPointer)NULL ) ;
+     }
+   }
+   return ;
 }
+
 /*-----------------------------------------------------------------------*/
 
 static void ENV_coorder( char *vname )
@@ -933,24 +859,6 @@ static void ENV_coorder( char *vname )
 
 /*-----------------------------------------------------------------------*/
 
-static void ENV_angle_string( char *vname )  /* 08 Nov 2011 */
-{
-   int ii ; Three_D_View *im3d ; MCW_DC *dc = NULL ;
-
-   for( ii=0 ; ii < MAX_CONTROLLERS ; ii++ ){
-      im3d = GLOBAL_library.controllers[ii] ;
-      if( IM3D_OPEN(im3d) && im3d->dc != dc ){
-        if( dc == NULL ) dc = im3d->dc ;
-        DC_init_im_col(dc) ;
-        if( dc->use_xcol_im ) DC_set_image_colors(dc) ;
-      }
-   }
-
-   PLUTO_force_rebar() ; PLUTO_force_redisplay() ;
-}
-
-/*-----------------------------------------------------------------------*/
-
 static void ENV_redisplay( char *vname )  /** 21 Mar 2005 */
 {
    PLUTO_force_redisplay() ;
@@ -1065,12 +973,6 @@ static void ENV_leftisleft( char *vname )
    GLOBAL_argopt.left_is_left = YESSISH(str) ;
 }
 
-static void ENV_leftisposterior( char *vname )  /* 27 Mar 2017 */
-{
-   char *str = getenv(vname) ;
-   GLOBAL_argopt.left_is_posterior = YESSISH(str) ;
-}
-
 /*-----------------------------------------------------------------------*/
 
 static void ENV_marksquality( char *vname )
@@ -1085,53 +987,4 @@ static void ENV_setjpegquality(char *vname)
 {
    ISQ_setup_ppmto_filters();
 }
-
-static void ENV_wami_maxrad(char *vname)
-{
-   float maxrad;
-
-   char *str = getenv(vname) ;
-   if(!str) return;
-   maxrad = strtod(str, NULL);
-   if(maxrad<=0.0) return;
-   Set_Whereami_Max_Rad(maxrad);
-}
-
-static void ENV_wami_maxfind(char *vname)
-{
-   int maxfind;
-
-   char *str = getenv(vname) ;
-   if(!str) return;
-   maxfind = atoi(str);
-   if(maxfind<=0) return;
-   Set_Whereami_Max_Find(maxfind);
-}
-
-static void ENV_atlas_reset(char *atlas)
-{
-   TTRR_resetup();
-   reset_atlas_ovdset();
-   return ;
-}
-
-/* reset the space used in the Jump to (MNI) menu */
-static void ENV_jumpspace_reset(char *vname)
-{
-   char *spacename;
-   int ii;
-
-   spacename = getenv(vname);
-   set_jump_space(spacename);
-
-  /* relabel controller windows */
-
-   for( ii=0 ; ii < MAX_CONTROLLERS ; ii++ )
-      if( IM3D_OPEN(GLOBAL_library.controllers[ii]) )
-         reset_mnito( GLOBAL_library.controllers[ii] ) ;
-
-   return ;
-}
-
 #endif
-/* endif above is for if plugins are compiled - "#else" near top of file*/
