@@ -31,21 +31,18 @@ static int DEBUG = 0 ;
 /*------------------------- various string constants -------------------------*/
 
 #undef  ICALC_NUMTYPE
-#define ICALC_NUMTYPE 4
+#define ICALC_NUMTYPE 3
 static char *ICALC_typestr[] = { "Dataset: Value" ,
                                  "Dataset: Stat." ,
-                                 "Constant Value" ,
-                                 "Dataset: Pvalu"  } ;
+                                 "Constant Value"  } ;
 
 static char *ICALC_choosestr[] = { "Choose Dataset" ,
                                    "Choose Dataset" ,
-                                   "--------------" ,
-                                   "Choose Dataset"  } ;
+                                   "--------------"  } ;
 
 static char *ICALC_labelstr[]  = { "diffsub:" ,
                                    "3D stat:" ,
-                                   "Value:"   ,
-                                   "diffsub:"  } ;
+                                   "Value:"     } ;
 
 static char *ICALC_nothing_chosen = "---nothing chosen---" ;
 
@@ -57,7 +54,6 @@ static char abet[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ" ;  /* the alphabet! */
 #define ICALC_DSET_VALUE  0
 #define ICALC_DSET_STAT   1
 #define ICALC_CONSTANT    2
-#define ICALC_DSET_PVALU  3  /* 26 Jun 2015 */
 
 #define DSHIFT_MODE_STOP  0
 #define DSHIFT_MODE_WRAP  1
@@ -107,9 +103,7 @@ static MCW_action_item ICALC_act[] =
 #define ICALC_toggle_row(rr,state)                                                          \
  do{ int qz = state && (rr).menu_av->ival != ICALC_CONSTANT ;                               \
      int wz = state &&                                                                      \
-        ((rr).menu_av->ival == ICALC_DSET_VALUE ||                                          \
-         (rr).menu_av->ival == ICALC_DSET_STAT  ||                                          \
-         (rr).menu_av->ival == ICALC_DSET_PVALU   ) ;                                       \
+        ((rr).menu_av->ival == ICALC_DSET_VALUE || (rr).menu_av->ival == ICALC_DSET_STAT) ; \
      AV_SENSITIZE((rr).menu_av,state) ;                                                     \
      XtSetSensitive((rr).chooser_pb,qz) ; AV_SENSITIZE((rr).index_av,wz) ;                  \
      XtSetSensitive((rr).chooser_lab,qz) ;                                                  \
@@ -365,7 +359,7 @@ static void ICALC_tog_bbox_CB( Widget w, XtPointer cd, XtPointer cbs )
    ICALC_widget_set *iwid = (ICALC_widget_set *)cd ;
    Three_D_View     *im3d = iwid->im3d ;
    ICALC_setup      *ics  = im3d->icalc_setup ;
-   int                 aa = ICALC_find_index(iwid,w) ; int  bb ;
+   int                 aa = ICALC_find_index(iwid,w) ; Boolean bb ;
 
    if( aa < 0 ) return ;
    bb = MCW_val_bbox(iwid->war[aa].tog_bbox) ;
@@ -414,7 +408,6 @@ static void ICALC_chooser_CB( Widget w, XtPointer cd, XtPointer cbs )
    dsa = -1 ;
 
    switch( bb ){
-     case ICALC_DSET_PVALU:
      case ICALC_DSET_VALUE:
      case ICALC_DSET_STAT:  ICALC_choose_dataset( iwid , aa ) ; break ;
 
@@ -495,7 +488,7 @@ if(DEBUG) ININFO_message("hollowing out old dataset") ;
        *slf.dset = *icaset ;      /* copy the guts, keep the pointer */
        slf.dset->idcode = old_idc ;           /* and keep the idcode */
        nds = slf.dset_index ;
-       INFO_message("trashed and reused old dataset %s",ics->prefix) ;
+       INFO_message("trashed and re-used old dataset %s",ics->prefix) ;
 
      } else {                                  /* add to the session */
        int vv = icaset->view_type ;
@@ -551,7 +544,6 @@ if(DEBUG) ININFO_message("change fim_now") ;
    }
 if(DEBUG) ININFO_message("reset func range") ;
    AFNI_reset_func_range(im3d) ;
-   flush_3Dview_sort(im3d,"T");  /* ZSS April 27 2012: Reset sorted threshold */
 
    if( MCW_val_bbox(im3d->vwid->view->see_func_bbox) == 0 ){ /* overlay is off */
      char cmd[32] , *cpt=AFNI_controller_label(im3d) ;
@@ -583,27 +575,28 @@ static char *helpstring =
    " (2) Select datasets to corresponds to symbols A, B, ..., as desired,\n"
    "     and then select a sub-brick index '[-]' to use.\n"
    "*OR* Choose a statistic (MIN or MAX) to use from a given dataset volume.\n"
-   "*OR* Set a given symbol to be a numeric constant (not from a dataset).\n"
-   "*OR* Select a dataset and sub-brick to be converted from a statistical\n"
-   "     distribution (e.g., from a t-test) to a p-value.\n"
+   "*OR* Set a given symbol to be a numeric constant.\n"
    "\n"
    " (3) Press the 'Compute InstaCalc' button to (re)calculate the output.\n"
    "\n"
    " * The output is stored into a dataset named A_ICALC (for controller A),\n"
    "   which will be switched to be the new overlay dataset.\n"
+   " * If you make changes to the expression, the datasets chosen, etc., the\n"
+   "   A_ICALC will NOT be recomputed automatically -- you must press the\n"
+   "   'Compute InstaCalc' button again.\n"
    "\n"
    "If you make changes to the expression, or to the symbol definitions, you\n"
    "must press 'Compute InstaCalc' again for the changes to be reflected in\n"
-   "the A_ICALC dataset -- it will not be recomputed automatically.\n"
+   "the dataset.\n"
    "\n"
-   "Simple Example: Dual Thresholding (AKA 'conjunction' mapping)\n"
+   "Simple Example: Dual Thresholding\n"
    "   A = Overlay sub-brick of interest\n"
    "   B = t-statistic for some effect\n"
    "   C = t-statistic for some other effect\n"
    "   Expression = 'A*astep(B,3.1)*astep(C,4.2)\n"
    "The effect is to colorize A only where abs(B) > 3.1 AND abs(C) > 4.2.\n"
    "\n"
-   "Advanced Usage [for Jedi AFNI Masters]:\n"
+   "Advanced Usage [for AFNI Jedi Masters]:\n"
    " * diffsub = as in 3dcalc, you can specify a differentially offset voxel,\n"
    "             which allows a limited amount of spatial processing.\n"
    "             Example:\n"
@@ -630,20 +623,12 @@ static char *helpstring =
    "             of the 'Index' time selector in the main AFNI controller window\n"
    "             will be used.  When you change the time 'Index' in AFNI,\n"
    "             InstaCalc will NOT be automatically updated -- you still have\n"
-   "             to press 'Compute InstaCalc' to get dataset A_ICALC re-computed.\n"
-   " * Pre-defined variables (if not set as described above) are\n"
-   "     x = DICOM x coordinate (R=- L=+)\n"
-   "     y = DICOM y coordinate (A=- P=+)\n"
-   "     z = DICOM z coordinate (I=- S=+)\n"
-   "     i = #1 3D index  j = #2 3D index  k = #3 3D index\n"
-   "   You can use these variable names in the expression without defining them\n"
-   "   in the variable choosers.  Other variables names used in the expression\n"
-   "   must be defined by selecting the appropriate row.\n"
+   "             to press 'Compute InstaCalc' to get A_ICALC re-computed.\n"
    "\n"
    "Author -- RW Cox -- Sep 2009\n"
    "\n"
    "DEBUGGING:\n"
-   "  If you can make InstaCalc reliably crash, please re-run AFNI with\n"
+   "  If you can make InstaCalc realiably crash, please re-run AFNI with\n"
    "  the extra option '-DAFNI_INSTACALC_DEBUG=YES' and then make it crash;\n"
    "  the screen printout of the processing steps might help figure out what\n"
    "  is going on when you report it to me.\n"
@@ -944,7 +929,6 @@ if(DEBUG) ININFO_message("  get constant string") ;
 
        /* these cases aren't so easy */
 
-       case ICALC_DSET_PVALU:
        case ICALC_DSET_VALUE:
        case ICALC_DSET_STAT:{
          int idx      = iwid->war[ids].index_av->ival ;
@@ -976,8 +960,7 @@ if(DEBUG) ININFO_message("  dataset idx = %d",idx) ;
                                            abet[ids] ,
                                            DSET_HEADNAME(dset) , idx ) ;
 
-         if( bb == ICALC_DSET_VALUE ||
-             bb == ICALC_DSET_PVALU   ){  /*---- actual dataset voxel values ----*/
+         if( bb == ICALC_DSET_VALUE ){  /*---- actual dataset voxel values ----*/
 
            if( ics->dset_master == NULL ){
 if(DEBUG) ININFO_message("  set dset_master") ;
@@ -1088,7 +1071,7 @@ if(DEBUG) ININFO_message("  completely done with dataset processing") ;
 if(DEBUG) ININFO_message("check datasets for compatibility") ;
    nxyz = DSET_NVOX(ics->dset_master) ;
    for( ids=0 ; ids < 26 ; ids++ ){
-     if( ics->intyp[ids] != ICALC_DSET_VALUE && ics->intyp[ids] != ICALC_DSET_PVALU ) continue ;
+     if( ics->intyp[ids] != ICALC_DSET_VALUE ) continue ;
      dset = ics->inset[ids] ;
      if( !ISVALID_DSET(dset) || dset == ics->dset_master ) continue ;
      if( DSET_NVOX(dset) != nxyz ){
@@ -1133,7 +1116,7 @@ static MRI_IMAGE * ICALC_compute( ICALC_setup *ics )
    float xxx[VSIZE], yyy[VSIZE], zzz[VSIZE] ;  /* xyz coordinates */
    int   iii,jjj,kkk , nx,ny,nz,nxy,nxyz ;
    THD_3dim_dataset *qset ;
-   byte *bar=NULL; short *sar=NULL; float *far=NULL; complex *car=NULL; void *var;
+   byte *bar; short *sar; float *far; complex *car; void *var;
    int dtyp , kts ; float ffac ;
 
 ENTRY("ICALC_compute") ;
@@ -1194,7 +1177,6 @@ if(DEBUG) INFO_message("Start computation loop") ;
 
          /* however, this is not so easy (too many sub-cases) */
 
-         case ICALC_DSET_PVALU:
          case ICALC_DSET_VALUE:{
            THD_3dim_dataset *dset ;
 
@@ -1337,17 +1319,6 @@ if(CEBUG) ININFO_message("  dshift: jds=%d  id=%d jd=%d kd=%d ld=%d",jds,id,jd,k
                      atoz[ids][jj-ii] = vv ;
                    }
                  } /* end of data type extraction switch */
-
-                 if( ics->intyp[ids] == ICALC_DSET_PVALU        &&
-                     FUNC_IS_STAT(DSET_BRICK_STATCODE(dset,kts))   ){  /* 26 Jun 2015 */
-                   if( atoz[ids][jj-ii] != 0.0 )
-                     atoz[ids][jj-ii] = THD_stat_to_pval( fabs(atoz[ids][jj-ii]) ,
-                                                          DSET_BRICK_STATCODE(dset,kts) ,
-                                                          DSET_BRICK_STATAUX (dset,kts)  ) ;
-                   else
-                     atoz[ids][jj-ii] = 1.0 ;
-                 }
-
                } /* end of jj loop over voxels */
              } /* end of if getting actual data (wasn't time shifted to 0) */
            } /* end of differential subscripted sub-case */
@@ -1403,18 +1374,6 @@ if(CEBUG) ININFO_message("  normal dataset: kts=%d",kts) ;
                break ;
              } /* end of data type extraction switch */
 
-             if( ics->intyp[ids] == ICALC_DSET_PVALU        &&
-                 FUNC_IS_STAT(DSET_BRICK_STATCODE(dset,kts))   ){  /* 26 Jun 2015 */
-               for( jj=jbot ; jj < jtop ; jj++ ){
-                 if( atoz[ids][jj-ii] != 0.0 )
-                   atoz[ids][jj-ii] = THD_stat_to_pval( fabs(atoz[ids][jj-ii]) ,
-                                                        DSET_BRICK_STATCODE(dset,kts) ,
-                                                        DSET_BRICK_STATAUX (dset,kts)  ) ;
-                 else
-                   atoz[ids][jj-ii] = 1.0 ;
-               }
-            }
-
           } /** end of 3D dataset normal sub-case **/
 
           /* the case of a voxel (x,y,z) or (i,j,k) coordinate */
