@@ -264,12 +264,12 @@ if(PRINT_TRACING)
                     icol = (jj < INIT_ncolovr) ? jj+1 : PAL_IIGNORE ;
                  }
                } else if( mode == SETUP_LATER_MODE ){
-                  icol = DC_find_closest_overlay_color( dc , right ) ;
+                  icol = DC_find_overlay_color( dc , right ) ;
                   if( icol < 0 ) icol = PAL_IIGNORE ;
 
 if(PRINT_TRACING)
 { char str[256] ;
-  sprintf(str,"  DC_find_closest_overlay_color(%s) returns %d\n",right,icol) ;
+  sprintf(str,"  DC_find_overlay_color(%s) returns %d\n",right,icol) ;
   STATUS(str) ; }
 
                }
@@ -523,7 +523,7 @@ ENTRY("load_PBAR_palette_array") ;
    }
 
    if( nn > 0 && !pbar->bigmode ){
-      Three_D_View * im3d = (Three_D_View *)pbar->parent ;
+      Three_D_View * im3d = (Three_D_View *) pbar->parent ;
       if( fixim && IM3D_OPEN(im3d) ){ HIDE_SCALE(im3d) ; }
       alter_MCW_pbar( pbar , 0 , NULL ) ;
       if( fixim && IM3D_OPEN(im3d) ){ FIX_SCALE_SIZE(im3d) ; }
@@ -550,9 +550,9 @@ char * AFNI_palette_label_CB( MCW_arrowval *av , XtPointer cd )
 -------------------------------------------------------------------*/
 
 void AFNI_pbar_EV( Widget w , XtPointer cd ,
-                   XEvent *ev , RwcBoolean *continue_to_dispatch )
+                   XEvent *ev , Boolean *continue_to_dispatch )
 {
-   Three_D_View *im3d = (Three_D_View *)cd ;
+   Three_D_View *im3d = (Three_D_View *) cd ;
 
 ENTRY("AFNI_pbar_EV") ;
 
@@ -563,14 +563,9 @@ ENTRY("AFNI_pbar_EV") ;
          XButtonEvent *event = (XButtonEvent *) ev ;
          im3d->vwid->butx = event->x_root ;  /* 17 May 2005 */
          im3d->vwid->buty = event->y_root ;
-         if( event->button == Button4 || event->button == Button5 ){ /* flip */
-           PBAR_flip(im3d->vwid->func->inten_pbar) ;          /* 19 Feb 2014 */
-           AFNI_inten_pbar_CB(im3d->vwid->func->inten_pbar,im3d,pbCR_COLOR) ;
-         } else {
-           event->button = Button3 ;                             /* fakeout */
-           XmMenuPosition( im3d->vwid->func->pbar_menu , event ) ; /* where */
-           XtManageChild ( im3d->vwid->func->pbar_menu ) ;         /* popup */
-        }
+         event->button    = Button3 ;                            /* fakeout */
+         XmMenuPosition( im3d->vwid->func->pbar_menu , event ) ; /* where */
+         XtManageChild ( im3d->vwid->func->pbar_menu ) ;         /* popup */
       }
       break ;
    }
@@ -584,7 +579,7 @@ ENTRY("AFNI_pbar_EV") ;
 
 void AFNI_pbar_CB( Widget w , XtPointer cd , XtPointer cbs )
 {
-   Three_D_View *im3d = (Three_D_View *)cd ;
+   Three_D_View *im3d = (Three_D_View *) cd ;
    MCW_pbar *pbar ;
    int npane , jm , ii ;
    double pmax , pmin ;
@@ -607,7 +602,7 @@ ENTRY("AFNI_pbar_CB") ;
 
    if( w == im3d->vwid->func->pbar_equalize_pb ){
 
-      if( pbar->bigmode ) EXRETURN ;
+      if( pbar->bigmode ){ BEEPIT; WARNING_message("Can't equalize!"); EXRETURN; } /* 30 Jan 2003 */
 
       for( ii=0 ; ii <= npane ; ii++ )
          pval[ii] = pmax - ii * (pmax-pmin)/npane ;
@@ -617,31 +612,14 @@ ENTRY("AFNI_pbar_CB") ;
       FIX_SCALE_SIZE(im3d) ;
    }
 
-   /*--- Set range = 1 ---*/
-
-   else if( w == im3d->vwid->func->pbar_setrange_1_pb ){
-     static char clabel[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ" ;
-     char cmd[128] ;
-     sprintf(cmd,"SET_FUNC_RANGE %c.1.0",clabel[AFNI_controller_index(im3d)]) ;
-     (void)AFNI_driver(cmd) ;
-   }
-
    /*--- Set top value ---*/
 
    else if( w == im3d->vwid->func->pbar_settop_pb ){
       MCW_choose_integer( im3d->vwid->func->options_label ,
-                          "Pbar Top" , 0 , 999999 , 1 ,
+                          "Pbar Top" , 0 , 99999 , 1 ,
                           AFNI_set_pbar_top_CB , cd   ) ;
    }
 
-   /*--- Flip [08 Feb 2012] ---*/
-
-   else if( w == im3d->vwid->func->pbar_flip_pb ||
-            w == im3d->vwid->func->pbar_flip_pb2  ){
-     PBAR_flip(pbar) ;
-     AFNI_inten_pbar_CB(pbar,im3d,pbCR_COLOR) ;
-   }
-
    /*--- Read in a palette file ---*/
 
    else if( w == im3d->vwid->func->pbar_readin_pb ){
@@ -691,9 +669,9 @@ ENTRY("AFNI_pbar_CB") ;
 
    else if( w == im3d->vwid->func->pbar_saveim_pb ){
       MCW_choose_string( im3d->vwid->func->options_label ,
-                         "PPM file prefix; OR:\n"
-                         " * end in .jpg or .png *\n"
-                         " * for those formats   *"
+                         "PPM file prefix\n"
+                         "  * end in .jpg or .png *\n"
+                         "  * for those formats   *"
                          , NULL ,
                          AFNI_finalize_saveim_CB , cd ) ;
    }
@@ -849,36 +827,21 @@ ENTRY("AFNI_finalize_read_palette_CB") ;
 }
 
 /*----------------------------------------------------------------------------*/
-static int ignore_pbar_top = 0 ;
-void AFNI_ignore_pbar_top(int ig){ ignore_pbar_top = ig ; }
 
-/*----------------------------------------------------------------------------*/
-/* Also see macro AFNI_pbar_topset() */
-/*----------------------------------------------------------------------------*/
-
-void AFNI_set_pbar_top_CB( Widget wcaller , XtPointer cd , MCW_choose_cbs *cbs )
+void AFNI_set_pbar_top_CB( Widget wcaller , XtPointer cd , MCW_choose_cbs * cbs )
 {
-   Three_D_View *im3d = (Three_D_View *)cd ;
-   MCW_pbar *pbar ;
+   Three_D_View * im3d = (Three_D_View *) cd ;
+   MCW_pbar * pbar ;
    float pval[NPANE_MAX+1] ;
-   float pmin,pmax , fac ;
+   double pmin,pmax , fac ;
    int ii ;
-   static int busy=0 ;  /* prevent recursion */
 
 ENTRY("AFNI_set_pbar_top_CB") ;
 
-   if( ignore_pbar_top || busy || !IM3D_OPEN(im3d) ) EXRETURN ;
+   if( ! IM3D_OPEN(im3d) ) EXRETURN ;
 
-   pmax = cbs->fval ; if( pmax <= 0.0f ) EXRETURN ;
-
-   if( !IM3D_ULAY_COHERENT(im3d) ){           /* 10 Jun 2014 */
-     STATUS("incoherent ulay -- patching") ;
-     ERROR_message("AFNI_set_pbar_top_CB: incoherent ulay -- patching") ;
-     AFNI_assign_ulay_bricks(im3d) ;
-   }
-
-   busy = 1 ;
-   pbar = im3d->vwid->func->inten_pbar ;
+   pmax  = cbs->fval ; if( pmax <= 0.0 ){ BEEPIT; WARNING_message("Bad pmax"); EXRETURN; }
+   pbar  = im3d->vwid->func->inten_pbar ;
 
    HIDE_SCALE(im3d) ;
    if( pbar->bigmode ){              /* 30 Jan 2003 */
@@ -896,7 +859,6 @@ ENTRY("AFNI_set_pbar_top_CB") ;
    }
    FIX_SCALE_SIZE(im3d) ;
 
-   busy = 0 ;
    EXRETURN ;
 }
 
@@ -940,7 +902,7 @@ ENTRY("AFNI_finalize_write_palette_CB") ;
       char buf[512] ;
       sprintf(buf,"\nWriting current palette to file\n %s\n",fname) ;
       (void) MCW_popup_message( im3d->vwid->func->options_label ,
-                                buf , MCW_USER_KILL | MCW_QUICK_KILL ) ;
+                                buf , MCW_USER_KILL | MCW_TIMER_KILL ) ;
    }
 
    pbar  = im3d->vwid->func->inten_pbar ;
@@ -999,7 +961,7 @@ void AFNI_finalize_saveim_CB( Widget wcaller, XtPointer cd, MCW_choose_cbs * cbs
 {
    Three_D_View * im3d = (Three_D_View *) cd ;
    char * fname , * ptr ;
-   int ll , nx=64 , ny=512 , flip=0 ;
+   int ll , nx=20 , ny=256 ;
    MRI_IMAGE * im ;
 
 ENTRY("AFNI_finalize_saveim_CB") ;
@@ -1026,17 +988,10 @@ ENTRY("AFNI_finalize_saveim_CB") ;
    ptr = getenv( "AFNI_PBAR_IMXY" );
    if( ptr != NULL ){
      ll = sscanf( ptr , "%dx%d" , &nx , &ny ) ;
-     if( ll < 2 || nx < 4 || ny < 32 ){ nx=64; ny=512; }
-     flip = (strcasestr(ptr,"F")!=NULL) || (strcasestr(ptr,"H")!=NULL) ;
+     if( ll < 2 || nx < 1 || ny < 32 ){ nx=20; ny=256; }
    }
 
    im = MCW_pbar_to_mri( im3d->vwid->func->inten_pbar , nx,ny ) ;
-   if( im != NULL && flip ){
-     MRI_IMAGE *qim = mri_flippo( MRI_ROT_270 , 0 , im ) ;
-     if( qim != im && qim != NULL ){ mri_free(im) ; im = qim ; }
-   } else if( im == NULL ){
-     ERROR_message("MCW_pbar_to_mri function failed!") ;
-   }
    mri_write_pnm( fname , im ) ;
 
    POPDOWN_string_chooser; mri_free(im); free(fname); EXRETURN;
