@@ -43,25 +43,18 @@ int AFNI_splash_isopen(void)
    return (ppp != NULL && ISQ_REALZ(ppp->seq)) ? num_splashup : 0 ;
 }
 /*----------------------------------------------------------------------------*/
-int AFNI_gcd( int m , int n ){
+static int gcd( int m , int n ){
   while( m > 0 ){
     if( n > m ){ int t=m; m=n; n=t; } /* swap */
     m -= n;
   }
   return n;
 }
-int AFNI_find_relprime_random( int n ) /* find one relatively prime to n */
+static int find_relprime_random( int n ) /* find one relatively prime to n */
 {
    int dj , n5=n/5 ;
    if( n5 < 2 ) return 1 ;
-   do{ dj = lrand48() % n + 1 ; } while( AFNI_gcd(n,dj) > 1 ) ;
-   return dj ;
-}
-int AFNI_find_relprime_fixed( int n )  /* find number relatively prime to n */
-{
-   int dj , n5=n/5 ;
-   if( n5 < 2 ) return 1 ;
-   for( dj=n5 ; AFNI_gcd(n,dj) > 1 ; dj++ ) ; /*nada*/
+   do{ dj = lrand48() % n + 1 ; } while( gcd(n,dj) > 1 ) ;
    return dj ;
 }
 /*---------------------------------------------------------------------------*/
@@ -163,7 +156,7 @@ static int AFNI_change_splash(void)
        int nxov,nyov,ee,dd ;
        if( ff >= 0 ) ff = (ff+df) % num_face ;
        else {        ff = (lrand48() >> 8) % num_face ;
-                     df = AFNI_find_relprime_random(num_face) ;
+                     df = find_relprime_random(num_face) ;
        }
        imov = mri_read_stuff( fname_face[ff] ) ;
        if( imov != NULL ){
@@ -328,7 +321,7 @@ ENTRY("AFNI_splashup") ;
           index_splash = (first_splash >= 0) ? first_splash
                                              : (lrand48() >> 8) % num_splash ;
           delta_splash = 2*((lrand48() >> 8)%2)-1 ;  /* -1 or +1 */
-          delta_splash *= AFNI_find_relprime_random(num_splash) ; /* 13 Sep 2007 */
+          delta_splash *= find_relprime_random(num_splash) ; /* 13 Sep 2007 */
         } else {
           index_splash = (index_splash+delta_splash+num_splash)%(num_splash) ;
         }
@@ -662,7 +655,7 @@ ENTRY("SPLASH_decodexx") ;
 int AFNI_find_jpegs( char *prefix , char ***fname )  /* 26 Nov 2003 */
 {
    char *epath , *elocal , *eee ;
-   char edir[THD_MAX_NAME] , fdir[THD_MAX_NAME] , *ename , *udir ;
+   char edir[THD_MAX_NAME] , *ename ;
    int epos , ll , ii , id , nfile , nx,ny , num_file=0 ;
    char **ffile , **fflist=NULL ;
 
@@ -714,12 +707,9 @@ ENTRY("AFNI_find_jpegs") ;
        edir[ii]  = '/' ; edir[ii+1] = '\0' ;
      }
 
-     strcpy(fdir,edir) ; strcat(fdir,"funstuff") ;  /* 07 Oct 2011 */
-     if( THD_is_directory(fdir) ){ strcat(fdir,"/"); udir = fdir; } else { udir = edir; }
-
      /* create wildcard for JPEG files in this directory */
 
-     sprintf(ename,"%s%s*.jpg %s%s*.JPG" , udir,prefix,udir,prefix ) ;
+     sprintf(ename,"%s%s*.jpg %s%s*.JPG" , edir,prefix,edir,prefix ) ;
 
      MCW_wildcards( ename , &nfile , &ffile ) ;  /* find matching files */
      if( nfile <= 0 ) continue ;                 /* no files found */
@@ -727,20 +717,12 @@ ENTRY("AFNI_find_jpegs") ;
       /** add files we found to list **/
 
      fflist = (char **)realloc(fflist,sizeof(char *)*(num_file+nfile));
-     for( ii=0 ; ii < nfile ; ii++ ){
-       if( strstr(ffile[ii],"face_wildman.jpg")   != NULL ||  /* 20 May 2005 */
-           strstr(ffile[ii],"face_akanevsky.jpg") != NULL   ) /* 09 Nov 2011 */
+     for( ii=0 ; ii < nfile ; ii++ )
+       if( strstr(ffile[ii],"face_wildman.jpg") != NULL )  /* 20 May 2005 */
          remove(ffile[ii]) ;
        else
          fflist[num_file++] = strdup(ffile[ii]) ;
 
-       if( udir == fdir ){         /* 07 Oct 2011 */
-         char qnam[THD_MAX_NAME] ;
-         strcpy(qnam,edir) ; strcat(qnam,THD_trailname(ffile[ii],0)) ;
-         if( THD_is_file(qnam) ) remove(qnam) ;
-       }
-     }
-
      MCW_free_wildcards( nfile , ffile ) ;  /* toss the junk */
 
    } while( epos < ll ) ;  /* scan until 'epos' is after end of epath */
@@ -788,7 +770,7 @@ ENTRY("AFNI_faceup") ;
 
    ddss = num_face + 16449/num_face ; if( ddss > 222 ) ddss = 222 ;
 
-   if( num_face > 4 ) dj = AFNI_find_relprime_random(num_face) ;
+   if( num_face > 4 ) dj = find_relprime_random(num_face) ;
    j0 = lrand48() % num_face ;
 
    for( ii=0 ; ii < num_face ; ii++ ){
@@ -877,7 +859,7 @@ ENTRY("AFNI_allsplash") ;
 
    if( num_splash > 4 ){
      ii = num_splash / 2 ;
-     do{ dj = 1 + lrand48() % ii ; } while( AFNI_gcd(num_splash,dj) > 1 ) ;
+     do{ dj = 1 + lrand48() % ii ; } while( gcd(num_splash,dj) > 1 ) ;
    }
    j0 = lrand48() % num_splash ;
 
@@ -1138,15 +1120,17 @@ void AFNI_startup_layout_CB( XtPointer client_data , XtIntervalId *id )
 
    int cc,ww , gww,ghh,gxx,gyy ;
    char *e_asp ;
-   int   e_turnoff=0 ;
+   int    e_turnoff=0 ;
 
-   int  * plugin_cont = NULL ;
+   int *  plugin_cont = NULL ;
    char **plugin_geom = NULL ;
    int ipl ;
    char def_layout[]={"\n"
                       " ***LAYOUT\n"
                       "  A geom=+0+44\n"
-                     };
+                      "  A.axialimage geom=+3+455 ifrac=0.8\n"
+                      "  A.sagittalimage geom=+311+455 ifrac=0.8\n"
+                      "\n"};
    Three_D_View *im3d         = GLOBAL_library.controllers[0] ; /* already open */
 
 #ifdef ALLOW_PLUGINS
@@ -1164,26 +1148,9 @@ ENTRY("AFNI_startup_layout_CB") ;
       fbuf = AFNI_suck_file(fname);
    } else if ( ALLOW_realtime ) {
       AFNI_splashdown(); EXRETURN;  /* no default in RT   4 Jan 2011 [rickr] */
-   } else {    /* ZSS Dec 2010 ++ RWC Apr 2016 */
-      int xxx = 3 ;
-      fbuf = (char *)malloc(strlen(def_layout)+1024);
+   } else {    /* ZSS Dec 2010. */
+      fbuf = (char *)malloc(strlen(def_layout)+1);
       strcpy(fbuf, def_layout);
-      if( !AFNI_noenv("AFNI_OPEN_AXIAL") ){
-        sprintf(fbuf+strlen(fbuf),
-               "  A.axialimage geom=+%d+455 ifrac=0.8\n" , xxx ) ;
-        xxx += 288 ;
-      }
-      if( !AFNI_noenv("AFNI_OPEN_SAGITTAL") ){
-        sprintf(fbuf+strlen(fbuf),
-                "  A.sagittalimage geom=+%d+455 ifrac=0.8\n" , xxx ) ;
-        xxx += 333 ;
-      }
-      if( !AFNI_noenv("AFNI_OPEN_CORONAL") ){
-        sprintf(fbuf+strlen(fbuf),
-                "  A.coronalimage geom=+%d+455 ifrac=0.8\n",xxx) ;
-        xxx += 288 ;
-      }
-      strcat(fbuf,"\n") ;
    }
    if( fbuf == NULL ){ AFNI_splashdown(); EXRETURN; }
    nbuf = strlen(fbuf) ;         if( nbuf == 0    ){ AFNI_splashdown(); EXRETURN; }
@@ -1214,7 +1181,7 @@ STATUS("no ***LAYOUT found") ;
       controller_geom[cc][0] =
        image_geom[cc][0][0] = image_geom[cc][1][0] = image_geom[cc][2][0] =
        image_mont[cc][0][0] = image_mont[cc][1][0] = image_mont[cc][2][0] =
-       graph_geom[cc][0][0] = graph_geom[cc][1][0] = graph_geom[cc][2][0] = '\0' ;
+       graph_geom[cc][0][0] = graph_geom[cc][1][0] = graph_geom[cc][1][0] = '\0' ;
 
       controller_mask[cc] =
        image_mask[cc][0] = image_mask[cc][1] = image_mask[cc][2] =
@@ -1420,7 +1387,6 @@ STATUS("no ***LAYOUT found") ;
 
    free(fbuf) ; free(linbuf) ;  /* toss the trash */
 
-#if 0
    /*-- if any image geom commands are present,
         we might need to enforce the aspect ratio --*/
 
@@ -1429,7 +1395,6 @@ STATUS("no ***LAYOUT found") ;
      putenv("AFNI_ENFORCE_ASPECT=YES") ;
      e_turnoff = 1 ;
    }
-#endif
 
    /*-- now do the commanded work --*/
 
@@ -1505,7 +1470,7 @@ STATUS("no ***LAYOUT found") ;
             if( nn >= 2 && mww >= 1 && mww <= MONT_NMAX && mhh >= 1 && mhh <= MONT_NMAX ){
                int mp[5] ;
                mp[0] = mww ; mp[1] = mhh ; mp[2] = msp ; mp[3] = mgap ;
-               mp[4] = DC_find_closest_overlay_color(GLOBAL_library.controllers[cc]->dc,mcol);
+               mp[4] = DC_find_overlay_color(GLOBAL_library.controllers[cc]->dc,mcol);
                drive_MCW_imseq( isq , isqDR_setmontage , (XtPointer) mp ) ;
 
                if( msp == 1 ) singleton++ ;
@@ -1658,9 +1623,7 @@ STATUS("no ***LAYOUT found") ;
    }
 #endif
 
-#if 0
    if( e_turnoff ) putenv("AFNI_ENFORCE_ASPECT=NO") ;
-#endif
 
    AFNI_splashdown() ; EXRETURN ;
 }
@@ -1803,14 +1766,7 @@ ENTRY("AFNI_finalsave_layout_CB") ;
         else
           fprintf(gp,"SET_FUNC_RANGE %c.%f\n" , abet[cc] ,
                   zm3d->vwid->func->range_av->fval        ) ;
-        
-        #if 0 /* Do we need this here ? */
-        if( zm3d->cont_perc_thr )  /* ZSS April 27 2012 */
-          fprintf(gp,"SET_FUNC_PERCENTILE %c.+\n" , abet[cc] ) ;
-        else
-          fprintf(gp,"SET_FUNC_PERCENTILE %c.-\n" , abet[cc] ) ;
-        #endif
-         
+
         if( ISVALID_DSET(zm3d->anat_now) ){          /* 27 Dec 2006 */
           char *pp = DSET_PREFIX(zm3d->anat_now) ;
           if( pp == NULL || *pp == '\0' ) pp = DSET_IDCODE_STR(zm3d->anat_now);
