@@ -54,23 +54,7 @@ void ssqrt_func( int num , float *vec )
    return ;
 }
 
-/*------------ Sample 0D function: Absolute value of each input point --------*/
-
-void absval_func( int num , float *vec )  /* 20 Oct 2020 */
-{
-   int ii ;
-   double val ;
-
-   if( num <= 0 || vec == NULL ) return ;
-
-   for( ii=0 ; ii < num ; ii++ )
-      vec[ii] = fabsf(vec[ii]) ;
-
-   return ;
-}
-
 /*--------------------------------------------------------------------------*/
-/* adaptive = downweight things a long ways from median */
 
 float adaptive_weighted_mean( int num , float *x )
 {
@@ -83,16 +67,15 @@ float adaptive_weighted_mean( int num , float *x )
    qmedmad_float( num , x , &med , &mad ) ;
    if( mad <= 0.0f ) return (med) ;
 
-   wsum = xsum = 0.0f ; mad = 0.56789f / mad ;
+   wsum = xsum = 0.0f ; mad = 0.4567f / mad ;
    for( ii=0 ; ii < num ; ii++ ){
-     wt = mad*fabsf(x[ii]-med); wt = 1.0f / (1.0f+wt*wt*wt); wsum += wt;
+     wt = fabsf( mad*fabsf(x[ii]-med) ); wt = 1.0f / (1.0f+wt*wt*wt); wsum += wt;
      xsum += wt * x[ii] ;
    }
    return (xsum/wsum) ;
 }
 
 /*--------------------------------------------------------------------------*/
-/* 1D adaptive filter 9 points wide */
 
 void adpt_wt_mn9( int num , double to,double dt, float *vec )
 {
@@ -113,59 +96,6 @@ void adpt_wt_mn9( int num , double to,double dt, float *vec )
    memcpy(vec,nv,sizeof(float)*num) ; free(nv) ; return ;
 }
 
-/*--------------------------------------------------------------------------*/
-/* 1D adaptive filter 19 points wide */
-
-void adpt_wt_mn19( int num , double to,double dt, float *vec )
-{
-   float x[19] , *nv ; int ii,jj,kk , n1=num-1 ;
-
-   nv = (float *)malloc(sizeof(float)*num) ;
-
-   for( ii=0 ; ii < num ; ii++ ){
-
-     for( jj=-9 ; jj <= 9 ; jj++ ){
-       kk = ii+jj ; if( kk < 0 ) kk = 0 ; else if( kk > n1 ) kk = n1 ;
-       x[jj+9] = vec[kk] ;
-     }
-
-     nv[ii] = adaptive_weighted_mean( 19 , x ) ;
-   }
-
-   memcpy(vec,nv,sizeof(float)*num) ; free(nv) ; return ;
-}
-
-/*--------------------------------------------------------------------------*/
-/* 1D adaptive filter user-initialized points wide (must be odd) */
-
-void adpt_wt_mnXX( int num , double to,double dt, float *vec )
-{
-   static int nXX=0,nHH=0 ; static float *XX=NULL ;
-   float *nv ; int ii,jj,kk , n1=num-1 ;
-
-   if( vec == NULL ){  /* setup call */
-     if( num > 0 && num != nXX ){
-       nXX = num ; nHH = nXX/2 ;
-       XX  = (float *)realloc((void *)XX,sizeof(float)*(2*nHH+1)) ;
-     }
-     return ;
-   }
-
-   nv = (float *)malloc(sizeof(float)*num) ;
-
-   for( ii=0 ; ii < num ; ii++ ){
-
-     for( jj=-nHH ; jj <= nHH ; jj++ ){
-       kk = ii+jj ; if( kk < 0 ) kk = 0 ; else if( kk > n1 ) kk = n1 ;
-       XX[jj+nHH] = vec[kk] ;
-     }
-
-     nv[ii] = adaptive_weighted_mean( nXX , XX ) ;
-   }
-
-   memcpy(vec,nv,sizeof(float)*num) ; free(nv) ; return ;
-}
-
 /*--------------- Sample 1D function: Order Statistics Filter -------------*/
 
 void osfilt3_func( int num , double to,double dt, float *vec )
@@ -206,7 +136,7 @@ void median3_func( int num , double to,double dt, float *vec )
 #undef  mmm7
 #define mmm7(j)                                            \
  { float qqq[7] ; int jj = (j)-3 ;                         \
-   if( jj < 0 ) jj = 0; else if( jj+7 > num ) jj = num-7;  \
+   if( jj < 0 ) jj = 0; else if( jj+6 >= num ) jj = num-7; \
    memcpy(qqq,vec+jj,sizeof(float)*7) ;                    \
    med    = qmed_float(7,qqq); qqq[0] = fabsf(qqq[0]-med); \
    qqq[1] = fabsf(qqq[1]-med); qqq[2] = fabsf(qqq[2]-med); \
@@ -258,7 +188,7 @@ void despike7pp_func( int num , double to,double dt , float *vec )
 #undef  mmm9
 #define mmm9(j)                                            \
  { float qqq[9] ; int jj = (j)-4 ;                         \
-   if( jj < 0 ) jj = 0; else if( jj+9 > num ) jj = num-9;  \
+   if( jj < 0 ) jj = 0; else if( jj+8 >= num ) jj = num-9; \
    memcpy(qqq,vec+jj,sizeof(float)*9) ;                    \
    med    = qmed_float(9,qqq); qqq[0] = fabsf(qqq[0]-med); \
    qqq[1] = fabsf(qqq[1]-med); qqq[2] = fabsf(qqq[2]-med); \
@@ -289,96 +219,6 @@ void despike9_func( int num , double to,double dt , float *vec )
 }
 #undef mmm9
 
-/*----------------------------------------------------------------------------*/
-/* Despiking-25 filter */
-
-#undef  SWAP
-#define SWAP(x,y) (temp=x,x=y,y=temp)
-#undef  SORT2
-#define SORT2(a,b) if(a>b) SWAP(a,b)
-
-static INLINE float median25f(float *p)
-{
-    register float temp ;
-    SORT2(p[0], p[1]) ;   SORT2(p[3], p[4]) ;   SORT2(p[2], p[4]) ;
-    SORT2(p[2], p[3]) ;   SORT2(p[6], p[7]) ;   SORT2(p[5], p[7]) ;
-    SORT2(p[5], p[6]) ;   SORT2(p[9], p[10]) ;  SORT2(p[8], p[10]) ;
-    SORT2(p[8], p[9]) ;   SORT2(p[12], p[13]) ; SORT2(p[11], p[13]) ;
-    SORT2(p[11], p[12]) ; SORT2(p[15], p[16]) ; SORT2(p[14], p[16]) ;
-    SORT2(p[14], p[15]) ; SORT2(p[18], p[19]) ; SORT2(p[17], p[19]) ;
-    SORT2(p[17], p[18]) ; SORT2(p[21], p[22]) ; SORT2(p[20], p[22]) ;
-    SORT2(p[20], p[21]) ; SORT2(p[23], p[24]) ; SORT2(p[2], p[5]) ;
-    SORT2(p[3], p[6]) ;   SORT2(p[0], p[6]) ;   SORT2(p[0], p[3]) ;
-    SORT2(p[4], p[7]) ;   SORT2(p[1], p[7]) ;   SORT2(p[1], p[4]) ;
-    SORT2(p[11], p[14]) ; SORT2(p[8], p[14]) ;  SORT2(p[8], p[11]) ;
-    SORT2(p[12], p[15]) ; SORT2(p[9], p[15]) ;  SORT2(p[9], p[12]) ;
-    SORT2(p[13], p[16]) ; SORT2(p[10], p[16]) ; SORT2(p[10], p[13]) ;
-    SORT2(p[20], p[23]) ; SORT2(p[17], p[23]) ; SORT2(p[17], p[20]) ;
-    SORT2(p[21], p[24]) ; SORT2(p[18], p[24]) ; SORT2(p[18], p[21]) ;
-    SORT2(p[19], p[22]) ; SORT2(p[8], p[17]) ;  SORT2(p[9], p[18]) ;
-    SORT2(p[0], p[18]) ;  SORT2(p[0], p[9]) ;   SORT2(p[10], p[19]) ;
-    SORT2(p[1], p[19]) ;  SORT2(p[1], p[10]) ;  SORT2(p[11], p[20]) ;
-    SORT2(p[2], p[20]) ;  SORT2(p[2], p[11]) ;  SORT2(p[12], p[21]) ;
-    SORT2(p[3], p[21]) ;  SORT2(p[3], p[12]) ;  SORT2(p[13], p[22]) ;
-    SORT2(p[4], p[22]) ;  SORT2(p[4], p[13]) ;  SORT2(p[14], p[23]) ;
-    SORT2(p[5], p[23]) ;  SORT2(p[5], p[14]) ;  SORT2(p[15], p[24]) ;
-    SORT2(p[6], p[24]) ;  SORT2(p[6], p[15]) ;  SORT2(p[7], p[16]) ;
-    SORT2(p[7], p[19]) ;  SORT2(p[13], p[21]) ; SORT2(p[15], p[23]) ;
-    SORT2(p[7], p[13]) ;  SORT2(p[7], p[15]) ;  SORT2(p[1], p[9]) ;
-    SORT2(p[3], p[11]) ;  SORT2(p[5], p[17]) ;  SORT2(p[11], p[17]) ;
-    SORT2(p[9], p[17]) ;  SORT2(p[4], p[10]) ;  SORT2(p[6], p[12]) ;
-    SORT2(p[7], p[14]) ;  SORT2(p[4], p[6]) ;   SORT2(p[4], p[7]) ;
-    SORT2(p[12], p[14]) ; SORT2(p[10], p[14]) ; SORT2(p[6], p[7]) ;
-    SORT2(p[10], p[12]) ; SORT2(p[6], p[10]) ;  SORT2(p[6], p[17]) ;
-    SORT2(p[12], p[17]) ; SORT2(p[7], p[17]) ;  SORT2(p[7], p[10]) ;
-    SORT2(p[12], p[18]) ; SORT2(p[7], p[12]) ;  SORT2(p[10], p[18]) ;
-    SORT2(p[12], p[20]) ; SORT2(p[10], p[20]) ; SORT2(p[10], p[12]) ;
-    return (p[12]);
-}
-
-/*--- get the local median and MAD of values vec[j-12 .. j+12] ---*/
-
-#undef  mead25
-#define mead25(j)                                              \
- { float qqq[25] ; int jj=(j)-12 ; register int pp;            \
-   if( jj < 0 ) jj = 0; else if( jj+25 > num ) jj = num-25;    \
-   for( pp=0 ; pp < 25 ; pp++ ) qqq[pp] = vec[jj+pp] ;         \
-   med = median25f(qqq) ;                                      \
-   for( pp=0 ; pp < 25 ; pp++ ) qqq[pp] = fabsf(qqq[pp]-med) ; \
-   mad = median25f(qqq); }
-
-void DES_despike25( int num , double to,double dt , float *vec )
-{
-   int ii , nsp ; float *zma,*zme , med,mad,val ;
-   static float *deswks = NULL ;
-   static int   ndeswks = 0 ;
-
-   if( vec == NULL ) return ;
-   if( num <  25 ) { despike9_func( num , to,dt , vec ) ; return ; }
-
-   if( ndeswks < num ){
-      deswks = (float *)realloc(deswks,sizeof(float)*(4*num)) ;
-     ndeswks = num ;
-   }
-
-   zme = deswks ; zma = zme + num ;
-
-   for( ii=0 ; ii < num ; ii++ ){
-     mead25(ii) ; zme[ii] = med ; zma[ii] = mad ;
-   }
-   mad = qmed_float(num,zma) ;
-   if( mad <= 0.0f ) return ;
-   mad *= 6.1234f ;  /* threshold value */
-
-   for( nsp=ii=0 ; ii < num ; ii++ )
-     if( fabsf(vec[ii]-zme[ii]) > mad ){ vec[ii] = zme[ii]; nsp++; }
-
-   return ;
-}
-#undef mead25
-#undef SORT2
-#undef SWAP
-
 /*-------------- Sample 1D function: HRF Decon [29 Oct 2010] ---------------*/
 
 static float lhs_legendre( float x, float bot, float top, float n )
@@ -442,23 +282,22 @@ void absfft_func( int num , double to,double dt, float *vec )
 {
    static complex *cx=NULL ;
    static int      ncx=0 , numold=0 ;
-   float f0,f1,f2 ;
+   float f0,f1 ;
    int ii ;
 
    if( num < 2 ) return ;
    if( num != numold ){
      numold = num ;
-     ncx    = csfft_nextup_even(numold) ;
+     ncx    = csfft_nextup(numold) ;
      cx     = (complex *)realloc(cx,sizeof(complex)*ncx) ;
-     INFO_message("1D FFT: ndata=%d nfft=%d",num,ncx) ;
    }
 
-   get_quadratic_trend( num , vec , &f0,&f1,&f2 ) ;  /* thd_detrend.c */
+   get_linear_trend( num , vec , &f0,&f1 ) ;  /* thd_detrend.c */
 
-   for( ii=0 ; ii < num ; ii++ ){ cx[ii].r = vec[ii]-(f0+f1*ii+f2*ii*ii); cx[ii].i = 0.0; }
+   for( ii=0 ; ii < num ; ii++ ){ cx[ii].r = vec[ii]-(f0+f1*ii); cx[ii].i = 0.0; }
    for(      ; ii < ncx ; ii++ ){ cx[ii].r = cx[ii].i = 0.0 ; }
 
-   csfft_cox( -1 , ncx , cx ) ;                      /* csfft.c */
+   csfft_cox( -1 , ncx , cx ) ;               /* csfft.c */
 
    vec[0] = 0.0 ;
    for( ii=1 ; ii < num ; ii++ ) vec[ii] = CABS(cx[ii]) ;
@@ -565,10 +404,10 @@ float osfilt_proj( int n , float *ar )  /* 07 Dec 2007 */
    qsort_float( n , ar ) ;
    n2 = n/2 ;
    for( ii=0 ; ii < n2 ; ii++ ){
-     v += (ii+1.0f)*(ar[ii]+ar[n-1-ii]) ;
-     d += 2.0f*(ii+1.0f) ;
+     v += (ii+1)*(ar[ii]+ar[n-1-ii]) ;
+     d += 2*(ii+1) ;
    }
-   v += (n2+1.0f)*ar[n2] ; d += (n2+1.0f) ;
+   v += (n2+1)*ar[n2] ; d += (n2+1) ;
    return (v/d) ;
 }
 
@@ -944,8 +783,8 @@ void fft2D_absfunc( int nx , int ny , double dx, double dy, float *ar )
 
    if( nx < 5 || ny < 5 ) return ;
 
-   nxup = csfft_nextup_even(nx) ;  /* get FFT size */
-   nyup = csfft_nextup_even(ny) ;
+   nxup = csfft_nextup_one35(nx) ;  /* get FFT size */
+   nyup = csfft_nextup_one35(ny) ;
 
    cxar = (complex *) malloc(sizeof(complex)*nxup*nyup) ;
 
@@ -995,8 +834,8 @@ void fft2D_phasefunc( int nx , int ny , double dx, double dy, float *ar )
 
    if( nx < 5 || ny < 5 ) return ;
 
-   nxup = csfft_nextup_even(nx) ;  /* get FFT size */
-   nyup = csfft_nextup_even(ny) ;
+   nxup = csfft_nextup_one35(nx) ;  /* get FFT size */
+   nyup = csfft_nextup_one35(ny) ;
 
    cxar = (complex *) malloc(sizeof(complex)*nxup*nyup) ;
 
@@ -1035,21 +874,3 @@ void fft2D_phasefunc( int nx , int ny , double dx, double dy, float *ar )
 
    free(cxar) ; free(cpt) ; return ;
 }
-
-/*----- 28 Oct 2014: sharpness estimate for an image -------------------------*/
-
-void sharpness2D_func( int nx , int ny , double dx, double dy, float *ar )
-{
-   MRI_IMAGE *inim , *outim ;
-
-   if( ar == NULL || nx < 5 || ny < 5 ) return ;
-
-   inim = mri_new_vol_empty( nx,ny,1 , MRI_float ) ;
-   mri_set_data_pointer(inim,ar) ;
-   outim = mri_sharpness(inim) ;
-   if( outim != NULL ){
-     memcpy( ar , MRI_FLOAT_PTR(outim) , sizeof(float)*nx*ny ) ;
-     mri_free(outim) ; mri_clear_and_free(inim) ;
-   }
-   return ;
-}
