@@ -16,47 +16,6 @@
 static int ignore_vedit = 0 ;   /* 28 Jan 2008 */
 void AFNI_set_ignore_vedit( int ii ){ ignore_vedit = ii; return; }
 
-/*------------------------------------------------------------------------*/
-/* return pointer to the 3D image that would be displayed for the
-   ival-th sub-brick of the dataset -- includes the possibility for
-   vedit (on-the-fly volume editing; currently == clusterize-ation).
-     ** This function is used in afni.c to find the min/max **
-     ** of the OLay image at voxels that survived threshold **
-*//*----------------------------------------------------------------------*/
-
-MRI_IMAGE * AFNI_dataset_displayim( THD_3dim_dataset *dset , int ival )
-{
-   int do_vedit ;
-   MRI_TYPE typ ;
-   MRI_IMAGE *im ;
-
-   if( !ISVALID_DSET(dset)                  ) return NULL ;
-   if( ival < 0 || ival >= DSET_NVALS(dset) ) return NULL ;
-   if( !DSET_INMEMORY(dset)                 ) return NULL ;
-
-   typ = DSET_BRICK_TYPE(dset,ival) ;
-   if( ! AFNI_GOOD_DTYPE(typ)               ) return NULL ;
-
-#if 0
-   if( dset->wod_flag                       ) return NULL ;
-#endif
-
-   do_vedit = ( !ignore_vedit                   &&
-                DSET_VEDIT_IVAL(dset)   == ival &&
-                dset->dblk->vedim       != NULL &&
-                dset->dblk->vedim->kind == typ    ) ;
-
-   if( do_vedit ){
-     im = dset->dblk->vedim ;
-   } else {
-     im = DSET_BRICK(dset,ival) ;
-     if( mri_data_pointer(im) == NULL ) DSET_load(dset) ;
-     if( mri_data_pointer(im) == NULL ) return NULL ;
-   }
-
-   return im ;
-}
-
 /*------------------------------------------------------------------------
    Return a slice from a dataset, possibly to be warped on-the-fly
    from its parent:
@@ -77,11 +36,11 @@ MRI_IMAGE * AFNI_dataset_slice( THD_3dim_dataset *dset ,
                                 int ival , int resam_mode )
 {
    MRI_IMAGE *newim ;
-   void *sar , *bar=NULL ;
+   void *sar , *bar ;
    int nxx,nyy,nzz , do_vedit ;
    MRI_TYPE typ ;
    THD_dataxes *daxes ;
-   THD_3dim_dataset *parent_dset=NULL ;
+   THD_3dim_dataset *parent_dset ;
    THD_warp parent_to_child_warp ;
 
 ENTRY("AFNI_dataset_slice") ;
@@ -110,7 +69,7 @@ ENTRY("AFNI_dataset_slice") ;
 #endif
 
 if(PRINT_TRACING)
-{ char str[1280] ;
+{ char str[256] ;
   sprintf(str,"Input dataset = %s",DSET_FILECODE(dset)) ; STATUS(str) ;
   sprintf(str,"nxx=%d nyy=%d nzz=%d",nxx,nyy,nzz) ;  STATUS(str) ;
   sprintf(str,"fixed_axis=%d fixed_index=%d ival=%d resam=%d",
@@ -259,12 +218,7 @@ STATUS("scaling slice to floats") ;
 
    /*-------------------- must warp from parent dataset ---------------------*/
 
-   if( 0 && do_vedit ){          /* 23 Aug 2012 - volume edit ==> must self-warp */
-STATUS("volume edit ==> self-warping with IDENTITY") ;
-     parent_dset = dset ;
-     parent_to_child_warp = IDENTITY_WARP ;
-     if( dset->vox_warp != NULL ) dset->vox_warp->type = ILLEGAL_TYPE ;
-   } else if( dset->warp != NULL ){
+   if( dset->warp != NULL ){
 STATUS("setting parent_to_child_warp to stored warp") ;
       parent_to_child_warp = *(dset->warp) ;
    } else {
@@ -272,32 +226,30 @@ STATUS("setting parent_to_child_warp to identity") ;
       parent_to_child_warp = IDENTITY_WARP ;  /* no warp ==> use identity */
    }
 
-   if( parent_dset == NULL ){
-     if( dset->warp_parent != NULL &&
-         (dset->dblk->diskptr->storage_mode == STORAGE_BY_BRICK ||
-          dset->dblk->diskptr->storage_mode == STORAGE_UNDEFINED  ) ){
+   if( dset->warp_parent != NULL &&
+       (dset->dblk->diskptr->storage_mode == STORAGE_BY_BRICK ||
+        dset->dblk->diskptr->storage_mode == STORAGE_UNDEFINED  ) ){
 if(PRINT_TRACING)
-{ char str[4096] ;
+{ char str[256] ;
   sprintf(str,"setting parent_dset to stored warp_parent=%p  this dset=%p",
           (void *)dset->warp_parent , (void *)dset ) ; STATUS(str) ;
   sprintf(str,"parent_dset=%s  this=%s",
           DSET_BRICKNAME(dset->warp_parent) , DSET_BRICKNAME(dset) ) ;
   STATUS(str) ; }
 
-        parent_dset = dset->warp_parent ;
-        DSET_load(parent_dset) ;          /* 17 Oct 2006 */
-     } else {
+      parent_dset = dset->warp_parent ;
+      DSET_load(parent_dset) ;          /* 17 Oct 2006 */
+   } else {
 STATUS("setting parent_dset to self") ;
-        parent_dset = dset ;                    /* self-parenting */
+      parent_dset = dset ;                    /* self-parenting */
 
-        if( dset->self_warp != NULL ){
+      if( dset->self_warp != NULL ){
 STATUS("setting parent_to_child_warp to self_warp") ;
-          parent_to_child_warp = *(dset->self_warp) ;  /* 26 Aug 2002 */
-        } else {
+        parent_to_child_warp = *(dset->self_warp) ;  /* 26 Aug 2002 */
+      } else {
 STATUS("setting parent_to_child_warp to IDENTITY_WARP") ;
-          parent_to_child_warp = IDENTITY_WARP ;  /* use identity warp */
-        }
-     }
+        parent_to_child_warp = IDENTITY_WARP ;  /* use identity warp */
+      }
    }
 
    /*----- make the voxel-to-voxel warp, if needed -----*/
@@ -318,24 +270,25 @@ STATUS("copying new voxwarp into dataset") ;
       }
    }
 
+   if( DSET_ARRAY(parent_dset,ival) == NULL ){  /* reload from disk */
+      Boolean good ;
+      good = THD_load_datablock( parent_dset->dblk ) ;
+      if( ! good ){
+STATUS("couldn't load parent dataset!") ;
+         mri_free(newim) ;
+         RETURN(NULL) ;  /* couldn't load data --> return nothing */
+      }
+   }
+
    /* 05 Sep 2006: substitution of volume edited brick, if available */
 
    if( parent_dset == dset && do_vedit ){
 STATUS("substituting vedim in dset") ;
      bar = mri_data_pointer(dset->dblk->vedim) ;
-     if( bar == NULL ) ERROR_message("vedim array is NULL!?") ;
-   }
-
-   if( bar == NULL ){
-     if( DSET_ARRAY(parent_dset,ival) == NULL ){  /* reload from disk */
-        RwcBoolean good ;
-        good = THD_load_datablock( parent_dset->dblk ) ;
-        if( ! good ){
-STATUS("couldn't load parent dataset!") ;
-           mri_free(newim) ;
-           RETURN(NULL) ;  /* couldn't load data --> return nothing */
-        }
+     if( bar == NULL ){
+       ERROR_message("vedim array is NULL!?"); bar = DSET_ARRAY(dset,ival);
      }
+   } else {
 STATUS("setting brick from which to extract data") ;
      bar = DSET_ARRAY(parent_dset,ival) ;  /* default brick to use */
    }
@@ -992,8 +945,6 @@ STATUS("scaling slice to floats") ;
    A version of FD_brick_to_mri that allows on-the-fly warping.
    25 Jul 2001 -- moved the flipping stuff to new function
    AFNI_slice_flip() -- RWCox
-     ** This function is how AFNI gets a slice for **
-     ** display, resampled to the underlay grid.   **
 ---------------------------------------------------------------*/
 
 MRI_IMAGE * FD_warp_to_mri( int kslice , int ival , FD_brick * br )
