@@ -1,5 +1,5 @@
 /*------------------------------------------------------------------------*/
-/*---- AFNI Image Viewer - quick adaptation from afni_plugin.c stuff. ----*/
+/*--- AFNI Image Viewer - quicky adaptation from afni_plugin.c stuff. ----*/
 /*------------------------------------------------------------------------*/
 
 #include "mrilib.h"
@@ -27,7 +27,7 @@ static void   AIVVV_imseq_retitle( void * , char * ) ;
 static XtPointer AIVVV_imseq_getim( int , int , XtPointer ) ;
 static void AIVVV_imseq_send_CB( MCW_imseq * , XtPointer , ISQ_cbs * ) ;
 static void AIVVV_imseq_addto( MRI_IMAGE *im ) ;  /* 25 Jul 2005 */
-static RwcBoolean AIVVV_workproc( XtPointer ) ;      /* 25 Jul 2005 */
+static Boolean AIVVV_workproc( XtPointer ) ;      /* 25 Jul 2005 */
 static void AIVVV_niml_quitter( char *, NI_stream , NI_element * ) ;
 
 /*------------------------------------------------------------------------*/
@@ -106,7 +106,7 @@ ENTRY("timeout_CB") ;
 
 int main( int argc , char *argv[] )
 {
-   int ii , quiet=0, verb=0 , iarg=1 , jj , dopad=0 , xpad=0,ypad=0 ;
+   int ii , quiet = 0, verb=0 , iarg=1 , jj ;
    MRI_IMAGE *im ;     /* 1 input image */
    MRI_IMARR *qar ;    /* all input images */
    Widget shell ;
@@ -115,13 +115,9 @@ int main( int argc , char *argv[] )
    if( argc < 2 || strcmp(argv[1],"-help") == 0 ){
      printf(
       "Usage: aiv [-v] [-q] [-title] [-p xxxx ] image ...\n"
-      "\n"
       "AFNI Image Viewer program.\n"
-      "\n"
       "Shows the 2D images on the command line in an AFNI-like image viewer.\n"
-      "\n"
       "Can also read images in NIML '<MRI_IMAGE...>' format from a TCP/IP socket.\n"
-      "\n"
       "Image file formats are those supported by to3d:\n"
       " * various MRI formats (e.g., DICOM, GEMS I.xxx)\n"
       " * raw PPM or PGM\n"
@@ -129,23 +125,15 @@ int main( int argc , char *argv[] )
       " * GIF, TIFF, BMP, and PNG (if netpbm is in the path)\n"
       "\n"
       "The '-v' option will make aiv print out the image filenames\n"
-      "  as it reads them - this can be a useful progress meter if\n"
-      "  the program starts up slowly.\n"
+      "as it reads them - this can be a useful progress meter if\n"
+      "the program starts up slowly.\n"
       "\n"
       "The '-q' option tells the program to be very quiet.\n"
       "\n"
-      "The '-pad' option tells the program to pad all input images\n"
-      " (from the command line) to be the same size.\n"
-      " Images that are much smaller than the largest image will\n"
-      " also be inflated somewhat so as not to look tiny.\n"
-      "In the form '-pad X Y', where 'X' and 'Y' are integers >= 64,\n"
-      " then all images will be resized to fit inside those dimensions.\n"
-      "\n"
       "The '-title WORD' option titles the window WORD. \n"
       "The default is the name of the image file if only one is \n"
       "specified on the command line. If many images are read in\n"
       "the default window title is 'Images'.\n"
-      "\n"
       "The '-p xxxx' option will make aiv listen to TCP/IP port 'xxxx'\n"
       "for incoming images in the NIML '<MRI_IMAGE...>' format.  The\n"
       "port number must be between 1024 and 65535, inclusive.  For\n"
@@ -176,7 +164,7 @@ int main( int argc , char *argv[] )
       "NI_stream_writestring( ns , \"<ni_do ni_verb='QUIT'>\" ) ;\n"
       "NI_stream_close( ns ) ;  /* do this, or the above, if done with aiv */\n"
       "\n"
-      "-- Authors: RW Cox and DR Glen\n"
+      "-- Author: RW Cox\n"
      ) ;
      PRINT_COMPILE_DATE ; exit(0) ;
    }
@@ -192,24 +180,15 @@ int main( int argc , char *argv[] )
             ERROR_message("Need a string after -title");
             /* ignore option */
          } else {
-            snprintf(wintit,128*sizeof(char),"%s", argv[++iarg]);
+            snprintf(wintit,128*sizeof(char),"%s", argv[++iarg]); 
          }
-         iarg++; continue;
-     }
+         iarg++; continue; 
+     } 
      /*-- verbosity --*/
 
      if( strncmp(argv[iarg],"-v",2) == 0 ){ verb=1; iarg++; continue; }
      if( strncmp(argv[iarg],"-q",2) == 0 ){ quiet=1; iarg++; continue; }
-
-     if( strcmp(argv[iarg],"-pad") == 0 ){  /* 02 Nov 2017 */
-       dopad++ ;
-       if( iarg+2 < argc && isdigit(argv[iarg+1][0]) && isdigit(argv[iarg+2][0]) ){
-         xpad = (int)strtod(argv[++iarg],NULL) ; if( xpad < 64 || xpad > 6666 ) xpad = 0 ;
-         ypad = (int)strtod(argv[++iarg],NULL) ; if( ypad < 64 || ypad > 6666 ) ypad = 0 ;
-       }
-       iarg++ ; continue ;
-     }
-
+      
      /*-- port or sherry? --*/
 
      if( strncmp(argv[iarg],"-p",2) == 0 ){
@@ -239,9 +218,10 @@ int main( int argc , char *argv[] )
 
      /*-- WTF? --*/
 
-     ERROR_exit("Unknown option: %s",argv[iarg]) ;
+     ERROR_message("Unknown option: %s",argv[iarg]) ;
    }
-   if (!quiet) { PRINT_VERSION("aiv") ; }
+   if (!quiet) { PRINT_VERSION("aiv") ; } 
+   
 
    /* glob filenames, read images */
 
@@ -278,17 +258,7 @@ int main( int argc , char *argv[] )
 
      for( jj=0 ; jj < IMARR_COUNT(qar) ; jj++ ){
        im = IMARR_SUBIM(qar,jj) ;
-       if( im != NULL && im->nx > 1 && im->ny > 1 ){
-         if( im->nx > 6666 || im->ny > 6666 ){ /* no big images [03 Nov 2017] */
-           float sx,sy ; MRI_IMAGE *qim ;
-           sx = (im->nx > 6000) ? im->nx/6000.0f : 1.0f ;
-           sy = (im->ny > 6000) ? im->ny/6000.0f : 1.0f ;
-           sx = MIN(sx,sy) ;
-           qim = mri_resize( im , (int)(sx*im->nx) , (int)(sx*im->ny) ) ;
-           if( qim != NULL ){ mri_free(im) ; im = qim ; }
-         }
-         ADDTO_IMARR(MAIN_imar,im);
-       }
+       if( im != NULL && im->nx > 1 && im->ny > 1 ) ADDTO_IMARR(MAIN_imar,im);
      }
      FREE_IMARR(qar) ;  /* just FREE, not DESTROY */
    }
@@ -297,73 +267,16 @@ int main( int argc , char *argv[] )
 
    if( IMARR_COUNT(MAIN_imar) == 0 && AIVVV_stream==(NI_stream)NULL )
      ERROR_exit("No images found on command line!?") ;
-
-   if( !quiet && IMARR_COUNT(MAIN_imar) > 0 ){
-     fprintf(stderr, (verb) ? " = " : "++ " ) ;
-     if( IMARR_COUNT(MAIN_imar) == 1 )fprintf(stderr,"1 image\n") ;
-     else fprintf(stderr,"%d images\n",IMARR_COUNT(MAIN_imar)) ;
+   if( IMARR_COUNT(MAIN_imar) > 0 ){
+     if (!quiet) fprintf(stderr, (verb) ? " = " : "++ " ) ;
+     if( IMARR_COUNT(MAIN_imar) == 1 )
+       if (!quiet) fprintf(stderr,"1 image\n") ;
+     else
+       if (!quiet) fprintf(stderr,"%d images\n",IMARR_COUNT(MAIN_imar)) ;
    }
 
    if( gnim > 0 ) MCW_free_expand( gnim , gname ) ;
 
-   /*----- padding? [02 Nov 2017] -----*/
-
-   if( dopad && IMARR_COUNT(MAIN_imar) > 1 ){
-     int nxtop=0,nytop=0, nx,ny, bx,tx,by,ty, fx,fy ; MRI_IMAGE *qim ;
-     float sx,sy ; char mark='\0'; int xfin,yfin ;
-
-     if( !quiet ) fprintf(stderr,"++ padding ") ;
-     for( ii=0 ; ii < IMARR_COUNT(MAIN_imar) ; ii++ ){
-       im = IMARR_SUBIM(MAIN_imar,ii) ;
-       if( im != NULL ){ nxtop = MAX(nxtop,im->nx); nytop = MAX(nytop,im->ny); }
-     }
-     if( xpad > 0 && ypad > 0 ){ xfin = xpad ; yfin = ypad ; }
-     else                      { xfin = nxtop; yfin = nytop; }
-     for( ii=0 ; ii < IMARR_COUNT(MAIN_imar) ; ii++ ){
-       im = IMARR_SUBIM(MAIN_imar,ii) ;
-       nx = im->nx ; ny = im->ny ; mark = '\0' ;
-       if( xpad > 0 && ypad > 0 ){
-         if( nx == xpad && ny == ypad ) continue ;
-         sx = (float)(xpad) / (float)(nx) ;
-         sy = (float)(ypad) / (float)(ny) ; sx = MIN(sx,sy) ;
-         qim = mri_resize( im , (int)(sx*nx) , (int)(sx*ny) ) ;
-         if( qim != NULL ){ mri_free(im) ; im = qim ; }
-         nx = im->nx ; ny = im->ny ;
-         mark = '*' ;
-       } else {
-         if( nx >= nxtop && ny >= nytop ) continue ;
-         if( nx <= 2     || ny <= 2     ) continue ;
-         sx = (float)(nxtop) / (float)(nx) ;
-         sy = (float)(nytop) / (float)(ny) ; sx = MIN(sx,sy) ;
-         fx = (int)sx; fy = (int)sy; fx = MIN(fx,fy) ;
-         if( fx > 2 && dopad == 1 ){
-           qim = mri_dup2D(fx,im) ;
-           if( qim != NULL ){ mri_free(im) ; im = qim ; }
-           nx = im->nx ; ny = im->ny ;
-           mark = '+' ;
-         } else if( sx > 1.1f ){
-           qim = mri_resize( im , (int)(sx*nx) , (int)(sx*ny) ) ;
-           if( qim != NULL ){ mri_free(im) ; im = qim ; }
-           nx = im->nx ; ny = im->ny ;
-           mark = '*' ;
-         }
-       }
-       if( nx < xfin ){ bx = (xfin-nx)/2 ; tx = xfin-nx-bx ; }
-       else           { bx = tx = 0 ; }
-       if( ny < yfin ){ by = (yfin-ny)/2 ; ty = yfin-ny-by ; }
-       else           { by = ty = 0 ; }
-       if( bx > 0 || tx > 0 || by > 0 || ty > 0 ){
-         qim = mri_zeropad_2D( bx,tx , by,ty , im ) ;
-         if( qim != NULL ){ mri_free(im) ; im = qim ; }
-         if( mark == '\0' ) mark = '.' ;
-       }
-       IMARR_SUBIM(MAIN_imar,ii) = im ;
-       if( !quiet ) fprintf(stderr,"%c",mark) ;
-     }
-     if( !quiet ) fprintf(stderr,"!\n") ;
-
-   } /*----- end of padding ----*/
-
    /* connect to X11 */
 
    shell = XtVaAppInitialize( &MAIN_app , "AFNI" , NULL , 0 ,
@@ -485,7 +398,6 @@ ENTRY("AIVVV_imseq_popup") ;
                      "v/V = Video image sequence up/down\n"
                      "r/R = Ricochet image sequence up/down\n"
                      "i/I = image fraction down/up\n"
-                     "e = toggle edge detection in image\n"
                    ) ;
 
    RETURN( (void *)psq ) ;
@@ -640,7 +552,7 @@ ENTRY("AIVVV_imseq_addto") ;
    appear.
 -----------------------------------------------------------------------------*/
 
-static RwcBoolean AIVVV_workproc( XtPointer fred )
+static Boolean AIVVV_workproc( XtPointer fred )
 {
    int nn ;
    NI_element *nel ;
