@@ -31,8 +31,6 @@
 #include "display.h"
 #include "xutil.h"
 #include "mrilib.h"
-#include "coxplot.h"
-#include "niml.h"
 
 #ifndef LABEL_ARG
 #define LABEL_ARG(str) \
@@ -66,15 +64,13 @@ typedef struct {
 extern "C" {
 #endif
 
-extern MCW_bbox * new_MCW_bbox( Widget , int , char *lab[] , int , int ,
+extern MCW_bbox * new_MCW_bbox( Widget , int , char * lab[] , int , int ,
                                 XtCallbackProc , XtPointer ) ;
 
 extern void MCW_set_bbox( MCW_bbox * , int ) ;
 extern int  MCW_val_bbox( MCW_bbox * ) ;
 extern void MCW_bbox_hints( MCW_bbox * , int , char ** ) ;
 
-extern void BBOX_set_wsubtype( char *wt ) ;  /* Feb 2012 */
-
 /*---------------------------------------------------------------------------------*/
 /***--- for arrowval ---***/
 
@@ -89,7 +85,6 @@ typedef char * str_func() ;
 typedef struct {
       Widget wrowcol ,                   /* Container */
              wlabel , wdown,wup , wtext ;/* left-to-right widgets */
-      Widget wname ;
 
       Widget wmenu ;                     /* for optmenu style only! */
       int block_assign_actions ;
@@ -97,7 +92,7 @@ typedef struct {
       int ival , imin,imax , decimals ;  /* value, min & max, decim shift */
       float fval , fmin,fmax ;           /* float values (includes decim) */
 
-      char *sval ;        /* current string value from TextField */
+      char * sval ;        /* current string value from TextField */
 
       int old_ival ;       /* values just before the last change */
       float old_fval ;
@@ -118,7 +113,7 @@ typedef struct {
 
       XtPointer parent , aux ;
 
-      float fstep ;                    /* 16 Feb 1999 */
+      float fstep ;  /* 16 Feb 1999 */
       int optmenu_call_if_unchanged ;  /* 10 Oct 2007 */
 } MCW_arrowval ;
 
@@ -191,7 +186,7 @@ extern void AV_assign_ival( MCW_arrowval * , int ) ;
 extern void AV_assign_fval( MCW_arrowval * , float ) ;
 extern void AV_textact_CB( Widget , XtPointer , XtPointer ) ;
 
-extern void AV_leave_EV( Widget , XtPointer , XEvent * , RwcBoolean * ) ;
+extern void AV_leave_EV( Widget , XtPointer , XEvent * , Boolean * ) ;
 
 char * AV_default_text_CB( MCW_arrowval * , XtPointer ) ;
 
@@ -216,7 +211,7 @@ extern char * MCW_av_substring_CB( MCW_arrowval * , XtPointer ) ;
     when simply using XtSetSensitive on av->wrowcol ) */
 
 #define AV_SENSITIZE(av,sss)                                    \
-   do{ RwcBoolean sen = (RwcBoolean) sss ;                            \
+   do{ Boolean sen = (Boolean) sss ;                            \
        if( av != NULL ) {                                       \
       int exp = (XtIsSensitive(av->wrowcol) != sen) ;           \
       if( av->wlabel != NULL ) XtSetSensitive(av->wlabel ,sen); \
@@ -239,37 +234,22 @@ extern char * MCW_av_substring_CB( MCW_arrowval * , XtPointer ) ;
 
 /*---------------------------------------------------------------------------------*/
 
-#define MSTUF_END     0
-#define MSTUF_NONE    0
-#define MSTUF_INT     1
-#define MSTUF_INTEGER 1
-#define MSTUF_STRING  2
-#define MSTUF_STRLIST 3
-#define MSTUF_YESNO   4
-
 #define POPDOWN_ovcolor_chooser    MCW_choose_ovcolor(NULL,NULL,0,NULL,NULL)
 #define POPDOWN_string_chooser     MCW_choose_string(NULL,NULL,NULL,NULL,NULL)
 #define POPDOWN_strlist_chooser    MCW_choose_strlist(NULL,NULL,0,0,NULL,NULL,NULL)
 #define POPDOWN_integer_chooser    MCW_choose_integer(NULL,NULL,0,0,0,NULL,NULL)
 #define POPDOWN_timeseries_chooser MCW_choose_timeseries(NULL,NULL,NULL,0,NULL,NULL)
 #define POPDOWN_vector_chooser     MCW_choose_vector(NULL,NULL,0,NULL,NULL,NULL,NULL)
-#define POPDOWN_tcsv_chooser       MCW_choose_tcsv(NULL,NULL,NULL,0,NULL,NULL)
 
 #define POPDOWN_editable_strlist_chooser \
                                    MCW_choose_editable_strlist(NULL,NULL,NULL,0,NULL,NULL)
 
-#define POPDOWN_stuff_chooser      MCW_choose_stuff(NULL,NULL,NULL,NULL,0)
-
 extern void MCW_list_mode_CB( MCW_arrowval * , XtPointer ) ;
 
 extern char * MCW_DC_ovcolor_text( MCW_arrowval * , MCW_DC * ) ;
 extern void   MCW_choose_ovcolor( Widget , MCW_DC * , int , gen_func * , XtPointer ) ;
 extern void   MCW_choose_CB( Widget , XtPointer , XtPointer ) ;
 
-extern void MCW_choose_stuff( Widget wpar , char *mainlabel ,
-                              gen_func *func , XtPointer func_data , ... ) ;
-extern void MCW_stuff_CB( Widget w , XtPointer client_data , XtPointer call_data ) ;
-
 extern void   MCW_destroy_chooser_CB( Widget , XtPointer , XtPointer ) ;
 extern void   MCW_kill_chooser_CB   ( Widget , XtPointer , XtPointer ) ;
 
@@ -282,31 +262,25 @@ extern void   MCW_choose_vector ( Widget, char *,
 extern MCW_arrowval ** MCW_choose_vector_avarray( int *nav ) ; /* Aug 2010 */
 
 extern void   MCW_choose_string ( Widget, char *,
-                                  char *, gen_func *, XtPointer ) ;
+                                  char *, gen_func *, XtPointer );
 
 extern void   MCW_choose_strlist( Widget, char *, int, int,
-                                  char * strlist[], gen_func *, XtPointer ) ;
-
-extern void   MCW_choose_binary ( Widget, char *, int, char *, char *,
-                                  gen_func *, XtPointer ) ; /* 10 Feb 2012 */
+                                  char * strlist[], gen_func *, XtPointer );
 
 extern void   MCW_choose_multi_strlist( Widget, char *, int,
                                         int, int *, char * strlist[],
-                                        gen_func *, XtPointer  ) ;
+                                        gen_func *, XtPointer  );
 
 extern void   MCW_choose_timeseries( Widget, char *, MRI_IMARR *,
-                                     int, gen_func *, XtPointer ) ;
-
-extern void   MCW_choose_tcsv      ( Widget , char *, NI_ELARR *,
-                                     int , gen_func *, XtPointer ) ;
+                                     int, gen_func *, XtPointer );
 
 extern void MCW_choose_editable_strlist( Widget, char *,
                                          THD_string_array *,
-                                         int, gen_func *, XtPointer ) ;
+                                         int, gen_func *, XtPointer );
 
 extern void MCW_choose_multi_editable_strlist( Widget, char *, int,
                                                THD_string_array *,
-                                               int *, gen_func *, XtPointer ) ;
+                                               int *, gen_func *, XtPointer );
 
 extern void MCW_stradd_CB( Widget , XtPointer , XtPointer ) ;
 
@@ -336,7 +310,6 @@ typedef struct {
 #define mcwCT_string     703
 #define mcwCT_timeseries 707
 #define mcwCT_vector     708  /* 19 Mar 2004 */
-#define mcwCT_tcsv       709  /* 17 Jun 2020 */
 
 #define mcwCT_single_mode 222
 #define mcwCT_multi_mode  223
@@ -363,7 +336,6 @@ typedef struct {
 #define mcwCR_string     203
 #define mcwCR_timeseries 207
 #define mcwCR_vector     208  /* 19 Mar 2004 */
-#define mcwCR_tcsv       209  /* 17 Jun 2020 */
 
 /*---------------------------------------------------------------------------------*/
 /*---- arrowpad stuff ----*/
@@ -417,7 +389,7 @@ extern void AP_timer_CB( XtPointer , XtIntervalId * ) ;
 /*! toggle sensitivity of an arrowpad */
 
 #define AP_SENSITIZE(ap,sss)                            \
-   do{ RwcBoolean sen = (RwcBoolean) sss ;                    \
+   do{ Boolean sen = (Boolean) sss ;                    \
        if( ap != NULL ) {                               \
         int exp = (XtIsSensitive(ap->wform) != sen) ;   \
         XtSetSensitive(ap->wbut[0],sen);                \
