@@ -86,8 +86,8 @@ void set_memplot_X11_rectfill( int i ){ rectfill = i ; }  /* 26 Oct 2005 */
 /*! Get the layout of a window/pixmap.  [12 Mar 2002]
 --------------------------------------------------------------------------*/
 
-void drawable_geom( Display *dpy , Drawable ddd ,
-                    int *width , int *height , int *depth )
+static void drawable_geom( Display *dpy , Drawable ddd ,
+                           int *width , int *height , int *depth )
 {
    int xx,yy ;
    unsigned int ww,hh,bb,dd ;
@@ -100,72 +100,6 @@ void drawable_geom( Display *dpy , Drawable ddd ,
    if( depth  != NULL ) *depth  = dd ;
 }
 
-/*--------------------------------------------------------------------------*/
-
-static void (*memplot_to_X11_substitute_function)() = NULL ;
-
-void memplot_to_X11_set_substitute( void (*msf)() )
-{
-   memplot_to_X11_substitute_function = msf ;
-   return ;
-}
-
-void * memplot_to_X11_get_substitute(void)
-{
-   return (void *)memplot_to_X11_substitute_function ;
-}
-
-/*--------------------------------------------------------------------------*/
-
-static void (*memplot_XDrawLines_substitute_function)() = NULL ;
-
-void memplot_XDrawLines_set_substitute( void (*msf)() )
-{
-   memplot_XDrawLines_substitute_function = msf ;
-   return ;
-}
-
-void * memplot_XDrawLines_get_substitute(void)
-{
-   return (void *)memplot_XDrawLines_substitute_function ;
-}
-
-/*--------------------------------------------------------------------------*/
-
-static int   nxdlist = 0 ;
-static XID   *xdlist = NULL ;
-static void **xdfunc = NULL ;
-
-static void addto_xdlist( XID xd , void *fn )
-{
-   int ii ;
-
-   if( fn == NULL ) return ;
-
-   for( ii=0 ; ii < nxdlist ; ii++ ){
-     if( xdlist[ii] == xd ){
-       xdfunc[ii] = fn ; return ;
-/* INFO_message("window ID %u reset substitute to %p",(unsigned int)xd,fn) ; */
-     }
-   }
-
-   xdlist = (XID *)  realloc(xdlist,sizeof(XID)    *(nxdlist+1)) ;
-   xdfunc = (void **)realloc(xdfunc,sizeof(void **)*(nxdlist+1)) ;
-   xdlist[nxdlist] = xd ;
-   xdfunc[nxdlist] = fn ;
-/* INFO_message("window ID %u gets substitute %p",(unsigned int)xd,fn) ; */
-   nxdlist++ ; return ;
-}
-
-static void * findin_xdlist( XID xd )
-{
-   int ii ; void *fp=NULL ;
-   for( ii=0 ; ii < nxdlist ; ii++ )
-     if( xdlist[ii] == xd ){ fp =xdfunc[ii] ; break ; }
-/* INFO_message("find window ID %u has substitute %p",(unsigned int)xd,fp) ; */
-   return fp ;
-}
-
 /*--------------------------------------------------------------------------
   Actually do the rendering.
   Plotting will start with line #start and go to #end-1.
@@ -187,7 +121,7 @@ static int      nseg = 0 ;    /* number in the buffer */
 
 static void draw_xseg(void) ; /* prototype for function below */
 
-void memplot_to_X11_sef( Display *dpy , Window w , MEM_plotdata *mp ,
+void memplot_to_X11_sef( Display * dpy , Window w , MEM_plotdata * mp ,
                          int start , int end , int mask                )
 {
    int ii , nline , same ;
@@ -197,14 +131,13 @@ void memplot_to_X11_sef( Display *dpy , Window w , MEM_plotdata *mp ,
    int skip ;
    int w_width, w_height, w_depth ;  /* 12 Mar 2002 */
    XGCValues gcv ;
-   void *xdf ;
 
    int freee = (mask & MEMPLOT_FREE_ASPECT) != 0 ;  /* 16 Nov 2001 */
    int erase = (mask & MEMPLOT_ERASE      ) != 0 ;
 
    /*--- check for madness ---*/
 
-   if( dpy == NULL || w == (Window)0 || mp == NULL ) return ;
+   if( dpy == NULL || w == (Window) 0 || mp == NULL ) return ;
    if( start < 0 ) start = 0 ;
 
    nline = MEMPLOT_NLINE(mp) ;
@@ -212,24 +145,6 @@ void memplot_to_X11_sef( Display *dpy , Window w , MEM_plotdata *mp ,
 
    if( end <= start || end > nline ) end = nline ;
 
-   /* 30 Apr 2012 -- check if we call some other function */
-
-   if( memplot_to_X11_substitute_function != NULL ){
-     addto_xdlist( (XID)w , (void *)memplot_to_X11_substitute_function ) ;
-/* ININFO_message("calling substitute") ; */
-     memplot_to_X11_substitute_function(dpy,w,mp,start,end,mask) ;
-     /* XSync(dpy,False) ; */
-     memplot_to_X11_substitute_function = NULL ;
-     return ;
-   }
-   xdf = findin_xdlist( (XID)w ) ;
-   if( xdf != NULL ){
-     void (*fp)() = (void (*)())xdf ;
-/* ININFO_message("re-calling substitute") ; */
-     fp(dpy,w,mp,start,end,mask) ;
-     return ;
-   }
-
    /*-- if we have a new X11 Display, get its coloring
         (note the tacit assumption that all windows on the same
          display in the same program will use the same visual and colormap!) --*/
@@ -280,8 +195,7 @@ void memplot_to_X11_sef( Display *dpy , Window w , MEM_plotdata *mp ,
 
    gcv.line_width = 0 ;
    gcv.join_style = JoinBevel ;
-   gcv.cap_style  = CapButt ;
-   XChangeGC( old_dpy , old_GC , GCLineWidth | GCJoinStyle | GCCapStyle , &gcv ) ;
+   XChangeGC( old_dpy , old_GC , GCLineWidth | GCJoinStyle , &gcv ) ;
 
    /*--- loop over lines, scale and plot ---*/
 
@@ -313,7 +227,6 @@ fprintf(stderr,"Changing color to %f %f %f\n",rr,gg,bb) ;
          int thc = (int)(-new_thick) ;
          switch( thc ){  /* default is to do nothing (e.g., thd = THCODE_INVALID) */
 
-            case THCODE_FRECT:
             case THCODE_RECT:{        /* rectangle */
                short xb,yb , xt,yt ;
                unsigned short w,h ;
@@ -325,7 +238,7 @@ fprintf(stderr,"Changing color to %f %f %f\n",rr,gg,bb) ;
                if( y1 < y2 ){ yb=y1; yt=y2; } else { yb=y2; yt=y1; }
                w = xt-xb ; h = yt-yb ;
                if( w || h ){
-                 if( rectfill || thc == THCODE_FRECT )
+                 if( rectfill )
                    XFillRectangle( old_dpy,old_w,old_GC , xb,yb,w,h ) ;
                  else
                    XDrawRectangle( old_dpy,old_w,old_GC , xb,yb,w,h ) ;
@@ -369,8 +282,7 @@ fprintf(stderr,"Changing thickness: old=%f  new=%f\n",old_thick,new_thick) ;
 
          gcv.line_width = lw ;
          gcv.join_style = JoinBevel ;
-         gcv.cap_style  = (lw > 2) ? CapRound : CapButt ;
-         XChangeGC( old_dpy , old_GC , GCLineWidth | GCJoinStyle | GCCapStyle , &gcv ) ;
+         XChangeGC( old_dpy , old_GC , GCLineWidth | GCJoinStyle , &gcv ) ;
          old_thick = new_thick ;
       }
 
@@ -396,12 +308,6 @@ fprintf(stderr,"Changing thickness: old=%f  new=%f\n",old_thick,new_thick) ;
 
    draw_xseg() ;
    set_memplot_X11_box(0,0,0,0) ; /* 26 Feb 2001: clear box */
-
-   gcv.line_width = 0 ;
-   gcv.join_style = JoinBevel ;
-   gcv.cap_style  = CapButt ;
-   XChangeGC( old_dpy , old_GC , GCLineWidth | GCJoinStyle | GCCapStyle , &gcv ) ;
-
    return ;
 }
 
@@ -453,12 +359,7 @@ for( ii=0 ; ii < nseg ; ii++ )
          for( ii=0 ; ii < nj ; ii++ ){
             xpt[ii+1].x = xseg[jbot+ii].x2 ; xpt[ii+1].y = xseg[jbot+ii].y2 ;
          }
-         if( memplot_XDrawLines_substitute_function != NULL ){  /* 30 Aug 2021 */
-           memplot_XDrawLines_substitute_function(
-             old_dpy,old_w,old_GC , xpt,nj+1 , CoordModeOrigin , 4 ) ;
-         } else {
-           XDrawLines( old_dpy,old_w,old_GC , xpt,nj+1 , CoordModeOrigin ) ;
-        }
+         XDrawLines( old_dpy,old_w,old_GC , xpt,nj+1 , CoordModeOrigin ) ;
 
 #if 0
 fprintf(stderr,"draw_xseg: XDrawLines for %d\n",nj) ;
@@ -739,9 +640,4 @@ Window getwin_from_XDBE( Display * dpy , Drawable w )
    if( bw == (Window) 0 ) bw = w ;
    return bw ;
 }
-
-static int XDBE_suspended = 0 ;
-
-int  get_XDBE_suspension(int i){ return XDBE_suspended ; }
-void set_XDBE_suspension(int i){ XDBE_suspended = i ; return ; }
 #endif  /* HAVE_XDBE */
