@@ -6,43 +6,6 @@
 
 #include "mrilib.h"
 
-/*------------------------------------------------------------------------*/
-
-float qmean_float( int n , float *ar )
-{
-   int ii ; float sum=0.0f ;
-
-   if( n <= 0 || ar == NULL ) return sum ;
-
-   for( ii=0 ; ii < n ; ii++ ) sum += ar[ii] ;
-   sum /= n ; return sum ;
-}
-
-
-/*------------------------------------------------------------------------
-    Compute non-zero mean of an array of floats 
--------------------------------------------------------------------------*/
-
-float qnzmean_float( int n , float *ar )
-{
-   int ii ; float sum=0.0f, v ;
-   int ngood = 0;
-
-   if( n <= 0 || ar == NULL ) return sum ;
-
-   for( ii=0 ; ii < n ; ii++ ){
-	    v = ar[ii];
-	    if(v!=0.0) {
-			sum += ar[ii] ;
-			ngood++;
-	    }
-   }
-   if( ngood <=0 ) sum = 0.0f ;   /* might have no nonzero voxels */
-   else            sum /= ngood ; /* otherwise return average */
-   return sum ;
-}
-
-
 /*------------------------------------------------------------------------
    Compute the median of an array of floats.  Will rearrange (partially
    sort) the array in the process.  The algorithm is based on Quicksort,
@@ -54,7 +17,6 @@ static float median_float4(float,float,float,float) ;
 static float median_float5(float *) ;  /* 5,7,9 added 20 Oct 2000 */
 static float median_float7(float *) ;
 static float median_float9(float *) ;
-static float median_float25(float *) ;
 
 /* macro for median-of-3 */
 
@@ -78,7 +40,6 @@ float qmed_float( int n , float *ar )
    /* special cases */
 
    switch( n ){
-      case 0: return 0.0f ;  /* should not happen */
       case 1: return ar[0] ;
       case 2: return 0.5*(ar[0]+ar[1]) ;
       case 3: return MED3( ar[0] , ar[1] , ar[2] ) ;
@@ -86,7 +47,6 @@ float qmed_float( int n , float *ar )
       case 5: return median_float5( ar ) ;
       case 7: return median_float7( ar ) ;
       case 9: return median_float9( ar ) ;
-      /*** case 25: return median_float25( ar ) ; ***/
    }
 
    /* general case */
@@ -146,86 +106,6 @@ float qmed_float( int n , float *ar )
    return (nodd) ? a[mid] : 0.5*(a[mid]+a[mid-1]) ;
 }
 
-/*-------------------------------------------------------------------------*/
-/* find the modal value in a list of numbers
-   mostly useful for integers, but not limiting here.
-   doing this brute force for now */
-
-float qmode_float( int n , float *ar )
-{
-   register int i , j ;           /* scanning indices */
-   register float temp, mode ;
-   register float *a = ar, *b;
-   register int cnt, maxcnt ;
-
-   /* no values, get out of here */
-   if (n==0) return(0.0f);
-
-
-   /* general case */
-   maxcnt = 0; mode = -9999;
-   for(i=0;i<n;i++) {
-      temp = *a++;    /* value in list */
-      if(temp==mode) continue;   /* same value as the mode already, skip to next */
-      b = a;
-      cnt = 1;   /* the value itself is the first time in the list */
-      /* count how many times that number occurs in the rest of the list */
-      for(j=i+1;j<n;j++){  /* only have to check remaining values*/
-         if(temp==*b++)
-            cnt++;
-      }
-
-      /* new mode value if value shows up more than the previous mode */
-      if(cnt>maxcnt) {
-         maxcnt = cnt;
-         mode = temp;
-      }
-   }
-
-   return(mode) ;
-}
-
-/*-------------------------------------------------------------------------*/
-/* find the non-zero modal value in a list of numbers
-   mostly useful for integers, but not limiting here.
-   doing this brute force for now */
-
-float qnzmode_float( int n , float *ar )
-{
-   register int i , j ;           /* scanning indices */
-   register float temp, mode ;
-   register float *a = ar, *b;
-   register int cnt, maxcnt ;
-
-   /* no values, get out of here */
-   if (n==0) return(0.0f);
-
-   /* general case */
-   maxcnt = 0; mode = -9999;
-   for(i=0;i<n;i++) {
-      temp = *a++;    /* value in list */
-      if((temp==mode)||(temp==0)) continue;   /* ignore zero or current mode value */
-      b = a;
-      cnt = 1;   /* the value itself is the first time in the list */
-      /* count how many times that number occurs in the rest of the list */
-      for(j=i+1;j<n;j++){  /* only have to check remaining values*/
-         if(temp==*b++)
-            cnt++;
-      }
-
-      /* new mode value if value shows up more than the previous mode */
-      if(cnt>maxcnt) {
-         maxcnt = cnt;
-         mode = temp;
-      }
-   }
-
-   /* if didn't find anything non-zero,return 0.0 */
-   if(maxcnt==0) return(0.0f);
-   /* normal case - return mode */
-   return(mode) ;
-}
-
 /*---------------------------------------------------------------
   Return mean and sigma of a float array -- 07 Dec 2006
 -----------------------------------------------------------------*/
@@ -266,7 +146,8 @@ void qmedmad_float( int n, float *ar, float *med, float *mad )
 
 #pragma omp critical (MALLOC)
    q = (float *)malloc(sizeof(float)*n) ;  /* workspace */
-   AAmemcpy(q,ar,sizeof(float)*n) ;  /* duplicate input array */
+#pragma omp critical (MEMCPY)
+   memcpy(q,ar,sizeof(float)*n) ;  /* duplicate input array */
    me = qmed_float( n , q ) ;      /* compute median (partially sorts q) */
 
    if( mad != NULL && n > 1 ){
@@ -298,10 +179,6 @@ void qmedmadbmv_float( int n, float *ar, float *med, float *mad, float *bmv )
 
    if( n <= 0 || ar == NULL || (med==NULL && mad==NULL && bmv==NULL) ) return;
 
-   if( med != NULL ) *med = 0.0f ; /* initialize outputs [24 Jun 2019] */
-   if( mad != NULL ) *mad = 0.0f ;
-   if( bmv != NULL ) *bmv = 0.0f ;
-
    qmedmad_float( n , ar , &lmed , &lmad ) ;
    if( med != NULL ) *med = lmed ;
    if( mad != NULL ) *mad = lmad ;
@@ -322,66 +199,24 @@ void qmedmadbmv_float( int n, float *ar, float *med, float *mad, float *bmv )
    return ;
 }
 
-/*---------------------------------------------------------------
-  Return median and MAD and mean AD -- 11 Aug 2015 - RWCox
------------------------------------------------------------------*/
-
-void qmedmadmeanad_float( int n, float *ar, float *med, float *mad , float *meanad )
-{
-   float me=0.0f , ma=0.0f , md=0.0f , *q ;
-   register int ii ;
-
-   if( (med == NULL && mad == NULL && meanad == NULL ) || n <= 0 || ar == NULL ) return ;
-
-   if( med    != NULL ) *med    = 0.0f ; /* initialize outputs [24 Jun 2019] */
-   if( mad    != NULL ) *mad    = 0.0f ;
-   if( meanad != NULL ) *meanad = 0.0f ;
-
-#pragma omp critical (MALLOC)
-   q = (float *)malloc(sizeof(float)*n) ;  /* workspace */
-   AAmemcpy(q,ar,sizeof(float)*n) ;  /* duplicate input array */
-   me = qmed_float( n , q ) ;      /* compute median (partially sorts q) */
-
-   if( (mad != NULL || meanad != NULL) && n > 1 ){
-     for( ii=0 ; ii < n ; ii++ ){   /* subtract off median */
-       q[ii] = fabsf(q[ii]-me) ;   /* (absolute deviation) */
-       md += q[ii] ;
-     }
-     md /= n ;
-     if( mad != NULL ){
-       ma = qmed_float( n , q ) ;    /* MAD = median absolute deviation */
-     }
-   }
-
-#pragma omp critical (MALLOC)
-   free(q) ;
-
-   if( med    != NULL ) *med    = me ;
-   if( mad    != NULL ) *mad    = ma ;
-   if( meanad != NULL ) *meanad = md ;
-   return ;
-}
-
 /*---------------------------------------------------------------*/
-/* mean of central 50% (or so) of array;
-   the actual number averaged is m = n-2*floor(n/4)
-   -- edited 11 Aug 2021 by RWC to change m a little
-   -- note that the sorting operation reorders array ar[],
-      so if this is not good, you'll have to supply a copy
-*//*-------------------------------------------------------------*/
 
 float centromean_float( int n , float *ar )  /* 01 Nov 2010 */
 {
-   int ii ; float sum=0.0f ;
-   int ibot , itop , m ;
+   int ibot, itop, ii ; float sum=0.0f ;
 
-   if( n <= 0 || ar == NULL ) return 0.0f ; /* bad inputs */
-
-   qsort_float( n , ar ) ;
-   ibot = n / 4 ;               /* bottom of sum range */
-   itop = n - ibot - 1 ;        /* top = symmetric */
-   for( ii=ibot ; ii <= itop ; ii++ ) sum += ar[ii] ;
-   sum /= (itop-ibot+1) ;
+   if( n <= 0 || ar == NULL ){
+    ; /* nada */
+   } else if( n < 6 ){
+     for( ii=0 ; ii < n ; ii++ ) sum += ar[ii] ;
+     sum /= n ;
+   } else {
+     qsort_float( n , ar ) ;
+     ibot = (int)(0.25f*n+0.49f) ;
+     itop = (int)(0.75f*n+0.49f) ;
+     for( ii=ibot ; ii <= itop ; ii++ ) sum += ar[ii] ;
+     sum /= (itop-ibot+1) ;
+   }
    return sum ;
 }
 
@@ -461,47 +296,6 @@ static float median_float9(float *p)
     SORT2(p[4],p[2]) ; return(p[4]) ;
 }
 
-/*--------------------------------------------------------------
- * median25(A) partitions the array A[0..24] such that element
- * A[12] is the median and subarrays A[0..11] and A[13..24]
- * are partitions containing elements of smaller and larger
- * value (rank), respectively.
- *
- * The exchange table lists element indices on the range 1..25,
- * this accounts for the "-1" offsets in the macro S2 and in
- * the final return value used to adjust subscripts to C-code
- * conventions (array indices begin at zero).
- *------- Code mildly adapted from Al Paeth's Median.c --------*
- *//*----------------------------------------------------------*/
-#undef  S2
-#define S2(i,j) if(A[i-1]>A[j-1]){temp=A[i-1];A[i-1]=A[j-1];A[j-1]=temp;}
-
-static float median_float25( float *A )
-{
-  register float temp ;
-  S2( 1, 2); S2( 4, 5); S2( 3, 5); S2( 3, 4); S2( 7, 8);
-  S2( 6, 8); S2( 6, 7); S2(10,11); S2( 9,11); S2( 9,10);
-  S2(13,14); S2(12,14); S2(12,13); S2(16,17); S2(15,17);
-  S2(15,16); S2(19,20); S2(18,20); S2(18,19); S2(22,23);
-  S2(21,23); S2(21,22); S2(24,25); S2( 3, 6); S2( 4, 7);
-  S2( 1, 7); S2( 1, 4); S2( 5, 8); S2( 2, 8); S2( 2, 5);
-  S2(12,15); S2( 9,15); S2( 9,12); S2(13,16); S2(10,16);
-  S2(10,13); S2(14,17); S2(11,17); S2(11,14); S2(21,24);
-  S2(18,24); S2(18,21); S2(22,25); S2(19,25); S2(19,22);
-  S2(20,23); S2( 9,18); S2(10,19); S2( 1,19); S2( 1,10);
-  S2(11,20); S2( 2,20); S2( 2,11); S2(12,21); S2( 3,21);
-  S2( 3,12); S2(13,22); S2( 4,22); S2( 4,13); S2(14,23);
-  S2( 5,23); S2( 5,14); S2(15,24); S2( 6,24); S2( 6,15);
-  S2(16,25); S2( 7,25); S2( 7,16); S2( 8,17); S2( 8,20);
-  S2(14,22); S2(16,24); S2( 8,14); S2( 8,16); S2( 2,10);
-  S2( 4,12); S2( 6,18); S2(12,18); S2(10,18); S2( 5,11);
-  S2( 7,13); S2( 8,15); S2( 5, 7); S2( 5, 8); S2(13,15);
-  S2(11,15); S2( 7, 8); S2(11,13); S2( 7,11); S2( 7,18);
-  S2(13,18); S2( 8,18); S2( 8,11); S2(13,19); S2( 8,13);
-  S2(11,19); S2(13,21); S2(11,21); S2(11,13);
-  return(A[13-1]);
-}
-
 /*************** General purpose sorty functions ZSS 06********************/
 
 int compare_Z_IQSORT_DOUBLE (Z_QSORT_DOUBLE *a, Z_QSORT_DOUBLE *b )
@@ -540,36 +334,6 @@ int compare_Z_IQSORT_INT (Z_QSORT_INT *a, Z_QSORT_INT *b )
    return (0);
 }
 
-int compare_Z_QSORT_INT (Z_QSORT_INT *a, Z_QSORT_INT *b )
-{
-   if (a->x < b->x)
-      return (-1);
-   else if (a->x == b->x)
-      return (0);
-   else if (a->x > b->x)
-      return (1);
-   /* this will never be reached but it will shut the compiler up */
-   return (0);
-}
-
-int compare_Z_IQSORT_STRING (Z_QSORT_STRING *a, Z_QSORT_STRING *b )
-{
-   if (!a->x && !b->x) return(0);
-   if (!a->x) return(-1);
-   if (!b->x) return(1);
-   return (strcmp(a->x, b->x));
-}
-
-int compare_string (const void *a, const void *b )
-{/* compare_string*/
-   const char **ia = (const char **)a;
-   const char **ib = (const char **)b;
-   if (!*ia && !*ib) return(0);
-   if (!*ia) return(-1);
-   if (!*ib) return(1);
-   return (strcmp(*ia, *ib));
-}
-
 int compare_double (double *a, double *b )
 {/* compare_double*/
     if (*a < *b)
@@ -710,7 +474,8 @@ void *Percentate (void *vec, byte *mm, int nxyz,
             if (!vvec) {
                ERROR_message("Failed to allocate 1."); RETURN(NULL);
             }
-            AAmemcpy(vvec, vec, nxyz*sizeof(byte));
+#pragma omp critical (MEMCPY)
+            memcpy(vvec, vec, nxyz*sizeof(byte));
             break;
          case MRI_short:
 #pragma omp critical (MALLOC)
@@ -718,7 +483,8 @@ void *Percentate (void *vec, byte *mm, int nxyz,
             if (!vvec) {
                ERROR_message("Failed to allocate 2."); RETURN(NULL);
             }
-            AAmemcpy(vvec, vec, nxyz*sizeof(short));
+#pragma omp critical (MEMCPY)
+            memcpy(vvec, vec, nxyz*sizeof(short));
             break;
          case MRI_int:
 #pragma omp critical (MALLOC)
@@ -726,7 +492,8 @@ void *Percentate (void *vec, byte *mm, int nxyz,
             if (!vvec) {
                ERROR_message("Failed to allocate 3."); RETURN(NULL);
             }
-            AAmemcpy(vvec, vec, nxyz*sizeof(int));
+#pragma omp critical (MEMCPY)
+            memcpy(vvec, vec, nxyz*sizeof(int));
             break;
          case MRI_float:
 #pragma omp critical (MALLOC)
@@ -734,7 +501,8 @@ void *Percentate (void *vec, byte *mm, int nxyz,
             if (!vvec) {
                ERROR_message("Failed to allocate 4."); RETURN(NULL);
             }
-            AAmemcpy(vvec, vec, nxyz*sizeof(float));
+#pragma omp critical (MEMCPY)
+            memcpy(vvec, vec, nxyz*sizeof(float));
             break;
          case MRI_double:
 #pragma omp critical (MALLOC)
@@ -742,7 +510,8 @@ void *Percentate (void *vec, byte *mm, int nxyz,
             if (!vvec) {
                ERROR_message("Failed to allocate 5."); RETURN(NULL);
             }
-            AAmemcpy(vvec, vec, nxyz*sizeof(double));
+#pragma omp critical (MEMCPY)
+            memcpy(vvec, vec, nxyz*sizeof(double));
             break;
          default:
             ERROR_message("Data type not supported."); RETURN(NULL);
@@ -1040,7 +809,6 @@ void *Percentate (void *vec, byte *mm, int nxyz,
 }
 
 /*----------------------------------------------------------------------*/
-/* Implementation not finished :( */
 
 float wtmed_float( int n , float *x , float *w )
 {
@@ -1066,137 +834,3 @@ float wtmed_float( int n , float *x , float *w )
 
    return 0.0f ;
 }
-
-/*------------------------------------------------------------------------*/
-
-float qfrac_float( int n , float frac , float *ar )
-{
-   int i , j ;           /* scanning indices */
-   float temp , pivot ;  /* holding places */
-   float *a=ar ;
-   float ni, fmid, ft,fb ;
-   int left, right, mid ;
-
-   /* special cases */
-
-   if( n <= 0 ) return 0.0f ;
-   if( n == 1 ) return a[0] ;
-
-   ni = 1.0f/(float)n ;
-
-   if( frac <= ni ){                    /* min */
-     temp = a[0] ;
-     for( i=1 ; i < n ; i++ ) if( temp > a[i] ) temp = a[i] ;
-     return temp ;
-   } else if( frac >= 1.0f-ni ){        /* max */
-     temp = a[0] ;
-     for( i=1 ; i < n ; i++ ) if( temp < a[i] ) temp = a[i] ;
-     return temp ;
-   } else if( fabsf(frac-0.5f) < ni ){  /* median */
-     return qmed_float(n,a) ;
-   }
-
-   fmid = frac * n - 0.5f ;
-    mid = (int)fmid ; if( mid >= n-1 ) mid = n-2 ;  /* shouldn't happen */
-     ft = fmid-mid ;
-     fb = 1.0f-ft ;
-
-   if( n <= 21 ){        /* fast sorting for small arrays */
-     qsort_float(n,a) ;
-     return (fb*a[mid]+ft*a[mid+1]) ;
-   }
-
-   /* general (longer) case */
-
-   left = 0 ; right = n-1 ;
-
-   /* loop while the subarray is at least 3 long */
-
-   while( right-left > 1  ){  /* work on subarray from left -> right */
-
-      i = ( left + right ) / 2 ;   /* middle of subarray */
-
-      /* sort the left, middle, and right a[]'s */
-
-      if( a[left] > a[i]     ) SWAP( a[left]  , a[i]     ) ;
-      if( a[left] > a[right] ) SWAP( a[left]  , a[right] ) ;
-      if( a[i] > a[right]    ) SWAP( a[right] , a[i]     ) ;
-
-      pivot = a[i] ;                 /* a[i] is the median-of-3 pivot! */
-      a[i]  = a[right] ;
-
-      i = left ;                     /* initialize scanning */
-      j = right ;
-
-      /*----- partition:  move elements bigger than pivot up and elements
-                          smaller than pivot down, scanning in from ends -----*/
-
-      do{
-        for( ; a[++i] < pivot ; ) ;  /* scan i up,   until a[i] >= pivot */
-        for( ; a[--j] > pivot ; ) ;  /* scan j down, until a[j] <= pivot */
-
-        if( j <= i ) break ;         /* if j meets i, quit */
-
-        SWAP( a[i] , a[j] ) ;
-      } while( 1 ) ;
-
-      /*----- at this point, the array is partitioned -----*/
-
-      a[right] = a[i] ;           /* restore the pivot */
-      a[i]     = pivot ;
-
-      if( i == mid ) break ;      /* good luck == hit the target exactly */
-
-      if( i <  mid ) left  = i ;  /* throw away bottom partition */
-      else           right = i ;  /* throw away top partition    */
-
-   }  /* end of while sub-array is long */
-
-   /* find smallest element in the fraction above */
-
-   temp = a[mid+1] ;
-   for( j=mid+2 ; j < n ; j++ ) if( temp > a[j] ) temp = a[j] ;
-
-#if 0
-INFO_message("qfrac(%g): fmid=%g mid=%d a[mid]=%g temp=%g",frac,fmid,mid,a[mid],temp) ;
-#endif
-
-   return (fb*a[mid]+ft*temp) ;
-}
-
-/*-------------------------------------------------------------------------*/
-/* The Mean Square Successive Difference
-   J von Neumann, RH Kent, HR Bellinson and BI Hart.
-   The Annals of Mathematical Statistics 12:153-162 (1941).
-*//*-----------------------------------------------------------------------*/
-
-float cs_mean_square_sd( int npt , float *x )
-{
-   float sum=0.0f , val ; int ii ;
-
-   if( npt < 2 || x == NULL ) return sum ;
-
-   for( ii=1 ; ii < npt ; ii++ ){
-     val = x[ii] - x[ii-1] ; sum += val*val ;
-   }
-   return (sum/(npt-1.0f)) ;
-}
-
-/*--- similar thing, but median absolute value of successive differences ---*/
-
-float cs_median_abs_sd( int npt , float *x , float *wks )
-{
-   float *dd=wks , val ; int ii ;
-
-   if( npt < 2 || x == NULL ) return 0.0f ;
-
-   if( dd == NULL ) dd = (float *)malloc(sizeof(float)*npt) ; /* local wks */
-
-   for( ii=1 ; ii < npt ; ii++ ){
-     dd[ii-1] = fabsf( x[ii] - x[ii-1] ) ;
-   }
-
-   val = qmed_float( npt-1 , dd ) ;
-   if( dd != wks ) free(dd) ;
-   return val ;
-}
