@@ -8,24 +8,14 @@
 #include <math.h>
 #include <stdlib.h>
 #include <string.h>
-#include "cs.h"
 #include "eispack.h"
-#include "Aomp.h"
 
 #ifdef isfinite
 # define IS_GOOD_FLOAT(x) isfinite(x)
 #else
 # define IS_GOOD_FLOAT(x) finite(x)
-# define isfinite finite
 #endif
 
-#undef  USE_SVDLIB
-#ifdef  USE_SVDLIB
-#include "svdlib.c"
-#endif
-
-void svd_double_ata( int m, int n, double *a, double *s, double *u, double *v ) ;
-
 /*---------------------------------------------------------------------------*/
 
 #undef  SQR
@@ -54,13 +44,10 @@ void svd_double_ata( int m, int n, double *a, double *s, double *u, double *v )
 
 /*---------------------------------------------------------------------------*/
 /*! Do a 3x3 symmetric eigen-problem.
-     - INPUT:  double a[9] = input matrix; a[i+3*j] = A(i,j) element
-     _         (only the [0], [1], [2], [4], [5], and [8] elements are used)
+     - INPUT: double a[9] = input matrix; a[i+3*j] = A(i,j) element
      - OUTPUT: e[i] = i'th eigenvalue, with e[0] <= e[1] <= e[2].
      - OUTPUT: if(dovec) then a[] is replaced with eigenvectors,
                and this orthogonal matrix will have determinant=1.
-     - METHOD: direct solution of cubic equation
-     - AUTHOR: RW Cox
 -----------------------------------------------------------------------------*/
 
 void symeig_3( double *a , double *e , int dovec )
@@ -132,7 +119,7 @@ void symeig_3( double *a , double *e , int dovec )
    /*-- Rewrite classical formula for qq as a sum of squares [26 Oct 2005] --*/
 #if 0
    qq = (a1*a1 - 3.0*a2) / 9.0 ;
-#else  /* note SQR(a) = (a)*(a) */
+#else
    qq = (  0.5 * ( SQR(dd-aa) + SQR(ff-aa) + SQR(ff-dd) )
          + 3.0 * ( bb*bb      + cc*cc      + ee*ee      ) ) / 9.0 ;
 #endif
@@ -140,6 +127,7 @@ void symeig_3( double *a , double *e , int dovec )
 
    if( qq <= 0.0 ){       /*** This should never happen!!! ***/
      static int nerr=0 ;
+#pragma omp critical (STDERR)
      {
      if( ++nerr < 4 )
        fprintf(stderr,"** ERROR in symeig_3: discrim=%g numer=%g\n",qq,rr) ;
@@ -161,7 +149,7 @@ void symeig_3( double *a , double *e , int dovec )
      if( lam1 > lam2 ) SWAP(lam1,lam2) ;
      if( lam1 > lam3 ) SWAP(lam1,lam3) ;
      if( lam2 > lam3 ) SWAP(lam2,lam3) ;
-     e[0] = ann*lam1 ; e[1] = ann*lam2 ; e[2] = ann*lam3 ;  /* re-scale */
+     e[0] = ann*lam1 ; e[1] = ann*lam2 ; e[2] = ann*lam3 ;
      return ;
    }
 
@@ -179,7 +167,7 @@ void symeig_3( double *a , double *e , int dovec )
      if( lam1 > lam2 )  SWAP(lam1,lam2) ;  /* start by sorting eigenvalues */
      if( lam1 > lam3 )  SWAP(lam1,lam3) ;
      if( lam2 > lam3 )  SWAP(lam2,lam3) ;
-     e[0] = ann*lam1 ; e[1] = ann*lam2 ; e[2] = ann*lam3 ;  /* re-scale */
+     e[0] = ann*lam1 ; e[1] = ann*lam2 ; e[2] = ann*lam3 ;
 
      /* find eigenvector for lam1 by computing Ay-lam1*y for
         vectors y1=[1,0,0], y2=[0,1,0], and y3=[0,0,1]; the eigenvector
@@ -209,7 +197,7 @@ void symeig_3( double *a , double *e , int dovec )
          CROSS(v1,v2,v3 , w1,w2,w3 , t1,t2,t3 ) ; tn = sqrt(t1*t1+t2*t2+t3*t3) ;
        }
      }
-     a[3] = t1/tn ; a[4] = t2/tn ; a[5] = t3/tn ;  /* normalize */
+     a[3] = t1/tn ; a[4] = t2/tn ; a[5] = t3/tn ;
 
      /* orthgonality of eigenvectors ==> can get last one by cross product */
 
@@ -226,9 +214,11 @@ void symeig_3( double *a , double *e , int dovec )
          CROSS(v1,v2,v3 , w1,w2,w3 , t1,t2,t3 ) ; tn = sqrt(t1*t1+t2*t2+t3*t3) ;
        }
      }
-     a[6] = t1/tn ; a[7] = t2/tn ; a[8] = t3/tn ;  /* normalize */
+     a[6] = t1/tn ; a[7] = t2/tn ; a[8] = t3/tn ;
 #endif
 
+     return ;
+
    } else { /*---- if here, we have a double root ----*/
 
      /* make sure that we have lam1=lam2 and lam3 is the outlier */
@@ -264,8 +254,7 @@ void symeig_3( double *a , double *e , int dovec )
 
      /* and the final vector is the cross product of these two */
 
-     CROSS( w1,w2,w3 , a[0],a[1],a[2] , t1,t2,t3 ) ; tn = sqrt(t1*t1+t2*t2+t3*t3) ;
-     a[3] = t1/tn ; a[4] = t2/tn ; a[5] = t3/tn ;
+     CROSS( w1,w2,w3 , a[0],a[1],a[2] , a[3],a[4],a[5] ) ;
 
      /* sort results (we know lam1==lam2) */
 
@@ -274,10 +263,9 @@ void symeig_3( double *a , double *e , int dovec )
        if( DET3(a) < 0.0 ){ a[6] = -a[6]; a[7] = -a[7]; a[8] = -a[8]; }
      }
 
-     e[0] = ann*lam1 ; e[1] = ann*lam2 ; e[2] = ann*lam3 ;  /* re-scale */
+     e[0] = ann*lam1 ; e[1] = ann*lam2 ; e[2] = ann*lam3 ;
+     return ;
    }
-
-   return ;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -527,6 +515,7 @@ int first_principal_vectors( int n , int m , float *xx ,
 
    if( nvec > nsym ) nvec = nsym ;  /* can't compute more vectors than nsym! */
 
+#pragma omp critical (MALLOC)
    { asym  = (double *)malloc(sizeof(double)*nsym*nsym) ;  /* symmetric matrix */
      deval = (double *)malloc(sizeof(double)*nsym) ;       /* its eigenvalues */
    }
@@ -550,6 +539,7 @@ int first_principal_vectors( int n , int m , float *xx ,
    } else {                             /* more columns than rows:  */
                                         /* so [A] = [X][X]' = n x n */
      float *xt ; int m1=mm-1 ;
+#pragma omp critical (MALLOC)
      xt = (float *)malloc(sizeof(float)*nn*mm) ;
      for( jj=0 ; jj < mm ; jj++ ){      /* form [X]' into array xt */
        for( ii=0 ; ii < nn ; ii++ ) xt[jj+ii*mm] = xx[ii+jj*nn] ;
@@ -565,6 +555,7 @@ int first_principal_vectors( int n , int m , float *xx ,
        }
      }
 
+#pragma omp critical (MALLOC)
      free(xt) ;  /* don't need this no more */
    }
 
@@ -574,6 +565,7 @@ int first_principal_vectors( int n , int m , float *xx ,
    ii = symeig_irange( nsym, asym, deval, nsym-nvec, nsym-1, (uvec==NULL) ) ;
 
    if( ii != 0 ){
+#pragma omp critical (MALLOC)
      { free(deval) ; free(asym) ; }
      return -33333 ;  /* eigensolver failed!? */
    }
@@ -592,6 +584,7 @@ int first_principal_vectors( int n , int m , float *xx ,
    /** if no output vectors desired, we are done done done!!! **/
 
    if( uvec == NULL ){
+#pragma omp critical (MALLOC)
      { free(deval) ; free(asym) ; }
      return nvec ;
    }
@@ -610,7 +603,7 @@ int first_principal_vectors( int n , int m , float *xx ,
                     will give the corresponding column in [U], but scaled;
                     below, just L2-normalize the column to get output vector **/
 
-   if( nn <= mm ){                    /* copy eigenvectors into output directly */
+	if( nn <= mm ){                    /* copy eigenvectors into output directly */
                                       /* (e.g., more vectors than time points) */
      for( jj=0 ; jj < nvec ; jj++ ){
        qq = nvec-1-jj ;               /* eigenvalues are in reversed order */
@@ -638,6 +631,7 @@ int first_principal_vectors( int n , int m , float *xx ,
 
    /** free at last!!! **/
 
+#pragma omp critical (MALLOC)
    { free(deval) ; free(asym) ; }
    return nvec ;
 }
@@ -646,7 +640,7 @@ int first_principal_vectors( int n , int m , float *xx ,
 
 /*--------------------------------------------------------------------*/
 
-#define CHECK_SVD   /* unfortunately, this is necessary */
+#define CHECK_SVD
 
 #undef CHK
 #ifdef CHECK_SVD
@@ -723,15 +717,13 @@ void svd_double( int m, int n, double *a, double *s, double *u, double *v )
    (void) svd_( &mm , &nn , &lda , aa , ww ,
                 &matu , &ldu , uu , &matv , &ldv , vv , &ierr , rv1 ) ;
 
-   /** the following code is to check if the SVD worked **/
-
 #ifdef CHECK_SVD
    /** back-compute [A] from [U] diag[ww] [V]'
        and see if it is close to the input matrix;
        if not, compute the results in another function;
        this is needed because the svd() function compiles with
        rare computational errors on some compilers' optimizers **/
-   { register int i,j,k ; register doublereal aij ; double err=0.0,amag=1.e-12 ;
+   { register int i,j,k ; register doublereal aij ; double err=0.0,amag=1.e-11 ;
      for( j=0 ; j < n ; j++ ){
       for( i=0 ; i < m ; i++ ){
         aij = A(i,j) ; amag += fabs(aij) ;
@@ -741,20 +733,16 @@ void svd_double( int m, int n, double *a, double *s, double *u, double *v )
      amag /= (m*n) ; /* average absolute value of matrix elements */
      err  /= (m*n) ; /* average absolute error per matrix element */
      if( err >= 1.e-5*amag || !IS_GOOD_FLOAT(err) ){
-       fprintf(stderr,"\n **** SVD avg err=%g; recomputing ...",err) ;
+       fprintf(stderr,"SVD avg err=%g; recomputing ...",err) ;
 
-#if 1     /* perturb matrix slightly */
-       { double arep=1.e-13*amag , *aj ;
+#if 1     /* mangle all zero columns */
+       { double arep=1.e-11*amag , *aj ;
          for( j=0 ; j < nn ; j++ ){
            aj = aa + j*mm ;
-#if 1
-           for( i=0 ; i < mm ; i++ ) aj[i] += (drand48()-0.5)*arep ;
-#else
            for( i=0 ; i < mm ; i++ ) if( aj[i] != 0.0 ) break ;
            if( i == mm ){
              for( i=0 ; i < mm ; i++ ) aj[i] = (drand48()-0.5)*arep ;
            }
-#endif
          }
        }
 #endif
@@ -771,34 +759,8 @@ void svd_double( int m, int n, double *a, double *s, double *u, double *v )
           err += fabs(aij) ;
        }}
        err /= (m*n) ;
-
-       /* not fixed YET?  try another algorithm (one that's usually slower) */
-
-       if( err >= 1.e-5*amag || !IS_GOOD_FLOAT(err) ){
-         fprintf(stderr," new avg err=%g; re-recomputing the hard way ...",err) ;
-#ifdef USE_SVDLIB
-         fprintf(stderr,"\n") ;
-         SVDVerbosity = 2 ;
-         AFNI_svdLAS2( mm , nn , aa , ww , uu , vv ) ;  /* svdlib.c */
-         SVDVerbosity = 0 ;
-#else
-         svd_double_ata( mm , nn , aa , ww , uu, vv ) ; /* below */
-#endif
-         err = 0.0 ;
-         for( j=0 ; j < n ; j++ ){
-          for( i=0 ; i < m ; i++ ){
-            aij = A(i,j) ;
-            for( k=0 ; k < n ; k++ ) aij -= U(i,k)*V(j,k)*ww[k] ;
-            err += fabs(aij) ;
-         }}
-         err /= (m*n) ;
-         fprintf(stderr," newer avg err=%g %s" ,
-                 err ,
-                 (err >= 1.e-5*amag || !IS_GOOD_FLOAT(err)) ? "**BAD** :-(" : "**OK** :-)" ) ;
-       } else {
-         fprintf(stderr," new avg error=%g **OK** :-)",err) ;
-       }
-       fprintf(stderr,"\n\n") ;
+       fprintf(stderr," new avg err=%g %s\n",
+               err , (err >= 1.e-5*amag || !IS_GOOD_FLOAT(err)) ? "**BAD**" : "**OK**" ) ;
      }
    }
 #endif
@@ -822,23 +784,23 @@ void svd_double( int m, int n, double *a, double *s, double *u, double *v )
      qsort_doubleint( n , sv , iv ) ;
      if( u != NULL ){
        double *cc = (double *)calloc(sizeof(double),m*n) ;
-#pragma omp critical
-       (void)AAmemcpy( cc , u , sizeof(double)*m*n ) ;
+#pragma omp critical (MEMCPY)
+       (void)memcpy( cc , u , sizeof(double)*m*n ) ;
        for( jj=0 ; jj < n ; jj++ ){
          kk = iv[jj] ;  /* where the new jj-th col came from */
-#pragma omp critical
-         (void)AAmemcpy( u+jj*m , cc+kk*m , sizeof(double)*m ) ;
+#pragma omp critical (MEMCPY)
+         (void)memcpy( u+jj*m , cc+kk*m , sizeof(double)*m ) ;
        }
        free((void *)cc) ;
      }
      if( v != NULL ){
        double *cc = (double *)calloc(sizeof(double),n*n) ;
-#pragma omp critical
-       (void)AAmemcpy( cc , v , sizeof(double)*n*n ) ;
+#pragma omp critical (MEMCPY)
+       (void)memcpy( cc , v , sizeof(double)*n*n ) ;
        for( jj=0 ; jj < n ; jj++ ){
          kk = iv[jj] ;
-#pragma omp critical
-         (void)AAmemcpy( v+jj*n , cc+kk*n , sizeof(double)*n ) ;
+#pragma omp critical (MEMCPY)
+         (void)memcpy( v+jj*n , cc+kk*n , sizeof(double)*n ) ;
        }
        free((void *)cc) ;
      }
@@ -850,76 +812,13 @@ void svd_double( int m, int n, double *a, double *s, double *u, double *v )
    return ;
 }
 
-/*----------------------------------------------------------------------------*/
-/* SVD via eigensolution of A'A (presumes n < m) */
-
-void svd_double_ata( int m, int n, double *a, double *s, double *u, double *v )
-{
-   double *ata , *ai,*aj , sum ;
-   int ii,jj,kk ;
-
-   if( a == NULL || s == NULL || m < 1 || n < 1 ) return ;
-
-   /* make A'A matrix */
-
-   ata = (double *)malloc(sizeof(double)*n*n) ;
-   for( ii=0 ; ii < n ; ii++ ){
-     ai = a + ii*m ;                   /* ii-th column of A */
-     for( jj=0 ; jj <= ii ; jj++ ){
-       aj = a + jj*m ;                 /* jj-th column of A */
-       for( sum=0.0,kk=0 ; kk < m ; kk++ ) sum += ai[kk]*aj[kk] ;
-       ata[ii+jj*n] = sum ; if( jj < ii ) ata[jj+ii*n] = sum ;
-     }
-   }
-
-   /* Since A = U S V', then A'A = V S^2 V', or A'A V = V S^2,
-      so the eigensolution of A'A gives S^2 as the eigenvalues,
-      and gives V as the eigenvectors (which here over-write ata). */
-
-   symeig_double( n , ata , s ) ;
-
-   /* sqrt the eigenvalues to get the singular values */
-
-   for( ii=0 ; ii < n ; ii++ )
-     s[ii] = (s[ii] <= 0.0) ? 0.0 : sqrt(s[ii]) ;
-
-   /* copy ata into the output place for V */
-
-   if( v != NULL ){
-#pragma omp critical
-     AAmemcpy( v , ata , sizeof(double)*n*n ) ;
-   }
-
-   /* manufacture U from A and V (which is in ata, recall):
-      AV = US, so if we form the matrix product AV, then
-      L2-normalizing each column will give us the matrix U. */
-
-   if( u != NULL ){
-     double *uj , *vj ;
-     for( jj=0 ; jj < n ; jj++ ){
-       uj = u   + jj*m ;              /* jj-th column of U */
-       vj = ata + jj*n ;              /* jj-th column of V */
-       for( ii=0 ; ii < m ; ii++ ){             /* A_{ii,kk} V_{kk,jj} */
-         for( sum=0.0,kk=0 ; kk < n ; kk++ ) sum += a[ii+kk*m]*vj[kk] ;
-         uj[ii] = sum ;
-       }
-       for( sum=0.0,ii=0 ; ii < m ; ii++ ) sum += uj[ii]*uj[ii] ;
-       if( sum > 0.0 ){
-         for( sum=1.0/sqrt(sum),ii=0 ; ii < m ; ii++ ) uj[ii] *= sum ;
-       }
-     }
-   }
-
-   free(ata) ; return ;
-}
-
 /*--------------------------------------------------------------------*/
 
 #define DBG_PC 0
 /*!
    Calculate the covariance matrix of data_mat based on code in 3dpc
 
-   data_mat: Data matrix with num_cols vectors that have num_rows elements.
+   data_mat: Data matrix containg num_cols vectors that have num_rows elements.
    cov_mat:  On output, cov_mat will contain the covariance matrix. Caller must
              allocate num_cols x num_cols elements for it.
    Both matrices are stored in column major order. M(i,j) = Mv(i+j*num_rows);
