@@ -3,9 +3,6 @@
    of Wisconsin, 1994-2000, and are released under the Gnu General Public
    License, Version 2.  See the file README.Copyright for details.
 ******************************************************************************/
-// drg - added this coxplot.h inclusion for macos10.15 
-// implicit declaration of find_color_name not allowed
-#include "coxplot.h"
 
 #include "display.h"
 #include "mrilib.h"
@@ -15,34 +12,6 @@ static char *x11_vcl[] =  { "StaticGray"  , "GrayScale" , "StaticColor" ,
 
 MCW_DC *first_dc = NULL ;              /* 26 Jun 2003 */
 
-int npane_big = 256 ;                  /* 06 May 2016 */
-
-extern int find_color_name( char *cnam, float *rr, float *gg, float *bb ) ; ;
-
-/*--------------------------------------------------------------------------*/
-#undef  USE_TURBO                      /* 22 Aug 2019 - made obsolete below */
-#define USE_PBARDEFS                   /* 24 Oct 2019 */
-
-#ifdef  USE_PBARDEFS
-
-# undef USE_TURBO
-# include "pbardefs_float.h"
-
-# define NPBARF 4
-static char *pbarfname[NPBARF] = { magma_name, plasma_name, viridis_name, googleturbo_name } ;
-static float  *pbarfar[NPBARF] = { magma_data, plasma_data, viridis_data, googleturbo_data } ;
-
-#endif
-
-/* use 256 colors for the colorbar? */
-
-#if defined(USE_TURBO) || defined(USE_PBARDEFS)
-# define USE_256
-#else
-# undef  USE_256
-#endif
-/*------------------------------------------------------------------------*/
-
 /*------------------------------------------------------------------------
   Returns position of highest set bit in 'ul' as an integer (0-31),
   or returns -1 if no bit is set.
@@ -104,8 +73,6 @@ static void setup_byper( MCW_DC *dc )
   14 Sep 1998: Modified to add argument
     newcmap = if nonzero, create a new Colormap;
               if zero, use the default Colormap for the display
-              this option is only for PseudoColor
-              [does anyone use PseudoColor any more?]
 ------------------------------------------------------------------------*/
 
 static MCW_DCOV * only_ovc = NULL ;  /* Dec 1997 */
@@ -213,7 +180,7 @@ if(PRINT_TRACING){
 
      } else {                            /* should never occur! */
         dc->visual_info  = NULL ;
-        dc->visual_class = PseudoColor ; /* we hope this still works [probably not] */
+        dc->visual_class = PseudoColor ; /* we hope */
      }
    }
 
@@ -240,11 +207,7 @@ if(PRINT_TRACING){
    dc->height  = HeightOfScreen( dc->screen ) ;
 
    if( dc->visual_class == TrueColor ){   /* 23 Feb 2011 */
-#ifndef USE_256
      if( ncol < 160 ) ncol = 160 ;
-#else
-     if( ncol < 256 ) ncol = 256 ;
-#endif
    }
 
    dc->ncol_im = ncol ;
@@ -337,68 +300,38 @@ if(PRINT_TRACING){
    }
    OVC_mostest( dc->ovc ) ;
 
-   /*-- May 1996: create new GC for use with text and graphics. --*/
-   /*-- Note that myGC is used only for text in afni_graph.c,  --*/
-   /*-- but is used for drawing graphics in some other places. --*/
+   /*-- May 1996: create new GC for use with text and graphics --*/
 
    { XGCValues gcv;
      int ifont ;
      XFontStruct *mfinfo = NULL ;
-     char *xdef , dashlist[2] = {6,4} ;
-
-     /* create the GC */
+     char *xdef ;
 
      gcv.function = GXcopy ;
      dc->myGC     = XCreateGC( dc->display,
                                RootWindowOfScreen(dc->screen) ,
                                GCFunction , &gcv ) ;
 
-     /** XSetFillRule( dc->display, dc->myGC, WindingRule ) ; **/
-
-     /**** find some font to load into myGC ****/
-
-     /* first try */
-
-     xdef = XGetDefault(dc->display,"AFNI","gfont") ;  /* from ~/.Xdefaults */
-     if( xdef != NULL ){
+     xdef = XGetDefault(dc->display,"AFNI","gfont") ;
+     if( xdef == NULL ) xdef = getenv("AFNI_GRAPH_FONT") ;
+     if( xdef != NULL )
        mfinfo = XLoadQueryFont(dc->display,xdef) ;
-       /** if( mfinfo != NULL ) INFO_message("gfontX = %s",xdef) ; **/
-     }
-
-     /* second try */
-
-     if( mfinfo == NULL ){
-       xdef = getenv("AFNI_GRAPH_FONT") ;              /* from ~/.afnirc */
-       if( xdef != NULL ){
-         mfinfo = XLoadQueryFont(dc->display,xdef) ;
-         /** if( mfinfo != NULL ) INFO_message("gfontA = %s",xdef) ; **/
-       }
-     }
-
-     /* third try: a list of fonts in display.h */
 
      if( mfinfo == NULL ){
         for( ifont=0 ; tfont_hopefuls[ifont] != NULL ; ifont++ ){
            mfinfo = XLoadQueryFont(dc->display, tfont_hopefuls[ifont]) ;
-           if( mfinfo != NULL ) break ; /* found one! */
+           if( mfinfo != NULL ) break ;
         }
-        /** if( mfinfo != NULL ) INFO_message("gfont[%d] = %s",ifont,tfont_hopefuls[ifont]) ; **/
      }
-
-     /* store font that we found above */
-
-     if( mfinfo == NULL ){  /* This has never happened, to my knowledge */
-        ERROR_message("Cannot load any text fonts in display.c :(") ;
+     if( mfinfo == NULL ){  /* this should not happen, fondly we do hope */
+        fprintf(stderr,
+                "\n*** Cannot load any text fonts in display.c ***\n" ) ;
      } else {
-        XSetFont( dc->display, dc->myGC, mfinfo->fid ); /* put font into myGC */
+        XSetFont( dc->display , dc->myGC , mfinfo->fid ) ;
      }
-     dc->myFontStruct = mfinfo ; /* save font info into AFNI display context (dc) */
-
-     /*** set initial colors in myGC ***/
-
      XSetForeground(dc->display , dc->myGC , dc->ovc->pixov_darkest ) ;
      XSetBackground(dc->display , dc->myGC , dc->ovc->pixov_brightest ) ;
-     XSetDashes(    dc->display , dc->myGC , 0 , dashlist , 2 ) ;
+     dc->myFontStruct = mfinfo ;
    }
 
    dc->parent = dc->aux = NULL ;
@@ -603,42 +536,6 @@ rgbyte DC_spectrum_AJJ( double an , double gamm )
    color.r = r ; color.g = g ; color.b = b ; return color ;
 }
 
-/*----------------------------------------------------------------------------*/
-#ifdef USE_TURBO   /* https://ai.googleblog.com/2019/08/turbo-improved-rainbow-colormap-for.html */
-static byte const turbo_srgb_bytes[256][3] = {
-   {48,18,59},{50,21,67},{51,24,74},{52,27,81},{53,30,88},{54,33,95},{55,36,102},{56,39,109},{57,42,115},
-   {58,45,121},{59,47,128},{60,50,134},{61,53,139},{62,56,145},{63,59,151},{63,62,156},{64,64,162},{65,67,167},
-   {65,70,172},{66,73,177},{66,75,181},{67,78,186},{68,81,191},{68,84,195},{68,86,199},{69,89,203},{69,92,207},
-   {69,94,211},{70,97,214},{70,100,218},{70,102,221},{70,105,224},{70,107,227},{71,110,230},{71,113,233},{71,115,235},
-   {71,118,238},{71,120,240},{71,123,242},{70,125,244},{70,128,246},{70,130,248},{70,133,250},{70,135,251},{69,138,252},
-   {69,140,253},{68,143,254},{67,145,254},{66,148,255},{65,150,255},{64,153,255},{62,155,254},{61,158,254},{59,160,253},
-   {58,163,252},{56,165,251},{55,168,250},{53,171,248},{51,173,247},{49,175,245},{47,178,244},{46,180,242},{44,183,240},
-   {42,185,238},{40,188,235},{39,190,233},{37,192,231},{35,195,228},{34,197,226},{32,199,223},{31,201,221},{30,203,218},
-   {28,205,216},{27,208,213},{26,210,210},{26,212,208},{25,213,205},{24,215,202},{24,217,200},{24,219,197},{24,221,194},
-   {24,222,192},{24,224,189},{25,226,187},{25,227,185},{26,228,182},{28,230,180},{29,231,178},{31,233,175},{32,234,172},
-   {34,235,170},{37,236,167},{39,238,164},{42,239,161},{44,240,158},{47,241,155},{50,242,152},{53,243,148},{56,244,145},
-   {60,245,142},{63,246,138},{67,247,135},{70,248,132},{74,248,128},{78,249,125},{82,250,122},{85,250,118},{89,251,115},
-   {93,252,111},{97,252,108},{101,253,105},{105,253,102},{109,254,98},{113,254,95},{117,254,92},{121,254,89},{125,255,86},
-   {128,255,83},{132,255,81},{136,255,78},{139,255,75},{143,255,73},{146,255,71},{150,254,68},{153,254,66},{156,254,64},
-   {159,253,63},{161,253,61},{164,252,60},{167,252,58},{169,251,57},{172,251,56},{175,250,55},{177,249,54},{180,248,54},
-   {183,247,53},{185,246,53},{188,245,52},{190,244,52},{193,243,52},{195,241,52},{198,240,52},{200,239,52},{203,237,52},
-   {205,236,52},{208,234,52},{210,233,53},{212,231,53},{215,229,53},{217,228,54},{219,226,54},{221,224,55},{223,223,55},
-   {225,221,55},{227,219,56},{229,217,56},{231,215,57},{233,213,57},{235,211,57},{236,209,58},{238,207,58},{239,205,58},
-   {241,203,58},{242,201,58},{244,199,58},{245,197,58},{246,195,58},{247,193,58},{248,190,57},{249,188,57},{250,186,57},
-   {251,184,56},{251,182,55},{252,179,54},{252,177,54},{253,174,53},{253,172,52},{254,169,51},{254,167,50},{254,164,49},
-   {254,161,48},{254,158,47},{254,155,45},{254,153,44},{254,150,43},{254,147,42},{254,144,41},{253,141,39},{253,138,38},
-   {252,135,37},{252,132,35},{251,129,34},{251,126,33},{250,123,31},{249,120,30},{249,117,29},{248,114,28},{247,111,26},
-   {246,108,25},{245,105,24},{244,102,23},{243,99,21},{242,96,20},{241,93,19},{240,91,18},{239,88,17},{237,85,16},
-   {236,83,15},{235,80,14},{234,78,13},{232,75,12},{231,73,12},{229,71,11},{228,69,10},{226,67,10},{225,65,9},
-   {223,63,8},{221,61,8},{220,59,7},{218,57,7},{216,55,6},{214,53,6},{212,51,5},{210,49,5},{208,47,5},
-   {206,45,4},{204,43,4},{202,42,4},{200,40,3},{197,38,3},{195,37,3},{193,35,2},{190,33,2},{188,32,2},
-   {185,30,2},{183,29,2},{180,27,1},{178,26,1},{175,24,1},{172,23,1},{169,22,1},{167,20,1},{164,19,1},
-   {161,18,1},{158,16,1},{155,15,1},{152,14,1},{149,13,1},{146,11,1},{142,10,1},{139,9,2},{136,8,2},
-   {133,7,2},{129,6,2},{126,5,2},{122,4,3}
-};
-#endif
-/*----------------------------------------------------------------------------*/
-
 /*-----------------------------------------------------------------------
    Initialize the color image palette.
    Modified 22 Aug 1998 for TrueColor support.
@@ -646,68 +543,22 @@ static byte const turbo_srgb_bytes[256][3] = {
 
 void DC_init_im_col( MCW_DC *dc )
 {
+   double da, an, c, s, sb, cb, ak, ab , a1,a2 , gamm ;
    int i, r=0, g=0, b=0, nc ;
-   double gamm ;
 
-#ifdef USE_256
-   int kt ; float tfac ;
-#else
-   double da, an, c, s, sb, cb, ak, ab , a1,a2 ;
-#endif
-
-#ifdef USE_PBARDEFS          /* 24 Oct 2019 */
-   static int mypbar = -1 ;
-   static float *mypbarf = NULL ;
-#endif
-
-#ifdef USE_PBARDEFS
-   mypbar = -1 ; mypbarf = NULL ; /* reset the color pbar to use */
-#endif
-   if( dc == NULL ) return ;
+   a1 = 0.0   ;  /* range of spectrum -- hardwired for now */
+   a2 = 240.0 ;
 
    nc   = dc->ncol_im ;
    gamm = dc->gamma ;
 
-#ifdef USE_256 /* setup for getting colors directly from a table */
-   tfac = 255.4f / (float)(nc-1) ;
-#else  /* setup for calculating AJJ's old color circle (from FD) */
-   a1 = 0.0   ;
-   a2 = AFNI_numenv("AFNI_IMAGE_COLORANGLE") ;  /* 08 Nov 2011 */
-   if( a2 < 90.0 || a2 > 360.0 ) a2 = 240.0 ;   /* set range   */
-
    ak = 105.; s  = 150.; c  = s/60.;
    ab = 65.;  sb = 190.; cb = s/60.;
 
    an = a1;   da = (a2 - a1)/nc ; an = an-da+360.;
-#endif
 
    for( i=0 ; i < nc ; i++ ){
 
-#ifdef USE_TURBO        /* directly use Google Turbo */
-     kt = (int)rint(tfac*i) ; if( kt < 0 ) kt=0; else if( kt > 255 ) kt=255 ;
-     r  = turbo_srgb_bytes[kt][0] ;
-     g  = turbo_srgb_bytes[kt][1] ;
-     b  = turbo_srgb_bytes[kt][2] ;
-#elif defined(USE_PBARDEFS)          /* 24 Oct 2019 */
-     if( mypbar < 0 ){
-       char *eee = getenv("AFNI_IMAGE_COLORSCALE") ; /* figure out which */
-       if( eee == NULL || *eee == '\0' ){           /* colorscale to use */
-         mypbar = NPBARF-1 ;
-       } else {
-         int qq ;
-         for( qq=0 ; qq < NPBARF ; qq++ ){
-           if( strcasecmp(eee,pbarfname[qq]) == 0 ) break ;
-         }
-         if( qq == NPBARF ) qq-- ;
-         mypbar = qq ;
-       }
-       mypbarf = pbarfar[mypbar] ;
-     }
-     kt = (int)rint(tfac*i) ; if( kt < 0 ) kt=0; else if( kt > 255 ) kt=255 ;
-     r  = (int)(255.4f*mypow(mypbarf[3*kt+0],gamm/1.555)) ;
-     g  = (int)(255.4f*mypow(mypbarf[3*kt+1],gamm/1.555)) ;
-     b  = (int)(255.4f*mypow(mypbarf[3*kt+2],gamm/1.555)) ;
-#else  /* the olden AJJ way, from program FD */
      an += da; an = fmod(an,360.);
 
      if((an >= 0) && (an < 120.)) {
@@ -719,12 +570,10 @@ void DC_init_im_col( MCW_DC *dc )
           g = 255.*mypow((ak + MIN(s ,(240. - an)*c))/255., gamm) +.5;
           b = 255.*mypow((ab + MIN(sb,(an - 120.)*cb))/255., gamm) +.5;
      } else if(an >= 240.) {
-          r = 255.*mypow((ak + MIN(s,(an - 240.)*c))/255., gamm) +.5;
+          r =  255.*mypow((ak + MIN(s,(an - 240.)*c))/255., gamm) +.5;
           g = 0;
           b = 255.*mypow((ak + MIN(s,(360. - an)*c))/255., gamm) +.5;
      }
-#endif
-
      dc->xcol_im[i].red   = BYTE_TO_INTEN(r) ;
      dc->xcol_im[i].green = BYTE_TO_INTEN(g) ;
      dc->xcol_im[i].blue  = BYTE_TO_INTEN(b) ;
@@ -1159,10 +1008,10 @@ int DC_char_width( MCW_DC *dc , char ccc )  /* 18 Apr 2011 */
 
 /*-------------------------------------------------------------------*/
 
-RwcBoolean MCW_check_iconsize( int width , int height , MCW_DC *dc )
+Boolean MCW_check_iconsize( int width , int height , MCW_DC *dc )
 {
    int ii ;
-   RwcBoolean good ;
+   Boolean good ;
    int nsl = 0 ;
    XIconSize * xsl = NULL ;
 
@@ -1567,15 +1416,14 @@ ENTRY("reload_DC_colordef") ;
 
 Pixel DC_rgb_to_pixel( MCW_DC *dc, byte rr, byte gg, byte bb )
 {
-   static MCW_DC *dcold = NULL ;
-   DC_colordef *cd = dc->cdef ;
+   static MCW_DC *dcold=NULL ;
+   DC_colordef * cd = dc->cdef ;
 
    if( cd == NULL ){ reload_DC_colordef(dc) ; cd = dc->cdef ; }
 
    switch( cd->classKRH ){
 
       /*--- TrueColor case: make color by appropriate bit twiddling ---*/
-      /*--- The code below is duplicated in xim.c for efficiency :) ---*/
 
       case TrueColor:{
          static unsigned long pold=0 ;
@@ -1605,9 +1453,7 @@ Pixel DC_rgb_to_pixel( MCW_DC *dc, byte rr, byte gg, byte bb )
 
       /*--- PseudoColor case: find closest match in colormap.
             Red, green, and blue are weighted according
-              to their importance to the human visual system.
-            This code is slower than the TrueColor case above,
-            which is due to the search through the PseudoColor palette. */
+            to their importance to the human visual system. ---*/
 
       case PseudoColor:{
 
@@ -1625,7 +1471,7 @@ Pixel DC_rgb_to_pixel( MCW_DC *dc, byte rr, byte gg, byte bb )
          if( cd->nwhite >= 0 && rr == 255 && gg == 255 && bb == 255 ) /* cases      */
             return (Pixel) cd->nwhite ;
 
-         if( dc == dcold ){     /* check in with the last call - maybe it's good */
+         if( dc == dcold ){
             rdif = rold - rr ;
             gdif = gold - gg ;
             bdif = bold - bb ; dif = RW*abs(rdif)+GW*abs(gdif)+BW*abs(bdif) ;
@@ -1634,16 +1480,11 @@ Pixel DC_rgb_to_pixel( MCW_DC *dc, byte rr, byte gg, byte bb )
 
          rold = rr ; gold = gg ; bold = bb ; dcold = dc ; /* No? Remember for next time. */
 
-         /* check first color in palette; if it is "close enough" (RGBSUM), use it */
-
          rdif = cd->rr[0] - rr ;
          gdif = cd->gg[0] - gg ;
          bdif = cd->bb[0] - bb ; dif = RW*abs(rdif)+GW*abs(gdif)+BW*abs(bdif) ;
          if( dif <= RGBSUM ){ iold = 0 ; return 0 ; }
 
-         /* scan thru the rest of the colors in palette,
-            either finding one close enough, or finding the closest one */
-
          ibest = 0 ; dbest = dif ;
          for( ii=1 ; ii < cd->ncolors ; ii++ ){
             rdif = cd->rr[ii] - rr ;
@@ -1658,7 +1499,7 @@ Pixel DC_rgb_to_pixel( MCW_DC *dc, byte rr, byte gg, byte bb )
 
    /*--- Illegal case! ---*/
 
-   return 0 ;  /* Black is always valid (but not very colorful) */
+   return 0 ;  /* always valid (but useless) */
 }
 
 /*---------------------------------------------------------------------
@@ -1834,8 +1675,6 @@ int DC_parse_color( MCW_DC *dc, char *str, float *rr, float *gg, float *bb )
      }
    }
 
-   ok = find_color_name(str,rr,gg,bb) ; if( ok >= 0 ) return 0 ; /* 02 Dec 2015 */
-
    /* let X11 try to understand the input string */
 
    ok = XParseColor( dc->display , dc->colormap , str , &cell ) ;
@@ -1845,7 +1684,6 @@ int DC_parse_color( MCW_DC *dc, char *str, float *rr, float *gg, float *bb )
       *bb = cell.blue  / 65535.0f ;
       return 0 ;
    }
-
    return 1 ;
 }
 
@@ -1854,29 +1692,28 @@ int NJ_bigmaps_init(int bigmap_num, char ***bigmap_namep, rgbyte ***bigmapp)
 {
    char **bigmap_name=NULL;
    rgbyte **bigmap = NULL;
-   int ii=0 ,mm=0, NPB_2=NPANE_BIG/2;
+   int ii=0;
 
    if (  !bigmap_namep || !bigmapp ||
          bigmap_num != NBIGMAP_INIT) return 1;
 
    {
      bigmap_name    = (char **) malloc(sizeof(char *)*bigmap_num) ;
-     /* copy all names */
-     for(mm = 0; mm < bigmap_num; mm++ )
-        bigmap_name[mm] = strdup(BIGMAP_NAMES[mm]) ;
-
-     bigmap = (rgbyte **)malloc(sizeof(rgbyte *)*bigmap_num) ;
-
-     /* ZSS: The +1 is to stop a a MCW_malloc post-corruption which happens
-     under certain compiler/OS combinations. The likely cause is the uneven
-     byte size of rgbyte which might be causing misalignment problems at the
-     very end          March 27 2012 */
-
-     /* allocate all RGB arrays */
-     for(mm = 0; mm < bigmap_num; mm++ )
-        bigmap[mm] = (rgbyte *) malloc(sizeof(rgbyte)*(NPANE_BIG+1)) ;
-
-     /* fill RGB arrays */
+     bigmap_name[0] = strdup(BIGMAP_NAMES[0]) ;
+     bigmap_name[1] = strdup(BIGMAP_NAMES[1]) ;
+     bigmap_name[2] = strdup(BIGMAP_NAMES[2]) ;
+     bigmap_name[3] = strdup(BIGMAP_NAMES[3]) ;
+     bigmap_name[4] = strdup(BIGMAP_NAMES[4]) ;
+     bigmap_name[5] = strdup(BIGMAP_NAMES[5]) ;
+     bigmap_name[6] = strdup(BIGMAP_NAMES[6]) ;
+     bigmap         = (rgbyte **) malloc(sizeof(rgbyte *)*bigmap_num) ;
+     bigmap[0]      = (rgbyte *) malloc(sizeof(rgbyte)*NPANE_BIG) ;
+     bigmap[1]      = (rgbyte *) malloc(sizeof(rgbyte)*NPANE_BIG) ;
+     bigmap[2]      = (rgbyte *) malloc(sizeof(rgbyte)*NPANE_BIG) ;
+     bigmap[3]      = (rgbyte *) malloc(sizeof(rgbyte)*NPANE_BIG) ;
+     bigmap[4]      = (rgbyte *) malloc(sizeof(rgbyte)*NPANE_BIG) ;
+     bigmap[5]      = (rgbyte *) malloc(sizeof(rgbyte)*NPANE_BIG) ;
+     bigmap[6]      = (rgbyte *) malloc(sizeof(rgbyte)*NPANE_BIG) ;
      for( ii=0 ; ii < NPANE_BIG ; ii++ ){
        bigmap[0][ii] = DC_spectrum_AJJ(      ii*((AJJ_BLU+8.0)/(NPANE_BIG-1.0))-4.0,0.8);
        bigmap[4][ii] = DC_spectrum_AJJ( 60.0-ii*(AJJ_YEL/(NPANE_BIG-1.0))          ,0.7);
@@ -1896,22 +1733,6 @@ int NJ_bigmaps_init(int bigmap_num, char ***bigmap_namep, rgbyte ***bigmapp)
          bigmap[3][ii].r = bigmap[3][ii].g = bigmap[3][ii].b = 0 ;
        }
      }
-
-     /* map[7] = "Reds_and_Blues" 10 Nov, 2014 [rickr] */
-     for( ii=0     ; ii < NPB_2     ; ii++ ) {
-        bigmap[7][ii] = DC_spectrum_AJJ(AJJ_YEL-ii*(AJJ_YEL/(NPB_2-1.0)), 0.8);
-        bigmap[8][ii] = DC_spectrum_AJJ(AJJ_YEL-ii*(AJJ_YEL/(NPB_2-1.0)), 0.8);
-     }
-     for( ii=NPB_2 ; ii < NPANE_BIG ; ii++ ) {
-        bigmap[7][ii] = DC_spectrum_AJJ(AJJ_BLU-(ii-NBIG_MTOP-1)*
-                                (60.0/(NPANE_BIG-NPB_2-2.0)),0.8);
-        bigmap[8][ii] = DC_spectrum_AJJ(AJJ_BLU-(ii-NBIG_MTOP-1)*
-                                (60.0/(NPANE_BIG-NPB_2-2.0)),0.8);
-     }
-
-     /* add greens to map[8] for "Reds_and_Blues_w_Green" */
-     bigmap[8][NPB_2-1] = bigmap[8][NPB_2] =
-        DC_spectrum_AJJ( (NPB_2)*((AJJ_BLU+8.0)/(NPANE_BIG-1.0))-4.0,0.8);
    }
    *bigmapp = bigmap;
    *bigmap_namep = bigmap_name;
