@@ -4,11 +4,6 @@
    License, Version 2.  See the file README.Copyright for details.
 ******************************************************************************/
 
-/*---------------------------------------------------------------------------*/
-/* This is the header file for imseq.c, the AFNI image viewer.
-   Please see that file for more commentary.
-*//*-------------------------------------------------------------------------*/
-
 #ifndef _MCW_IMSEQ_HEADER_
 #define _MCW_IMSEQ_HEADER_
 
@@ -52,14 +47,9 @@ extern "C" {
 
 #ifndef HAVE_GET_PTR_TYPEDEF
 #  define HAVE_GET_PTR_TYPEDEF
-   typedef XtPointer (*get_ptr)() ;  /* function type that returns a pointer */
+   typedef XtPointer (*get_ptr)() ;  /* function type */
 #endif
 
-/* This struct is returned from AFNI to indicate the general
-   'status' or setup of the images to be displayed.
-   Other stuff is stuffed into here, such as the lists of
-   image transformation function that AFNI provides for fun. */
-
 typedef struct {
       int num_total , num_series ;  /* # of images, # in "series" */
 
@@ -72,16 +62,10 @@ typedef struct {
       XtPointer parent , aux ;
 } MCW_imseq_status ;
 
-/* macro to see if a viewer is doing slice projection
-   -- which is controlled from the 'Disp' popup menu. */
-
 #define ISQ_DOING_SLICE_PROJ(ss)      \
  ( (ss)->slice_proj_range >  0   &&   \
    (ss)->slice_proj_func  != NULL   )
 
-/* macros for image physical size --
-   not pixels but pixels time physical width per pixels (mm) */
-
 #define IM_WIDTH(im) \
   ( ((im)->dx > 0) ? ((im)->nx * (im)->dx) : ((im)->nx) )
 
@@ -90,24 +74,20 @@ typedef struct {
 
 /* define dimensions used in the window */
 
-#define FORM_FRAC_BASE  1000   /* for positioning things in the Form */
-#define IMAGE_FRAC      0.8    /* default image fraction as size of Form */
-#define DFRAC           0.01   /* parameters for changing image fraction */
+#define FORM_FRAC_BASE  1000
+#define IMAGE_FRAC      0.8
+#define DFRAC           0.01
 #define FRAC_MAX        0.95
 #define FRAC_MIN        0.25
 
-#define COLOR_BAR_WIDTH 16     /* size of the 'bar' next to the image */
-#define COLOR_BAR_SPACE  4     /* space between bar and image */
+#define COLOR_BAR_WIDTH 16
+#define COLOR_BAR_SPACE  4
 
 /* button stuff */
 
 #define NBUTTON_BOT 4   /* # buttons at bottom */
 #define NBUTTON_RIG 3   /* # buttons at right  */
 
-/* Motif things for how to attach buttons (Widgets)
-   to each other in the bottom array and in the right array,
-   so that they remain together as the viewer window is resized */
-
 #define LEADING_BOT        XmNleftAttachment
 #define LEADING_WIDGET_BOT XmNleftWidget
 #define TRAILING_BOT       XmNrightAttachment
@@ -124,10 +104,6 @@ typedef struct {
 
 /* image destruction stuff */
 
-/* for deleting XImages, which are a struct created in xim.c
-   from an AFNI internal MRI_IMAGE
-   -- XImage is something that X11 knows how to put to the display */
-
 #define KILL_2XIM(one,two)                          \
    do { if( (two) != (one) ) MCW_kill_XImage(two) ; \
         MCW_kill_XImage(one) ; (one) = (two) = NULL ; } while(0)
@@ -136,18 +112,13 @@ typedef struct {
    do { if( (two) != (one) ) MCW_kill_XImage(two) ; \
         (two) = NULL ; } while(0)
 
-/* kill a MRI_IMAGE, and set its pointer to NULL */
-
 #define KILL_1MRI(one) \
    do{ if( (one) != NULL ){ mri_free(one) ; (one) = NULL ; }} while(0)
 
-/* an image viewer can be VALID, which means created successfully,
-   and it can also be REALiZed, meaning it is actually open for business */
-
 #define ISQ_VALID(seq) ((seq)!=NULL && ((seq)->valid)>0)
 #define ISQ_REALZ(seq) ((seq)!=NULL && ((seq)->valid)>1)
 
-/*--------------------- button box stuff for Disp menu ---------------------*/
+/*----------------------- button box stuff -----------------------*/
 
 typedef struct {
       int nbut ;
@@ -186,15 +157,12 @@ typedef struct {
 #define ISQ_IMPROC_FLAT   1
 #define ISQ_IMPROC_SHARP  2  /* boxes in the Disp dialog improc box */
 #define ISQ_IMPROC_SOBEL  4  /* (powers of 2 of button indexes)     */
-#define ISQ_IMPROC_VG     8
 
 #define ISQ_CX_MAG        1  /* values returned by buttons in */
 #define ISQ_CX_PHASE      2  /* the Disp dialog "complex" box */
 #define ISQ_CX_REAL       4
 #define ISQ_CX_IMAG       8
 
-/* This struct stores the options settable from the Disp menu */
-
 typedef struct {
       int mirror , rot , no_overlay ,
           scale_group , scale_range , free_aspect ,
@@ -221,9 +189,6 @@ typedef struct {
 #define RAW_MODE      5
 #define RAWMONT_MODE  6
 
-/* check to see if two Disp options structs have
-   the same entries -- if so, we can sometimes avoid a redisplay */
-
 #define ISQ_OPT_EQUAL(opta,optb)                    \
     ( ((opta).mirror      == (optb).mirror     ) && \
       ((opta).rot         == (optb).rot        ) && \
@@ -234,7 +199,7 @@ typedef struct {
       ((opta).improc_code == (optb).improc_code) && \
       ((opta).cx_code     == (optb).cx_code    )     )
 
-/* Set the default Disp options [09 Oct 1998] */
+/* 09 Oct 1998 */
 
 #define ISQ_DEFAULT_OPT(opt) do{ (opt).mirror      = FALSE ;            \
                                  (opt).rot         = ISQ_ROT_0 ;        \
@@ -258,10 +223,8 @@ typedef struct {
 
 #define NHISTOG 500
 
-/* This struct stores some statistics for a single image (slice),
-   which can be used to determine the value-to-grayscale mapping. */
 typedef struct {
-      RwcBoolean one_done , glob_done ;
+      Boolean one_done , glob_done ;
       float   min,max , per02,per98 ,
               scl_mm,lev_mm , scl_per,lev_per ;
       float   entropy ;
@@ -269,12 +232,8 @@ typedef struct {
       XtPointer parent , aux ;
 } ISQ_indiv_statistics ;
 
-/* This struct is for a now disabled ability
-   in the image viewer -- to scan thru all the
-   images and set global statistics from them. */
-
 typedef struct {
-      RwcBoolean mm_done , per_done ;
+      Boolean mm_done , per_done ;
       float   min,max , per02,per98 ,
               scl_mm,lev_mm , scl_per,lev_per ;
       int hist[NHISTOG] ;
@@ -283,8 +242,6 @@ typedef struct {
       XtPointer parent , aux ;
 } ISQ_glob_statistics ;
 
-/* macro to compute 'level' and 'scale' factors for image display */
-
 #define ISQ_SCLEV(mn,mx,dp,sc,lv) \
   ( (lv) = (mn) , (sc) = (((mx)>(mn)) ? (((dp)-0.49)/((mx)-(mn))) : 1.0) )
 
@@ -304,10 +261,6 @@ typedef struct {
       XtPointer parent , aux ;
 } ISQ_cbs ;
 
-/* Here is where the Callback Reasons (CRs) used to tell
-   AFNI what kind of information is being sent and/or requested
-   when the get_image() function is invoked in imseq.c somewhere. */
-
 #define isqCR_buttonpress 1   /* button press in image */
 #define isqCR_keypress    2   /* key press in image */
 #define isqCR_geometry    3   /* the display geometry altered */
@@ -338,19 +291,9 @@ typedef struct {
 #define isqCR_button2_points 501  /* Feb 1998 */
 #define isqCR_button2_key    502  /* 20 Feb 2003 */
 
-#define isqCR_force_redisplay   601 /* 22 Aug 1998 */
-#define isqCR_setindex          602 /* 26 Apr 2007 */
-#define isqCR_deltival          603 /* 23 Feb 2011 */
-#define isqCR_raiseupthedead    604 /* 17 Jun 2011 */
-#define isqCR_globalrange       605 /* 03 Feb 2013 */
-#define isqCR_resetglobalrange  606
-#define isqCR_opacitychange     607 /* 06 Jun 2019 */
-#define isqCR_zoomchange        608 /* 10 Dec 2019 */
-
-/* what to do if the colormap (or grayscale map) changes:
-    If we are actually part of the AFNI GUI, let AFNI handle the
-     necessary redisplay (for all image viewers).
-    Otherwise, just force a redisplay internally. */
+#define isqCR_force_redisplay 601 /* 22 Aug 1998 */
+#define isqCR_setindex        602 /* 26 Apr 2007 */
+#define isqCR_deltival        603 /* 23 Feb 2011 */
 
 #define COLORMAP_CHANGE(sq)                                          \
   do{ if( ISQ_REALZ((sq)) && (sq)->dc->visual_class == TrueColor ){  \
@@ -367,44 +310,10 @@ typedef struct {
          }                                                           \
     } } while(0)
 
-/* Ditto for opacity change */
-
-#define OPACITY_CHANGE(sq,oval)                                      \
-  do{ if( ISQ_REALZ((sq)) && (sq)->dc->visual_class == TrueColor ){  \
-         if( (sq)->status->send_CB != NULL ){                        \
-            ISQ_cbs cbs ;                                            \
-            cbs.reason = isqCR_opacitychange ;                       \
-            cbs.nim    = (oval) ;                                    \
-            AFNI_CALL_VOID_3ARG( (sq)->status->send_CB      ,        \
-                                 MCW_imseq * , (sq)         ,        \
-                                 XtPointer   , (sq)->getaux ,        \
-                                 ISQ_cbs *   , &cbs          ) ;     \
-         } else {                                                    \
-            KILL_2XIM( (sq)->given_xbar , (sq)->sized_xbar ) ;       \
-            ISQ_redisplay( (sq) , -1 , isqDR_display ) ;             \
-         }                                                           \
-    } } while(0)
-
-/* and for Zoom change */
-
-#define ZOOM_CHANGE(sq)                                              \
-  do{ if( ISQ_REALZ((sq)) ){                                         \
-         if( (sq)->status->send_CB != NULL ){                        \
-            ISQ_cbs cbs ;                                            \
-            cbs.reason = isqCR_zoomchange ;                          \
-            cbs.nim    = 0 ;                                         \
-            AFNI_CALL_VOID_3ARG( (sq)->status->send_CB      ,        \
-                                 MCW_imseq * , (sq)         ,        \
-                                 XtPointer   , (sq)->getaux ,        \
-                                 ISQ_cbs *   , &cbs          ) ;     \
-         }                                                           \
-    } } while(0)
-
 /*------------------------------*/
-/* Montage-ization */
 
 #ifndef MONT_NMAX
-#define MONT_NMAX 199  /* up from 13 [18 Nov 2017] */
+#define MONT_NMAX 13
 #endif
 
 #ifndef MONT_SMAX
@@ -433,9 +342,7 @@ extern void ISQ_montage_CB( Widget , XtPointer , XtPointer ) ;
 extern void ISQ_montage_action_CB( Widget , XtPointer , XtPointer ) ;
 extern void ISQ_set_anim_dup( int ) ;  /* 09 Feb 2009 */
 
-/*------------------------------------------------------------*/
-/*------------- the central data type: MCW_imseq -------------*/
-/*------------------------------------------------------------*/
+/*------------- the central data type -------------*/
 
 #define ISQ_NHELP   2047
 #define ISQ_NWIDGET 128
@@ -459,7 +366,7 @@ typedef struct MCW_imseq {
      float scl , lev ;       /* for scaling intensities */
      int   bot , top ;       /* for clipping intensities */
 
-     RwcBoolean done_first ;    /* for the done button */
+     Boolean done_first ;    /* for the done button */
 
      MCW_DC *dc ;            /* graphics data (copy of a pointer) */
 
@@ -471,13 +378,11 @@ typedef struct MCW_imseq {
 
      Widget wtop, wform, wimage, wbar, wscale , winfo ,
             wbut_bot[NBUTTON_BOT] , wbut_rig[NBUTTON_RIG] ; /* windows */
-     Widget rinfo_sep , rinfo ;                             /* 11 Mar 2020 */
 
      Widget wbar_menu , wbar_rng_but , wbar_zer_but  , wbar_flat_but ,
-            wbar_sharp_but , wbar_vgize_but ;
+            wbar_sharp_but ;
      MCW_bbox *wbar_amask_bbox ;  /* 14 Jun 2010 */
-     MCW_bbox *wbar_invrt_bbox ;  /* 14 Sep 2020 */
-     float  rng_bot,rng_top,rng_ztop , flat_bot,flat_top , sharp_fac , vgize_fac ;
+     float  rng_bot,rng_top,rng_ztop , flat_bot,flat_top , sharp_fac ;
      int    zer_color , rng_extern ;
 
      MCW_arrowval *arrow[NARROW] ; /* arrow controls */
@@ -546,7 +451,6 @@ typedef struct MCW_imseq {
      /*--- data below here should be freed before deletion ---*/
 
      MRI_IMAGE *imim , *ovim ;  /* latest and greatest (already processed) */
-     MRI_IMAGE *last_automask ;
 
      int        need_orim , set_orim ; /* flag to compute orim */
      MRI_IMAGE *orim ;                 /* input underlay image (for rowgraphs) */
@@ -559,7 +463,7 @@ typedef struct MCW_imseq {
 
      /*--- temporary, I hope [Hah!] ---*/
 
-     int saver_from , saver_to , saver_blowup ;
+     int saver_from , saver_to ;
      char *saver_prefix ;
 
      /*--- the obligatory ---*/
@@ -569,7 +473,6 @@ typedef struct MCW_imseq {
      /* extra text for winfo [07 Aug 1999] */
 
      char winfo_extra[64] ;
-     char rinfo_label[64] ; /* 11 Mar 2020 */
 
      /* text for sides of window in default orientation [01 Dec 1999] */
 
@@ -588,7 +491,7 @@ typedef struct MCW_imseq {
      int record_status ;
      int record_method ;
      int record_mode ;
-     struct MCW_imseq *record_imseq ;  /* an image viewer inside an image viewer! */
+     struct MCW_imseq *record_imseq ;
      MRI_IMARR        *record_imarr ;
      MEM_plotdata    **record_mplot ;  /* 05 Jan 2005 */
 
@@ -601,9 +504,6 @@ typedef struct MCW_imseq {
      MCW_bbox *wbar_plots_bbox ;        /* 20 Sep 2001 */
      MCW_arrowval *wbar_label_av ;      /* 20 Sep 2001 */
      MCW_arrowval *wbar_labsz_av ;      /* 21 Sep 2001 */
-     MCW_arrowval *wbar_globrange_av ;  /* 30 Jan 2013 */
-
-     Widget        wbar_labst_pb ;      /* 23 Dec 2011 */
 
      Widget        zoom_sep              /* 11 Mar 2002 */;
      MCW_arrowval *zoom_val_av ;
@@ -619,8 +519,6 @@ typedef struct MCW_imseq {
      int crop_nxorg , crop_nyorg , crop_allowed ;
      Widget        crop_drag_pb ;                     /* 17 Jun 2002 */
      int           crop_drag ;
-     int           crop_autocenter ;                  /* 14 Jan 2014 */
-     MCW_bbox     *wbar_crop_bbox ;                   /* 15 Jan 2014 */
 
      int button2_width ;                              /* 08 Oct 2002 */
 
@@ -654,30 +552,16 @@ typedef struct MCW_imseq {
 
      int render_mode ;                                /* 25 Oct 2008 */
      MCW_arrowval *wbar_checkbrd_av ;
-     float render_fac ;                               /* 22 Aug 2014 */
-     Widget render_scal ;
-     int allowmerger ;
 
      MCW_arrowval *wbar_animdup_av ;                  /* 10 Feb 2009 */
 
      int shft_ctrl_dragged ;                          /* 17 Mar 2010 */
-
-     char *overlay_label ;                            /* 23 Dec 2011 */
 } MCW_imseq ;
 
-/* codes for how the underlay and overlay images are to be combined */
-
-#define RENDER_DEFAULT     0
-#define RENDER_CHECK_UO    1   /* checkerboard */
-#define RENDER_CHECK_OU    2
-#define RENDER_WIPE_LEFT   3   /* wipers */
-#define RENDER_WIPE_BOT    4
-#define RENDER_MIX         5   /* blending */
-#define RENDER_WIPE_RIGHT  6
-#define RENDER_WIPE_TOP    7
-#define RENDER_LASTMODE    7
-
-/* Stuff for the timer functions, like the 'v' key produces */
+#define RENDER_DEFAULT    0
+#define RENDER_CHECK_UO   1
+#define RENDER_CHECK_OU   2
+#define RENDER_LASTMODE   2
 
 #define ISQ_TIMERFUNC_INDEX  701
 #define ISQ_TIMERFUNC_BOUNCE 702
@@ -685,8 +569,6 @@ typedef struct MCW_imseq {
 extern void ISQ_timer_CB( XtPointer , XtIntervalId * ) ; /* 03 Dec 2003 */
 extern void ISQ_timer_stop( MCW_imseq * ) ;
 
-/* Callbacks for zooming, cropping */
-
 extern void ISQ_zoom_av_CB( MCW_arrowval *, XtPointer ) ;
 extern void ISQ_zoom_pb_CB( Widget, XtPointer, XtPointer ) ;
 extern void ISQ_crop_pb_CB( Widget, XtPointer, XtPointer ) ;
@@ -694,11 +576,9 @@ extern void ISQ_actually_pan( MCW_imseq * , int , int ) ;
 extern int ISQ_show_zoom( MCW_imseq *seq )  ;
 extern void ISQ_center_zoom( MCW_imseq *seq ) ; /* 27 Aug 2009 */
 
-extern void ISQ_adjust_crop( MCW_imseq *,int,int,int,int,int) ; /* 25 Aug 2009 */
+extern void ISQ_adjust_crop( MCW_imseq *,int,int,int,int) ; /* 25 Aug 2009 */
 extern void ISQ_set_crop_hint( MCW_imseq *seq ) ;
 
-/* changing the cursor in the image, for cropping or drawing */
-
 #define CURSOR_NORMAL    0                            /* 10 Mar 2003 */
 #define CURSOR_PENCIL    1
 #define CURSOR_CROSSHAIR 2                            /* 18 Jul 2003 */
@@ -718,7 +598,6 @@ extern void ISQ_pen_bbox_CB( Widget, XtPointer, XtPointer ) ; /* 18 Jul 2003 */
 #define ISQ_LABEL_DNMD 6
 
 /*--------------------------------------------------------------------*/
-/* For the 'left=Left' stuff at the bottom of an image */
 
 #define ISQ_USE_SIDES(isq) ( (isq)->winfo_sides[0][0] != '\0' || \
                              (isq)->winfo_sides[1][0] != '\0' || \
@@ -757,14 +636,12 @@ extern MCW_imseq * open_MCW_imseq( MCW_DC * , get_ptr , XtPointer ) ;
 #define isqDR_setrange      131
 #define isqDR_bgicon        132
 #define isqDR_settopclip    133  /* 14 Sep 2007 */
-#define isqDR_allowmerger   134  /* 25 Aug 2014 */
 
 #define isqDR_arrowpadhint  201
 #define isqDR_winfotext     202
 #define isqDR_getoptions    203
 #define isqDR_winfosides    204
 #define isqDR_winfoprefix   205
-#define isqDR_rinfolabel    211
 
 #define isqDR_destroy       666
 
@@ -781,10 +658,6 @@ extern MCW_imseq * open_MCW_imseq( MCW_DC * , get_ptr , XtPointer ) ;
 #define isqDR_ignore_redraws  521
 #define isqDR_keypress        522  /* 18 Feb 2005 */
 
-#define isqDR_pressbut_Colr   533  /* 25 Oct 2019 */
-#define isqDR_pressbut_Swap   534
-#define isqDR_pressbut_Norm   535
-
 #define BUTTON2_OPENPOLY        0
 #define BUTTON2_CLOSEDPOLY      1
 #define BUTTON2_POINTS          2
@@ -801,10 +674,6 @@ extern MCW_imseq * open_MCW_imseq( MCW_DC * , get_ptr , XtPointer ) ;
 #define isqDR_penbbox         610  /* 18 Jul 2003 */
 #define isqDR_get_crop        611  /* 03 May 2007 */
 #define isqDR_set_crop        612  /* 03 May 2007 */
-#define isqDR_get_zoom        613  /* 10 Dec 2019 */
-#define isqDR_set_zoom        614  /* 10 Dec 2019 */
-#define isqDR_get_panoff      615  /* 10 Dec 2019 */
-#define isqDR_set_panoff      616  /* 10 Dec 2019 */
 
 #define isqDR_plot_label      701  /* 20 Sep 2001 */
 #define isqDR_plot_plot       702  /* 20 Sep 2001 */
@@ -818,11 +687,9 @@ extern MCW_imseq * open_MCW_imseq( MCW_DC * , get_ptr , XtPointer ) ;
 #define isqDR_save_raw        710  /* 13 Nov 2007 */
 #define isqDR_save_rawmont    711  /* 13 Nov 2007 */
 
-/* function to 'drive' an image viewer with one of the isqDR codes above */
+extern Boolean drive_MCW_imseq( MCW_imseq * , int , XtPointer ) ;
 
-extern RwcBoolean drive_MCW_imseq( MCW_imseq * , int , XtPointer ) ;
-
-extern RwcBoolean ISQ_setup_new( MCW_imseq * , XtPointer ) ;
+extern Boolean ISQ_setup_new( MCW_imseq * , XtPointer ) ;
 
 /*** prototypes: internals ***/
 
@@ -836,18 +703,13 @@ extern void ISQ_scale_CB( Widget , XtPointer , XtPointer ) ;
 
 extern void ISQ_wbar_plots_CB( Widget , XtPointer , XtPointer ) ; /* 20 Sep 2001 */
 extern void ISQ_wbar_label_CB( MCW_arrowval * , XtPointer ) ;
-extern void ISQ_wbar_globrange_CB( MCW_arrowval * , XtPointer ) ;
 extern void ISQ_wbar_amask_CB( Widget , XtPointer , XtPointer ) ; /* 14 Jun 2010 */
-extern void ISQ_wbar_invrt_CB( Widget , XtPointer , XtPointer ) ; /* 14 Sep 2020 */
-extern void ISQ_wbar_crop_CB ( Widget , XtPointer , XtPointer ) ; /* 15 Jan 2014 */
 
 extern void ISQ_wbar_menu_CB( Widget , XtPointer , XtPointer ) ;
 extern void ISQ_set_rng_CB( Widget , XtPointer , MCW_choose_cbs * ) ;
 extern void ISQ_set_zcol_CB( Widget , XtPointer , MCW_choose_cbs * ) ;
 extern void ISQ_set_flat_CB( Widget , XtPointer , MCW_choose_cbs * ) ;
 extern void ISQ_set_sharp_CB( Widget , XtPointer , MCW_choose_cbs * ) ;
-extern void ISQ_overlay_label_CB( Widget , XtPointer , MCW_choose_cbs * ) ;
-extern void ISQ_set_vgize_CB( Widget , XtPointer , MCW_choose_cbs * ) ;
 
 extern void ISQ_but_disp_CB( Widget , XtPointer , XtPointer ) ;
 extern void ISQ_but_save_CB( Widget , XtPointer , XtPointer ) ;
@@ -868,8 +730,8 @@ extern void ISQ_place_widget( Widget, Widget ) ;  /* 27 Oct 2003 */
 
 extern void ISQ_disp_act_CB( Widget , XtPointer , XtPointer ) ;
 
-extern void ISQ_drawing_EV( Widget , XtPointer , XEvent * , RwcBoolean * ) ;
-extern void ISQ_button2_EV( Widget , XtPointer , XEvent * , RwcBoolean * ) ;
+extern void ISQ_drawing_EV( Widget , XtPointer , XEvent * , Boolean * ) ;
+extern void ISQ_button2_EV( Widget , XtPointer , XEvent * , Boolean * ) ;
 
 extern void ISQ_make_image( MCW_imseq * ) ;
 extern void ISQ_show_image( MCW_imseq * ) ;
@@ -877,20 +739,13 @@ extern void ISQ_draw_winfo( MCW_imseq * ) ;
 
  /* 06 Mar 2001 */
 extern MRI_IMAGE * ISQ_overlay( MCW_DC *, MRI_IMAGE *, MRI_IMAGE *, float ) ;
-#define ISQ_GOOD_OVERLAY_TYPE(dt) ( (dt)==MRI_short || (dt)==MRI_rgb || (dt)==MRI_rgba )
- /* 13 Feb 2020 */
-extern MRI_IMAGE * ISQ_overlay_rgba( MCW_DC *dc , MRI_IMAGE *ulim, MRI_IMAGE *ovim, float alpha ) ;
-
-extern MRI_IMAGE * ISQ_binarize_overlay( MRI_IMAGE * ) ; /* Mar 2013 */
-
-extern void ISQ_apply_mask( MRI_IMAGE * , MRI_IMAGE * ) ; /* 12 Dec 2014 */
+#define ISQ_GOOD_OVERLAY_TYPE(dt) ( (dt)==MRI_short || (dt)==MRI_rgb )
 
  /* 07 Mar 2001 */
 extern void ISQ_opacity_CB( MCW_arrowval * , XtPointer ) ;
 extern char * ISQ_opacity_label( int ) ;
 extern MRI_IMAGE * ISQ_index_to_rgb( MCW_DC * , int , MRI_IMAGE * ) ;
-#define ISQ_SKIP_OVERLAY(isq) \
-   ( (isq)->opt.no_overlay || (isq)->ov_opacity == 0.0 || (isq)->render_mode > 0 )
+#define ISQ_SKIP_OVERLAY(isq) ((isq)->opt.no_overlay || (isq)->ov_opacity == 0.0)
 
 extern MRI_IMAGE * ISQ_manufacture_one( int nim , int overlay , MCW_imseq * seq ) ;
 extern void ISQ_make_montage( MCW_imseq * ) ;
@@ -899,13 +754,7 @@ extern void ISQ_make_bar( MCW_imseq * ) ;
 extern void ISQ_show_bar( MCW_imseq * ) ;
 extern void ISQ_set_barhint( MCW_imseq * , char * ) ; /* 29 Jul 2001 */
 
-#define PFLAG_NOTRAN0D 1
-#define PFLAG_NOTRAN2D 2
-#define PFLAG_NOTRAN   (PFLAG_NOTRAN0D | PFLAG_NOTRAN2D)
-#define PFLAG_NOIMPROC 4
-#define PFLAG_NOTHING  65535
-
-extern MRI_IMAGE * ISQ_process_mri( int , MCW_imseq * , MRI_IMAGE * , int ) ;
+extern MRI_IMAGE * ISQ_process_mri( int , MCW_imseq * , MRI_IMAGE * ) ;
 
 extern MRI_IMAGE    * ISQ_getimage  ( int , MCW_imseq * ) ; /* 31 Jan 2002 */
 extern MRI_IMAGE    * ISQ_getoverlay( int , MCW_imseq * ) ; /* 11 Jun 2002 */
@@ -914,14 +763,11 @@ extern char         * ISQ_getlabel  ( int , MCW_imseq * ) ;
 extern MRI_IMAGE    * ISQ_getchecked( int nn , MCW_imseq *seq ) ;
 extern int_triple ISQ_get_crosshairs( MCW_imseq *seq ) ;    /* 27 Aug 2009 */
 
-extern void ISQ_render_scal_CB( Widget , XtPointer , XtPointer ) ; /* 22 Aug 2014 */
-extern void ISQ_destroy_render_scal( MCW_imseq *seq ) ;
-
 extern void ISQ_free_alldata( MCW_imseq * ) ;
 
 extern int ISQ_set_image_number( MCW_imseq * , int ) ;
 
-extern RwcBoolean ISQ_disp_options( MCW_imseq * , RwcBoolean ) ;
+extern Boolean ISQ_disp_options( MCW_imseq * , Boolean ) ;
 
 /* type for defining buttons */
 
@@ -932,10 +778,10 @@ typedef struct {
    XtPointer parent , aux ;
 } ISQ_bdef ;
 
-RwcBoolean ISQ_statistics_WP( XtPointer ) ;
+Boolean ISQ_statistics_WP( XtPointer ) ;
 
 void ISQ_statify_one( MCW_imseq * , int , MRI_IMAGE * ) ;
-void ISQ_statify_all( MCW_imseq * , RwcBoolean ) ;
+void ISQ_statify_all( MCW_imseq * , Boolean ) ;
 
 void ISQ_perpoints( float,float , int h[] , float * , float * ) ;
 
@@ -976,11 +822,11 @@ extern void ISQ_surfgraph_arrowpad_CB( MCW_arrowpad * , XtPointer ) ;
 
 /*---- temporary, I hope (yeah, sure, right, uh huh) ----*/
 
-extern void ISQ_saver_CB( Widget w , XtPointer cd , int nval , void **val ) ;
+extern void ISQ_saver_CB( Widget , XtPointer , MCW_choose_cbs * ) ;
 
 extern MEM_plotdata * ISQ_plot_label( MCW_imseq *, char * ) ; /* 20 Sep 2001 */
 
-/*---- 24 Apr 2001: image recorder stuff (the viewer within a viewer) ----*/
+/*---- 24 Apr 2001: recording stuff ----*/
 
 #define RECORD_STATUS_OFF         (1<<0)
 #define RECORD_STATUS_NEXTONE     (1<<1)
@@ -998,9 +844,8 @@ extern MEM_plotdata * ISQ_plot_label( MCW_imseq *, char * ) ; /* 20 Sep 2001 */
 
 extern void ISQ_record_button( MCW_imseq * ) ;
 extern void ISQ_record_CB( Widget,XtPointer,XtPointer ) ;
-extern void ISQ_butsave_EV( Widget, XtPointer, XEvent *, RwcBoolean * ) ;
-extern void ISQ_butcrop_EV( Widget, XtPointer, XEvent *, RwcBoolean * ) ;
-extern void ISQ_butdisp_EV( Widget, XtPointer, XEvent *, RwcBoolean * ) ;
+extern void ISQ_butsave_EV( Widget, XtPointer, XEvent *, Boolean * ) ;
+extern void ISQ_butcrop_EV( Widget, XtPointer, XEvent *, Boolean * ) ;
 
 extern void ISQ_record_open( MCW_imseq * ) ;
 extern void ISQ_record_update( MCW_imseq * , int ) ;
@@ -1014,13 +859,8 @@ extern void ISQ_cropper( MCW_imseq *, XButtonEvent *) ; /* 17 Jun 2002 */
 
 #define MINCROP 9  /* moved here 03 May 2007 */
 
-/* Stuff for making snapshots of Widgets, etc.
-   Also see functions in xim.c for snapshots directly to disk files. */
-
 extern void ISQ_snapshot( Widget w ) ;                 /* 18 Jun 2003 */
 extern void ISQ_snapsave( int,int, byte *, Widget ) ;  /* 03 Jul 2003 */
-extern MRI_IMAGE * ISQ_snap_to_mri_image( int  , int  , byte *); /* Dec 2011 */
-extern MRI_IMAGE * ISQ_snap4_to_mri_image( int  , int  , byte *); /* May 2013 */
 extern void ISQ_snap_agif( char * ) ;                  /* 06 Dec 2006 */
 extern void ISQ_snap_mpeg( char * ) ;
 extern void ISQ_snap_jpeg( char * ) ;
@@ -1030,8 +870,6 @@ extern void ISQ_snap_mpeg_rng( char *,int,int ) ;
 extern void ISQ_snap_jpeg_rng( char *,int,int ) ;
 extern void ISQ_snap_png_rng ( char *,int,int ) ;
 
-/* for dealing with keypress events */
-
 extern int ISQ_handle_keypress( MCW_imseq *, unsigned long, unsigned int ); /* 18 Feb 2005 */
 
 extern void mri_rgb_transform_nD( MRI_IMAGE *, int, generic_func * ) ;
