@@ -55,6 +55,12 @@ static char *license[] = {
    "  Center at San Antonio.  Thanks go to Drs. Jack Lancaster and Peter Fox\n" ,
    "  for sharing this database.\n" ,
    "\n" ,
+   "  The netCDF functions included are from the netCDF library from\n" ,
+   "  the Unidata Program at the University Corporation for Atmospheric\n" ,
+   "  Research (http://www.unidata.ucar.edu/) and distributed in accordance\n" ,
+   "  with their Copyright notice (which of course disavows any liability\n" ,
+   "  for anything).\n" ,
+   "\n" ,
    "  The CDF library routines were developed at the University of Texas\n" ,
    "  M.D. Anderson Cancer Center, and have been placed into the public domain.\n" ,
    "  See the file \"cdflib.txt\" for more details.\n" ,
@@ -71,6 +77,10 @@ static char *license[] = {
    "  The popup hint functions in \"LiteClue.c\" are from Computer Generation, Inc.\n" ,
    "  See that file for their copyright declaration.\n" ,
    "\n" ,
+   "  The volume rendering library \"volpack\" is by Phil Lacroute, and is copy-\n" ,
+   "  righted by The Board of Trustees of The Leland Stanford Junior University.\n" ,
+   "  See file \"volpack.h\" for their copyright declaration.\n" ,
+   "\n" ,
    "  The MD5 routines in thd_md5.c are adapted from the functions in RFC1321\n" ,
    "  by R Rivest, and so are derived from the RSA Data Security, Inc MD5\n" ,
    "  Message-Digest Algorithm.  See file \"thd_md5.c\" for the RSA Copyright\n" ,
