@@ -71,9 +71,6 @@
 #undef _POSIX_SOURCE
 #endif
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
 #include <sys/types.h>
 #include <sys/param.h>
 #include <sys/stat.h>
@@ -99,10 +96,6 @@ typedef void * ptr_t;
 
 #include "mcw_glob.h"
 
-/* it would be nice to put these in the library           4 Aug 2011 [rickr] */
-static char * loc_strcpy_realloc(char ** dest, char * src, int * dlen);
-static char * loc_strcat_realloc(char ** dest, char * src, int * dlen);
-
 /* added for direction control on sorting                14 Feb 2005 [rickr] */
 /* (copied from rickr/l_mcw_glob.c)                       4 Jan 2011 [rickr] */
 static int g_sort_dir = 1 ;       /* 1 = small to large, -1 = large to small */
@@ -124,11 +117,11 @@ typedef unsigned short Char;
 #undef  __P
 #define __P(a) a
 
-static	int	 glob1 		__P((Char *, afni_glob_t *, int));
-static	int	 glob2		__P((Char *, Char *, Char *, afni_glob_t *, int));
+static	int	 glob1 		__P((Char *, glob_t *, int));
+static	int	 glob2		__P((Char *, Char *, Char *, glob_t *, int));
 static	int	 glob3		__P((Char *, Char *, Char *, Char *,
-				     afni_glob_t *, int));
-static	int	 globextend	__P((Char *, afni_glob_t *));
+				     glob_t *, int));
+static	int	 globextend	__P((Char *, glob_t *));
 static	int	 match		__P((Char *, Char *, Char *, int));
 #ifndef __clipper__
 static	int	 compare	__P((const ptr_t, const ptr_t));
@@ -317,12 +310,8 @@ compare(const ptr_t p, const ptr_t q)
  * if things went well, nonzero if errors occurred.  It is not an error
  * to find no matches.
  */
-
-/* as a shared object under R, glob() and globfree() seem to be called
- * as system functions rather than the local ones, so rename as afni_*
- *                                                 10 May 2013 [rickr] */
 int
-afni_glob(const char *pattern, int flags, int(*errfunc)(char *,int), afni_glob_t *pglob)
+glob(const char *pattern, int flags, int(*errfunc)(char *,int), glob_t *pglob)
 {
     int     err, oldpathc;
     Char *bufnext, *bufend, *compilebuf, m_not;
@@ -476,7 +465,7 @@ afni_glob(const char *pattern, int flags, int(*errfunc)(char *,int), afni_glob_t
 }
 
 static int
-glob1(Char *pattern, afni_glob_t *pglob, int no_match)
+glob1(Char *pattern, glob_t *pglob, int no_match)
 {
     Char pathbuf[MAXPATHLEN + 1];
 
@@ -494,7 +483,7 @@ glob1(Char *pattern, afni_glob_t *pglob, int no_match)
  * more meta characters.
  */
 static int
-glob2( Char *pathbuf,Char *pathend, Char *pattern, afni_glob_t *pglob, int no_match)
+glob2( Char *pathbuf,Char *pathend, Char *pattern, glob_t *pglob, int no_match)
 {
     struct stat sbuf;
     int anymeta;
@@ -550,11 +539,8 @@ glob2( Char *pathbuf,Char *pathend, Char *pattern, afni_glob_t *pglob, int no_ma
 }
 
 
-/* no great place to put this, but it should be here or above */
-static int mcw_glob_whine = 1;          /* 7 Feb 2012 [rickr] */
-
 static int
-glob3(Char *pathbuf, Char *pathend, Char *pattern, Char *restpattern, afni_glob_t *pglob, int no_match)
+glob3(Char *pathbuf, Char *pathend, Char *pattern, Char *restpattern, glob_t *pglob, int no_match)
 {
 #if 0
     extern int errno;
@@ -636,8 +622,7 @@ glob3(Char *pathbuf, Char *pathend, Char *pattern, Char *restpattern, afni_glob_
 	    break;
     }
     /* todo: check error from readdir? */
-    /* only whine on mcw_glob_whine            7 Feb 2012 [rickr] */
-    if( errno != 0 && mcw_glob_whine ){
+    if( errno != 0 ){
       static int cnt=2 ;
       if( cnt ){
         perror("** glob error"); errno = 0; cnt-- ;
@@ -690,7 +675,7 @@ glob3(Char *pathbuf, Char *pathend, Char *pattern, Char *restpattern, afni_glob_
 
 
 /*
- * Extend the gl_pathv member of a afni_glob_t structure to accommodate a new item,
+ * Extend the gl_pathv member of a glob_t structure to accomodate a new item,
  * add the new item, and update gl_pathc.
  *
  * This assumes the BSD realloc, which only copies the block when its size
@@ -699,12 +684,12 @@ glob3(Char *pathbuf, Char *pathend, Char *pattern, Char *restpattern, afni_glob_
  *
  * Return 0 if new item added, error code if memory couldn't be allocated.
  *
- * Invariant of the afni_glob_t structure:
+ * Invariant of the glob_t structure:
  *	Either gl_pathc is zero and gl_pathv is NULL; or gl_pathc > 0 and
  *	 gl_pathv points to (gl_offs + gl_pathc + 1) items.
  */
 static int
-globextend(Char *path, afni_glob_t *pglob)
+globextend(Char *path, glob_t *pglob)
 {
     register char **pathv;
     register int i;
@@ -795,9 +780,9 @@ match(Char *name, Char *pat, Char *patend, int m_not)
     return (*name == EOS);
 }
 
-/* free allocated data belonging to a afni_glob_t structure */
+/* free allocated data belonging to a glob_t structure */
 void
-afni_globfree(afni_glob_t *pglob)
+globfree(glob_t *pglob)
 {
     register int i;
     register char **pp;
@@ -819,7 +804,6 @@ afni_globfree(afni_glob_t *pglob)
 
 static int warn = 0 ;
 void MCW_warn_expand( int www ){ warn = www; return; }  /* 13 Jul 2001 */
-void MCW_set_glob_whine( int www ){ mcw_glob_whine = www; return; }
 
 /*------------------------------------------------------------------------*/
 /*! Routines that allows filename wildcarding to be handled inside
@@ -832,25 +816,17 @@ void MCW_set_glob_whine( int www ){ mcw_glob_whine = www; return; }
 
 void MCW_file_expand( int nin , char **fin , int *nout , char ***fout )
 {
-   afni_glob_t gl ;
+   glob_t gl ;
    int    ii , gnum, gold , ilen ;
    char **gout ;
    char *fn , *ehome ;
-   char prefix[4] , fpre[128] ;
+   char prefix[4] , fpre[128] , fname[2048] ;
    int  b1,b2,b3,b4,b5 , ib,ig , lpre=0 ;
    char *eee ;
-
-   /* apply fname, sel as char *, not s[2048]    4 Aug 2011 [rickr] */
-   char *fname, *sel ;
-   int   flen = 2048, slen = 2048 ;
-   int save_sel=0,nsel=0 ;  /* 09 Mar 2011 */
+   char sel[2048] ; int save_sel=0,nsel=0 ;  /* 09 Mar 2011 */
 
    if( nin <= 0 ){ *nout = 0 ; return ; }
 
-   /* init resizable arrays */
-   fname = (char *)malloc(flen*sizeof(char));
-   sel   = (char *)malloc(slen*sizeof(char));
-
    gnum  = 0 ;
    gout  = NULL ;
    ehome = getenv("HOME") ;
@@ -906,14 +882,11 @@ void MCW_file_expand( int nin , char **fin , int *nout , char ***fout )
          }
       }
 
-      if( fname[0] == '\0' ) loc_strcpy_realloc(&fname, fn, &flen) ;
+      if( fname[0] == '\0' ) strcpy(fname,fn) ;
       if( ehome != NULL && fname[0] == TILDE && fname[1] == '/' ){
-        /* char qname[1024] ; another static string... */
-        /* strcpy(qname,ehome); strcat(qname,fname+1); strcpy(fname,qname); */
-        char * qname = NULL;  int qlen = 0;
-        loc_strcpy_realloc(&qname, ehome, &qlen);       /* fill qname    */
-        loc_strcat_realloc(&qname, fname+1, &qlen);     /* append fname  */
-        loc_strcpy_realloc(&fname, qname, &flen);       /* move to fname */
+        char qname[1024] ;
+        strcpy(qname,ehome); strcat(qname,fname+1);
+        strcpy(fname,qname);
       }
 
       /* 09 Mar 2011 [Ash Wednesday]: save selectors for later? */
@@ -924,8 +897,7 @@ void MCW_file_expand( int nin , char **fin , int *nout , char ***fout )
         for( jj=0 ; jj < nf ; jj++ )
           if( fname[jj] == '{' || fname[jj] == '[' || fname[jj] == '<' ) break ;
         if( jj < nf ){
-          loc_strcpy_realloc(&sel, fname+jj, &slen);
-          fname[jj] = '\0' ; nsel = strlen(sel) ;
+          strcpy(sel,fname+jj) ; fname[jj] = '\0' ; nsel = strlen(sel) ;
         }
       }
 
@@ -963,7 +935,7 @@ void MCW_file_expand( int nin , char **fin , int *nout , char ***fout )
 
       /** the olden way (via glob function) **/
 
-      (void) afni_glob( fname , 0 , NULL , &gl ) ;
+      (void) glob( fname , 0 , NULL , &gl ) ;
 
       /** put each matched string into the output array **/
 
@@ -1008,7 +980,7 @@ void MCW_file_expand( int nin , char **fin , int *nout , char ***fout )
            fprintf(stderr,"** Can't find file %s\n", (ig>0) ? fname : fn ) ;
       }
 
-      afni_globfree( &gl ) ;
+      globfree( &gl ) ;
 
     NEXT_STRING: continue ;
    }
@@ -1016,88 +988,14 @@ void MCW_file_expand( int nin , char **fin , int *nout , char ***fout )
 #if 1
    eee = getenv("AFNI_GLOB_DEBUG") ;
    if( eee != NULL && (*eee == 'Y' || *eee == 'y') && gnum > 0 ){
-     fprintf(stderr,"++ filename expansion gives:\n") ;
-     for( ii=0 ; ii < gnum ; ii++ ) fprintf(stderr,"  %s",gout[ii]) ;
-     fprintf(stderr,"\n") ;
+     INFO_message("filename expansion gives:") ;
+     for( ii=0 ; ii < gnum ; ii++ ) ININFO_message(" %s",gout[ii]) ;
    }
 #endif
 
-   if( fname ) free(fname);
-   if( sel   ) free(sel);
-
    *nout = gnum ; *fout = gout ; return ;
 }
 
-/*-----------------------------------------------------------------------*/
-/*! loc_strcpy_realloc(dest, src)                      4 Aug 2011 [rickr]
- *
- * Basically strcpy, but with any needed realloc if the source string
- * is longer than the passed destination length.
- *
- *   - dest is the address of the destination pointer, as it may change
- *   - src is the source pointer
- *   - dlen is the address of the destination length, as it may change
- *   - loc_ was used since I might put strcpy_realloc in the libmri.a
- *-----------------------------------------------------------------------*/
-static char * loc_strcpy_realloc(char ** dest, char * src, int * dlen)
-{
-   int tlen;
-
-   /* bail on any unset pointer */
-   if( !dest ) return NULL;
-   if( !src || !dlen ) return *dest;
-
-   if( !*dest && (*dlen != 0) ) *dlen = 0;      /* allow init */
-
-   tlen = strlen(src) + 1;
-
-   if( *dlen < tlen ) {
-      *dlen = tlen;
-
-      *dest = (char *)realloc(*dest, (*dlen)*sizeof(char));
-      if( ! *dest ) {
-         fprintf(stderr,"** strcpy_realloc: failed to alloc %d chars\n",*dlen);
-         return NULL;
-      }
-   }
-
-   strcpy(*dest, src);
-
-   return *dest;
-}
-
-/*-----------------------------------------------------------------------*/
-/*! loc_strcat_realloc(dest, src)                      4 Aug 2011 [rickr]
- *  As with strcpy.
- *-----------------------------------------------------------------------*/
-static char * loc_strcat_realloc(char ** dest, char * src, int * dlen)
-{
-   int tlen;  /* total len */
-
-   /* bail on any unset pointer */
-   if( !dest ) return NULL;
-   if( !src || !dlen ) return *dest;
-
-   if( !*dest && (*dlen != 0) ) *dlen = 0;      /* allow init */
-
-   tlen = strlen(src) + 1;
-   if( *dest ) tlen += strlen(*dest);
-
-   if( *dlen < tlen ) {
-      *dlen = tlen;
-
-      *dest = (char *)realloc(*dest, (*dlen)*sizeof(char));
-      if( ! *dest ) {
-         fprintf(stderr,"** strcat_realloc: failed to alloc %d chars\n",*dlen);
-         return NULL;
-      }
-   }
-
-   strcat(*dest, src);
-
-   return *dest;
-}
-
 /*-----------------------------------------------------------------------*/
 /*! Simpler interface to MCW_file_expand().
       - fnam = string of form "*.zork fred*.* ?a?b"; e.g., 1 or more
