@@ -40,11 +40,8 @@
  */
 
 /*
- *  $Header$
- *  $Log$
- *  Revision 1.5  2011/11/19 01:06:58  ziad
- *  Cput
- *
+ *  $Header: /share/cvs/AFNI/src/mpeg_encodedir/iframe.c,v 1.4 2004/04/02 15:12:40 rwcox Exp $
+ *  $Log: iframe.c,v $
  *  Revision 1.4  2004/04/02 15:12:40  rwcox
  *  Cput
  *
@@ -68,7 +65,7 @@
  *
  * Revision 1.21  1995/06/21  22:24:25  smoot
  * added CalcDistortion (TUNEing)
- * fixed timing stuff for ANSI
+ * fixed timeing stuff for ANSI
  * fixed specifics bug
  *
  * Revision 1.20  1995/05/02  21:59:43  smoot
@@ -99,7 +96,7 @@
  * Added realQuiet
  *
  * Revision 1.11  1994/12/07  00:40:36  smoot
- * Added separate P and B search ranges
+ * Added seperate P and B search ranges
  *
  * Revision 1.10  1994/11/14  22:30:30  smoot
  * Merged specifics and rate control
@@ -250,8 +247,6 @@ void AllocDctBlocks _ANSI_ARGS_((void ));
 int SetFCodeHelper _ANSI_ARGS_((int sr));
 void CalcDistortion _ANSI_ARGS_((MpegFrame *current, int y, int x));
 
-extern void Mpost_UnQuantZigBlockLaplace _ANSI_ARGS_((FlatBlock in, Block out, int qscale, boolean iblock));
-
 int
   SetFCodeHelper(SR)
 int SR;
@@ -856,8 +851,8 @@ BlockComputeSNR(current, snr, psnr)
 {
   register int32	tempInt;
   register int y, x;
-  int32	varDiff[3]={0, 0, 0};
-  double	ratio[3]={1.0, 1.0, 1.0};
+  int32	varDiff[3];
+  double	ratio[3];
   double	total[3];
   register uint8 **origY=current->orig_y, **origCr=current->orig_cr, 
   **origCb=current->orig_cb;
