@@ -10,8 +10,7 @@
  ** implied warranty.
  */
 
-/* if an error happens, spit out the string    17 Sep 2013 [rickr] */
-#define pm_error(x) do { fputs(x, stderr); (void)exit(1); } while(0)
+#define pm_error(x) exit(1)
 
 
 #if defined(SVR2) || defined(SVR3) || defined(SVR4)
@@ -29,7 +28,6 @@
 #endif
 
 #include <stdio.h>
-#include <stdlib.h>     /* for free() and exit()   17 Sep 2013 [rickr] */
 #include "libpnmrw.h"
 
 /* if don't have string.h, try strings.h */
