@@ -37,8 +37,8 @@
  */
 
 /*  
- *  $Header$
- *  $Log$
+ *  $Header: /share/cvs/AFNI/src/mpeg_encodedir/psearch.c,v 1.4 2004/04/02 15:12:41 rwcox Exp $
+ *  $Log: psearch.c,v $
  *  Revision 1.4  2004/04/02 15:12:41  rwcox
  *  Cput
  *
@@ -58,7 +58,7 @@
  * Changed copyrights
  *
  * Revision 1.8  1994/12/07  00:40:36  smoot
- * Added separate P and B search ranges
+ * Added seperate P and B search ranges
  *
  * Revision 1.7  1994/11/12  02:09:45  eyhung
  * full pixel bug
@@ -138,7 +138,7 @@ int psearchAlg;
  *
  * PRECONDITIONS:	The relevant block in 'current' is valid (it has not
  *			been dct'd).  Thus, the data in 'current' can be
- *			accessed through y_blocks, cr_blocks, and cb_blocks.
+ *			accesed through y_blocks, cr_blocks, and cb_blocks.
  *			This is not the case for the blocks in 'prev.'
  *			Therefore, references into 'prev' should be done
  *			through the struct items ref_y, ref_cr, ref_cb
