@@ -22,8 +22,7 @@
       - Points not in the mask are not processed, and will be set to zero
         in the output.
       - The input mask can be NULL.  If you really want speed, a special
-        version should be written for the mask=NULL case.  Please send
-        pumpernickel bagels or dark chocolate covered cranberries.
+        version should be written for the mask=NULL case.  Please send money.
       - Author: Zhark, Emperor of the Galaxy!!!  (Nov 2006)
 ------------------------------------------------------------------------------*/
 
@@ -84,7 +83,8 @@ ENTRY("mri_blur3D_variable") ;
        qar[ijk] += vout ;  /* whatever wasn't diffused away from this voxel */
    }}}
 
-   AAmemcpy(iar,qar,sizeof(float)*nxyz) ;
+#pragma omp critical (MEMCPY)
+   memcpy(iar,qar,sizeof(float)*nxyz) ;
    free((void *)qar) ;
    EXRETURN ;
 }
@@ -99,7 +99,7 @@ void mri_blur3D_inmask( MRI_IMAGE *im, byte *mask,
 {
    int nx,ny,nz,nxy,nxyz ;
    float *iar , *qar ;
-   int ijk , ii,jj,kk , nn, nfloat_err =0 ;
+   int ijk , ii,jj,kk , nn ;
    register float vcc , vsub , vout , vx,vy,vz ;
 
 ENTRY("mri_blur3D_inmask") ;
@@ -150,9 +150,11 @@ ENTRY("mri_blur3D_inmask") ;
 
          qar[ijk] += vout ;  /* whatever wasn't diffused away from this voxel */
      }}}
-     AAmemcpy(iar,qar,sizeof(float)*nxyz) ;
+#pragma omp critical (MEMCPY)
+     memcpy(iar,qar,sizeof(float)*nxyz) ;
      if( nn != nrep-1 ){
-       AAmemset(qar,0,sizeof(float)*nxyz) ;
+#pragma omp critical (MEMSET)
+       memset(qar,0,sizeof(float)*nxyz) ;
      }
    }
 
@@ -161,10 +163,10 @@ ENTRY("mri_blur3D_inmask") ;
    EXRETURN ;
 }
 
-/*! This function can be a slightly faster (20%) version of mri_blur3D_inmask
+/*! This function can be a slightly faster (20%) version of mri_blur3D_inmask 
     under the following conditions:
       1- The mask is big and has few or no holes in it, as a brain mask would
-      2- You have a volume with more than 2 voxels in each direction and you
+      2- You have a volume with more than 2 voxels in each direction and you 
          are blurring in 3D
       ZSS March 2011
 */
@@ -173,7 +175,7 @@ void mri_blur3D_inmask_speedy( MRI_IMAGE *im, byte *mask,
 {
    int nx,ny,nz,nxy,nxyz ;
    float *iar , *qar ;
-   int ijk , ii,jj,kk , nn, ijkm, nfloat_err=0 ;
+   int ijk , ii,jj,kk , nn, ijkm ;
    byte *skin = NULL;
    register float vcc , vsub , vout , vx,vy,vz ;
 
@@ -199,10 +201,10 @@ ENTRY("mri_blur3D_inmask_speedy") ;
      for( jj=0 ; jj < ny ; jj++ ){
        for( ii=0 ; ii < nx ; ii++,ijk++ ){
          if( !INMASK(ijk) ) continue ;
-         if (  ii == 0    || jj == 0    || kk == 0 ||
+         if (  ii == 0    || jj == 0    || kk == 0 || 
                ii == nx-1 || jj == ny-1 || jj == nz-1 ||
                ijk < nxy || ijk > ijkm) {
-            skin[ijk] = 1; /* in mask, on edge of volume,
+            skin[ijk] = 1; /* in mask, on edge of volume, 
                               or close to boundary slices */
          } else if (        !INMASK(ijk-1)  || !INMASK(ijk+1) ||
                      !INMASK(ijk-nx) || !INMASK(ijk+nx)||
@@ -276,9 +278,11 @@ ENTRY("mri_blur3D_inmask_speedy") ;
          qar[ijk] += vout ;  /* whatever wasn't diffused away from this voxel */
      }}}
 
-     AAmemcpy(iar,qar,sizeof(float)*nxyz) ;
+#pragma omp critical (MEMCPY)
+     memcpy(iar,qar,sizeof(float)*nxyz) ;
      if( nn != nrep-1 ){
-       AAmemset(qar,0,sizeof(float)*nxyz) ;
+#pragma omp critical (MEMSET)
+       memset(qar,0,sizeof(float)*nxyz) ;
      }
    }
 
@@ -289,96 +293,6 @@ ENTRY("mri_blur3D_inmask_speedy") ;
    EXRETURN ;
 }
 
-/*
-   Nearest neighbor averaging, for faster but poorly titrated smoothing.
-                                 ZSS Nov 2011
-*/
-void mri_blur3D_inmask_NN( MRI_IMAGE *im, byte *mask, int nrep )
-{
-   int nx,ny,nz,nxy,nxyz ;
-   float *iar , *qar ;
-   int ijk , ii,jj,kk , nn, ijkm, nfloat_err=0 ;
-   byte *skin = NULL;
-   register float vout ;
-
-ENTRY("mri_blur3D_inmask_NN") ;
-
-   if( im == NULL || nrep <= 0 ) EXRETURN ;
-
-   nx = im->nx; ny = im->ny; nz = im->nz; nxy = nx*ny; nxyz = nxy*nz;
-
-   iar = MRI_FLOAT_PTR(im) ;
-
-#pragma omp critical (MALLOC)
-   skin = (byte *)calloc(sizeof(byte), nxyz);
-   ijkm = nxyz-nxy-1;
-   for( ijk=kk=0 ; kk < nz ; kk++ ){
-     for( jj=0 ; jj < ny ; jj++ ){
-       for( ii=0 ; ii < nx ; ii++,ijk++ ){
-         if( !INMASK(ijk) ) continue ;
-         if (  ii == 0    || jj == 0    || kk == 0 ||
-               ii == nx-1 || jj == ny-1 || jj == nz-1 ||
-               ijk < nxy || ijk > ijkm) {
-            skin[ijk] = 1; /* in mask, on edge of volume,
-                              or close to boundary slices */
-         } else if (        !INMASK(ijk-1)  || !INMASK(ijk+1) ||
-                     !INMASK(ijk-nx) || !INMASK(ijk+nx)||
-                     !INMASK(ijk-nxy)|| !INMASK(ijk+nxy) ){
-            skin[ijk] = 1; /* on edge of mask */
-         }
-       }
-     }
-   }
-
-#pragma omp critical (MALLOC)
-   qar = (float *)calloc(sizeof(float),nxyz) ;
-
-   for( nn=0 ; nn < nrep ; nn++ ){
-     for( ijk=kk=0 ; kk < nz ; kk++ ){
-      for( jj=0 ; jj < ny ; jj++ ){
-       for( ii=0 ; ii < nx ; ii++,ijk++ ){
-         if( !INMASK(ijk) ) continue ;
-         vout = iar[ijk] ;
-         if (!skin[ijk]) { /* Not skin, go fast */
-            qar[ijk] = (iar[ijk]     +
-                        iar[ijk-1]   + iar[ijk+1]  +
-                        iar[ijk-nx]  + iar[ijk+nx] +
-                        iar[ijk-nxy] + iar[ijk+nxy] ) / 7.0;
-         } else { /* skin voxel, go slow */
-            vout = 1.0;
-            qar[ijk] = iar[ijk];
-            if( ii-1 >= 0 && INMASK(ijk-1) ){
-             qar[ijk] += qar[ijk-1]; ++vout;
-            }
-            if( ii+1 < nx && INMASK(ijk+1) ){
-             qar[ijk] += qar[ijk+1]; ++vout;
-            }
-            if( jj-1 >= 0 && INMASK(ijk-nx) ){
-             qar[ijk] += qar[ijk-nx]; ++vout;
-            }
-            if( jj+1 < ny && INMASK(ijk+nx) ){
-             qar[ijk] += qar[ijk+nx]; ++vout;
-            }
-            if( kk-1 >= 0 && INMASK(ijk-nxy) ){
-             qar[ijk] += qar[ijk-nxy]; ++vout;
-            }
-            if( kk+1 < nz && INMASK(ijk+nxy) ){
-             qar[ijk] += qar[ijk+nxy]; ++vout;
-            }
-            qar[ijk] /= vout;
-         }
-     }}}
-
-     AAmemcpy(iar,qar,sizeof(float)*nxyz) ;
-   }
-
-#pragma omp critical (MALLOC)
-   free((void *)qar) ;
-#pragma omp critical (MALLOC)
-   free((void *)skin) ;
-   EXRETURN ;
-}
-
 /*----------------------------------------------------------------------------*/
 
 #undef  DMAX
@@ -423,70 +337,10 @@ ENTRY("mri_blur3D_addfwhm") ;
    dz = im->dz; if( dz == 0.0f ) dz = 1.0f; else if( dz < 0.0f ) dz = -dz;
 
    mri_blur3D_getfac( fwhm , dx,dy,dz , &nrep,&fx,&fy,&fz ) ;
-
-   if( 1 || MRILIB_verb )
-     INFO_message("mri_blur3D: #iter=%d fx=%.5f fy=%.5f fz=%.5f",nrep,fx,fy,fz) ;
    if( nrep < 0 || fx < 0.0f || fy < 0.0f || fz < 0.0f ) EXRETURN ;
 
-   mri_blur3D_inmask( im , mask , fx,fy,fz , nrep ) ;
-
-   EXRETURN ;
-}
-
-/*----------------------------------------------------------------------------*/
-/* 24 Mar 2021 */
-
-void mri_blur3D_getfac3( float fwhmx, float fwhmy, float fwhmz ,
-                         float dx   , float dy   , float dz    ,
-                         int *nrep , float *fx , float *fy , float *fz )
-{
-   float fxx  =0.0f , fyy  =0.0f , fzz  =0.0f ;
-   int   nrepx=0    , nrepy=0    , nrepz=0    , nrepout=0 ;
-
-   if( fwhmx > 0.0f && dx > 0.0f ) nrepx = 2 + (int)(fwhmx*fwhmx/(dx*dx)) ;
-   if( fwhmy > 0.0f && dy > 0.0f ) nrepy = 2 + (int)(fwhmy*fwhmy/(dy*dy)) ;
-   if( fwhmz > 0.0f && dz > 0.0f ) nrepz = 2 + (int)(fwhmz*fwhmz/(dz*dz)) ;
-
-   if( nrepx > nrepout ) nrepout = nrepx ;
-   if( nrepy > nrepout ) nrepout = nrepy ;
-   if( nrepz > nrepout ) nrepout = nrepz ;
-
-   if( fwhmx > 0.0f && dx > 0.0f ) fxx = 0.045084f*(fwhmx*fwhmx)/(nrepout*dx*dx) ;
-   if( fwhmy > 0.0f && dy > 0.0f ) fyy = 0.045084f*(fwhmy*fwhmy)/(nrepout*dy*dy) ;
-   if( fwhmz > 0.0f && dz > 0.0f ) fzz = 0.045084f*(fwhmz*fwhmz)/(nrepout*dz*dz) ;
-
-   *fx = fxx ; *fy = fyy ; *fz = fzz ; *nrep = nrepout ;
-   return ;
-}
-
-/*----------------------------------------------------------------------------*/
-/* 24 Mar 2021 */
-
-void mri_blur3D_addfwhm3( MRI_IMAGE *im , byte *mask , float fwhmx,float fwhmy,float fwhmz )
-{
-   int nrep=-1 ;
-   float fx=-1.0f,fy=-1.0f,fz=-1.0f , dx,dy,dz ;
-
-ENTRY("mri_blur3D_addfwhm3") ;
-
-   if( im == NULL ) EXRETURN ;
-
-#if 0
-   if( fwhmx == fwhmy && fwhmx == fwhmz ){
-     mri_blur3D_addfwhm( im , mask , fwhmx ) ;
-     EXRETURN ;
-   }
-#endif
-
-   dx = im->dx; if( dx == 0.0f ) dx = 1.0f; else if( dx < 0.0f ) dx = -dx;
-   dy = im->dy; if( dy == 0.0f ) dy = 1.0f; else if( dy < 0.0f ) dy = -dy;
-   dz = im->dz; if( dz == 0.0f ) dz = 1.0f; else if( dz < 0.0f ) dz = -dz;
-
-   mri_blur3D_getfac3( fwhmx,fwhmy,fwhmz , dx,dy,dz , &nrep,&fx,&fy,&fz ) ;
-
-   if( 1 || MRILIB_verb )
+   if( MRILIB_verb )
      INFO_message("mri_blur3D: #iter=%d fx=%.5f fy=%.5f fz=%.5f",nrep,fx,fy,fz) ;
-   if( nrep <= 0 || (fx <= 0.0f && fy <= 0.0f && fz <= 0.0f) ) EXRETURN ;
 
    mri_blur3D_inmask( im , mask , fx,fy,fz , nrep ) ;
 
@@ -494,7 +348,7 @@ ENTRY("mri_blur3D_addfwhm3") ;
 }
 
 /*----------------------------------------------------------------------------*/
-/*! A version of mri_blur3D_addfwhm that can be about 20%faster under certain
+/*! A version of mri_blur3D_addfwhm that can be about 20%faster under certain 
    conditions. See mri_blur3D_inmask_speedy for details.
    ZSS March 2011
 */
@@ -523,13 +377,11 @@ ENTRY("mri_blur3D_addfwhm_speedy") ;
    } else {
       INFO_message("mri_blur3D_addfwhm_speedy:\n"
                    " Thin volume or 2D blurring, Going the slow route.");
-      mri_blur3D_inmask( im , mask , fx,fy,fz , nrep ) ;
+      mri_blur3D_inmask( im , mask , fx,fy,fz , nrep ) ; 
    }
    EXRETURN ;
 }
 
-
-#ifndef MRILIB_MINI
 /*----------------------------------------------------------------------------*/
 /*! Blur a vectim, by converting each time point to a 3D image,
     blurring that image, and then putting it back into the vectim.
@@ -572,13 +424,10 @@ ENTRY("mri_blur3d_vectim") ;
 #pragma omp critical (BLUR3D_vectim)
    { qim = mri_new_vol( nx,ny,nz , MRI_float ) ; qar = MRI_FLOAT_PTR(qim) ; }
 
-#ifdef USE_OMP
-   if( MRILIB_verb ) ININFO_message(" start OpenMP thread %d",omp_get_thread_num());
-#endif
-
 #pragma omp for
    for( iv=0 ; iv < vim->nvals ; iv++ ){
-     AAmemset( qar , 0 , sizeof(float)*nvox ) ;
+#pragma omp critical (MEMSET)
+     memset( qar , 0 , sizeof(float)*nvox ) ;
      for( jj=0 ; jj < vim->nvec ; jj++ ){
        var = VECTIM_PTR(vim,jj) ; qar[ivar[jj]] = var[iv] ;
      }
@@ -596,4 +445,3 @@ ENTRY("mri_blur3d_vectim") ;
 
    free(mmm) ; EXRETURN ;
 }
-#endif /* MRILIB_MINI */
