@@ -22,15 +22,8 @@
 #define DDA_SCALE 8192
 
 /*---------------------- Set opacity [22 Jul 2004] ----------------------------*/
-static int   force_opaque=0 ;
-static float opa = 1.0f ;
-void mri_draw_opacity( float val )
-{
-   if( force_opaque ) opa = 1.0f ;
-   else if( val >= 0.0 && val <= 1.0 ) opa = val ;
-}
-
-void mri_draw_force_opaque(int fo){ force_opaque = fo ; }
+static float opa = 1.0 ;
+void mri_draw_opacity( float val ){ if( val >= 0.0 && val <= 1.0 ) opa = val ; }
 
 #undef  ASSPIX
 #undef  ASSPIX_OLD
@@ -66,8 +59,8 @@ void ppmd_filledrectangle( byte *pixels, int cols, int rows,
 
     /* Draw. */
     for ( row = cy; row < cy + cheight; ++row )
-      for ( col = cx; col < cx + cwidth; ++col )
-          ASSPIX(pixels,col,row,r,g,b) ;
+	for ( col = cx; col < cx + cwidth; ++col )
+            ASSPIX(pixels,col,row,r,g,b) ;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -142,45 +135,41 @@ void ppmd_line( byte *pixels, int cols, int rows,
     } /* end of clip */
 
     /* Draw, using a simple DDA. */
+    if ( abs( cx1 - cx0 ) > abs( cy1 - cy0 ) ) { /* Loop over X domain. */
+	register long dy, srow;
+	register int dx, col, row, prevrow;
 
-   if ( abs( cx1 - cx0 ) > abs( cy1 - cy0 ) ) { /* Loop over X domain. */
-	 register long dy, srow;
-	 register int dx, col, row ;
-
-	 if ( cx1 > cx0 ) dx =  1;
-	 else             dx = -1;
-	 dy = ( cy1 - cy0 ) * DDA_SCALE / abs( cx1 - cx0 );
-	 row  = cy0;
-	 srow = row * DDA_SCALE + DDA_SCALE / 2;
-	 col  = cx0;
-	 for ( ; ; ) {
-       ASSPIX(pixels,col,row,r,g,b) ;
+	if ( cx1 > cx0 ) dx =  1;
+	else             dx = -1;
+	dy = ( cy1 - cy0 ) * DDA_SCALE / abs( cx1 - cx0 );
+	prevrow = row = cy0;
+	srow = row * DDA_SCALE + DDA_SCALE / 2;
+	col = cx0;
+	for ( ; ; ) {
+            ASSPIX(pixels,col,row,r,g,b) ;
 	    if ( col == cx1 ) break;
 	    srow += dy; row = srow / DDA_SCALE; col += dx;
-    }
-   } else { /* Loop over Y domain. */
-	 register long dx, scol;
-	 register int dy, col, row ;
+        }
+    } else { /* Loop over Y domain. */
+	register long dx, scol;
+	register int dy, col, row, prevcol;
 
-	 if ( cy1 > cy0 ) dy =  1;
-	 else             dy = -1;
-	 dx = ( cx1 - cx0 ) * DDA_SCALE / abs( cy1 - cy0 );
-	 row  = cy0;
-	 col  = cx0;
-	 scol = col * DDA_SCALE + DDA_SCALE / 2;
-	 for ( ; ; ) {
-       ASSPIX(pixels,col,row,r,g,b) ;
+	if ( cy1 > cy0 ) dy =  1;
+	else             dy = -1;
+	dx = ( cx1 - cx0 ) * DDA_SCALE / abs( cy1 - cy0 );
+	row = cy0;
+	prevcol = col = cx0;
+	scol = col * DDA_SCALE + DDA_SCALE / 2;
+	for ( ; ; ) {
+            ASSPIX(pixels,col,row,r,g,b) ;
 	    if ( row == cy1 ) break;
 	    row += dy; scol += dx; col = scol / DDA_SCALE;
+        }
     }
-   }
-
-   return ;
 }
 
 /*----------------------------------------------------------------------------*/
 
-#if 0   /*-------------------- NOT USED AT THIS TIME -----------------------*/
 #define SPLINE_THRESH 3
 
 /*! Draw a spline between 3 points, using recursion and lines. */
@@ -207,11 +196,9 @@ void ppmd_spline3( byte *pixels, int cols, int rows,
     else
 	ppmd_line( pixels, cols, rows, xb, yb, x2, y2, r,g,b ) ;
 }
-#endif  /*-------------------- spline drawing ------------------------------*/
 
 /*----------------------------------------------------------------------------*/
 
-#if 0   /*-------------------- NOT USED AT THIS TIME -----------------------*/
 /*! Draw a spline between a bunch of points. */
 
 static
@@ -229,7 +216,6 @@ void ppmd_polyspline( byte *pixels, int cols, int rows,
     }
     ppmd_spline3( pixels, cols, rows, x, y, xc[nc - 1], yc[nc - 1], x1, y1, r,g,b ) ;
 }
-#endif  /*-------------------- spline drawing ------------------------------*/
 
 /*----------------------------------------------------------------------------*/
 
@@ -250,15 +236,15 @@ void ppmd_circle( byte *pixels, int cols, int rows,
     ASSPIX(pixels,x+cx,y+cy,r,g,b) ;
     nopointsyet = 1;
     do {
-	  prevx = x; prevy = y;
-	  sx += e * sy / DDA_SCALE;
-	  sy -= e * sx / DDA_SCALE;
-	  x   = sx / DDA_SCALE;
-	  y   = sy / DDA_SCALE;
-	  if ( x != prevx || y != prevy ) {
+	prevx = x; prevy = y;
+	sx += e * sy / DDA_SCALE;
+	sy -= e * sx / DDA_SCALE;
+	x = sx / DDA_SCALE;
+	y = sy / DDA_SCALE;
+	if ( x != prevx || y != prevy ) {
             nopointsyet = 0;
             ASSPIX(pixels,x+cx,y+cy,r,g,b) ;
-     }
+        }
     } while ( nopointsyet || x != x0 || y != y0 );
 }
 
@@ -657,10 +643,10 @@ void ppmd_text(byte *pixels, int cols, int rows,
 			    int tx1, ty1, tx2, ty2;
 
                             /* Note that up until this  moment  we've  been
-			       working	in  an	arbitrary model coordinate
+			       working	in  an	arbitrary model co-ordinate
 			       system with  fixed  size  and  no  rotation.
 			       Before  drawing	the  stroke,  transform  to
-			       viewing coordinates to	honour	the  height
+			       viewing co-ordinates to	honour	the  height
 			       and angle specifications. */
 
 			    mx1 = (lx * height) / Scalef;
