@@ -8,6 +8,7 @@
 
 /*** Not 7D safe ***/
 
+#define MAX_NUP 32
 
 static void (*usammer)(int,int,float *,float *) = upsample_7 ;
 
@@ -49,13 +50,12 @@ MRI_IMAGE * mri_dup2D( int nup , MRI_IMAGE *imin )
 ENTRY("mri_dup2D") ;
    /*-- sanity checks --*/
 
-   if( nup < 1 || imin == NULL ) RETURN( NULL );
+   if( nup < 1 || nup > MAX_NUP || imin == NULL ) RETURN( NULL );
 
    if( nup == 1 ){ newim = mri_to_mri( imin->kind, imin ); RETURN(newim); }
 
    /* does the user want neighbor interpolation?     22 Feb 2004 [rickr] */
-
-   if( usammer_mode != -7 && AFNI_yesenv("AFNI_IMAGE_ZOOM_NN") ){
+   if ( AFNI_yesenv("AFNI_IMAGE_ZOOM_NN") ) {
       mri_dup2D_mode(0);
       NNmode = 1;
    }
@@ -86,30 +86,31 @@ ENTRY("mri_dup2D") ;
      if ( NNmode )
          qqim = mri_dup2D_rgb_NN(imin, nup);  /* 22 Feb 2004 [rickr] */
      else {
-       if( usammer_mode != -7 ){
-         switch(nup){
-           case 4: qqim = mri_dup2D_rgb4(imin); break; /* special purpose fast codes */
-           case 3: qqim = mri_dup2D_rgb3(imin); break; /* using fixed pt arithmetic  */
-           case 2: qqim = mri_dup2D_rgb2(imin); break;
-         }
-       }
-       if( qqim == NULL ){ /*-- other factors: do each color separately as a byte image --*/
-         MRI_IMARR *imtriple ; MRI_IMAGE *rim, *gim, *bim, *tim ;
+       switch(nup){
+         case 4: qqim = mri_dup2D_rgb4(imin); break; /* special purpose fast codes */
+         case 3: qqim = mri_dup2D_rgb3(imin); break; /* using fixed pt arithmetic  */
+         case 2: qqim = mri_dup2D_rgb2(imin); break;
 
-         imtriple = mri_rgb_to_3byte( imin ) ;
-         if( imtriple == NULL ){                 /* should never happen */
-           fprintf(stderr,"*** mri_rgb_to_3byte fails in mri_dup2D!\n"); RETURN(NULL);
+        /*-- other factors: do each color separately as a byte image --*/
+        default:{
+           MRI_IMARR *imtriple ; MRI_IMAGE *rim, *gim, *bim, *tim ;
+
+           imtriple = mri_rgb_to_3byte( imin ) ;
+           if( imtriple == NULL ){
+             fprintf(stderr,"*** mri_rgb_to_3byte fails in mri_dup2D!\n"); RETURN(NULL);
+           }
+           rim = IMAGE_IN_IMARR(imtriple,0) ;
+           gim = IMAGE_IN_IMARR(imtriple,1) ;
+           bim = IMAGE_IN_IMARR(imtriple,2) ; FREE_IMARR(imtriple) ;
+           tim = mri_dup2D( nup, rim ); mri_free(rim); rim = tim;
+           tim = mri_dup2D( nup, gim ); mri_free(gim); gim = tim;
+           tim = mri_dup2D( nup, bim ); mri_free(bim); bim = tim;
+           newim = mri_3to_rgb( rim, gim, bim ) ;
+           mri_free(rim) ; mri_free(gim) ; mri_free(bim) ;
+           MRI_COPY_AUX(newim,imin) ;
+           qqim = newim ;
          }
-         rim = IMAGE_IN_IMARR(imtriple,0) ;
-         gim = IMAGE_IN_IMARR(imtriple,1) ;
-         bim = IMAGE_IN_IMARR(imtriple,2) ; FREE_IMARR(imtriple) ;
-         tim = mri_dup2D( nup, rim ); mri_free(rim); rim = tim;
-         tim = mri_dup2D( nup, gim ); mri_free(gim); gim = tim;
-         tim = mri_dup2D( nup, bim ); mri_free(bim); bim = tim;
-         newim = mri_3to_rgb( rim, gim, bim ) ;
-         mri_free(rim) ; mri_free(gim) ; mri_free(bim) ;
-         MRI_COPY_AUX(newim,imin) ;
-         qqim = newim ;
+         break ;
        }
      }
 
@@ -118,7 +119,7 @@ ENTRY("mri_dup2D") ;
 
    /*-- Special case: byte-valued image upsampled by 2/3/4 [13 Mar 2002] --*/
 
-   if( imin->kind == MRI_byte && nup <= 4 && usammer_mode != -7 ){
+   if( imin->kind == MRI_byte && nup <= 4 ){
      void (*usbyte)(int,byte *,byte *) = NULL ;
      byte *bar=MRI_BYTE_PTR(imin) , *bnew , *cold, *cnew ;
      nx = imin->nx; ny = imin->ny; nxup = nx*nup; nyup = ny*nup ;
@@ -178,8 +179,6 @@ ENTRY("mri_dup2D") ;
 
    switch( imin->kind ){
 
-      default: break ;
-
       case MRI_byte:{
          byte * bar ; MRI_IMAGE * bim ; float fmin , fmax ;
 
@@ -233,10 +232,6 @@ ENTRY("mri_dup2D") ;
 #define S_P3(x) (x*(x*x-1.0)*(x*x-4.0)*(x+3.0)*(4.0-x)*0.001388888889)
 #define S_P4(x) (x*(x*x-1.0)*(x*x-4.0)*(x*x-9.0)*0.0001984126984)
 
-/* ZFILL (zero fill off edges) is not set by default:
-    would have to be set by compile command
-    or by a file #include-ing this one                */
-
 #ifdef ZFILL
 #  define FINS(i) ( ((i)<0 || (i)>=nar) ? 0.0 : far[(i)] )
 #else
@@ -253,8 +248,6 @@ ENTRY("mri_dup2D") ;
                     + fp1[k] * FINS(i+1) + fp2[k] * FINS(i+2) \
                     + fp3[k] * FINS(i+3) + fp4[k] * FINS(i+4)  )
 
-#define RENUP_VEC(vv,kk)  { (vv) = (float *)realloc((vv),(kk)*sizeof(float)); }
-
 /*----------------------------------------------------------------------------
   Up sample an array far[0..nar-1] nup times to produce fout[0..nar*nup-1].
   Uses 7th order polynomial interpolation.
@@ -264,21 +257,13 @@ void upsample_7( int nup , int nar , float * far , float * fout )
 {
    int kk,ii , ibot,itop ;
    static int nupold = -1 ;
-   static int nupmax = 0;
-   static float *fm3=NULL, *fm2=NULL, *fm1=NULL, *f00=NULL,
-                *fp1=NULL, *fp2=NULL, *fp3=NULL, *fp4=NULL;
+   static float fm3[MAX_NUP], fm2[MAX_NUP], fm1[MAX_NUP], f00[MAX_NUP],
+                fp1[MAX_NUP], fp2[MAX_NUP], fp3[MAX_NUP], fp4[MAX_NUP] ;
 
    /*-- sanity checks --*/
 
-   if( nup < 1 || nar < 2 || far == NULL || fout == NULL ) return ;
+   if( nup < 1 || nup > MAX_NUP || nar < 2 || far == NULL || fout == NULL ) return ;
 
-   if (nupmax < nup) {
-      nupmax = nup;
-      RENUP_VEC(fm3,nup); RENUP_VEC(fm2,nup);
-      RENUP_VEC(fm1,nup); RENUP_VEC(f00,nup);
-      RENUP_VEC(fp1,nup); RENUP_VEC(fp2,nup);
-      RENUP_VEC(fp3,nup); RENUP_VEC(fp4,nup);
-   }
    if( nup == 1 ){ memcpy( fout, far, sizeof(float)*nar ); return; }
 
    /*-- initialize interpolation coefficient, if nup has changed --*/
@@ -299,25 +284,25 @@ void upsample_7( int nup , int nar , float * far , float * fout )
    ibot = 3 ; itop = nar-5 ;
 
    switch( nup ){
-      default:       /* outer and inner loops */
+      default:
         for( ii=ibot ; ii <= itop ; ii++ )
           for( kk=0 ; kk < nup ; kk++ ) fout[kk+ii*nup] = INT7(kk,ii) ;
       break ;
 
-      case 2:        /* unrolled for optimizer */
+      case 2:
         for( ii=ibot ; ii <= itop ; ii++ ){
           fout[ii*nup]   = INT7(0,ii) ; fout[ii*nup+1] = INT7(1,ii) ;
         }
       break ;
 
-      case 3:        /* unrolled for optimizer */
+      case 3:
         for( ii=ibot ; ii <= itop ; ii++ ){
           fout[ii*nup]   = INT7(0,ii) ; fout[ii*nup+1] = INT7(1,ii) ;
           fout[ii*nup+2] = INT7(2,ii) ;
         }
       break ;
 
-      case 4:        /* unrolled for optimizer */
+      case 4:
         for( ii=ibot ; ii <= itop ; ii++ ){
           fout[ii*nup]   = INT7(0,ii) ; fout[ii*nup+1] = INT7(1,ii) ;
           fout[ii*nup+2] = INT7(2,ii) ; fout[ii*nup+3] = INT7(3,ii) ;
@@ -325,21 +310,13 @@ void upsample_7( int nup , int nar , float * far , float * fout )
       break ;
    }
 
-   /*-- do what has not be done --*/
+   /*-- interpolate the outside edges --*/
 
-   if( ibot > itop ){    /* for very short input arrays (nar < 8) */
+   for( ii=0 ; ii < ibot ; ii++ )
+     for( kk=0 ; kk < nup ; kk++ ) fout[kk+ii*nup] = FINT7(kk,ii) ;
 
-     for( ii=0 ; ii < nar ; ii++ )
-       for( kk=0 ; kk < nup ; kk++ ) fout[kk+ii*nup] = FINT7(kk,ii) ;
-
-   } else {              /* just the edges for longer arrays */
-
-     for( ii=0 ; ii < ibot ; ii++ )
-       for( kk=0 ; kk < nup ; kk++ ) fout[kk+ii*nup] = FINT7(kk,ii) ;
-     for( ii=itop+1 ; ii < nar ; ii++ )
-       for( kk=0 ; kk < nup ; kk++ ) fout[kk+ii*nup] = FINT7(kk,ii) ;
-
-   }
+   for( ii=itop+1 ; ii < nar ; ii++ )
+     for( kk=0 ; kk < nup ; kk++ ) fout[kk+ii*nup] =  FINT7(kk,ii) ;
 
    return ;
 }
@@ -359,18 +336,11 @@ void upsample_1( int nup , int nar , float * far , float * fout )
 {
    int kk,ii , ibot,itop ;
    static int nupold=-1 ;
-   static int nupmax=0;
-   static float *f00=NULL, *fp1=NULL ;
+   static float f00[MAX_NUP], fp1[MAX_NUP] ;
 
    /*-- sanity checks --*/
 
-   if( nup < 1 || nar < 2 || far == NULL || fout == NULL ) return ;
-
-   if (nupmax < nup) {
-      nupmax = nup;
-      RENUP_VEC(f00,nup);
-      RENUP_VEC(fp1,nup);
-   }
+   if( nup < 1 || nup > MAX_NUP || nar < 2 || far == NULL || fout == NULL ) return ;
 
    if( nup == 1 ){ memcpy( fout, far, sizeof(float)*nar ); return; }
 
@@ -507,7 +477,7 @@ ENTRY("mri_dup2D_rgb_NN") ;
    bout  = (rgbyte *) MRI_RGB_PTR(outim) ;
 
    for( jj=0 ; jj < ny ; jj++ ){   /* loop over input rows */
-
+     
      for ( kk= 0; kk < nup; kk++ ) { /* do rows nup times */
 
        bin1 = bin;
@@ -515,7 +485,7 @@ ENTRY("mri_dup2D_rgb_NN") ;
        for( ii=0 ; ii < nx ; ii++ ){
 
          for ( ll= 0; ll < nup; ll++ ) {
-           *bout++ = *bin1;
+	     *bout++ = *bin1;
          }
 
          bin1++;
