@@ -8,7 +8,6 @@
 
 static char * extract_bytes_from_file(FILE *fp, off_t start, size_t len,
                                       int strize);
-static int check_for_3D_acquisition( char ** epos, int * slices);
 
 /* global noting whether to use this functionality */
 int use_new_mosaic_code = 1;  /* 1 means use mri_process_siemens.c  [rickr] */
@@ -38,7 +37,7 @@ int process_siemens_mosaic(
    char * s_start=NULL, * s_start2=NULL, * s_end=NULL; /* KRH 25 Jul 2003 */
    int    mos_nx=0, mos_ny=0 , mos_ix=0, mos_iy=0;
    int    len=0,loc=0 , aa,bb , ii ;
-   int    verb = g_dicom_ctrl.verb;   /* just a convenience */
+   int    verb = g_info.verb;   /* just a convenience */
 
    ENTRY("process_siemens_mosaic") ;
    
@@ -107,15 +106,13 @@ int process_siemens_mosaic(
 
    /* KRH 25 Jul 2003 try to shrink Sstr between BEGIN and END,
     * particularly if there are 2 BEGINs (require both BEGIN and END) */
-   /* Now there might be something between BEGIN and ### ...
-    *                                   27 Jan 2012 [dglen, rickr]    */
-   s_start = strstr(*Sstr,    "### ASCCONV BEGIN");
-   if( s_start ) s_end = strstr(s_start, "### ASCCONV END");
+   s_start = strstr(*Sstr,    "### ASCCONV BEGIN ###");
+   if( s_start ) s_end = strstr(s_start, "### ASCCONV END ###");
    if( s_end ) {
       char *s_tmp;
       int s_size;
 
-      s_start2 = strstr(s_start+21, "### ASCCONV BEGIN");
+      s_start2 = strstr(s_start+21, "### ASCCONV BEGIN ###");
  
       /* update start to start2, if it seems appropriate */
       if( s_start2 && (s_start2 < s_end) ) s_start = s_start2;
@@ -137,7 +134,7 @@ int process_siemens_mosaic(
    for(ii = 0; ii < 3; ii++)
         Sinfo->have_data[ii] = 0; /* 25 Feb 03 Initialize new member KRH */
 
-   get_siemens_extra_info( *Sstr , Sinfo, epos );
+   get_siemens_extra_info( *Sstr , Sinfo );
    
    if( ! Sinfo->good ){
       static int nwarn=0 ;
@@ -270,7 +267,7 @@ int read_mosaic_data( FILE *fp, MRI_IMAGE *im, MRI_IMARR *imar,
    char * dar=NULL, * iar ;
    int    nvox, yy, xx, nxx, ii, jj, slice ;
    int    mos_nx, mos_ny, mos_nz, mos_ix, mos_iy, mosaic_num;
-   int    verb = g_dicom_ctrl.verb;  /* typing ease, default level is 1 */
+   int    verb = g_info.verb;  /* typing ease, default level is 1 */
 
    ENTRY("read_mosaic_data");
 
@@ -296,7 +293,7 @@ int read_mosaic_data( FILE *fp, MRI_IMAGE *im, MRI_IMARR *imar,
 
    nvox = mos_nx*mos_ny*mos_nz ;         /* total number of voxels */
 
-   if( g_dicom_ctrl.read_data ) {
+   if( g_info.read_data ) {
       dar = (char*)calloc(bpp,nvox) ; /* make space for super-image */
       if(dar==NULL)  {  /* exit if can't allocate memory */
          ERROR_message("Could not allocate memory for mosaic volume");
@@ -325,8 +322,7 @@ int read_mosaic_data( FILE *fp, MRI_IMAGE *im, MRI_IMARR *imar,
       xx = slice % mos_ix; /* xx,yy are indices for position in mosaic matrix */
       yy = slice / mos_iy;
       /* im = mri_new( mos_nx , mos_ny , datum ) ; */
-      im = mri_new_7D_generic(mos_nx,mos_ny, 1,1,1,1,1, datum,
-                              g_dicom_ctrl.read_data);
+      im = mri_new_7D_generic(mos_nx,mos_ny, 1,1,1,1,1, datum,g_info.read_data);
       if( !im ) {
          fprintf(stderr,"** RMD: failed to allocate %d voxel image\n",
                  mos_nx * mos_ny);
@@ -334,7 +330,7 @@ int read_mosaic_data( FILE *fp, MRI_IMAGE *im, MRI_IMARR *imar,
       }
 
       /* if reading data, actually copy data into MRI image */
-      if( g_dicom_ctrl.read_data ) {
+      if( g_info.read_data ) {
          iar = mri_data_pointer( im ) ;             /* sub-image array */
 
          for( jj=0 ; jj < mos_ny ; jj++ )  /* loop over rows inside sub-image */
@@ -375,7 +371,7 @@ int flip_slices_mosaic (Siemens_extra_info *mi, int kor)
   /*       where 1=L-R, 2=P-A, 3=I-S */
   ENTRY("flip_slices_mosaic");
 
-  if( g_dicom_ctrl.verb > 1 ) {
+  if( g_info.verb > 1 ) {
      printf("flip_slices_mosaic kor = %d\n", kor);
      printf("ImageNumbSag,Cor,Tra= %d,%d,%d\n",
             mi->ImageNumbSag, mi->ImageNumbCor, mi->ImageNumbTra);
@@ -422,20 +418,19 @@ int apply_z_orient(Siemens_extra_info * Sinfo, char * orients, int * kor,
 
    /* validate the inputs */
    if( !Sinfo || !orients || !zoff || !kor) {
-      if( g_dicom_ctrl.verb )
+      if( g_info.verb )
          fprintf(stderr,"** apply_z_orient, bad params (%p,%p,%p,%p)\n",
                  Sinfo, orients, zoff, kor);
       RETURN(1);
    }
 
    if( !Sinfo->good ) {
-      if(g_dicom_ctrl.verb) fprintf(stderr,"** apply_z_orient but not mosaic");
+      if( g_info.verb ) fprintf(stderr,"** apply_z_orient but not mosaic");
       RETURN(1);
    }
 
    if( *kor > 3 || *kor < 1 ) {
-      if(g_dicom_ctrl.verb )
-         fprintf(stderr,"** apply_z_orient, bad kor = %d\n",*kor);
+      if(g_info.verb )fprintf(stderr,"** apply_z_orient, bad kor = %d\n",*kor);
       RETURN(1);
    }
 
@@ -473,7 +468,7 @@ int apply_z_orient(Siemens_extra_info * Sinfo, char * orients, int * kor,
    if( *kor > 0 ) *zoff = -z0;
    else           *zoff =  z0;
 
-   if( g_dicom_ctrl.verb > 1 )
+   if( g_info.verb > 1 )
       fprintf(stderr,"-- apply_z_orient: z0,z1=(%f,%f), kor=%d, orients=%s\n",
               z0, z1, *kor, orients);
 
@@ -490,14 +485,14 @@ int apply_z_orient(Siemens_extra_info * Sinfo, char * orients, int * kor,
 
     return 0 on success, 1 on error
 -----------------------------------------------------------------------------*/
-int get_siemens_extra_info(char *str, Siemens_extra_info *mi, char ** epos)
+int get_siemens_extra_info(char *str, Siemens_extra_info *mi)
 {
    char *cpt=NULL , *dpt, *ept ;
    int nn , mm , snum , last_snum=-1 ;
    int have_x[2] = {0,0},
        have_y[2] = {0,0},
        have_z[2] = {0,0};
-   int verb = g_dicom_ctrl.verb;  /* typing convenience */
+   int verb = g_info.verb;  /* typing convenience */
    float val ;
    char name[1024] ;
   
@@ -531,8 +526,7 @@ int get_siemens_extra_info(char *str, Siemens_extra_info *mi, char ** epos)
 
    /* require at least 3 of the 4 parameters in slice information */
    while ((nn < 3) && (strlen(ept) > 20)) {  /* mod drg, fredtam */
-     /* use the updated ept for new searches      27 Jan 2012 [rickr, dglen] */
-     cpt = strstr( ept , "sSliceArray.asSlice[" ) ; /* 20 characters minimum */
+     cpt = strstr( str , "sSliceArray.asSlice[" ) ; /* 20 characters minimum */
      if( cpt == NULL ) {
         if( verb > 1 ) fprintf(stderr,"-- GSEI: no sSliceArray.asSlice\n");
         RETURN(0);
@@ -550,7 +544,6 @@ int get_siemens_extra_info(char *str, Siemens_extra_info *mi, char ** epos)
      ept = cpt + 20; /* skip to end of "false match", advance to next KRH */
    }
 
-
    /*-- scan for coordinates, until can't find a good string to scan --*/
    while(1){
      if( nn   <  3                   ) break ;  /* bad conversion set */
@@ -580,7 +573,7 @@ int get_siemens_extra_info(char *str, Siemens_extra_info *mi, char ** epos)
      if( cpt-dpt > 16 ) break ;                 /* too much space */
      if( strncmp(cpt,"sSliceArray.asSlice[",20) != 0 ) break ;  /* bad line */
      /* 04 Mar 2003 moved around to allow for locating "fake matches"  *
-      * of the target text in the binary sections of some mosaic files   */
+      * of the target text in some mosaic files' binary sections       */
 
      /* interpret next string into
          snum = slice subscript (0,1,...)
@@ -601,9 +594,6 @@ int get_siemens_extra_info(char *str, Siemens_extra_info *mi, char ** epos)
      mi->mosaic_num = last_snum+1 ;
    }
 
-   /* maybe it is a 3D acquisition     2 Jun 2016 [rickr,DRG] */
-   if( check_for_3D_acquisition(epos, &mi->mosaic_num) ) RETURN(1);
-
    ept = str;
    if( (cpt = strstr(str,"\nsSliceArray.ucImageNumbSag")) ){
       sscanf(cpt, "%1022s = %x", name, &mi->ImageNumbSag);
@@ -625,51 +615,3 @@ int get_siemens_extra_info(char *str, Siemens_extra_info *mi, char ** epos)
 
    RETURN(0);
 }
-
-/* adjust mi data if 3D volume acquisition
- * return 0 on success                          2 Jun 2016 [rickr,DRG] */
-static int check_for_3D_acquisition(char ** epos, int * nslices)
-{
-   char * cp;
-   int    nread=0, lslices=0;  /* local slices */
-
-   ENTRY("check_for_3D_acquisition");
-   
-   if( ! nslices ) RETURN(0);
-
-   /* maybe we already know what is here */ 
-   if( *nslices > 1 ) RETURN(0);
-
-   /* --------------- check that E_MR_ACQ_TYPE shows 3D --------------- */
-   if( ! epos[E_MR_ACQ_TYPE] ) RETURN(0);
-
-   cp = af_strnstr(epos[E_MR_ACQ_TYPE], "//", 60);
-   if( ! cp ) RETURN(0);
-
-   if( strncmp(cp+2, "3D", 2) ) RETURN(0);
-
-   /* --------------- have 3D, check E_SIEMENS_3D_NSLICES --------------- */
-
-   if( ! epos[E_SIEMENS_3D_NSLICES] ) RETURN(0);
-
-   cp = af_strnstr(epos[E_SIEMENS_3D_NSLICES], "//", 60);
-   if( ! cp ) RETURN(0);
-
-   nread = sscanf(cp+2,"%d" , &lslices);
-   if( nread == 0 ) {
-      if( g_dicom_ctrl.verb > 1 )
-         ERROR_message("** CF3DM: failed to read DICOM 3D nslices from:\n"
-                       "   '%.60s'\n", epos[E_SIEMENS_3D_NSLICES]);
-      RETURN(1);
-   }
-
-   if( lslices <= 1 ) RETURN(0);
-
-   if( g_dicom_ctrl.verb > 1 )
-      INFO_message("++ CF3DM: found %d slices in DICOM 3D\n", lslices);
-
-   *nslices = lslices;
-
-   RETURN(0);
-}
-
