@@ -91,7 +91,7 @@ ENTRY("RBF_evaluate") ;
    int ii , jj , uselin=rbk->uselin ;
    float  rr , xm,ym,zm , xd,yd,zd , rad,rqq , xt,yt,zt , *xx,*yy,*zz ;
    float  xk , yk , zk , sum , *ev ;
-   float b0=0.0,bx=0.0,by=0.0,bz=0.0 , rai ;
+   float b0,bx,by,bz , rai ;
    RBFKINT *kfirst , *klast ; int kbot,ktop ;
 
    /* load some local variables */
@@ -454,7 +454,7 @@ ENTRY("RBF_setup_kranges") ;
    if( rbg->klast != NULL ){ free(rbg->klast) ; rbg->klast = NULL; }
    if( rbg->kfirst!= NULL ){ free(rbg->kfirst); rbg->kfirst= NULL; }
 
-   if( rbk->nknot > RBFKINT_MAX ) EXRETURN ; /* too many to store r/
+   if( rbk->nknot > 65535 ) EXRETURN ; /* can't store as unsigned short */
 
    /* load some local variables */
 
