@@ -42,7 +42,6 @@ static float get_dz(  char **epos);
 static int CheckObliquity(float xc1, float xc2, float xc3, float yc1, float yc2, float yc3);
 static int get_posns_from_elist(char *plist[], char *elist[], char *text,
                                 int nume);
-static int set_sop_iuids(char * estr, int * iuid_maj, int * iuid_min);
 
 /* sorry, dicom is a mess... */
 #include "mri_process_siemens.c"
@@ -51,12 +50,6 @@ int   obl_info_set = 0;
 int   g_is_oblique = 0;
 int   g_image_ori_ind[3] = {0, 0, 0};                   /* ior, jor, kor  */
 float g_image_posn[3]    = {-666.0, -666.0, -666.0};    /* IMAGE_POSITION */
-int   g_ge_nim_acq = -1;               /* number of images in acquisition */
-float g_ge_echo_time = -1.0;           /* GE echo time */
-int   g_ge_echo_num = -1;              /* GE echo number */
-int   g_ge_me_index = -1;
-int   g_sop_iuid_maj = -1;             /* ID SOP Instanced UID (major)    */
-int   g_sop_iuid_min = -1;             /* ID SOP Instanced UID (minor)    */
 
 /*-----------------------------------------------------------------------------------*/
 /* Save the Siemens extra info string in case the caller wants to get it. */
@@ -85,6 +78,7 @@ static void RWC_set_endianosity(void)
 /*---------------------------------------------------------------------------*/
 /* global set via 'to3d -assume_dicom_mosaic'            13 Mar 2006 [rickr] */
 int assume_dicom_mosaic = 0;   /* (case of 1 is equivalent to Rich's change) */
+int use_last_elem = 0;         /* when filling epos list 10 Apr 2009 [rickr] */
 
 #undef  SINT
 #undef  SFLT
@@ -132,7 +126,6 @@ MRI_IMARR * mri_read_dicom( char *fname )
                                       - 1 = little endian, 0 = big - RWCox */
    int un16 = 0 ;      /* 05 Jul 2006 - is it 16 bit unsigned data? */
    int ov16 = 0 ;      /*             - did 16 bit overflow occur? */
-   static int ov16_whine = 1;     /* only whine once   10 Jul 2013 [rickr] */
 
    float xc1=0.0,xc2=0.0,xc3=0.0 , yc1=0.0,yc2=0.0,yc3=0.0 ;
    float xn,yn ; int qq ;
@@ -142,11 +135,10 @@ ENTRY("mri_read_dicom") ;
    if( str_sexinfo != NULL ){ free(str_sexinfo); str_sexinfo=NULL; }
 
    /* clear image-based globals */
-
-   if( ! g_dicom_ctrl.init ) init_dicom_globals(&g_dicom_ctrl);
+   if( ! g_info.init ) init_dicom_globals(&g_info);
 
    if( !mri_possibly_dicom(fname) ){                /* 07 May 2003 */
-     if( g_dicom_ctrl.verb > 1 )
+     if( g_info.verb > 1 )
        ERROR_message("file %s is not possibly DICOM",fname) ;
      RETURN(NULL) ;
    }
@@ -159,7 +151,7 @@ ENTRY("mri_read_dicom") ;
    mri_dicom_noname(1) ;             /* don't print names, just tags */
    ppp = mri_dicom_header( fname ) ; /* print header to malloc()-ed string */
    if( ppp == NULL ){                /* didn't work; not a DICOM file? */
-     if( g_dicom_ctrl.verb > 1 )
+     if( g_info.verb > 1 )
        ERROR_message("file %s is not interpretable as DICOM",fname) ;
      RETURN(NULL) ;
    }
@@ -212,12 +204,9 @@ ENTRY("mri_read_dicom") ;
        }
        if( ts_endian < 0 ){
          static int nwarn=0 ;
-         if( nwarn < NWMAX ){
-           WARNING_message("DICOM file %s: unsupported Transfer Syntax '%s'\n"
-               "***** Reading this data is likely to fail because this format is not understood\n"
-               "***** AFNI reads only uncompressed DICOM. Other formats are not supported.",
+         if( nwarn < NWMAX )
+           WARNING_message("DICOM file %s: unsupported Transfer Syntax '%s'",
                            fname,ts) ;
-         }
          if( nwarn == NWMAX )
            WARNING_message("DICOM: no more Transfer Syntax messages "
                            " will be printed") ;
@@ -303,7 +292,7 @@ ENTRY("mri_read_dicom") ;
    }
    bpp /= 8 ; /* now bytes per pixel, instead of bits */
 
-   if( g_dicom_ctrl.verb > 2 ) fprintf(stderr,"-d dicom: datum %d\n",datum);
+   if( g_info.verb > 2 ) fprintf(stderr,"-d dicom: datum %d\n",datum);
 
    /*** Print some warnings if appropriate ***/
 
@@ -330,7 +319,7 @@ ENTRY("mri_read_dicom") ;
    /* 23 Dec 2002: actually get the rescale params, if environment says to */
 
    if( epos[E_RESCALE_INTERCEPT] != NULL && epos[E_RESCALE_SLOPE] != NULL ){
-     if( ! g_dicom_ctrl.rescale ) {
+     if( ! g_info.rescale ) {
        static int nwarn=0 ;
        if( nwarn < NWMAX )
          fprintf(stderr,
@@ -350,7 +339,7 @@ ENTRY("mri_read_dicom") ;
    /* 23 Dec 2002: actually get the window params, if environment says to */
 
    if( epos[E_WINDOW_CENTER] != NULL && epos[E_WINDOW_WIDTH] != NULL ){
-     if( ! g_dicom_ctrl.window ) {
+     if( ! g_info.window ) {
        static int nwarn=NWMAX+1 ; /* never show these messages   31 Aug 2007 */
        if( nwarn < NWMAX )
          fprintf(stderr,
@@ -387,7 +376,7 @@ ENTRY("mri_read_dicom") ;
    if( epos[E_NUMBER_OF_FRAMES] != NULL ){
      ddd = strstr(epos[E_NUMBER_OF_FRAMES],"//") ;
      if( ddd != NULL ) nz = SINT(ddd+2) ;
-     if( g_dicom_ctrl.verb>2 ) fprintf(stderr,"-- DICOM: num frames = %d\n",nz);
+     if( g_info.verb > 2 ) fprintf(stderr,"-- DICOM: num frames = %d\n",nz);
    }
 
    /* if didn't get nz above, make up a value */
@@ -403,7 +392,7 @@ ENTRY("mri_read_dicom") ;
     static int nwarn=0 ;
     int rv = process_siemens_mosaic(&sexinfo, &str_sexinfo, epos, fname,
                                     assume_dicom_mosaic, nx,ny,nz);
-    if( g_dicom_ctrl.verb > 2 || (g_dicom_ctrl.verb > 1 && nwarn < NWMAX) )
+    if( g_info.verb > 2 || (g_info.verb > 1 && nwarn < NWMAX) )
         fprintf(stderr,"-- used process_siemens_mosaic...\n");
     nwarn++;
     if( rv  < 0 ) { free(ppp); RETURN(NULL); }   /* fatal */
@@ -417,14 +406,13 @@ ENTRY("mri_read_dicom") ;
        mos_ny = sexinfo.mos_ny;
        mos_nz = sexinfo.mos_ix * sexinfo.mos_ix ;  /* total slices in mosaic */
 
-       if( g_dicom_ctrl.verb > 1 )
+       if( g_info.verb > 1 )
           fprintf(stderr,"   mos_ix, iy, nx ,ny, nz = (%d, %d, %d, %d, %d)\n",
                   mos_ix, mos_iy, mos_nx, mos_ny, mos_nz);
     }  /* else not mosaic */
  } else {       /* eventually delete this else condition */
 
-   if( g_dicom_ctrl.verb > 1 )
-      fprintf(stderr,"-- not using process_siemens_mosaic...\n");
+   if(g_info.verb>1) fprintf(stderr,"-- not using process_siemens_mosaic...\n");
 
    /*-- 28 Oct 2002: Check if this is a Siemens mosaic.        --*/
    /*-- 02 Dec 2002: Don't use Acquisition Matrix anymore;
@@ -463,13 +451,11 @@ ENTRY("mri_read_dicom") ;
          ( epos[E_ID_IMAGE_TYPE] && strstr(epos[E_ID_IMAGE_TYPE],"MOSAIC") ) )
        && str_sexinfo                               != NULL   ){
 
-     /* newer DICOM images have extra garbage between BEGIN and ###, so
-      * do not look farther than BEGIN (or END)    31 Jan, 2012 [rickr] */
-     sexi_start = strstr(str_sexinfo, "### ASCCONV BEGIN");
+     sexi_start = strstr(str_sexinfo, "### ASCCONV BEGIN ###");
      if(sexi_start != NULL) {
         /* search for end after start - drg,fredtam 23 Mar 2007 */
-        sexi_start2 = strstr(sexi_start+21, "### ASCCONV BEGIN");
-        sexi_end = strstr(sexi_start, "### ASCCONV END");
+        sexi_start2 = strstr(sexi_start+21, "### ASCCONV BEGIN ###");
+        sexi_end = strstr(sexi_start, "### ASCCONV END ###");
         if (sexi_end != NULL) {
            char *sexi_tmp;
            int sexi_size;
@@ -493,7 +479,7 @@ ENTRY("mri_read_dicom") ;
      /* 25 Feb 03 Initialize new member KRH */
      for(ii = 0; ii < 3; ii++) sexinfo.have_data[ii] = 0;
 
-     get_siemens_extra_info( str_sexinfo , &sexinfo , epos ) ;
+     get_siemens_extra_info( str_sexinfo , &sexinfo ) ;
 
      if( sexinfo.good ){                                 /* if data is good */
        if((        epos[E_ID_IMAGE_TYPE]              != NULL &&
@@ -578,20 +564,11 @@ ENTRY("mri_read_dicom") ;
 
    /* dx,dy first */
 
-   /* Pixel Spacing is defined as the distance between rows and columns,
-    * meaning (akin to reading ny, nx) it is read as dy, dx.  It seems that
-    * not too many people use non-square voxels, though some in D Leopold's
-    * lab do.
-    * see medical.nema.org/DICOM/CP/CPack-36_DOC/cp626_lb.doc
-    *     nipy.sourceforge.net/nibabel/dicom/dicom_orientation.html
-    *     www.cmake.org/Wiki/Proposals:Orientation
-    *                                                   11 Jan 2012 [rickr] */
    if( epos[E_PIXEL_SPACING] != NULL ){
      ddd = strstr(epos[E_PIXEL_SPACING],"//") ;
-     if( ddd != NULL ) sscanf( ddd+2 , "%f\\%f" , &dy , &dx ) ; /* switched */
+     if( ddd != NULL ) sscanf( ddd+2 , "%f\\%f" , &dx , &dy ) ;
      if( dy == 0.0 && dx > 0.0 ) dy = dx ;
-     if( g_dicom_ctrl.verb > 2 )
-        fprintf(stderr,"-- DICOM PSP dx, dy = %f, %f\n", dx, dy);
+     if(g_info.verb>2) fprintf(stderr,"-- DICOM PSP dx, dy = %f, %f\n", dx, dy);
    }
    if( dx == 0.0 && epos[E_FIELD_OF_VIEW] != NULL ){
      ddd = strstr(epos[E_FIELD_OF_VIEW],"//") ;
@@ -600,28 +577,24 @@ ENTRY("mri_read_dicom") ;
        if( dy == 0.0 ) dy = dx ;
        dx /= nx ; dy /= ny ;
      }
-     if( g_dicom_ctrl.verb > 2 )
-        fprintf(stderr,"-- DICOM FOV dx, dy = %f, %f\n", dx, dy);
+     if(g_info.verb>2) fprintf(stderr,"-- DICOM FOV dx, dy = %f, %f\n", dx, dy);
    }
 
    /* get dz now*/
    dz = get_dz(epos);
 
-   if( g_dicom_ctrl.verb > 2 )
-        fprintf(stderr,"-- DICOM dxyz = %f, %f, %f\n", dx,dy,dz);
+   if(g_info.verb>2) fprintf(stderr,"-- DICOM dxyz = %f, %f, %f\n", dx,dy,dz);
 
    /* get dt */
    if( epos[E_REPETITION_TIME] != NULL ){
      ddd = strstr(epos[E_REPETITION_TIME],"//") ;
      if( ddd != NULL ) {
         dt = 0.001f * SFLT(ddd+2) ;  /* ms to s conversion */
-        if( g_dicom_ctrl.verb > 2 )
-           fprintf(stderr,"-- DICOM REP TIME dt = %f s\n", dt);
+        if(g_info.verb>2) fprintf(stderr,"-- DICOM REP TIME dt = %f s\n", dt);
      }
    }
 
    /* check if we might have 16 bit unsigned data that fills all bits */
-   MRILIB_dicom_s16_overflow = 0;   /* track overflow   8 Jul 2013 [rickr] */
    if( bpp == 2 ){
      if( epos[E_PIXEL_REPRESENTATION] != NULL ){
        ddd = strstr(epos[E_PIXEL_REPRESENTATION],"//") ;
@@ -686,11 +659,6 @@ ENTRY("mri_read_dicom") ;
      if( ddd != NULL ) sscanf( ddd+2 , "%f" , &g_image_info.acq_time);
    }
 
-   if( epos[E_SLICE_LOCATION] != NULL ){
-     ddd = strstr(epos[E_SLICE_LOCATION],"//") ;
-     if( ddd != NULL ) sscanf( ddd+2 , "%f" , &g_image_info.slice_loc);
-   }
-
    /* add mosaic info to g_image_info */
    if( mosaic ) {
       g_image_info.is_mosaic  = 1;
@@ -778,7 +746,7 @@ ENTRY("mri_read_dicom") ;
          kor = 6 - abs(ior)-abs(jor) ;   /* which spatial direction is z-axis */
                                          /* where 1=L-R, 2=P-A, 3=I-S */
          have_orients = 1 ;
-         if( g_dicom_ctrl.verb > 2 )
+         if( g_info.verb > 2 )
             fprintf(stderr,"MRILIB_orients=%s (from IMAGE_ORIENTATION)\n",
                     MRILIB_orients) ;
        }
@@ -866,7 +834,7 @@ ENTRY("mri_read_dicom") ;
      }
      MRILIB_orients[6] = '\0' ;
 
-     if( g_dicom_ctrl.verb > 2 )
+     if( g_info.verb > 2 )
         fprintf(stderr,"z0=%f z1=%f kor=%d MRILIB_orients=%s\n",
                 z0,z1,kor,MRILIB_orients) ;
 
@@ -890,40 +858,6 @@ ENTRY("mri_read_dicom") ;
       }
    }
 
-   /**---------- for GE multi-echo sorting ----------**/
-
-   /* check for GE echo time */
-   if( epos[E_GE_ECHO_TIME] ){
-      ddd = strstr(epos[E_GE_ECHO_TIME],"//");
-      if( ddd ) g_ge_echo_time = SFLT(ddd+2);
-   }
-
-   /* check for GE echo number */
-   if( epos[E_GE_ECHO_NUMBER] ){
-      ddd = strstr(epos[E_GE_ECHO_NUMBER],"//");
-      if( ddd ) g_ge_echo_num = SINT(ddd+2);
-   }
-
-   /* check for GE multi-echo index */
-   if( epos[E_GE_ME_INDEX] ){
-      ddd = strstr(epos[E_GE_ME_INDEX],"//");
-      if( ddd ) g_ge_me_index = SINT(ddd+2);
-   }
-
-   /* check for ID SOP Instance UID */
-   if( epos[E_SOP_IUID] ){
-      ddd = strstr(epos[E_SOP_IUID],"//");
-      set_sop_iuids(ddd+2, &g_sop_iuid_maj, &g_sop_iuid_min);
-   }
-
-   /* check for num images in acquisition */
-   if( epos[E_NIM_IN_ACQ] ){
-      ddd = strstr(epos[E_NIM_IN_ACQ],"//");
-      if( ddd ) g_ge_nim_acq = SINT(ddd+2);
-   }
-
-   /**---------- end GE multi-echo sorting ----------**/
-
    /** use image position vector to set offsets,
        and (2cd time in) the z-axis orientation **/
 
@@ -936,7 +870,7 @@ ENTRY("mri_read_dicom") ;
          static float zoff ;      /* saved from nzoff=0 case */
          float zz = xyz[abs(kor)-1] ;  /* kor from orients above */
 
-     if( g_dicom_ctrl.verb > 2 )
+     if( g_info.verb > 2 )
         fprintf(stderr,"IMAGE_POSITION=%f %f %f  kor=%d\n",
                 xyz[0],xyz[1],xyz[2],kor) ;
 
@@ -979,7 +913,7 @@ ENTRY("mri_read_dicom") ;
 
            float qoff = zz - zoff ;    /* vive la difference */
            if( qoff < 0 ) kor = -kor ; /* kor determines z-axis orientation */
-           if( g_dicom_ctrl.verb > 2 )
+           if( g_info.verb > 2 )
               fprintf(stderr,"  nzoff=1 kor=%d qoff=%f\n",kor,qoff) ;
            switch( kor ){
              case  1: MRILIB_orients[4] = 'R'; MRILIB_orients[5] = 'L'; break;
@@ -1020,7 +954,7 @@ ENTRY("mri_read_dicom") ;
        if( qq == 1 ){
          static float zoff ;      /* saved from nzoff=0 case */
 
-       if( g_dicom_ctrl.verb > 2 ) fprintf(stderr,"SLICE_LOCATION = %f\n",zz) ;
+       if( g_info.verb > 2 ) fprintf(stderr,"SLICE_LOCATION = %f\n",zz) ;
 
          if( nzoff == 0 ){  /* 1st DICOM image */
 
@@ -1103,12 +1037,11 @@ ENTRY("mri_read_dicom") ;
    if( !mosaic ){   /*-- 28 Oct 2002: old method, not a mosaic --*/
 
     for( ii=0 ; ii < nz ; ii++ ){
-      if( g_dicom_ctrl.verb > 2 )
-         fprintf(stderr,"++ making image (read_data=%d)\n",
-                 g_dicom_ctrl.read_data);
+      if( g_info.verb > 2 )
+         fprintf(stderr,"++ making image (read_data=%d)\n", g_info.read_data);
 
       /* replace mri_new, since we may not want data  29 Dec 2010 [rickr] */
-      im = mri_new_7D_generic(nx,ny , 1,1,1,1,1, datum, g_dicom_ctrl.read_data);
+      im = mri_new_7D_generic(nx,ny , 1,1,1,1,1, datum , g_info.read_data) ;
       if( !im ) {
          fprintf(stderr,"** MRD: failed to allocate %d voxel image\n", nx*ny);
          free(ppp) ; RETURN(NULL);
@@ -1117,7 +1050,7 @@ ENTRY("mri_read_dicom") ;
       iar = mri_data_pointer( im ) ;       /* data array in struct */
 
       /* if we actually want the data, read it in and possibly swap */
-      if( g_dicom_ctrl.read_data ) {
+      if( g_info.read_data ) {
          fread( iar , bpp , nx*ny , fp ) ;    /* read data directly into it */
 
          if( swap ){                          /* swap bytes? */
@@ -1173,20 +1106,15 @@ ENTRY("mri_read_dicom") ;
    /* make sure im wasn't TRUNCATEd   1 Jul 2008 (and 5 Aug 2008) [rickr] */
    im = IMARR_SUBIM(imar,0) ;
 
-   if( un16 && g_dicom_ctrl.read_data && ov16_whine ){
+   if( un16 && g_info.read_data ){
      for( ov16=ii=0 ; ii < IMARR_COUNT(imar) ; ii++ ){
        short *sar = MRI_SHORT_PTR( IMARR_SUBIM(imar,ii) ) ;
        for( jj=0 ; jj < im->nvox ; jj++ ) if( sar[jj] < 0 ) ov16++ ;
      }
-     if( ov16 ) {
-       MRILIB_dicom_s16_overflow = 1;  /* let calling function know */
+     if( ov16 )
        WARNING_message(
-         "DICOM file %s:\n"
-         "  --> unsigned 16-bit; AFNI stores as signed; %d pixels < 0\n"
-         "  --> consider 'to3d -ushort2float', if not already being applied",
-         fname , ov16 ) ;
-       ov16_whine = 0 ;
-     }
+        "DICOM file %s: unsigned 16-bit; AFNI stores signed: %d pixels < 0" ,
+          fname , ov16 ) ;
    }
 
 
@@ -1194,11 +1122,10 @@ ENTRY("mri_read_dicom") ;
 
    /*-- 23 Dec 2002: implement Rescale, if ordered --*/
 
-   if( rescale_slope > 0.0 && g_dicom_ctrl.read_data ){
+   if( rescale_slope > 0.0 && g_info.read_data ){
      for( ii=0 ; ii < IMARR_COUNT(imar) ; ii++ ){
        im = IMARR_SUBIM(imar,ii) ;
        switch( im->kind ){
-         default: break ;
          case MRI_byte:{
            byte *ar = mri_data_pointer( im ) ;
            for( jj=0 ; jj < im->nvox ; jj++ )
@@ -1226,7 +1153,7 @@ ENTRY("mri_read_dicom") ;
    /*-- 23 Dec 2002: implement Window, if ordered --*/
    /*                section C.11.2.1.2 (page 503)  */
 
-   if( window_width >= 1.0 && g_dicom_ctrl.read_data ){
+   if( window_width >= 1.0 && g_info.read_data ){
      float wbot,wtop,wfac ;
      int ymax=0 ;
 
@@ -1238,7 +1165,6 @@ ENTRY("mri_read_dicom") ;
      }
      if( ymax <= 0 ){
        switch( IMARR_SUBIM(imar,0)->kind ){
-         default:                              break ;
          case MRI_byte:  ymax = MRI_maxbyte  ; break ;
          case MRI_short: ymax = MRI_maxshort ; break ;
          case MRI_int:   ymax = MRI_maxint   ; break ;
@@ -1252,7 +1178,6 @@ ENTRY("mri_read_dicom") ;
        for( ii=0 ; ii < IMARR_COUNT(imar) ; ii++ ){
          im = IMARR_SUBIM(imar,ii) ;
          switch( im->kind ){
-           default: break ;
            case MRI_byte:{
              byte *ar = mri_data_pointer( im ) ;
              for( jj=0 ; jj < im->nvox ; jj++ )
@@ -1285,7 +1210,6 @@ ENTRY("mri_read_dicom") ;
        for( ii=0 ; ii < IMARR_COUNT(imar) ; ii++ ){
          im = IMARR_SUBIM(imar,ii) ;
          switch( im->kind ){
-           default: break ;
            case MRI_byte:{
              byte *ar = mri_data_pointer( im ) ;
              for( jj=0 ; jj < im->nvox ; jj++ )
@@ -1322,55 +1246,16 @@ ENTRY("mri_read_dicom") ;
    g_image_ori_ind[1] = jor;
    g_image_ori_ind[2] = kor;
 
-   if( g_dicom_ctrl.verb > 2 )
+   if( g_info.verb > 2 )
       fprintf(stderr,"-- mri_read_dicom return, orients = %s, TR = %.2f\n"
               "   MRILIB_offsets %f, %f, %f\n   g_image_posn %f, %f, %f\n",
               MRILIB_orients, MRILIB_tr,
               MRILIB_xoff, MRILIB_yoff, MRILIB_zoff,
-              g_image_posn[0], g_image_posn[1], g_image_posn[2]);
-
-    for( ii=0 ; ii < IMARR_COUNT(imar) ; ii++ )    /* 14 Nov 2011 */
-      mri_add_name(fname,IMARR_SUBIM(imar,ii)) ;
+              g_image_posn[0], g_image_posn[1], g_image_posn[2]); 
 
    free(ppp); RETURN( imar );
 }
 
-/* try to extract major and minor indices from the tail of the
- * SOP Instance UID (0008,0018) field, which is unique to every
- * DICOM image (note: 64 bytes, max)
- *
- * do not set return values unless the elements are found
- *
- * return 1 if set, 0 otherwise             28 Aug 2014 [rickr]
- */
-static int set_sop_iuids(char * estr, int * iuid_maj, int * iuid_min)
-{
-   char * endp, * startp ;
-   int    ind, dcount, major=-1, minor=-1;
-
-   if( ! iuid_maj || ! iuid_min || ! estr ) return 0; /* nothing to do */
-
-   /* find end search point, up to a max of 64 characters */
-   for( ind=0, endp=estr; ind<64 && (isdigit(*endp)||*endp=='.'); ind++,endp++)
-      /* nada */ ;
-
-   /* now find starting point, searching for 2 prior '.' char */
-   for( startp = endp-1, dcount=0; startp > estr && dcount < 2; startp-- ) {
-      if( *startp != '.' ) continue;
-      dcount++;
-
-      if( dcount == 1 ) minor = SINT(startp+1);       /* set minor */
-      if( dcount == 2 ) major = SINT(startp+1);       /* set minor */
-   }
-
-   if( startp <= estr || dcount != 2 ) return 0;  /* overkill */
-
-   *iuid_maj = major;
-   *iuid_min = minor;
-
-   return 1;
-}
-
 /*---------- compute slice thickness from DICOM header ----------*/
 
 static float get_dz(  char **epos)
@@ -1577,7 +1462,7 @@ ENTRY("mri_imcount_dicom") ;
      }
    }
 
-  if(g_dicom_ctrl.verb > 3) {
+  if(g_info.verb > 3) {
     fprintf(stderr,"str_sexinfo initially set to %d\n", PTOI(str_sexinfo) );
     if( str_sexinfo ) fprintf(stderr,"length %d\n", (int) strlen(str_sexinfo));
   }
@@ -1594,12 +1479,11 @@ ENTRY("mri_imcount_dicom") ;
      /* KRH 25 Jul 2003 if start and end markers are present for
       * Siemens extra info, cut string down to those boundaries */
 
-     sexi_start = strstr(str_sexinfo, "### ASCCONV BEGIN");
-     if(sexi_start != NULL) {
-        /* search for end after start - drg,fredtam 23 Mar 2007 */
-        sexi_start2 = strstr(sexi_start+21, "### ASCCONV BEGIN");
-        sexi_end = strstr(sexi_start, "### ASCCONV END");
-        if(g_dicom_ctrl.verb > 3)
+     sexi_start = strstr(str_sexinfo, "### ASCCONV BEGIN ###");
+     if(sexi_start != NULL) {  /* search for end after start - drg,fredtam 23 Mar 2007 */
+        sexi_start2 = strstr(sexi_start+21, "### ASCCONV BEGIN ###");
+        sexi_end = strstr(sexi_start, "### ASCCONV END ###");
+        if(g_info.verb > 3)
            fprintf(stderr, "sexi_start %d sexi_start2 %d sexi_end %d\n",
                   PTOI(sexi_start), PTOI(sexi_start2),PTOI(sexi_end) );
         if (sexi_end != NULL) {
@@ -1620,7 +1504,7 @@ ENTRY("mri_imcount_dicom") ;
            sexi_tmp[sexi_size] = '\0';
 	   free(str_sexinfo);
 	   str_sexinfo = sexi_tmp;
-	   if(g_dicom_ctrl.verb > 3)  {
+	   if(g_info.verb > 3)  {
 	     fprintf(stderr,"str_sexinfo now moved to %d\n", PTOI(str_sexinfo));
 	     fprintf(stderr,"sexi_size %d\n", (int) sexi_size);
 	     fprintf(stderr,"length %d\n", (int) strlen(str_sexinfo));
@@ -1631,7 +1515,7 @@ ENTRY("mri_imcount_dicom") ;
      /* end KRH 25 Jul 2003 change */
 
      sexinfo.good = 0 ;  /* start by marking it as bad */
-     get_siemens_extra_info( str_sexinfo , &sexinfo , epos ) ;
+     get_siemens_extra_info( str_sexinfo , &sexinfo ) ;
 
      if( sexinfo.good ){                                   /* if data is good */
 
@@ -1661,7 +1545,7 @@ ENTRY("mri_imcount_dicom") ;
 }
 
 /*---------------------------------------------------------------------------*/
-/*! Normally we will find the first occurrence of each element in the text.
+/*! Normally we will find the first occurance of each element in the text.
  *  Maybe the user wants to use the last, instead.     10 Apr 2009 [rickr]
 -----------------------------------------------------------------------------*/
 
@@ -1670,38 +1554,37 @@ static int get_posns_from_elist(char *plist[], char *elist[], char *text,
 {
    static int check_env = 1;
    int    ee, nset=0;
-   char * cp, etemp[128] ;
+   char * cp;
 
    ENTRY("get_posns_from_elist");
 
-   if( check_env ) {
-      check_env = 0;
-      if ( my_getenv("AFNI_DICOM_USE_LAST_ELEMENT") )
-         g_dicom_ctrl.use_last_elem=AFNI_yesenv("AFNI_DICOM_USE_LAST_ELEMENT");
+   if( check_env && !use_last_elem ) {
+        check_env = 0;
+        cp = getenv("AFNI_DICOM_USE_LAST_ELEMENT") ;
+        if( cp && (*cp == 'Y' || *cp == 'y') ) {
+           use_last_elem = 1 ;
+           fprintf(stderr,"-- will search for last Dicom elements...\n");
+        }
    }
 
    for( ee=0 ; ee < nume ; ee++ ) {
-      strcpy(etemp,elist[ee]) ;  /* 15 Nov 2011 - erase comma */
-      if( etemp[4] == ',' ) etemp[4] = ' ' ;
-
-      plist[ee] = strstr(text,etemp) ;
+      plist[ee] = strstr(text,elist[ee]) ;
       if( plist[ee] ) nset++;
 
-      if( g_dicom_ctrl.verb > 4 ) {
+      if( g_info.verb > 4 ) {
          if(plist[ee]) fprintf(stderr,"-- DICOM field %s set\n", elist[ee]);
          else          fprintf(stderr,"-- DICOM field %s not set\n",elist[ee]);
       }
 
-      if( g_dicom_ctrl.use_last_elem && plist[ee] ) {
-         while( (cp = strstr(plist[ee]+1, etemp)) != NULL ) {
+      if( use_last_elem && plist[ee] ) {
+         while( (cp = strstr(plist[ee]+1, elist[ee])) != NULL ) {
             plist[ee] = cp ;
-            if( g_dicom_ctrl.verb > 4 )
-               fprintf(stderr,".. updating %s...\n",elist[ee]);
+            if(g_info.verb>4) fprintf(stderr,".. updating %s...\n",elist[ee]);
          }
       }
    }
 
-   if( g_dicom_ctrl.verb > 2 )
+   if( g_info.verb > 2 )
       fprintf(stderr,"-- get_posns: set %d of %d fields\n", nset, nume);
 
    RETURN(0);
@@ -1817,7 +1700,7 @@ static void get_siemens_extra_info( char *str , Siemens_extra_info *mi )
      if( cpt-dpt > 16 ) break ;                                 /* too much space */
      if( strncmp(cpt,"sSliceArray.asSlice[",20) != 0 ) break ;   /* bad next line */
      /* 04 Mar 2003 moved this stuff around to allow for locating "fake matches"  *
-      * of the target text in the binary sections of some mosaic files     */
+      * of the target text in some mosaic files' binary sections                  */
 
      /* interpret next string into
          snum = slice subscript (0,1,...)
@@ -1841,21 +1724,21 @@ static void get_siemens_extra_info( char *str , Siemens_extra_info *mi )
    ept = str;
    if(cpt = strstr(str,"\nsSliceArray.ucImageNumbSag")){
       sscanf(cpt, "%1022s = %x", name, &mi->ImageNumbSag);
-      if( g_dicom_ctrl.verb > 2 )
+      if( g_info.verb > 2 )
          fprintf(stderr,"ImageNumbSag in header %x\n",mi->ImageNumbSag);
    }
    else
       mi->ImageNumbSag = 0;
    if(cpt = strstr(str,"\nsSliceArray.ucImageNumbTra")){
       sscanf(cpt, "%1022s = %x", name, &mi->ImageNumbTra);
-      if( g_dicom_ctrl.verb > 2 )
+      if( g_info.verb > 2 )
          fprintf(stderr,"ImageNumbTra in header %x\n",mi->ImageNumbTra);
    }
    else
       mi->ImageNumbTra = 0;
    if(cpt = strstr(str,"\nsSliceArray.ucImageNumbCor")){
       sscanf(cpt, "%1022s = %x", name, &mi->ImageNumbCor);
-      if( g_dicom_ctrl.verb > 2 )
+      if( g_info.verb > 2 )
          fprintf(stderr,"ImageNumbCor in header %x\n",mi->ImageNumbCor);
    }
    else
@@ -1864,7 +1747,6 @@ static void get_siemens_extra_info( char *str , Siemens_extra_info *mi )
    return ;
 }
 
-/*----------------------------------------------------------------------------*/
 /* determine if slice order is reversed in Siemens mosaic files */
 static int
 flip_slices_mosaic (Siemens_extra_info *mi, int kor)
@@ -1872,7 +1754,7 @@ flip_slices_mosaic (Siemens_extra_info *mi, int kor)
   /*       kor = orientation of slices,  which spatial direction is z-axis */
   /* where 1=L-R, 2=P-A, 3=I-S */
    ENTRY("flip_slices_mosaic");
-   if( g_dicom_ctrl.verb > 2 ) {
+   if( g_info.verb > 2 ) {
       fprintf(stderr,"-- flip_slices_mosaic kor = %d\n", kor);
       fprintf(stderr,"   ImageNumbSag,Cor,Tra= %d,%d,%d\n",
               mi->ImageNumbSag, mi->ImageNumbCor, mi->ImageNumbTra);
@@ -1897,7 +1779,6 @@ flip_slices_mosaic (Siemens_extra_info *mi, int kor)
 }
 #endif  /* moved to mri_process_siemens.c */
 
-/*----------------------------------------------------------------------------*/
 # if 0  /* moved to mri_process_siemens.c       21 Dec 2010 [rickr] */
 /* copy data from mosaic input to image array */
 static int
@@ -2043,7 +1924,7 @@ int mri_possibly_dicom( char *fname )
    }
 }
 
-/*----------------------------------------------------------------------------*/
+
 /* clear oblique information structure */
 static void
 Clear_obl_info(oblique_info *obl_info)
@@ -2076,7 +1957,6 @@ Clear_obl_info(oblique_info *obl_info)
 /*         memset(&obl_info->Tr_dicom[0][0], 0, 16*sizeof(float)); */
 }
 
-/*----------------------------------------------------------------------------*/
 /* fill oblique information structure */
 static void
 Fill_obl_info(oblique_info *obl_info, char **epos, Siemens_extra_info *siem)
@@ -2128,8 +2008,8 @@ Fill_obl_info(oblique_info *obl_info, char **epos, Siemens_extra_info *siem)
           &yc.xyz[0], &yc.xyz[1], &yc.xyz[2]);
        /* check if both vectors OK */
        if( qq == 6 && SIZE_FVEC3(xc) > 0.0 && SIZE_FVEC3(yc) > 0.0 ){
-          xc = NORMALIZE_FVEC3(xc);
-          yc = NORMALIZE_FVEC3(yc);
+          NORMALIZE_FVEC3(xc);
+          NORMALIZE_FVEC3(yc);
           /* if the values are close to 0 or 1 make it so */
           for(ii=0;ii<3;ii++) {
              if(ALMOST(xc.xyz[ii],0.0))
@@ -2198,7 +2078,6 @@ Fill_obl_info(oblique_info *obl_info, char **epos, Siemens_extra_info *siem)
 
 }
 
-/*----------------------------------------------------------------------------*/
 /* check if data is oblique by using the vectors from the ImageOrientation field */
 static int CheckObliquity(float xc1, float xc2, float xc3, float yc1, float yc2, float yc3)
 {
@@ -2215,7 +2094,6 @@ static int CheckObliquity(float xc1, float xc2, float xc3, float yc1, float yc2,
    return(oblique);
 }
 
-/*----------------------------------------------------------------------------*/
 /* mod -16 May 2007 */
 /* compute Tr transformation matrix for oblique data */
 /* 16 element float array */
@@ -2270,7 +2148,7 @@ static float *ComputeObliquity(oblique_info *obl_info)
     /* switch direction of normal vector by factor */
     dc4 = SCALE_FVEC3(dc3, fac);
 
-    if( g_dicom_ctrl.verb > 3 ) {
+    if( g_info.verb > 3 ) {
        DUMP_FVEC3("-- COMP_OBL  xvec", obl_info->xvec);
        DUMP_FVEC3("   COMP_OBL  yvec", obl_info->yvec);
        DUMP_FVEC3("   COMP_OBL  vec3", vec3);
@@ -2314,7 +2192,7 @@ static float *ComputeObliquity(oblique_info *obl_info)
        RETURN(&(obl_info->Tr_dicom[0][0]));
    }
    /* for Siemens mosaic data, seen two cases */
-   if( g_dicom_ctrl.verb > 2 )
+   if( g_info.verb > 2 )
     fprintf(stderr,"-- mos_ix %d mos_nx %d, mos_ny %d, mos_nslice %d\n"
             "   nx %d ny %d (g_is_oblique=%d)\n",
             obl_info->mos_ix, obl_info->mos_nx, obl_info->mos_ny,
@@ -2325,7 +2203,7 @@ static float *ComputeObliquity(oblique_info *obl_info)
    /* will rely on ImagePosition method for now*/
    /*  Siemens mosaic with limited slice information - rely on ImagePosition*/
    /* compute central mosaic point - in funny way */
-
+   
    /* get center of mass, starting from center of corner voxel and shift by */
    /*    (N-1)*vox_dim/2 in each of the 3 directions                        */
 
@@ -2335,7 +2213,7 @@ static float *ComputeObliquity(oblique_info *obl_info)
    offsetyvec = SCALE_FVEC3(dc2, ((obl_info->ny-1)/2.0));
 
    offsetzvec = SCALE_FVEC3(dc3, ((obl_info->mos_nslice - 1.0)*fac/2.0));
-   if( obl_info->flip_slices )
+   if( obl_info->flip_slices ) 
       offsetzvec = SCALE_FVEC3(offsetzvec, -1.0);
 
    Cm = ADD_FVEC3(obl_info->dfpos1, offsetxvec);
@@ -2402,8 +2280,8 @@ static float *ComputeObliquity(oblique_info *obl_info)
       else
          INFO_message("Slice based center matches mosaic center - good!\n");
    }
-
-   if( g_dicom_ctrl.verb > 2 ) {
+   
+   if( g_info.verb > 2 ) {
       DUMP_FVEC3("Mosaic Center", Cm);
       DUMP_FVEC3("Origin Coordinates", Orgin);
    }
@@ -2424,7 +2302,7 @@ static float *ComputeObliquity(oblique_info *obl_info)
       }
    }
 
-   if( g_dicom_ctrl.verb > 2 ) {
+   if( g_info.verb > 2 ) {
       DUMP_FVEC3("Image Position", obl_info->dfpos1);
       DUMP_FVEC3("dc1", dc1);
       DUMP_FVEC3("dc2", dc2);
@@ -2455,14 +2333,12 @@ DUMP_FVEC3("vec4", vec4);
 
 }
 
-/*----------------------------------------------------------------------------*/
 /* externally available function to reset oblique info */
 void mri_read_dicom_reset_obliquity()
 {
    Clear_obl_info(&obl_info);
 }
 
-/*----------------------------------------------------------------------------*/
 /* externally available function to compute oblique transformation */
 /* and store resulting matrix in 16 element float array */
 void mri_read_dicom_get_obliquity(float *Tr)
@@ -2483,7 +2359,7 @@ void mri_read_dicom_get_obliquity(float *Tr)
    return;
 }
 
-/*----------------------------------------------------------------------------*/
+
 /* externally available function to set origin and orientation from obliquity */
 /* transformation matrix */
 void
@@ -2533,7 +2409,7 @@ Obliquity_to_coords(THD_3dim_dataset *tdset)
    daxes->yydel =  (ORIENT_sign[orixyz.ijk[1]]=='+') ? dytmp : -dytmp ;
    daxes->zzdel =  (ORIENT_sign[orixyz.ijk[2]]=='+') ? dztmp : -dztmp ;
 
-   if( g_dicom_ctrl.verb > 2 ) {
+   if( g_info.verb > 2 ) {
       fprintf(stderr,"Orients = %d %d %d\n", daxes->xxorient, daxes->yyorient,
               daxes->zzorient);
       fprintf(stderr,"daxes origins = %f %f %f\n", daxes->xxorg, daxes->yyorg,
@@ -2542,9 +2418,7 @@ Obliquity_to_coords(THD_3dim_dataset *tdset)
  /*     daxes->xxdel    =   user_inputs.xsize ;
    daxes->yydel    =   user_inputs.ysize ;*/
 
-}
-
-/*----------------------------------------------------------------------------*/
+ }
 
 static int init_dicom_globals(dicom_globals_t * info)
 {
@@ -2558,12 +2432,7 @@ static int init_dicom_globals(dicom_globals_t * info)
    else info->verb     = 1;
    info->rescale       = AFNI_yesenv("AFNI_DICOM_RESCALE");
    info->window        = AFNI_yesenv("AFNI_DICOM_WINDOW");
-
-   /* replace lone global with that in g_dicom_ctrl struct 8 Aug 2012 [rickr] */
-   /* multiple ways to set: to3d/Dimon -use_last_elem, or env var        */
-   /* (if set in env, let it override)                                   */
-   if( my_getenv("AFNI_DICOM_USE_LAST_ELEMENT") )
-      info->use_last_elem = AFNI_yesenv("AFNI_DICOM_USE_LAST_ELEMENT");
+   info->use_last_elem = AFNI_yesenv("AFNI_DICOM_USE_LAST_ELEMENT");
 
    info->init = 1;
 
@@ -2572,151 +2441,3 @@ static int init_dicom_globals(dicom_globals_t * info)
    return 0;
 }
 
-/*----------------------------------------------------------------------------*/
-/* Get some header info from a DICOM file [15 Nov 2011 - RWCox] */
-/*
- * nposn = name position (was dolast): -1 = first, 0 = skip, 1 = last
- *                                                 5 Oct 2012 [rickr]
- * sepstr: if non-NULL, use a separator (instead of space) 11 Jan 2019 [rickr]
- */
-char * mri_dicom_hdrinfo( char *fname , int natt , char **att , int nposn,
-                          char *sepstr )
-{
-   char *strout=NULL , *ppp , **epos , *ddd , sss[256] ;
-   int aa ;
-
-ENTRY("mri_dicom_hdrinfo") ;
-
-   if( fname == NULL || (natt > 0 && att == NULL) ) RETURN(NULL) ;
-
-   if( ! g_dicom_ctrl.init ) init_dicom_globals(&g_dicom_ctrl);
-
-   if( !mri_possibly_dicom(fname) ){                /* 07 May 2003 */
-     if( g_dicom_ctrl.verb > 1 )
-       ERROR_message("file %s is not possibly DICOM",fname) ;
-     RETURN(NULL) ;
-   }
-
-   /*-- extract header info from file into a string --*/
-
-   mri_dicom_nohex(1) ;              /* don't print ints in hex mode */
-   mri_dicom_noname(1) ;             /* don't print names, just tags */
-   ppp = mri_dicom_header( fname ) ; /* print header to malloc()-ed string */
-   if( ppp == NULL ){                /* didn't work; not a DICOM file? */
-     if( g_dicom_ctrl.verb > 1 )
-       ERROR_message("file %s is not interpretable as DICOM",fname) ;
-     RETURN(NULL) ;
-   }
-
-   /*-- initialize output --*/
-
-   if( nposn == -1 || natt <= 0 ) strout = THD_zzprintf(strout,"%s",fname) ;
-
-   /*-- simple case, probably never used --*/
-
-   if( natt <= 0 ){ free(ppp) ; RETURN(strout) ; }
-
-   /* find positions in header of elements we care about */
-
-   epos = (char **)calloc( sizeof(char *) , natt ) ;
-   get_posns_from_elist( epos, att, ppp, natt ) ;
-
-   /*-- scan and copy output --*/
-
-   for( aa=0 ; aa < natt ; aa++ ){
-     strcpy(sss,"null") ;
-     if( epos[aa] != NULL ){
-       ddd = strstr(epos[aa],"//") ;
-       if( ddd != NULL ) sscanf(ddd+2,"%254s",sss) ;
-     }
-
-     /* if name is first or after first output, add a space */
-     if( nposn != -1 && aa == 0 ) 
-        strout = THD_zzprintf(strout,"%s" ,sss) ;
-     else
-        strout = THD_zzprintf(strout,"%s%s",sepstr?sepstr:" ", sss) ;
-   }
-   if( nposn == 1 ) strout = THD_zzprintf(strout," %s",fname) ;
-
-   free(epos) ; free(ppp) ; RETURN(strout) ;
-}
-
-/*----------------------------------------------------------------------------*/
-/* Get some header info from a DICOM file with full tag including spaces    */
-/* [Justin Rajendra 01/2018] */
-
-/* stupid function to subset string on indices */
-static char *cut_str_range(char const *input, size_t start, size_t len) {
-     char *ret = malloc(len+1);
-     memcpy(ret, input+start, len);
-     ret[len]  = '\0';
-     return ret;
- }
-
-/* get full tag until new line character */
-char * mri_dicom_hdrinfo_full( char *fname , int natt , char **att , int nposn,
-                               char *sepstr )
-{
-   char *strout=NULL, *ppp, **epos, *ddd, *end_of_line, *full_tag=NULL;
-   int aa, end_index;
-
-ENTRY("mri_dicom_hdrinfo_full") ;
-
-   if( fname == NULL || (natt > 0 && att == NULL) ) RETURN(NULL) ;
-
-   if( ! g_dicom_ctrl.init ) init_dicom_globals(&g_dicom_ctrl);
-
-   if( !mri_possibly_dicom(fname) ){                /* 07 May 2003 */
-     if( g_dicom_ctrl.verb > 1 )
-       ERROR_message("file %s is not possibly DICOM",fname) ;
-     RETURN(NULL) ;
-   }
-
-   /*-- extract header info from file into a string --*/
-
-   mri_dicom_nohex(1) ;              /* don't print ints in hex mode */
-   mri_dicom_noname(1) ;             /* don't print names, just tags */
-   ppp = mri_dicom_header( fname ) ; /* print header to malloc()-ed string */
-   if( ppp == NULL ){                /* didn't work; not a DICOM file? */
-     if( g_dicom_ctrl.verb > 1 )
-       ERROR_message("file %s is not interpretable as DICOM",fname) ;
-     RETURN(NULL) ;
-   }
-
-   /*-- initialize output --*/
-   if( nposn == -1 || natt <= 0 ) strout = THD_zzprintf(strout,"%s",fname) ;
-
-   /*-- simple case, probably never used --*/
-   if( natt <= 0 ){ free(ppp) ; RETURN(strout) ; }
-
-   /* find positions in header of elements we care about */
-   epos = (char **)calloc( sizeof(char *) , natt ) ;
-   get_posns_from_elist( epos, att, ppp, natt ) ;
-
-   /*-- scan and copy output --*/
-   for( aa=0 ; aa < natt ; aa++ ){
-     full_tag = NULL;
-     if( epos[aa] != NULL ){
-       ddd = strstr(epos[aa],"//") ; /* get start */
-       if( ddd != NULL ){
-           /*  end and end index */
-           end_of_line = strchr(ddd,'\n') ;
-           end_index = (int)(end_of_line - ddd);
-
-           /* chop out and save */
-           full_tag = cut_str_range(ddd,2,end_index-2);
-       }
-     }
-
-     /* if name is first or after first output, add a space */
-     if( nposn != -1 && aa == 0 ){
-         strout = THD_zzprintf(strout,"%s" ,full_tag?full_tag:"null") ;
-     } else {
-         strout = THD_zzprintf(strout,"%s%s", sepstr?sepstr:" ",
-                                              full_tag?full_tag:"null") ;
-     }
-     if( full_tag ) free(full_tag);
-   }
-   if(nposn == 1) strout = THD_zzprintf(strout,"%s%s",sepstr?sepstr:" ",fname);
-   free(epos) ; free(ppp) ; RETURN(strout) ;
-}
