@@ -5,8 +5,8 @@ int main( int argc , char * argv[] )
    char * buf ;
    int    nbuf , iarg=1 ;
 
-   if( argc < 2 || ( argc == 2 && ! strcmp(argv[1], "-help") ) ) { 
-      printf("Usage: myget [-1|-1.1] URL > filename\n"); 
+   if( argc < 2 ){ 
+      fprintf(stderr,"Usage: myget [-1|-1.1] URL > filename\n"); 
       exit(0) ; 
    }
 
