@@ -6,7 +6,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <ctype.h>
-#include <inttypes.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -23,20 +22,11 @@
 #include <fcntl.h>
 #include <sys/times.h>
 #include <limits.h>
-#include <math.h>     /* 14 Sep 2018 */
 
 #ifdef  __cplusplus
 extern "C" {                    /* care of Greg Balls    7 Aug 2006 [rickr] */
 #endif
 
-/* preferentially include f2c header from local directory, otherwise use system
- header */
-#include "f2c.h"
-/* The following was added to harmonize with system f2c header. Subsequent
-typedef for complex is now ignored */
-#define TYPEDEF_complex
-
-
 /*****---------------------------------------------------*****/
 
 /* This is suppose to be defined in stddef.h, but
@@ -183,7 +173,6 @@ extern int          NI_rowtype_code_to_size ( int ) ;
 
 extern int          NI_rowtype_vsize     ( NI_rowtype *, void * ) ;
 extern void         NI_val_to_text       ( NI_rowtype *, char *, char * ) ;
-extern void         NI_set_raw_val_to_text( int ) ;
 extern int          NI_val_to_binary     ( NI_rowtype *, char *, char * ) ;
 extern void         NI_multival_to_text  ( NI_rowtype *, int, char *, char * );
 extern int          NI_multival_to_binary( NI_rowtype *, int, char *, char * );
@@ -222,7 +211,6 @@ typedef struct {
    int    vec_filled ; /*!< Length that each one was filled up. */
    int   *vec_typ ;    /*!< Type code for each vector. */
    void **vec ;        /*!< Pointer to each vector. */
-   char **vec_lab ;    /*!< Ptr to label string for each vector [optional] */
 
    int    vec_rank ;        /*!< Number of dimensions, from ni_dimen. */
    int   *vec_axis_len ;    /*!< Array of dimensions, from ni_dimen. */
@@ -230,8 +218,6 @@ typedef struct {
    float *vec_axis_origin ; /*!< Array of origins, from ni_origin. */
    char **vec_axis_unit ;   /*!< Array of units, from ni_units. */
    char **vec_axis_label ;  /*!< Array of labels, from ni_axes. */
-
-   char  *filename ;        /*!< filename it came from, if any. [16 Jun 2020] */
 } NI_element ;
 #endif
 
@@ -251,8 +237,6 @@ typedef struct {
    void **part ;       /*!< Pointer to each part. */
 
    char  *name ;       /*!< Name (default="ni_group") - 03 Jun 2002 */
-
-   char  *filename ;   /*!< filename it came from, if any. [16 Jun 2020] */
 } NI_group ;
 #endif
 
@@ -366,7 +350,7 @@ typedef struct {
    int sd ;          /*!< TCP only: socket descriptor */
 
    FILE *fp ;        /*!< FILE only: pointer to open file */
-   int64_t fsize ;   /*!< FILE only: length of file for input */
+   int fsize ;       /*!< FILE only: length of file for input */
 
    char name[256] ;  /*!< Hostname or filename */
 
@@ -547,9 +531,8 @@ typedef struct { int nar ; float  *ar ; } NI_floatvec ;
 /** 18 Nov 2002: replace old malloc functions with new ones **/
 
 #undef NIML_OLD_MALLOC
-#if (defined(NIML_OLD_MALLOC) || !defined(ALLOW_MCW_MALLOC)) && !defined(__cplusplus) && !defined(c_plusplus)
+#if (defined(NIML_OLD_MALLOC) || defined(DONT_USE_MCW_MALLOC)) && !defined(__cplusplus) && !defined(c_plusplus)
 #define NI_malloc(typ,a) (typ*) old_NI_malloc((a))
-#define NI_calloc(a,b) old_NI_malloc((a)*(b))
 #define NI_realloc(a,typ,b)  (typ*) old_NI_realloc((a),(b))
 
   extern void * old_NI_malloc( size_t ) ;
@@ -587,8 +570,7 @@ extern char * NI_strncpy( char *, const char *, size_t ) ;
 extern char * NI_strdup( char * ) ;
 extern char * NI_strdup_len( char *, int ) ;
 extern int    NI_strlen( char * ) ;
-extern int64_t NI_filesize( char * ) ;  /* changed to int64_t 20 Jul 2021 */
-extern int    NI_is_fifo( char * ) ;            /* 27 Aug 2019 */
+extern long   NI_filesize( char * ) ;
 extern int    NI_clock_time(void) ;
 extern int    NI_byteorder(void) ;
 extern void   NI_swap2( int, void * ) ;
@@ -611,22 +593,16 @@ extern char * NI_element_name( void * ) ;  /* 18 Apr 2005 */
 
 extern NI_element * NI_new_data_element( char *, int ) ;
 extern void NI_add_column( NI_element *, int, void * ) ;
-extern void NI_set_column_label( NI_element *nel, int cc, char *lab ) ; /* 11 Sep 2018 */
 extern void NI_move_column(NI_element *nel, int ibefore, int iafter);
 extern void NI_insert_column( NI_element *nel , int typ , void *arr, int icol );
-extern float NI_extract_float_value( NI_element *nel , int row , int col ) ; /* 14 Sep 2018 */
-extern char * NI_extract_text_value( NI_element *nel , int row , int col ) ; /* 19 Jun 2020 */
 extern void NI_remove_column(NI_element *nel, int irm);
 extern void NI_copy_all_attributes( void *nisrc , void *nitrg );
 void *NI_duplicate(void *vel, byte with_data);
 void *NI_duplicate_element (void *vel, byte with_data);
-void *NI_duplicate_group (void *vel, byte with_data);
+void *NI_duplicate_group (void *vel, byte with_data); 
 extern void   NI_kill_attribute( void *, char * ) ;
 extern void   NI_set_attribute( void *, char *, char * ) ;
 extern char * NI_get_attribute( void *, char * ) ;
-extern char * NI_get_attribute_nocase( void *, char * ) ;           /* 20 Aug 2019 */
-extern void NI_set_dimen( NI_element *nel , int rank , int *nd );
-extern void NI_set_axes( NI_element *nel , char **ax );
 extern void NI_insert_value( NI_element *, int,int, void * );       /* 03 Apr 2003 */
 extern void NI_insert_column_stride( NI_element *nel, int typ, void *arr, int stride, int icol );
 extern void NI_add_column_stride( NI_element *, int, void *, int ); /* 29 May 2003 */
@@ -635,9 +611,6 @@ extern void NI_insert_string( NI_element *, int,int, char *);       /* 19 Apr 20
 extern void NI_alter_veclen( NI_element * , int ) ;                 /* 19 Apr 2005 */
 extern void NI_set_ni_type_atr( NI_element * ) ;       /* 14 Jul 2006 [rickr] */
 
-extern NI_element * NI_extract_columns( NI_element *nel, int nc, int *cc ) ; /* 13 Sep 2018 */
-
-
 extern NI_group * NI_new_group_element(void) ;
 extern void NI_add_to_group( NI_group *, void * ) ;
 extern void NI_rename_group( NI_group *, char * ) ;                 /* 03 Jun 2002 */
@@ -654,23 +627,6 @@ extern void NI_swap_vector( int, int, void * ) ;
 #define NI_set_attribute_int(el,nm,vv)  \
  do{ char ib[16]; sprintf(ib,"%d",(vv)); NI_set_attribute((el),(nm),ib); } while(0)
 
-/* port assignment functions from afni_ports.c */
-extern int init_ports_list();
-extern void set_ports_list_reinit(void);
-extern int get_port_named(char *name);
-extern void show_ports_list(void);
-extern int get_available_npb(void);
-extern int set_user_np(int v);
-extern int get_user_np(void);
-extern char *get_port_numbered(int port);
-extern char *get_np_help();
-extern int set_user_pif(char *s);
-extern char * get_user_pif(void);
-extern int set_user_np_bloc(int v);
-extern int get_max_port_bloc(void);
-extern int get_num_ports(void);
-extern int get_user_np_bloc(void);
-
 /** I/O functions **/
 
 extern NI_stream NI_stream_open( char *, char * ) ;
@@ -691,7 +647,7 @@ extern char * NI_stream_name( NI_stream_type * ) ;
 extern int NI_stream_readable( NI_stream_type * ) ;
 extern int NI_stream_writeable( NI_stream_type * ) ;
 extern int NI_stream_hasinput( NI_stream_type * , int ) ;
-extern void NI_stream_seek( NI_stream_type * , int64_t , int ) ; /* 24 Mar 2003 */
+extern void NI_stream_seek( NI_stream_type * , int , int ) ; /* 24 Mar 2003 */
 extern int NI_stream_writestring( NI_stream_type * , char * ) ;
 
 extern int NI_stream_setbufsize( NI_stream_type *, int ) ; /* 03 Jan 2003 */
@@ -706,13 +662,14 @@ extern int NI_stream_setb64( NI_stream_type * , int ) ;   /* 20 Apr 2005 */
 
 extern int NI_stream_reopen( NI_stream_type *, char * ) ; /* 23 Aug 2002 */
 
-extern char * NI_suck_file( char * ) ;                    /* 27 Aug 2019 */
+extern void NI_binary_threshold( NI_stream_type *, int ) ;
+
 extern void * NI_read_element ( NI_stream_type *, int ) ;
-extern int64_t  NI_write_element( NI_stream_type *, void *, int ) ;
+extern int    NI_write_element( NI_stream_type *, void *, int ) ;
 extern int    NI_write_procins( NI_stream_type *, char * ) ; /* 17 Mar 2005 */
-extern int64_t NI_write_columns( NI_stream_type * ,
+extern int    NI_write_columns( NI_stream_type * ,
                                 int , int * , int , void ** , int ) ;
-extern int64_t NI_write_rowtype( NI_stream_type * ,
+extern int    NI_write_rowtype( NI_stream_type * ,
                                 NI_rowtype * , int , void * , int ) ;
 extern int    NI_read_columns ( NI_stream_type *,
                                 int, int *, int, void **, int,int ) ;
@@ -720,17 +677,13 @@ extern void   NI_free_column  ( NI_rowtype * , int , void * );
 extern void * NI_copy_column  ( NI_rowtype * , int , void * );
 extern int    NI_size_column  ( NI_rowtype * , int , void * ); /* 26 Mar 2003 */
 
-extern void   NI_set_read_header_only   ( int ) ;              /* 21 Mar 2003 */
-extern int    NI_get_read_header_only( void );                 /* 24 Feb. 2012 */
+extern void   NI_read_header_only   ( int ) ;                  /* 21 Mar 2003 */
 extern void * NI_read_element_header( NI_stream_type *, int ); /* 26 Mar 2003 */
 extern void   NI_skip_procins( int ) ;                         /* 03 Jun 2005 */
 
-extern int64_t NI_write_element_tofile( char *, void *, int ) ;    /* 07 Mar 2007 */
+extern int NI_write_element_tofile( char *, void *, int ) ;    /* 07 Mar 2007 */
 extern void * NI_read_element_fromfile( char * ) ;             /* 12 Mar 2007 */
 extern void * NI_read_element_fromstring( char *nstr );     /* 26 Feb 2010 ZSS*/
-extern char * NI_write_element_tostring( void *nel ); /* Oct 2011 ZSS */
-
-extern char * NI_preview_string( NI_element *, int , char *) ; /* 22 Jun 2020 */
 
 #define NI_SWAP_MASK  (1<<0)
 #define NI_LTEND_MASK (1<<1)
@@ -758,14 +711,10 @@ extern char * MD5_malloc_file(char * filename) ;
 extern char * MD5_B64_array( int n, char * bytes ) ;
 extern char * MD5_B64_string( char * string ) ;
 extern char * MD5_B64_file(char * filename) ;
-extern void   MD5_set_xor_use(int) ;  /* 09 Apr 2015 */
 
 extern char * UNIQ_idcode(void) ;
-extern char * UNIQ_idcode_11(void) ;             /* 10 Feb 2016 */
 extern void   UNIQ_idcode_fill( char * ) ;
 extern char * UNIQ_hashcode( char * ) ;
-extern void UNIQ_hashprefix_fill( char *idc ) ;  /* 30 Apr 2013 */
-extern char * UNIQ_hashprefix( void ) ;
 
 extern char * UUID_hashcode( char * ) ;   /* 20 Aug 2002 */
 extern char * UUID_idcode(void) ;
@@ -1257,7 +1206,7 @@ extern void NI_register_doer( char *, NI_voidfunc * ) ;
 /*-------------------------------------------------------------------------*/
 /*! An array of strings, each allocated with NI_malloc(). */
 
-typedef struct { int num; char **str; } NI_str_array ;
+typedef struct { int num; char **str;} NI_str_array ;
 
 #define NI_delete_str_array(sar)             \
   do{ int pp ;                               \
@@ -1272,8 +1221,6 @@ extern NI_str_array * NI_strict_decode_string_list( char *ss , char *sep );
 
 extern int NI_str_array_find( char *, NI_str_array *) ; /* 20 May 2010 */
 
-extern int NI_count_numbers( int nstr , char **str ) ;  /* 11 Sep 2018 */
-
 /*-------------------------------------------------------------------------*/
 /*! An array of floats. */
 
@@ -1282,7 +1229,7 @@ typedef struct { int num; float *ar; } NI_float_array ;
 #define NI_delete_float_array(far) \
   do{ if( (far)->ar != NULL ) NI_free((far)->ar); NI_free(far); } while(0)
 
-extern NI_float_array * NI_decode_float_list( char *ss , char *sep ) ;
+extern NI_float_array * NI_decode_float_list( char *ss , char* sep ) ;
 extern char *           NI_encode_float_list( NI_float_array *, char * ) ;
 #define NI_decode_float_array NI_decode_float_list
 
@@ -1341,77 +1288,6 @@ extern void   NI_register_objconverters( char * ,
                                          NI_objconverter_func ,
                                          NI_objconverter_func  ) ;
 
-/**-------------------------------------------------------------------------**/
-/** Type: array of NI_element pointers [adapted from MRI_IMARR 16 Jun 2020] **/
-
-/*! Array of NI_element pointers */
-
-typedef struct NI_ELARR {
-      int num ;             /*!< Number of actual NI_element here */
-      int nall ;            /*!< Size of elarr array currently allocated */
-      NI_element **elarr ;  /*!< Array of NI_element pointers */
-} NI_ELARR ;
-
-/*! Get the nn-th element from the NIML array "name" */
-
-#define ELEMENT_IN_ELARR(name,nn) ((name)->elarr[(nn)])
-#define ELARR_SUBELEMENT          ELEMENT_IN_ELARR
-#define ELARR_SUBEL               ELEMENT_IN_ELARR
-
-/*! Get the number of elements in the array "name" */
-
-#define ELARR_COUNT(name)         ((name)->num)
-
-#define ELARR_LASTEL(name)        ((name)->elarr[(name)->num-1])
-#define ELARR_FIRSTEL(name)       ((name)->elarr[0])
-
-#define INC_ELARR 32
-
-/*! Initialize an NI_ELARR struct */
-
-#define INIT_ELARR(name)                                                           \
-   do{ int iq ; (name) = (NI_ELARR *) malloc(sizeof(NI_ELARR)) ;                   \
-       (name)->num = 0 ; (name)->nall = INC_ELARR ;                                \
-       (name)->elarr = (NI_element **)malloc(sizeof(NI_element *)*INC_ELARR) ;     \
-       for( iq=(name)->num ; iq < (name)->nall ; iq++ ) (name)->elarr[iq] = NULL ; \
-       break ; } while(0)
-
-/*! Add one NI_element to the NI_ELARR struct */
-
-#define ADDTO_ELARR(name,emm)                                                              \
-   do{ int nn , iq ;                                                                       \
-       if( (name)->num == (name)->nall ){                                                  \
-          nn = (name)->nall = 1.1*(name)->nall + INC_ELARR ;                               \
-          (name)->elarr = (NI_element **)realloc( (name)->elarr,sizeof(NI_element *)*nn ); \
-          for( iq=(name)->num ; iq < (name)->nall ; iq++ ) (name)->elarr[iq] = NULL ; }    \
-       nn = (name)->num ; ((name)->num)++ ;                                                \
-       (name)->elarr[nn] = (emm) ; break ; } while(0)
-
-/*! Free the NI_ELARR struct (but not the data within) */
-
-#define FREE_ELARR(name)                                                        \
-   do{ if( (name) != NULL ){                                                    \
-          free((name)->elarr); free((name)); (name) = NULL; } break; } while(0)
-
-/*! Free the NI_ELARR struct, including the data within */
-
-#define DESTROY_ELARR(name)                                                          \
-   do{ int nn ;                                                                      \
-       if( (name) != NULL ){                                                         \
-          for( nn=0 ; nn < (name)->num ; nn++ ) NI_free_element((name)->elarr[nn]) ; \
-          free((name)->elarr); free((name)); (name) = NULL; } break; } while(0)
-
-/*! Free all data elements at-and-after [qq] in the NI_ELARR struct. */
-
-#define TRUNCATE_ELARR(name,qq)                                                      \
-   do{ int nn ;                                                                      \
-       if( (name) != NULL && qq < (name)->num ){                                     \
-          for( nn=qq ; nn < (name)->num ; nn++ ) NI_free_element((name)->elarr[nn]); \
-          (name)->num = qq ;                                                         \
-       } } while(0)
-
-/**-------------------------------------------------------------------------**/
-
 #ifdef  __cplusplus
 }
 #endif
