@@ -100,31 +100,6 @@ static unsigned char PADDING[64] = {
  (a) += (b); \
   }
 
-/*----------------------------------------------------------------------*/
-/* #define USE_XOR  
-                        ZSS: Apr. 15 2015 
-   I have no idea at the moment why USE_XOR ends up causing SUMA labels
-   to get written on top of each other in the viewer. This happens on mac
-   and linux versions. This definition might also be causing 
-   other mysterious crashes in SUMA when opening the surface controller 
-   as reported on the message borad. 
-   For now, it will stay off until we sort out why this is causing grief.
-   Valgrind did not point to anything fishy related to USE_XOR.
-                                                                       */
-#ifdef  USE_XOR
-# define               XOR_NUM 1024
- static int            XOR_iii = -1 ;
- static unsigned char *XOR_bbb = NULL ;
- static int            XOR_use = 1 ;
-#endif /* USE_XOR */
-
-void MD5_set_xor_use(int xx){
-#ifdef USE_XOR
-  XOR_use = xx ;
-#endif
-}
-/*----------------------------------------------------------------------*/
-
 /*----------------------------------------------------------------------*/
 /*! MD5 initialization. Begins an MD5 operation, writing a new context.
 ------------------------------------------------------------------------*/
@@ -139,17 +114,6 @@ void MD5Init (MD5_CTX *context)
   context->state[1] = 0xefcdab89;
   context->state[2] = 0x98badcfe;
   context->state[3] = 0x10325476;
-
-#ifdef USE_XOR
-  if( XOR_iii < 0 ){
-    XOR_bbb = (unsigned char *)malloc(sizeof(unsigned char)*XOR_NUM) ;
-    for( XOR_iii=0 ; XOR_iii < XOR_NUM ; XOR_iii++ )
-      XOR_bbb[XOR_iii] = (unsigned char)((XOR_iii*557+1021)%255) ;
-    XOR_iii = 0 ;
-  }
-#endif
-
-  return ;
 }
 
 /*----------------------------------------------------------------------*/
@@ -159,7 +123,7 @@ void MD5Init (MD5_CTX *context)
 ------------------------------------------------------------------------*/
 
 void MD5Update (MD5_CTX *context, unsigned char *input,
-                                  unsigned int inputLen  )
+                                         unsigned int inputLen  )
 {
   unsigned int i, index, partLen;
 
@@ -239,14 +203,6 @@ static void MD5Transform (UINT4 state[4], unsigned char block[64])
 {
   UINT4 a = state[0], b = state[1], c = state[2], d = state[3], x[16];
 
-#ifdef USE_XOR
-  { register int qq ;
-    for( qq=0 ; qq < 64 ; qq++ ){
-      block[qq] ^= XOR_bbb[XOR_iii] ; XOR_iii = (XOR_iii+1)%XOR_NUM ;
-    }
-  }
-#endif
-
   Decode (x, block, 64);
 
   /* Round 1 */
@@ -460,7 +416,7 @@ char * MD5_static_file(char *filename)
 
   MD5Init( &context ) ;
 
-  while( (len = fread(buffer, 1, 1024, file)) )
+  while( len = fread(buffer, 1, 1024, file) )
       MD5Update( &context, buffer, len ) ;
 
   MD5Final( digest, &context );
@@ -553,7 +509,7 @@ char * MD5_B64_file(char *filename)
 
   MD5Init( &context ) ;
 
-  while( (len = fread(buffer, 1, 1024, file)) )
+  while( len = fread(buffer, 1, 1024, file) )
       MD5Update( &context, buffer, len ) ;
 
   MD5Final( digest, &context );
@@ -670,18 +626,12 @@ static void sha256_process( sha256_context *ctx, uint8 data[64] )
 #define  SHR(x,n) ((x & 0xFFFFFFFF) >> n)
 #define ROTR(x,n) (SHR(x,n) | (x << (32 - n)))
 
-#undef  S0
-#undef  S1
 #define S0(x) (ROTR(x, 7) ^ ROTR(x,18) ^  SHR(x, 3))
 #define S1(x) (ROTR(x,17) ^ ROTR(x,19) ^  SHR(x,10))
 
-#undef  S2
-#undef  S3
 #define S2(x) (ROTR(x, 2) ^ ROTR(x,13) ^ ROTR(x,22))
 #define S3(x) (ROTR(x, 6) ^ ROTR(x,11) ^ ROTR(x,25))
 
-#undef  F0
-#undef  F1
 #define F0(x,y,z) ((x & y) | (z & (x | y)))
 #define F1(x,y,z) (z ^ (x & (y ^ z)))
 
