@@ -860,10 +860,6 @@ int NI_rowtype_vsize( NI_rowtype *rt , void *dpt )
     or NI_STRING.  Structs with var dim arrays must be handled separately.
 ---------------------------------------------------------------------------*/
 
-static int do_raw = 0 ;
-
-void NI_set_raw_val_to_text( int ii ){ do_raw = ii ; }
-
 void NI_val_to_text( NI_rowtype *rt , char *dpt , char *wbuf )
 {
    int jj = strlen(wbuf) ;
@@ -922,7 +918,7 @@ void NI_val_to_text( NI_rowtype *rt , char *dpt , char *wbuf )
      case NI_FLOAT:{
        float *vpt = (float *)dpt ;
        char fbuf[32] ; int ff ;
-       sprintf(fbuf,"%14.7g",vpt[0]) ;
+       sprintf(fbuf,"%12.6g",vpt[0]) ;
        for( ff=strlen(fbuf) ; fbuf[ff]==' ' ; ff-- ) fbuf[ff] = '\0' ;
        for( ff=0 ; fbuf[ff] == ' ' ; ff++ ) ;
        sprintf(wbuf+jj," %s",fbuf+ff) ;
@@ -932,7 +928,7 @@ void NI_val_to_text( NI_rowtype *rt , char *dpt , char *wbuf )
      case NI_DOUBLE:{
        double *vpt = (double *)dpt ;
        char fbuf[32] ; int ff ;
-       sprintf(fbuf,"%20.14g",vpt[0]) ;
+       sprintf(fbuf,"%18.12g",vpt[0]) ;
        for( ff=strlen(fbuf) ; fbuf[ff]==' ' ; ff-- ) fbuf[ff] = '\0' ;
        for( ff=0 ; fbuf[ff] == ' ' ; ff++ ) ;
        sprintf(wbuf+jj," %s",fbuf+ff) ;
@@ -942,10 +938,10 @@ void NI_val_to_text( NI_rowtype *rt , char *dpt , char *wbuf )
      case NI_COMPLEX:{
        complex *vpt = (complex *)dpt ;
        char fbuf[32],gbuf[32] ; int ff,gg ;
-       sprintf(fbuf,"%14.7g",vpt[0].r) ;
+       sprintf(fbuf,"%12.6g",vpt[0].r) ;
        for( ff=strlen(fbuf) ; fbuf[ff]==' ' ; ff-- ) fbuf[ff] = '\0' ;
        for( ff=0 ; fbuf[ff] == ' ' ; ff++ ) ;
-       sprintf(gbuf,"%14.7g",vpt[0].i) ;
+       sprintf(gbuf,"%12.6g",vpt[0].i) ;
        for( gg=strlen(gbuf) ; gbuf[gg]==' ' ; gg-- ) gbuf[gg] = '\0' ;
        for( gg=0 ; gbuf[gg] == ' ' ; gg++ ) ;
        sprintf(wbuf+jj,"  %s %s",fbuf+ff,gbuf+gg) ;
@@ -954,13 +950,9 @@ void NI_val_to_text( NI_rowtype *rt , char *dpt , char *wbuf )
 
      case NI_STRING:{                         /* 30 Dec 2002 */
        char **vpt = (char **)dpt , *str ;
-       if( !do_raw ){
-         str = quotize_string( *vpt ) ;
-         sprintf(wbuf+jj," %s",str) ;
-         NI_free(str) ;
-       } else {
-         sprintf(wbuf+jj," %s",*vpt) ;
-       }
+       str = quotize_string( *vpt ) ;
+       sprintf(wbuf+jj," %s",str) ;
+       NI_free(str) ;
      }
      break ;
 
@@ -1062,22 +1054,17 @@ int NI_has_String( NI_rowtype *rt )
 
 /*------------------------------------------------------------------------*/
 /*! Write one column of structs to the output stream.  Now superseded
-    by NI_write_columns(). This function is not used anywhere (I think).
+    by NI_write_columns().
 --------------------------------------------------------------------------*/
 
-int64_t NI_write_rowtype( NI_stream_type *ns , NI_rowtype *rt ,
-                          int ndat , void *dat , int tmode )
+int NI_write_rowtype( NI_stream_type *ns , NI_rowtype *rt ,
+                      int ndat , void *dat , int tmode )
 {
    void *dpt = dat ;
    if( rt == NULL ) return -1 ;
    return NI_write_columns( ns , 1 , &(rt->code) , ndat , &dpt , tmode ) ;
 }
 
-/*------------------------------------------------------------------------*/
-
-#undef  WCERR
-#define WCERR(x) fprintf(stderr,"NIML write data error %s\n",x)
-
 /*------------------------------------------------------------------------*/
 /*! Write "columns" of data to a NI_stream.  Each column is an array of
     structs of some NI_rowtype (including the builtin types):
@@ -1099,12 +1086,11 @@ int64_t NI_write_rowtype( NI_stream_type *ns , NI_rowtype *rt ,
    This function is adapted from the 1st edition of NI_write_element().
 --------------------------------------------------------------------------*/
 
-int64_t NI_write_columns( NI_stream_type *ns,
-                          int col_num , int   *col_typ ,
-                          int col_len , void **col_dpt , int tmode )
+int NI_write_columns( NI_stream_type *ns,
+                      int col_num , int   *col_typ ,
+                      int col_len , void **col_dpt , int tmode )
 {
-   int ii,jj , row , dim , col ;
-   int64_t ntot , nout ;                     /* 28 Jul 2021 */
+   int ii,jj , row , dim , ntot,nout , col ;
    char *ptr , **col_dat=(char **)col_dpt ;
    int  nwbuf,bb=0,cc=0;
    char *wbuf=NULL ; /* write buffer */
@@ -1122,9 +1108,9 @@ int64_t NI_write_columns( NI_stream_type *ns,
 
    /*-- check inputs --*/
 
-   if( col_num <= 0    || col_len <= 0    )              return  0;
-   if( col_typ == NULL || col_dat == NULL ){ WCERR("a"); return -1; }
-   if( !NI_stream_writeable(ns)           ){ WCERR("b"); return -1; }
+   if( col_num <= 0    || col_len <= 0    ) return  0 ;
+   if( col_typ == NULL || col_dat == NULL ) return -1 ;
+   if( !NI_stream_writeable(ns)           ) return -1 ;
 
 #if 0
 fprintf(stderr,"NI_write_columns: col_num=%d col_len=%d tmode=%d\n",col_num,col_len,tmode) ;
@@ -1134,12 +1120,11 @@ fprintf(stderr,"NI_write_columns: col_num=%d col_len=%d tmode=%d\n",col_num,col_
 
    if( ns->bad ){                        /* not connected yet? */
      jj = NI_stream_goodcheck(ns,666) ;  /* try to connect it */
-     if( jj < 0 ) WCERR("c") ;
      if( jj < 1 ) return jj ;            /* 0 is nothing yet, -1 is death */
    }
 #if 1
    jj = NI_stream_writecheck(ns,666) ;
-   if( jj < 0 ){ WCERR("d"); return jj; }  /* only exit if stream is actually bad */
+   if( jj < 0 ) return jj ;              /* only exit if stream is actually bad */
 #endif
 
    if( ns->type == NI_STRING_TYPE )  /* output to string buffer ==> text mode */
@@ -1158,8 +1143,7 @@ fprintf(stderr,"NI_write_columns: col_num=%d col_len=%d tmode=%d\n",col_num,col_
 
      /* can't find type, or no data in column?  take this job and shove it */
 
-     if( rt[col]      == NULL ){ FREEUP; WCERR("e") ; return -1; }
-     if( col_dat[col] == NULL ){ FREEUP; WCERR("e'"); return -1; }
+     if( rt[col] == NULL || col_dat[col] == NULL ){ FREEUP; return -1; }
 
      vsiz[col] = ROWTYPE_is_varsize(rt[col]) ;         /* variable dim type? */
      fsiz[col] = rt[col]->size ;         /* fixed size of struct (w/padding) */
@@ -1184,8 +1168,7 @@ int ct = NI_clock_time() ;
 ct = NI_clock_time()-ct ;
 fprintf(stderr,"NI_write_columns FAST case: %d bytes in %d ms\n",fsiz[0]*col_len,ct) ;
 #endif
-     FREEUP ; if( nout < 0 ) WCERR("f") ;
-     return nout ;
+     FREEUP ; return nout ;
    }
 
    /*-- allocate space for the write buffer (1 row at a time) --*/
@@ -1212,10 +1195,10 @@ fprintf(stderr,"NI_write_columns FAST case: %d bytes in %d ms\n",fsiz[0]*col_len
       if all was not well with the write, then it aborts the output */
 
 # undef  ADDOUT
-# define ADDOUT(x)                           \
+# define ADDOUT                              \
   if( nout < 0 ){                            \
     fprintf(stderr,"NIML:: write abort!\n"); \
-    FREEUP ; WCERR(x) ; return -1 ;          \
+    FREEUP ; return -1 ;                     \
   } else ntot+=nout
 
    /*-- loop over output rows,
@@ -1310,7 +1293,7 @@ fprintf(stderr,"NI_write_columns FAST case: %d bytes in %d ms\n",fsiz[0]*col_len
        case NI_TEXT_MODE:     /* each row is on a separate line */
          strcat(wbuf,"\n") ;
          nout = NI_stream_writestring( ns , wbuf ) ;
-         ADDOUT("A") ;
+         ADDOUT ;
        break ;
 
        case NI_BINARY_MODE:   /* jj bytes of binary in wbuf */
@@ -1318,7 +1301,7 @@ fprintf(stderr,"NI_write_columns FAST case: %d bytes in %d ms\n",fsiz[0]*col_len
 #ifdef NIML_DEBUG
 if( nout != jj ) NI_dpr("NI_write_columns: col#%d sends %d bytes; nout=%d\n",col,jj,nout) ;
 #endif
-         ADDOUT("B") ;
+         ADDOUT ;
        break ;
 
        case NI_BASE64_MODE:{  /* convert binary triples into base64 quads */
@@ -1348,7 +1331,7 @@ if( nout != jj ) NI_dpr("NI_write_columns: col#%d sends %d bytes; nout=%d\n",col
          /* write base64 bytes to output */
 
          nout = NI_stream_write( ns , cbuf , qq ) ;
-         ADDOUT("C") ;
+         ADDOUT ;
 
          /* deal with leftover bytes in bbuf */
 
@@ -1375,17 +1358,17 @@ if( nout != jj ) NI_dpr("NI_write_columns: col#%d sends %d bytes; nout=%d\n",col
        cbuf[0] = w ; cbuf[1] = x ;
        cbuf[2] = y ; cbuf[3] = z ; cbuf[4] = B64_EOL2 ;
        nout = NI_stream_write( ns , cbuf , 5 ) ;
-       ADDOUT("D") ;
+       ADDOUT ;
      } else if( cc > 0 ){           /* just write an end of line */
        cbuf[0] = B64_EOL2 ;
        nout = NI_stream_write( ns , cbuf , 1 ) ;
-       ADDOUT("E") ;
+       ADDOUT ;
      }
    }
 
    /*-- cleanup and return --*/
 
-   FREEUP ; if( ntot < 0 ) WCERR("Z") ;
+   FREEUP ;
    return ntot ;
 }
 
