@@ -28,24 +28,13 @@ void NI_dpr( char *fmt , ... )      /* print debug stuff */
 /*! Return the file length (-1 if file not found).
 ----------------------------------------------------------------------------*/
 
-int64_t NI_filesize( char *pathname )
+long NI_filesize( char *pathname )
 {
    static struct stat buf ; int ii ;
+
    if( pathname == NULL ) return -1 ;
    ii = stat( pathname , &buf ) ; if( ii != 0 ) return -1 ;
-   return (int64_t)buf.st_size ;
-}
-
-/*--------------------------------------------------------------------------*/
-/*! Is this a FIFO or not? [27 Aug 2019]
-----------------------------------------------------------------------------*/
-
-int NI_is_fifo( char *pathname )
-{
-   static struct stat buf ; int ii ;
-   if( pathname == NULL ) return 0 ;
-   ii = stat( pathname , &buf ) ; if( ii != 0 ) return 0 ;
-   return (buf.st_mode & S_IFIFO) ;
+   return buf.st_size ;
 }
 
 /*-------------------------------------------------------------------*/
@@ -437,7 +426,7 @@ char * quotize_float_vector( int num , float *vec , char sep )
 
    qstr = NI_malloc(char*, sizeof(char *)*num) ;
    for( ii=0 ; ii < num ; ii++ ){
-      sprintf(fbuf," %14.7g",vec[ii]) ;
+      sprintf(fbuf," %12.6g",vec[ii]) ;
       for( ff=strlen(fbuf) ; fbuf[ff]==' ' ; ff-- ) /* skip trailing blanks */
         fbuf[ff] = '\0' ;
       for( ff=0 ; fbuf[ff] == ' ' ; ff++ ) ;         /* skip leading blanks */
@@ -507,68 +496,3 @@ char * trailname( char *fname , int lev )
 
    return (fname+fpos) ;
 }
-
-/*--------------------------------------------------------------------------*/
-/*! Given an array of strings, determine how many are numbers [11 Sep 2018] */
-/*  (After conversion to floats, thd_floatscan() can be used to for fixups) */
-/*--------------------------------------------------------------------------*/
-
-#undef  FBAD
-#define FBAD(sss)                       \
- ( strcasecmp ((sss),"N/A"  ) == 0 ||   \
-   strncasecmp((sss),"NAN",3) == 0 ||   \
-   strncasecmp((sss),"INF",3) == 0   )
-
-int NI_count_numbers( int nstr , char **str )
-{
-   int nnum=0 , ii ; double val ; char *cpt ;
-
-   if( nstr < 1 || str == NULL ) return nnum ;
-
-   for( ii=0 ; ii < nstr ; ii++ ){
-     if( str[ii] != NULL ){
-       if( FBAD(str[ii]) ) nnum++ ;  /* 17 Oct 2018 */
-       else {
-         val = strtod(str[ii],&cpt) ;
-         if( *cpt == '\0' || isspace(*cpt) ) nnum++ ;
-       }
-     }
-   }
-   return nnum ;
-}
-
-/*---------------------------------------------------------------------------*/
-/*! Read an entire text file into a string [27 Aug 2019] */
-/*---------------------------------------------------------------------------*/
-
-#undef  DBUF
-#define DBUF 8192       /* how many bytes per fifo read */
-
-#undef  MAXBUF
-#define MAXBUF 8388608  /* 8 Mbytes */
-
-char * NI_suck_file( char *fname )
-{
-   int fd , ii , nbuf ;
-   char *buf ;
-
-   if( fname == NULL || fname[0] == '\0' ) return NULL ;
-
-   fd = open( fname , O_RDONLY ) ; /* blocking reads */
-   if( fd < 0 ) return NULL ;
-
-   nbuf = 0 ;
-   buf  = (char *)malloc( sizeof(char) * (DBUF+4) ) ;
-
-   while( nbuf < MAXBUF ){
-     ii = read( fd , buf+nbuf , DBUF ) ;      /* try to read up to DBUF bytes */
-     if( ii <= 0 ) break ;                                     /* read failed */
-     nbuf += ii ;                        /* add in how many bytes we now have */
-     buf = (char *)realloc( buf, sizeof(char)*(nbuf+DBUF+4) ) ; /* resize buf */
-   }
-
-   close(fd) ;
-   buf = (char *)realloc( buf , sizeof(char)*(nbuf+4) ) ;
-   buf[nbuf] = '\0' ; /* terminate string */
-   return buf ;
-}
