@@ -5,13 +5,11 @@
 ******************************************************************************/
 
 #define  NEED_PARSER_INTERNALS
-#include "mrilib.h"     /* to deal with isfinite(x)  9 Feb 2016 [rickr] */
 #include "parser.h"
 #include "Amalloc.h"
 #include <time.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include "testprime.c"
 
 /***** C routines to interface to the f2c generated parser code *****/
 
@@ -441,7 +439,7 @@ doublereal legendre_( doublereal *mm , doublereal *xx )
 
 	/** if here, m > 20 ==> use recurrence relation **/
 
-   { double k , pk=0.0, pkm1, pkm2 ;
+   { double k , pk, pkm1, pkm2 ;
 
      k = 19.0; pkm2 = legendre_( &k , xx ) ;
      k = 20.0; pkm1 = legendre_( &k , xx ) ;
@@ -766,384 +764,3 @@ doublereal hrfbk5_( doublereal *ttp , doublereal *TTp )
    }
    return (doublereal)w ;
 }
-
-/*-----------------------------------------------------------------------*/
-/* Stuff for mixed-model ACF calculations */
-
-static double ACFaa, ACFbb, ACFcc, ACFflev ;
-
-double acfwxm_cost( int npar , double *par )
-{
-   double fit , rr=*par ;
-   double apar,bpar,cpar , flev ;
-
-   apar = ACFaa ; bpar = ACFbb ; cpar = ACFcc ; flev = ACFflev ;
-
-   fit =        apar * exp( -0.5*rr*rr/(bpar*bpar) )
-        + (1.0-apar) * exp( -rr/cpar) ;
-
-   return fabs(fit-flev) ;
-}
-
-doublereal acfwxm_( doublereal *apar , doublereal *bpar , doublereal *cpar , doublereal *flev )
-{
-   double rhalf , rtop , rbot ;
-
-   ACFaa = *apar ; ACFbb = *bpar ; ACFcc = *cpar ; ACFflev = *flev ;
-
-   if( ACFaa   >  1.0 || ACFaa   <  0.0 ) return 0.0 ;
-   if( ACFbb   <= 0.0 || ACFcc   <= 0.0 ) return 0.0 ;
-   if( ACFflev <= 0.0 || ACFflev >= 1.0 ) return 0.0 ;
-
-   if( ACFflev > 0.1 ){
-     rtop = 2.5*ACFbb+2.0*ACFcc ;
-     rbot = 0.0666*rtop ;
-   } else {
-     double gg = -log(ACFflev) ;
-     rtop = sqrt(5.0*gg)*ACFbb+2.0*ACFcc ;
-     rbot = 0.0333*rtop ;
-   }
-
-   rhalf = minimize_in_1D( rbot       , rtop       , acfwxm_cost ) ;
-   rhalf = minimize_in_1D( 0.50*rhalf , 2.00*rhalf , acfwxm_cost ) ;
-   rhalf = minimize_in_1D( 0.80*rhalf , 1.25*rhalf , acfwxm_cost ) ;
-
-   return 2.0*rhalf ;
-}
-
-/*-----------------------------------------------------------------------*/
-
-doublereal gamp_( doublereal *peak , doublereal *fwhm )
-{
-   double_pair result ;
-   result = gam_find_pq( *peak , *fwhm ) ;
-   return result.a ;
-}
-
-doublereal gamq_( doublereal *peak , doublereal *fwhm )
-{
-   double_pair result ;
-   result = gam_find_pq( *peak , *fwhm ) ;
-   return result.b ;
-}
-
-/*===========================================================================*/
-/* Stuff for fitting an expression to a time series: PARSER_fitter().        */
-/*---------------------------------------------------------------------------*/
-
-#include "cs.h"
-
-static int    natoz     = 0 ;
-static double *atoz[26] = { NULL , NULL , NULL , NULL , NULL ,
-                            NULL , NULL , NULL , NULL , NULL ,
-                            NULL , NULL , NULL , NULL , NULL ,
-                            NULL , NULL , NULL , NULL , NULL ,
-                            NULL , NULL , NULL , NULL , NULL , NULL } ;
-
-static double *dval = NULL ;
-static double *eval = NULL ;
-
-static PARSER_code *pcode = NULL ;
-static int          mcode = 2 ;
-
-static int    nfree = 0 ;
-static int    jfree[26] ;
-static double bfree[26] ;
-static double tfree[26] ;
-
-static int    nfix  = 0 ;
-static int    jfix[26] ;
-static double vfix[26] ;
-
-static double *wtard=NULL ;
-
-/*----------*/
-
-static void pfit_allocate_atoz( int nval , float *depar )
-{
-   int jj ;
-
-   natoz = nval ;
-   for( jj=0 ; jj < 26 ; jj++ ){
-     atoz[jj] = (double *)realloc( atoz[jj] , sizeof(double)*natoz ) ;
-     memset( atoz[jj] , 0 , sizeof(double)*natoz ) ;
-   }
-   dval = (double *)realloc( dval , sizeof(double)*natoz ) ;
-   eval = (double *)realloc( eval , sizeof(double)*natoz ) ;
-   for( jj=0 ; jj < natoz ; jj++ ) dval[jj] = (double)depar[jj] ;
-   return ;
-}
-
-/*----------*/
-
-static void pfit_free_atoz(void)
-{
-   int jj ;
-   for( jj=0 ; jj < 26 ; jj++ ){
-     if( atoz[jj] != NULL ){ free(atoz[jj]) ; atoz[jj] = NULL ; }
-   }
-   if( dval != NULL ){ free(dval) ; dval = NULL ; }
-   if( eval != NULL ){ free(eval) ; eval = NULL ; }
-   natoz = 0 ;
-   return ;
-}
-
-/*----------*/
-
-static void pfit_fill_atoz( int jj , double val )
-{
-   int tt ;
-   for( tt=0 ; tt < natoz ; tt++ ) atoz[jj][tt] = val ;
-   return ;
-}
-
-/*----------*/
-
-static void pfit_load_atoz( int jj , float *val )
-{
-   int tt ;
-   for( tt=0 ; tt < natoz ; tt++ ) atoz[jj][tt] = (double)val[tt] ;
-   return ;
-}
-
-/*----------*/
-
-static void pfit_eval_model( double *par , double *fitts )
-{
-   int aa ;
-   for( aa=0 ; aa < nfree ; aa++ )
-     pfit_fill_atoz( jfree[aa] , par[aa] ) ;
-
-   PARSER_evaluate_vector( pcode , atoz , natoz , fitts ) ;
-   return ;
-}
-
-/*----------*/
-
-static double pfit_ufunc( int nnn , double *par )
-{
-   double sum=0.0 , rrr ; int tt ;
-   pfit_eval_model( par , eval ) ;
-   for( tt=0 ; tt < natoz ; tt++ ){
-#if 0
-if( !isfinite(dval[tt]) ) ERROR_message("pfit_ufunc: dval[%d] = %g",tt,dval[tt]) ;
-if( !isfinite(eval[tt]) ) ERROR_message("pfit_ufunc: eval[%d] = %g",tt,eval[tt]) ;
-#endif
-     rrr = dval[tt] - eval[tt] ;
-     if( mcode == 1 )    rrr  = fabsf(rrr) ;
-     else                rrr *= rrr ;
-     if( wtard != NULL ) rrr *= wtard[tt] ;
-     sum += rrr ;
-   }
-   return sum ;
-}
-
-/*---------------------------------------------------------------------------*/
-/* Nonlinear fit of an expression to a time series:
-     nval    = number of time series points
-     indval  = array of independent values [nval]
-     depval  = array of dependent (to be fit) values [nval]
-     expr    = expression to be fit
-     indet   = single character indicating which variable name
-               in expr corresponds to indval
-     parbot  = Array of length [26]; parbot[j] indicates the
-               smallest allowed value for the j-th variable
-               ("a" is j=0, etc).
-     partop  = Array of length [26]; partop[j] indicates the
-               largest allowed value for the j-th variable.
-               ++ If the j-th variable is not used in expr, then
-                  parbot[j] and partop[j] are ignored.
-               ++ parbot[j] and partop[j] are also ignored for
-                  the 'indet' variable.
-               ++ Otherwise, if parbot[j] >= partop[j], then
-                  the j-th variable value is fixed at parbot[j].
-               ++ If parbot[j] < partop[j], then this is the
-                  range of values that will be searched for the
-                  j-th parameter.
-     parout  = Array of length [26]; gets the output values
-               of all estimated parameters.
-     meth    = 1 for L1 fitting, 2 for L2 fitting
-     wtar    = weight array [nval] -- can be NULL
-
-     The return value is a malloc()-ed float array of the fitted
-     time series (e.g., for plotting on top of the data depval[]).
-
-     float xar[100] , yar[100] ,
-           parbot[26] , partop[26] , parout[26] , *yfit ;
-     parbot[0] = 0.0f ; partop[0] = 30.0f ;
-     parbot[1] = partop[1] = 0.7f ;
-     partop[2] = -5.0f ; partop[2] = 5.0f ;
-     yfit = PARSER_fitter( 100 , xar , yar ,
-                           "c*sin(a*x+b)" , "x" ,
-                           parbot , partop , parout , 2 , NULL ) ;
-
-     Here, "c" and "a" are to be fit, "b" is a constant parameter.
-*//*-------------------------------------------------------------------------*/
-
-float * PARSER_fitter( int nval, float *indval, float *depval,
-                       char *expr, char *indet,
-                       float *parbot, float *partop, float *parout,
-                       int meth , float *wtar )
-{
-   int jind=0 ; char cind ;
-   int jj,aa ; char cjj ;
-   int nbad=0 ;
-   double pval[26] ;
-   float *fitts ;
-
-   mcode = (meth == 1) ? 1 : 2 ;  /* L2 default */
-
-   /*--- check for errors on input ---*/
-
-   if( nval < 3 ){
-     ERROR_message("PARSER_fitter: nval=%d",nval) ; nbad++ ;
-   }
-   if( indval == NULL ){
-     ERROR_message("PARSER_fitter: indval=NULL"); nbad++ ;
-   }
-   if( depval == NULL ){
-     ERROR_message("PARSER_fitter: depval=NULL"); nbad++ ;
-   }
-   if( expr == NULL ){
-     ERROR_message("PARSER_fitter: expr=NULL"); nbad++ ;
-   }
-   if( indet == NULL ){
-     ERROR_message("PARSER_fitter: indet=NULL"); nbad++ ;
-   } else {
-     cind = toupper(indet[0]) ;
-     jind = cind - 'A' ;
-     if( jind < 0 || jind >= 26 ){
-       ERROR_message("PARSER_fitter: indet is invalid") ; nbad++ ;
-     }
-   }
-   if( parbot == NULL ){
-     ERROR_message("PARSER_fitter: parbot=NULL"); nbad++ ;
-   }
-   if( partop == NULL ){
-     ERROR_message("PARSER_fitter: partop=NULL"); nbad++ ;
-   }
-   if( parout == NULL ){
-     ERROR_message("PARSER_fitter: parout=NULL"); nbad++ ;
-   }
-   if( indval != NULL ){
-     for( jj=0 ; jj < nval ; jj++ ){
-       if( !isfinite(indval[jj]) ){
-         ERROR_message("PARSER_fitter: indval[%d] = %g",jj,indval[jj]) ; nbad++ ;
-       }
-     }
-   }
-   if( depval != NULL ){
-     for( jj=0 ; jj < nval ; jj++ ){
-       if( !isfinite(depval[jj]) ){
-         ERROR_message("PARSER_fitter: depval[%d] = %g",jj,depval[jj]) ; nbad++ ;
-       }
-     }
-   }
-   if( nbad > 0 ) return (NULL) ;
-
-   /*--- parse expression ---*/
-
-   PARSER_set_printout(1) ;
-   pcode = PARSER_generate_code(expr) ;
-   if( pcode == NULL ){
-     ERROR_message("PARSER_fitter: invalid expression") ; return (NULL) ;
-   }
-
-   /*--- check for further errors ---*/
-
-   if( ! PARSER_has_symbol(&cind,pcode) ){
-     ERROR_message("PARSER_fitter: expr doesn't use indet symbol '%c'",indet[0]) ;
-     nbad++ ;
-   }
-
-   nfree = nfix = 0 ;
-   for( jj=0 ; jj < 26 ; jj++ ){
-     if( jj == jind ) continue ;
-     cjj = 'A' + jj ;
-     if( ! PARSER_has_symbol(&cjj,pcode) ) continue ;
-     if( parbot[jj] < partop[jj] ){
-       jfree[nfree] = jj ;               /* add to list of free parameters */
-       bfree[nfree] = (double)parbot[jj] ;
-       tfree[nfree] = (double)partop[jj] ;
-       pval [nfree] = 0.5 * ( bfree[nfree] + tfree[nfree] ) ; nfree++ ;
-       if( !isfinite(parbot[jj]) || !isfinite(partop[jj]) ){
-         ERROR_message("PARSER_fitter: parbot[%d] = %g  partop = %g",jj,parbot[jj],partop[jj]) ;
-         nbad++ ;
-       }
-     } else {
-       jfix[nfix] = jj ; vfix[nfix] = parbot[jj] ; nfix++ ; /* fixed param */
-       if( !isfinite(parbot[jj]) ){
-         ERROR_message("PARSER_fitter: parbot[%d] = %g",jj,parbot[jj]) ;
-         nbad++ ;
-       }
-     }
-   }
-   if( nfree == 0 ){
-     ERROR_message("PARSER_fitter: expr has no free parameters to fit") ; nbad++ ;
-   }
-   if( nbad > 0 ) return (NULL) ;
-
-   /*--- setup for evaluation ---*/
-
-   pfit_allocate_atoz(nval,depval) ;
-
-   for( aa=0 ; aa < nfix ; aa++ ) pfit_fill_atoz( jfix[aa] , vfix[aa] ) ;
-
-   pfit_load_atoz( jind , indval ) ;
-
-   if( wtar != NULL ){
-     int ngood=0 ;
-     wtard = (double *)calloc(sizeof(double),nval) ;
-     for( aa=0 ; aa < nval ; aa++ ){
-       if( wtar[aa] > 0.0 && isfinite(wtar[aa]) ){
-         wtard[aa] = (double)wtar[aa] ; ngood++ ;
-       }
-       if( ngood == 0 ){
-         WARNING_message("PARSER_fitter: wtar has no positive values ==> ignoring it!") ;
-         free(wtard) ; wtard = NULL ;
-       }
-     }
-   }
-
-   /*--- optimize ---*/
-
-   if( nfree > 1 ){  /* more than 1 parameter */
-     double pcost1=1.e+38 , pcost2=1.e+38 , pval2[26] ; int j1,j2 ;
-     /* optimize twice for safety */
-     j1 = powell_newuoa_constrained( nfree , pval , &pcost1 ,
-                                     bfree , tfree ,
-                                     666*nfree+111 , 77*nfree+11 , 33*nfree+7 ,
-                                     0.111 , 0.0000333 , 666*nfree , pfit_ufunc ) ;
-     memcpy( pval2 , pval , sizeof(double)*26 ) ;
-     j2 = powell_newuoa_constrained( nfree , pval2 , &pcost2 ,
-                                     bfree , tfree ,
-                                     333*nfree+77 , 33*nfree+7 , 17*nfree+5 ,
-                                     0.055 , 0.0000333 , 666*nfree , pfit_ufunc ) ;
-
-     if( j1 < 0 && j2 < 0 ){
-       ERROR_message("PARSER_fitter: fitting failed!") ;
-       pfit_free_atoz() ;
-       return (NULL) ;
-     }
-     if( j1 < 0 || (j2 > 0 && pcost2 < pcost1) ){     /* if first failed, or */
-       memcpy( pval , pval2 , sizeof(double)*26 ) ;  /* second is better-ish */
-     }
-   } else {         /* only one parameter (powell_newuoa doesn't work in 1D) */
-     double xout ;
-     xout = minimize_in_1D( bfree[0] , tfree[0] , pfit_ufunc ) ;
-     pval[0] = xout ;
-   }
-
-   /*--- output results ---*/
-
-   for( jj=0 ; jj < 26    ; jj++ ) parout[jj]        = 0.0f ;
-   for( aa=0 ; aa < nfix  ; aa++ ) parout[jfix[aa]]  = vfix[aa] ;
-   for( aa=0 ; aa < nfree ; aa++ ) parout[jfree[aa]] = pval[aa] ;
-
-   pfit_eval_model( pval , eval ) ;
-   fitts = (float *)malloc(sizeof(float)*nval) ;
-   for( aa=0 ; aa < nval ; aa++ ) fitts[aa] = (float)eval[aa] ;
-
-   pfit_free_atoz() ; if( wtard != NULL ) free(wtard) ;
-   return (fitts) ;
-}
