@@ -11,7 +11,7 @@
 #endif
 
 /* -----------------------START---------------------------------*/
-/* definition and declaration part to support the main algorithm */
+/* definition and decleration part to suport the main algorithm */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -29,7 +29,7 @@ typedef struct {
 
 
 /***********************************************************************
-  Plugin to extract 3D+time time courses whos index or xyz coordinates 
+  Plugin to extract 3D+time time courses whos index or xyz corrdinates 
   match a certain criterion
 ************************************************************************/
 typedef struct 
@@ -50,7 +50,7 @@ typedef struct
 		  int yloc;
 		  int zloc;
 		  float pass;  /* value of voxels that are extracted */
-		  float fail;	/* value of voxels that are not extracted */
+		  float fail;	/* value of voxels that are not extacted */
 		  int ncols;
 		  int nrows;
 		  float * indvect;	/* vector that will hold the list of indices */
@@ -105,10 +105,10 @@ static char helpstring[] =
   "      AFNI Prfx  -> 3D Mask Brick generated by giving voxels specified in the ascii\n"
   "                    mask file a value of 'Pass Value' and 0 otherwise.\n"
   "                    If no output prefix is specified, the default is the prefix\n"
-  "                    of the 3D+time input brick with the extension '.XTRCT' appended to it.\n"
+  "                    of the 3D+time input brick with the extenstion '.XTRCT' appended to it.\n"
   "      Filename   -> Name of the ascii file where the time series are written.\n"
   "                    If no output filename is specified, the ouput is the prefix\n"
-  "                    of the 3D+time input brick with the extension '.4Ddump' appended to it.\n"
+  "                    of the 3D+time input brick with the extenstion '.4Ddump' appended to it.\n"
   "                    A LOG file, 'Filename.log' is also written to disk.\n"
   "                    The log file contains all the parameters settings used\n"
   "                    for generating 'Filename'.\n"
@@ -119,7 +119,7 @@ static char helpstring[] =
   "       the option i x y z ts[1] ts[2] .... to know which time series came from which voxel\n\n"
   "If you have/find questions/comments/bugs about the plugin, \n"
   "send me an E-mail: ziad@image.bien.mu.edu\n\n"
-  "                          Ziad Saad June 29 97, last update Feb 23 98.\n\n"
+  "                          Ziad Saad June 29 97, lastest update Feb 23 98.\n\n"
 ;
 
 /*--------------------- strings for output format --------------------*/
@@ -193,7 +193,6 @@ PLUGIN_interface * PLUGIN_init( int ncall )
    PLUGIN_interface * plint ;     /* will be the output of this routine */
 
    if( ncall > 0 ) return NULL ;  /* only one interface */
-   CHECK_IF_ALLOWED("3DEXTRACT","3D+t Extract") ;  /* 30 Sep 2016 */
 
    /*---------------- set titles and call point ----------------*/
 
@@ -356,7 +355,7 @@ static char * EXTRACT_main( PLUGIN_interface * plint )
    MCW_idcode * idc ;                          /* input dataset idcode */
    THD_3dim_dataset * old_dset , * new_dset ;  /* input and output datasets */
    char *tmpstr , * str , *nprfxstr;                 
-   int   ntime, nvec ,nprfx, Err=0 , itmp;
+   int   ntime, nvec ,nprfx, Err , itmp;
 	float * vec , fs , T ;
 	char * tag;                     /* plugin option tag */	
 	
@@ -789,8 +788,8 @@ static void indexTOxyz (extract_data* ud, int ncall, int *xpos , int *ypos , int
 	
 /* ************************************************************ */
 /* function to report errors encountered to the logfile         */
-/* Only errors that happen during runtime  are handled here,   */
-/* the others are handled instantaneously, and need not be 	*/
+/* Only errors that happen during runtime  are handeled here,   */
+/* the others are handeled instantaneously, and need not be 	*/
 /* logged 																		 */
 /* ************************************************************ */
 
@@ -804,7 +803,7 @@ static void error_report (extract_data* ud, int ncall )
 			{
 				
 				default:
-					fprintf (ud->outlogfile,"De Fault, De Fault (%d), the two sweetest words in the english language ! ",ud->errcode);
+					fprintf (ud->outlogfile,"De Fault, De Fault (%d), the two sweetest words in the english langage ! ",ud->errcode);
 					break;
 			}	
 		fprintf (ud->outlogfile,"%d\t%d\t%d\t%d\t\n", ncall , xpos , ypos , zpos  );
@@ -840,7 +839,7 @@ static void writets (extract_data * ud,float * ts, int ncall)
 	}
 
 /* *************************************************************** */
-/* function to extract x y z columns form a matrix format  file */
+/* function to extract x y z colums form a matrix format  file */
 /* *************************************************************** */
 static fXYZ * extract_xyz (char *fname, int x_col_loc, int y_col_loc, int z_col_loc, int ncols, int *nrows, int *Err)
 {/*extract_xyz*/
