@@ -106,8 +106,6 @@ PLUGIN_interface * PLUGIN_init( int ncall )
 
    /*---------------- set titles and call point ----------------*/
 
-   CHECK_IF_ALLOWED("POWERSPECTRUM","Power Spectrum") ;  /* 30 Sep 2016 */
-
    plint = PLUTO_new_interface( "Power Spectrum" ,
                                 "Power Spectrum of a 3D+time Dataset" ,
                                 helpstring ,
@@ -303,7 +301,7 @@ char * POWER_main( PLUGIN_interface * plint )
 #if 0
       for( nfft=32 ; nfft < nuse ; nfft *= 2 ) ; /* loop until nfft >= nuse */
 #else
-      nfft = csfft_nextup_even(nuse) ;
+      nfft = csfft_nextup_one35(nuse) ;
 #endif
 
    } else {
