@@ -106,8 +106,6 @@ PLUGIN_interface * PLUGIN_init( int ncall )
 
    if( ncall > 0 ) return NULL ;  /* only one interface */
 
-   CHECK_IF_ALLOWED("RETROICOR","RETROICOR") ;  /* 30 Sep 2016 */
-
    /*-- set titles and call point --*/
 
    plint = PLUTO_new_interface( "RETROICOR" ,
@@ -184,7 +182,7 @@ static char * PRIC_main( PLUGIN_interface * plint )
    double * ca , * cb, * ra, * rb;
    MRI_IMAGE * card = NULL, * resp = NULL;
    MRI_IMAGE * cardphase = NULL, * respphase = NULL;
-   float threshold=0.0, ignore_input, M_input;
+   float threshold, ignore_input, M_input;
    /*-- removed winsize ui
    , winsize_input;
    removed winsize ui --*/
