@@ -46,8 +46,8 @@
 #include <values.h>
 #endif
 
-#ifndef THRESH_MAXINT
-#define THRESH_MAXINT (1<<30)
+#ifndef MAXINT
+#define MAXINT (1<<30)
 #endif
 
 #include "afni.h"
@@ -403,7 +403,7 @@ short	threshold;	/*threshold below which pixels are included*/
 static int THRESH_mask_brain(short *img, int xdim, int ydim, int zdim, short threshold)
   {
   register int x, y, z, region;
-  int region_size=0, max_region_size=0, max_region=0;
+  int region_size, max_region_size, max_region;
   short *mask_img;
   int *stack;
   mask_img = calloc(xdim*ydim*zdim, sizeof(*mask_img));
@@ -503,7 +503,7 @@ static short *THRESH_compute(THD_3dim_dataset *dset, int verbose)
   while(x > THRESH_MAX_BRAIN-THRESH_FILTER_LEN)
     insert_newest(histogram[--x], &filter);
   histo_max = -1;
-  histo_min = THRESH_MAXINT;
+  histo_min = MAXINT;
   cutoff = brain_peak = THRESH_MAX_BRAIN;
   /*inv: filter contains histogram[x..x+THRESH_FILTER_LEN-1], histo_max is the
     maximum median-filtered value of histogram[x+1+THRESH_FILTER_LEN/2..
@@ -617,9 +617,8 @@ DEFINE_PLUGIN_PROTOTYPE
 PLUGIN_interface *PLUGIN_init(int ncall)
   {
   PLUGIN_interface *plint;
-  if(ncall > 0) return (PLUGIN_interface *)0;	/*only one interface*/
-  CHECK_IF_ALLOWED("THRESHOLD","Threshold") ;  /* 30 Sep 2016 */
- 
+  if(ncall > 0)
+    return (PLUGIN_interface *)0;	/*only one interface*/
 /*set titles and entry point*/
   plint = PLUTO_new_interface("Threshold", hint, help, PLUGIN_CALL_VIA_MENU, THRESH_main);
   PLUTO_add_hint(plint, hint);
