@@ -32,19 +32,16 @@
 *******************************************************************/
 
 /***** Header file for communication routines *****/
-#include "afni_environ.h"
+
 #include "afni_plugout.h"
 #include "thd_iochan.h"
-#include "niml.h"
-#include "cs.h"
 
 /***** Global variable determining on which system AFNI runs.  *****/
 /***** [default is the current system, can be changed by user] *****/
 
 static char afni_host[128] = "localhost" ;
 static char afni_name[128] = "\0" ;
-static int  afni_port      = 0 ;  /* Init. before parsing command line
-                                    ZSS June 2011 */
+static int  afni_port      = 8099 ;
 static int  afni_verbose   = 0 ;  /* print out debug info? */
 static int  DontWait = 0;
 static int  N_com = 0;
@@ -56,7 +53,7 @@ static char *com[1024];
   This routine handles all communications with AFNI.
   The only input is the global variable afni_host, which determines
   on which system AFNI is running.
-  The output is -1 if an error occurred, 0 if everything is OK.
+  The output is -1 if an error occured, 0 if everything is OK.
 =====================================================================*/
 
 /***** Mode flags for determining what afni_io does.
@@ -117,15 +114,12 @@ int afni_io(void)
       char afni_iocname[128] ;           /* will hold name of I/O channel */
 
       /** Note that the control channel is always a
-          TCP/IP channel to port #get_port_named("AFNI_PLUGOUT_TCP_0")
-          (used to be #7955) on the AFNI host system **/
+          TCP/IP channel to port # 7955 on the AFNI host system **/
 
       if( strcmp(afni_host,".") == 0 )
-         sprintf( afni_iocname , "tcp:%s:%d" ,
-            "localhost", get_port_named("AFNI_PLUGOUT_TCP_0") ); /* make name */
+         sprintf( afni_iocname , "tcp:%s:7955" , "localhost" ); /* make name */
       else
-         sprintf( afni_iocname , "tcp:%s:%d" ,
-            afni_host, get_port_named("AFNI_PLUGOUT_TCP_0") ) ;  /* make name */
+         sprintf( afni_iocname , "tcp:%s:7955" , afni_host ) ;  /* make name */
 
       afni_ioc = iochan_init( afni_iocname , "create" ) ;    /* create it */
       if( afni_ioc == NULL ){
@@ -138,7 +132,7 @@ int afni_io(void)
       gettimeofday(&tw, NULL);   /* keep track of time that you began waiting */
 
       if( afni_verbose )
-         fprintf(stderr,"++ AFNI control channel %s created\n", afni_iocname) ;
+         fprintf(stderr,"++ AFNI control channel created\n") ;
    }
 
    /****************************************************/
@@ -155,7 +149,7 @@ int afni_io(void)
 
       if( ii < 0 ){
          fprintf(stderr,"** Control channel to AFNI failed!\a\n") ;
-         IOCHAN_CLOSENOW(afni_ioc) ;
+         IOCHAN_CLOSE(afni_ioc) ;
          afni_mode = 0 ;
          return -1 ;
       } else if( ii > 0 ){
@@ -163,13 +157,11 @@ int afni_io(void)
          if( afni_verbose )
             fprintf(stderr,"++ AFNI control channel connected\n");
       } else {
-         delta_t = (((float)(tn.tv_sec  - tw.tv_sec )*Time_Fact) +
-                                                      /* time spent waiting */
+         delta_t = (((float)(tn.tv_sec  - tw.tv_sec )*Time_Fact) +     /* time spent waiting */
                      (float)(tn.tv_usec - tw.tv_usec))/Time_Fact ;
          if (delta_t > maxwait) {
-            fprintf(stderr,
-                     "** Waited %g seconds to no avail ==> I quit.\n",maxwait);
-            IOCHAN_CLOSENOW(afni_ioc) ;
+            fprintf(stderr,"** Waited %g seconds to no avail ==> I quit.\n",maxwait);
+            IOCHAN_CLOSE(afni_ioc) ;
             afni_mode = 0 ;
             return -1 ;
          } else {
@@ -198,8 +190,7 @@ int afni_io(void)
            key (in function string_to_key in iochan.c).       **/
 
       if( strcmp(afni_host,".") == 0 ) {
-         sprintf( shmstr, "shm:test_plugout:%dK+%dK",
-                     PLUGOUT_SHM_SIZE_K, PLUGOUT_SHM_SIZE_K);
+         sprintf( shmstr, "shm:test_plugout:%dK+%dK", PLUGOUT_SHM_SIZE_K, PLUGOUT_SHM_SIZE_K);
          strcpy( afni_iocname , shmstr ) ;
       } else
          sprintf( afni_iocname , "tcp:%s:%d" , afni_host , afni_port ) ;
@@ -212,15 +203,14 @@ int afni_io(void)
             * PONAME means 'use this string for informative messages';
             * IOCHAN means 'use this I/O channel from now on'. **/
 
-      if( afni_name[0] == '\0' ) strcpy(afni_name,"plugout_drive") ;
+      if( afni_name[0] == '\0' ) strcpy(afni_name,"ManOfLaMancha") ;
 
       sprintf( afni_buf , "PONAME %s\n"
                           "IOCHAN %s" ,
                afni_name , afni_iocname ) ;
 
       if( afni_verbose )
-         fprintf(stderr,"++ Sending control information to AFNI\n   %s\n",
-                afni_buf) ;
+         fprintf(stderr,"++ Sending control information to AFNI\n") ;
 
       /** note that the ASCII NUL at the end of the buffer is sent **/
 
@@ -231,7 +221,7 @@ int afni_io(void)
 
       if( ii < 0 ){
          fprintf(stderr,"** Transmission of control data to AFNI failed!\a\n") ;
-         IOCHAN_CLOSENOW(afni_ioc) ;
+         IOCHAN_CLOSE(afni_ioc) ;
          afni_mode = 0 ;
          return -1 ;
 
@@ -240,7 +230,7 @@ int afni_io(void)
          /** wait for the acknowledgment from AFNI, then close channel **/
 
          ii = iochan_recvall( afni_ioc , afni_buf , POACKSIZE ) ;
-         IOCHAN_CLOSENOW(afni_ioc) ;
+         IOCHAN_CLOSE(afni_ioc) ;
 
          if( ii < 0 || strncmp(afni_buf,"OK!",3) != 0 ){
             fprintf(stderr,"** AFNI didn't like control information!\a\n") ;
@@ -272,7 +262,7 @@ int afni_io(void)
       if( ii < 0 ){
          fprintf(stderr,
                  "** AFNI data channel aborted before any data was sent!\a\n") ;
-         IOCHAN_CLOSENOW( afni_ioc ) ;
+         IOCHAN_CLOSE( afni_ioc ) ;
          afni_mode = 0 ;
          return -1 ;
       } else if( ii > 0 ){                     /* ready to go! */
@@ -294,8 +284,7 @@ int afni_io(void)
          strcpy(afni_buf, "DRIVE_AFNI ") ;
          strcat(afni_buf, com[I_com]   ) ; strcpy(cmd_buf,com[I_com]) ;
          if (afni_verbose) {
-            fprintf(stderr,"Command String %d Echo: '%s'\n",
-                           I_com, afni_buf); fflush(stderr) ;
+            fprintf(stderr,"Command String %d Echo: '%s'\n", I_com, afni_buf); fflush(stderr) ;
          }
          I_com++ ;
       } else {
@@ -304,7 +293,7 @@ int afni_io(void)
          /* get user input */
 
          printf("Enter command: ") ; fflush(stdout) ;
-         qpt = afni_fgets(cmd_buf,PLUGOUT_COM_LENGTH,stdin) ;
+         qpt = fgets(cmd_buf,PLUGOUT_COM_LENGTH,stdin) ;
          if( qpt == NULL ) exit(0) ;  /* 18 Mar 2007 */
 
          /* make command to AFNI */
@@ -329,7 +318,7 @@ int afni_io(void)
 
       if( ii < 0 ){   /* send or acknowledgment failed */
          fprintf(stderr,"** AFNI data channel aborted!\a\n") ;
-         IOCHAN_CLOSENOW(afni_ioc) ;
+         IOCHAN_CLOSE(afni_ioc) ;
          afni_mode = 0 ;
          return -1 ;
       }
@@ -339,117 +328,6 @@ int afni_io(void)
    return 0 ;
 }
 
-extern char *SUMA_Offset_SLines(char *, int);
-
-void usage_plugout_drive(int detail)
-{
-      printf("\n"
-"Usage: plugout_drive [-host name] [-v]\n\n"
-"This program connects to AFNI and sends commands\n"
-" that the user specifies interactively or on command line\n"
-" over to AFNI to be executed.\n"
-"\n"
-"NOTE:\n"
-" If you quit plugout_drive and then re-start it immediately\n"
-" (as in a script), you might run into problems re-connecting\n"
-" to AFNI. The reason is that the TCP/IP system doesn't hang\n"
-" up a socket instantly when commanded to do so; the socket\n"
-" takes about a second to close down completely. If you are\n"
-" writing a script that starts plugout_drive repeatedly, you\n"
-" should insert a command 'sleep 1' between each start, to\n"
-" give the operating system time to clean the socket up.\n"
-" Otherwise, AFNI might not be able to open the socket,\n"
-" and plugout_drive will output an error message:\n"
-"   ** AFNI didn't like control information!\n"
-"\n"
-"OPTIONS:\n"
-"  -host name    Means to connect to AFNI running on the computer\n"
-"                'name' using TCP/IP.  The default is to connect\n"
-"                on the current host 'localhost' using TCP/IP.\n"
-"\n"
-"  -shm          Means to connect to the current host using shared\n"
-"                memory.  There is no reason to do this unless\n"
-"                you are transferring huge quantities of data.\n"
-"                N.B.:  '-host .' is equivalent to '-shm'.\n"
-"\n"
-"  -v            Verbose mode.\n"
-"\n"
-"  -port pp      Use TCP/IP port number 'pp'.  The default is\n"
-"                %d, but if two plugouts are running on the\n"
-"                same computer, they must use different ports.\n"
-"                For a list of currently used ports use afni -list_ports\n"
-"\n"
-"  -maxwait t    Wait a maximum of 't' seconds for AFNI to connect;\n"
-"                if the connection doesn't happen in that time, exit.\n"
-"                [default wait time is 9 seconds]\n"
-"\n"
-"  -name sss     Use the string 'sss' for the name that AFNI assigns\n"
-"                to this plugout.  The default is something stupid.\n"
-"\n"
-"  -com 'ACTION DATA'  Execute the following command. For example:\n"
-"                       -com 'SET_FUNCTION SomeFunction'\n"
-"                       will switch AFNI's function (overlay) to\n"
-"                       dataset with prefix SomeFunction. \n"
-"                      Make sure ACTION and DATA are together enclosed\n"
-"                       in one pair of single quotes.\n"
-"                      There are numerous actions listed in AFNI's\n"
-"                       README.driver file.\n"
-"                      You can use the option -com repeatedly. \n"
-"\n"
-"  -quit         Quit after you are done with all the -com commands.\n"
-"                The default is for the program to wait for more\n"
-"                commands to be typed at the terminal's prompt.\n"
-"\n"
-"NOTES:\n"
-"You will need to turn plugouts on in AFNI using one of the\n"
-"following methods: \n"
-" 1. Including '-yesplugouts' as an option on AFNI's command line\n"
-" 2. From AFNI GUI: Define Datamode->Misc->Start Plugouts\n"
-" 3. From AFNI GUI: Press the 'NIML+PO' button (near 'Overlay')\n"
-" 4. Set environment variable AFNI_YESPLUGOUTS to YES in .afnirc\n"
-"Otherwise, AFNI won't be listening for a plugout connection.\n"
-"  [AFNI doesn't listen for socket connections, unless]\n"
-"  [it is told to,  in order to avoid the overhead of]\n"
-"  [checking for incoming data every few milliseconds]\n"
-"\n"
-"This program's exit status will be 1 if it couldn't connect\n"
-"to AFNI at all.  Otherwise, the exit status will be 0.\n"
-"You could use this feature in a script to check if a copy of\n"
-"AFNI is ready to rumble, and if not then start one, as in the\n"
-"following csh fragment:\n"
-"    plugout_drive -maxwait 1 -com 'OPEN_WINDOW axialimage'\n"
-"    if( $status == 1 )then\n"
-"      afni -yesplugouts &\n"
-"      sleep 2 ; plugout_drive -com 'OPEN_WINDOW axialimage'\n"
-"    endif\n"
-"\n"
-"To have different plugout_* programs talking to different\n"
-"AFNI, use the -np* options below\n"
-"%s\n"
-"Global Options (available to all AFNI/SUMA programs)\n"
-"%s\n%s"
-"Example 1:\n"
-"    afni -yesplugouts\n"
-"    plugout_drive  -com 'SWITCH_SESSION A.afni'                       \\\n"
-"                   -com 'OPEN_WINDOW A.axialimage geom=600x600+416+44 \\\n"
-"                         ifrac=0.8 opacity=9'                         \\\n"
-"                   -com 'OPEN_WINDOW A.sagittalimage geom=+45+430     \\\n"
-"                         ifrac=0.8 opacity=9'                         \\\n"
-"                   -com 'SWITCH_UNDERLAY anat'                        \\\n"
-"                   -com 'SWITCH_OVERLAY strip'                        \\\n"
-"                   -com 'SEE_OVERLAY +'                               \\\n"
-"                   -com 'SET_DICOM_XYZ 7 12 2'                        \\\n"
-"                   -com 'OPEN_WINDOW A.axialimage keypress=v'         \\\n"
-"                   -quit             \n"
-"\n"
-"More help in: README.driver\n"
-"More Demos is: @DriveAfni\n"
-"\n"
-   , afni_port, get_np_help(), SUMA_Offset_SLines(get_help_help(),2),
-    get_gopt_help() );
-   return;
-}
-
 /*===================================================================
    Main program:
      Read command line for options
@@ -460,17 +338,76 @@ int main( int argc , char *argv[] )
 {
    int narg , ii;
 
-   (void)AFNI_prefilter_args(&argc,&argv);
-
-   afni_port = get_port_named("PLUGOUT_DRIVE_PORT"); /* ZSS June 2011 */
-
    /***** See if the pitiful user wants help *****/
 
-   if( argc == 2 && (
-      strcasecmp(argv[1],"-help") == 0 ||
-      strcasecmp(argv[1],"-h")    == 0)  ){
-      usage_plugout_drive(strlen(argv[1]) > 3 ? 2:1);
-      exit (0);
+   if( argc == 2 && strncmp(argv[1],"-help",5) == 0 ){
+      printf("Usage: plugout_drive [-host name] [-v]\n"
+             "This program connects to AFNI and sends commands\n"
+             " that the user specifies interactively or on command line\n"
+             " over to AFNI to be executed.\n"
+             "\n"
+             "Options:\n"
+             "  -host name    Means to connect to AFNI running on the computer\n"
+             "                'name' using TCP/IP.  The default is to connect\n"
+             "                on the current host 'localhost' using TCP/IP.\n"
+             "\n"
+             "  -shm          Means to connect to the current host using shared\n"
+             "                memory.  There is no reason to do this unless\n"
+             "                you are transferring huge quantities of data.\n"
+             "                N.B.:  '-host .' is equivalent to '-shm'.\n"
+             "\n"
+             "  -v            Verbose mode.\n"
+             "\n"
+             "  -port pp      Use TCP/IP port number 'pp'.  The default is\n"
+             "                8099, but if two plugouts are running on the\n"
+             "                same computer, they must use different ports.\n"
+             "\n"
+             "  -maxwait t    Wait a maximum of 't' seconds for AFNI to connect;\n"
+             "                if the connection doesn't happen in that time, exit.\n"
+             "                [default wait time is 9 seconds]\n"
+             "\n"
+             "  -name sss     Use the string 'sss' for the name that AFNI assigns\n"
+             "                to this plugout.  The default is something stupid.\n"
+             "\n"
+             "  -com 'ACTION DATA'  Execute the following command. For example:\n"
+             "                       -com 'SET_FUNCTION SomeFunction'\n"
+             "                       will switch AFNI's function (overlay) to\n"
+             "                       dataset with prefix SomeFunction. \n"
+             "                      Make sure ACTION and DATA are together enclosed\n"
+             "                       in one pair of single quotes.\n"
+             "                      There are numerous actions listed in AFNI's\n"
+             "                       README.driver file.\n"
+             "                      You can use the option -com repeatedly. \n"
+             "\n"
+             "  -quit         Quit after you are done with all the -com commands.\n"
+             "                The default is for the program to wait for more\n"
+             "                commands to be typed at the terminal's prompt.\n"
+             "\n"
+             "NOTES:\n"
+             "You will need to turn plugouts on in AFNI using one of the\n"
+             "following methods: \n"
+             " 1. Including '-yesplugouts' as an option on AFNI's command line\n"
+             " 2. From AFNI GUI: Define Datamode->Misc->Start Plugouts\n"
+             " 3. From AFNI GUI: Press the 'NIML+PO' button (near 'Overlay')\n"
+             " 4. Set environment variable AFNI_YESPLUGOUTS to YES in .afnirc\n"
+             "Otherwise, AFNI won't be listening for a plugout connection.\n"
+             "  [AFNI does't listen for socket connections, unless]\n"
+             "  [it is told to,  in order to avoid the overhead of]\n"
+             "  [checking for incoming data every few milliseconds]\n"
+             "\n"
+             "This program's exit status will be 1 if it couldn't connect\n"
+             "to AFNI at all.  Otherwise, the exit status will be 0.\n"
+             "You could use this feature in a script to check if a copy of\n"
+             "AFNI is ready to rumble, and if not then start one, as in the\n"
+             "following csh fragment:\n"
+             "    plugout_drive -maxwait 1 -com 'OPEN_WINDOW axialimage'\n"
+             "    if( $status == 1 )then\n"
+             "      afni -yesplugouts &\n"
+             "      sleep 2 ; plugout_drive -com 'OPEN_WINDOW axialimage'\n"
+             "    endif\n"
+             "\n"
+            ) ;
+      exit(0) ;
    }
 
    /***** Process command line options *****/
@@ -579,7 +516,6 @@ int main( int argc , char *argv[] )
       /** Je ne sais pas **/
 
       fprintf(stderr,"** Unrecognized option: %s\a\n",argv[narg]) ;
-      suggest_best_prog_option(argv[0], argv[narg]);
       exit(1) ;
    }
 
