@@ -6,16 +6,13 @@
    
 #include <math.h>
 #include "thd_iochan.h"
-#include "niml.h"
-#include "afni_environ.h"
 
 /***** Global variable determining on which system AFNI runs.  *****/
 /***** [default is the current system, can be changed by user] *****/
 
 static char afni_host[128] = "." ;
 static char afni_name[128] = "\0" ;
-static int  afni_port      = 0 ;  /* Init. before parsing command line  
-                                    ZSS June 2011 */
+static int  afni_port      = 8005 ;
 
 static int  afni_verbose = 0 ;  /* print out debug info? */
 
@@ -48,10 +45,6 @@ int main( int argc , char * argv[] )
 {
    int narg , ii ;
 
-   (void)AFNI_prefilter_args(&argc,&argv);
-
-   afni_port = get_port_named("PLUGOUT_TTA_PORT"); /* ZSS June 2011 */
-   
    /***** See if the pitiful user wants help *****/
 
    if( argc == 2 && strncmp(argv[1],"-help",5) == 0 ){
@@ -68,16 +61,11 @@ int main( int argc , char * argv[] )
              "                connect on the current host using shared memory.\n"
              "                To connect to the current host with TCP/IP, use\n"
              "                '-host localhost', or use the '-port' option.\n"
-             "              For a list of currently used ports use afni -list_ports\n"
              "  -v          Verbose mode: prints out progress reports.\n"
-             "  -port pp    Use TCP/IP port number 'pp'; default is %d.\n"
+             "  -port pp    Use TCP/IP port number 'pp'; default is 8005.\n"
              "The environment variable AFNI_TTAHOME controls where the atlas\n"
              "images are loaded from.  If not given, a default value is used.\n"
-             "\n"
-             "To have different plugout_* programs talking to different\n"
-             "AFNI, use the -np* options below\n"
-             "%s\n"
-            , afni_port, get_np_help()) ;
+            ) ;
       exit(0) ;
    }
 
@@ -158,7 +146,7 @@ int main( int argc , char * argv[] )
   This routine handles all communications with AFNI.
   The only input is the global variable afni_host, which determines
   on which system AFNI is running.
-  The output is -1 if an error occurred, 0 if everything is OK.
+  The output is -1 if an error occured, 0 if everything is OK.
 =====================================================================*/
 
 /***** Mode flags for determining what afni_io does.
@@ -210,15 +198,12 @@ int afni_io(void)
       char afni_iocname[128] ;           /* will hold name of I/O channel */
 
       /** Note that the control channel is always a
-          TCP/IP channel to port #get_port_named("AFNI_PLUGOUT_TCP_0") 
-          (used to be #7955) on the AFNI host system **/
+          TCP/IP channel to port # 7955 on the AFNI host system **/
 
       if( strcmp(afni_host,".") == 0 )
-         sprintf( afni_iocname , "tcp:%s:%d" , 
-            "localhost", get_port_named("AFNI_PLUGOUT_TCP_0") ); /* make name */
+         sprintf( afni_iocname , "tcp:%s:7955" , "localhost" ); /* make name */
       else
-         sprintf( afni_iocname , "tcp:%s:%d" , 
-            afni_host, get_port_named("AFNI_PLUGOUT_TCP_0") ) ;  /* make name */
+         sprintf( afni_iocname , "tcp:%s:7955" , afni_host ) ;  /* make name */
       afni_ioc = iochan_init( afni_iocname , "create" ) ;    /* create it */
       if( afni_ioc == NULL ){
          fprintf(stderr,
