@@ -1,39 +1,22 @@
-#ifndef __POWELL_NEWUOA__
-#define __POWELL_NEWUOA__
-
-#undef  AFmax
-#undef  AFmin
-#define AFmax(a,b) (((a)<(b)) ? (b) : (a))
-#define AFmin(a,b) (((a)>(b)) ? (b) : (a))
-
-#define DEBUG 0
-
-/*---------------------------------------------------------------------------*/
-
 /* powell_newuoa.f -- translated by f2c (version 19961017).
    You must link the resulting object file with the libraries:
 	-lf2c -lm   (in that order)
 */
 
-#undef  STATIC
-#define STATIC /*static*/   /*** disable use of static internal variables ***/
-                            /*** all local variables instead init to =0   ***/
-
-#include <stdio.h>
 #include "f2c.h"
 
 /* CC      SUBROUTINE NEWUOA (N,NPT,X,RHOBEG,RHOEND,IPRINT,MAXFUN,W) */
-/* Subroutine */ int newuoa_(integer *n, integer *npt, doublereal *x,
+/* Subroutine */ int newuoa_(integer *n, integer *npt, doublereal *x, 
 	doublereal *rhobeg, doublereal *rhoend, integer *maxfun, doublereal *
 	w, integer *icode)
 {
-    STATIC integer ndim=0, nptm=0, ibmat=0, izmat=0, id=0, np=0, iw=0;
-    extern /* Subroutine */ int newuob_(integer *, integer *, doublereal *,
+    static integer ndim, nptm, ibmat, izmat, id, np, iw;
+    extern /* Subroutine */ int newuob_(integer *, integer *, doublereal *, 
 	    doublereal *, doublereal *, integer *, doublereal *, doublereal *,
-	     doublereal *, doublereal *, doublereal *, doublereal *,
+	     doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *, integer *,
 	     doublereal *, doublereal *, doublereal *, integer *);
-    STATIC integer igq=0, ihq=0, ixb=0, ifv=0, ipq=0, ivl=0, ixn=0, ixo=0, ixp=0;
+    static integer igq, ihq, ixb, ifv, ipq, ivl, ixn, ixo, ixp;
 
 
 /*    This subroutine seeks the least value of a function of many variable
@@ -42,19 +25,20 @@ s,*/
 n.*/
 /*     There can be some freedom in the interpolation conditions, which is
  */
-/*    taken up by minimizing the Frobenius norm of the change to the second */
+/*    taken up by minimizing the Frobenius norm of the change to the secon
+d*/
 /*    derivative of the quadratic model, beginning with a zero matrix. The
 */
 /*     arguments of the subroutine are as follows. */
 
-/*     N must be set to the number of variables and must be at least two.
+/*     N must be set to the number of variables and must be at least two. 
 */
-/*    NPT is the number of interpolation conditions. Its value must be in
+/*    NPT is the number of interpolation conditions. Its value must be in 
 the*/
 /*       interval [N+2,(N+1)(N+2)/2]. */
 /*    Initial values of the variables must be set in X(1),X(2),...,X(N). T
 hey*/
-/*       will be changed to the values that give the least calculated F.
+/*       will be changed to the values that give the least calculated F. 
 */
 /*    RHOBEG and RHOEND must be set to the initial and final values of a t
 rust*/
@@ -71,7 +55,7 @@ s the*/
 =0 and*/
 /*CCC       there is output only at the return if IPRINT=1. Otherwise, eac
 h new*/
-/*CCC       value of RHO is printed, with the best vector of variables so
+/*CCC       value of RHO is printed, with the best vector of variables so 
 far and*/
 /*CCC       the corresponding value of the objective function. Further, ea
 ch new*/
@@ -82,15 +66,15 @@ N.*/
 ast*/
 /*     (NPT+13)*(NPT+N)+3*N*(N+3)/2. */
 
-/*    SUBROUTINE CALFUN (N,X,F) must be provided by the user. It must set
+/*    SUBROUTINE CALFUN (N,X,F) must be provided by the user. It must set 
 F to*/
 /*    the value of the objective function for the variables X(1),X(2),...,
 X(N).*/
 
 /*    Partition the working space array, so that different parts of it can
  be*/
-/*    treated separately by the subroutine that performs the main
- calculation.*/
+/*    treated separately by the subroutine that performs the main calculat
+ion.*/
 
     /* Parameter adjustments */
     --w;
@@ -120,14 +104,14 @@ X(N).*/
     ivl = id + *n;
     iw = ivl + ndim;
 
-/*     The above settings provide a partition of W for subroutine NEWUOB.
+/*     The above settings provide a partition of W for subroutine NEWUOB. 
 */
 /*    The partition requires the first NPT*(NPT+N)+5*N*(N+3)/2 elements of
 */
 /*     W plus the space that is needed by the last array of NEWUOB. */
 
 /* CC      CALL NEWUOB (N,NPT,X,RHOBEG,RHOEND,IPRINT,MAXFUN,W(IXB), */
-    newuob_(n, npt, &x[1], rhobeg, rhoend, maxfun, &w[ixb], &w[ixo], &w[ixn],
+    newuob_(n, npt, &x[1], rhobeg, rhoend, maxfun, &w[ixb], &w[ixo], &w[ixn], 
 	    &w[ixp], &w[ifv], &w[igq], &w[ihq], &w[ipq], &w[ibmat], &w[izmat],
 	     &ndim, &w[id], &w[ivl], &w[iw], icode);
 /* L20: */
@@ -135,68 +119,68 @@ X(N).*/
 } /* newuoa_ */
 
 /* CC      SUBROUTINE NEWUOB (N,NPT,X,RHOBEG,RHOEND,IPRINT,MAXFUN,XBASE, */
-/* Subroutine */ int newuob_(integer *n, integer *npt, doublereal *x,
+/* Subroutine */ int newuob_(integer *n, integer *npt, doublereal *x, 
 	doublereal *rhobeg, doublereal *rhoend, integer *maxfun, doublereal *
-	xbase, doublereal *xopt, doublereal *xnew, doublereal *xpt,
-	doublereal *fval, doublereal *gq, doublereal *hq, doublereal *pq,
-	doublereal *bmat, doublereal *zmat, integer *ndim, doublereal *d__,
+	xbase, doublereal *xopt, doublereal *xnew, doublereal *xpt, 
+	doublereal *fval, doublereal *gq, doublereal *hq, doublereal *pq, 
+	doublereal *bmat, doublereal *zmat, integer *ndim, doublereal *d__, 
 	doublereal *vlag, doublereal *w, integer *icode)
 {
     /* System generated locals */
-    integer xpt_dim1=0, xpt_offset=0, bmat_dim1=0, bmat_offset=0, zmat_dim1=0,
-	    zmat_offset=0, i__1=0, i__2=0, i__3=0;
-    doublereal d__1=0, d__2=0, d__3=0;
+    integer xpt_dim1, xpt_offset, bmat_dim1, bmat_offset, zmat_dim1, 
+	    zmat_offset, i__1, i__2, i__3;
+    doublereal d__1, d__2, d__3;
 
     /* Builtin functions */
     double sqrt(doublereal);
 
     /* Local variables */
-    STATIC doublereal fbeg=0, diff=0, half=0, beta=0;
-    STATIC integer nfmm=0;
-    STATIC doublereal gisq=0;
-    STATIC integer knew=0;
-    STATIC doublereal temp=0, suma=0, sumb=0, fopt=0, bsum=0, gqsq=0;
-    STATIC integer kopt=0, nptm=0;
-    STATIC doublereal zero=0, xipt=0, xjpt=0, sumz=0, f=0;
-    STATIC integer i__=0, j=0, k=0;
-    STATIC doublereal diffa=0, diffb=0, diffc=0, hdiag=0, alpha=0, delta=0, recip=0, reciq=0,
-	    fsave=0;
-    STATIC integer ksave=0, nfsav=0, itemp=0;
-    STATIC doublereal dnorm=0, ratio=0, dstep=0, tenth=0, vquad=0;
-    STATIC integer ktemp=0;
-    STATIC doublereal tempq=0;
-    STATIC integer itest=0;
-    STATIC doublereal rhosq=0;
-    STATIC integer ih=0, nf=0;
-    extern /* Subroutine */ int biglag_(integer *, integer *, doublereal *,
-	    doublereal *, doublereal *, doublereal *, integer *, integer *,
+    static doublereal fbeg, diff, half, beta;
+    static integer nfmm;
+    static doublereal gisq;
+    static integer knew;
+    static doublereal temp, suma, sumb, fopt, bsum, gqsq;
+    static integer kopt, nptm;
+    static doublereal zero, xipt, xjpt, sumz, f;
+    static integer i__, j, k;
+    static doublereal diffa, diffb, diffc, hdiag, alpha, delta, recip, reciq, 
+	    fsave;
+    static integer ksave, nfsav, itemp;
+    static doublereal dnorm, ratio, dstep, tenth, vquad;
+    static integer ktemp;
+    static doublereal tempq;
+    static integer itest;
+    static doublereal rhosq;
+    static integer ih, nf;
+    extern /* Subroutine */ int biglag_(integer *, integer *, doublereal *, 
+	    doublereal *, doublereal *, doublereal *, integer *, integer *, 
 	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
 	     doublereal *, doublereal *, doublereal *, doublereal *);
-    STATIC integer nh=0, ip=0, jp=0;
-    STATIC doublereal dx=0;
-    extern /* Subroutine */ int bigden_(integer *, integer *, doublereal *,
-	    doublereal *, doublereal *, doublereal *, integer *, integer *,
-	    integer *, integer *, doublereal *, doublereal *, doublereal *,
+    static integer nh, ip, jp;
+    static doublereal dx;
+    extern /* Subroutine */ int bigden_(integer *, integer *, doublereal *, 
+	    doublereal *, doublereal *, doublereal *, integer *, integer *, 
+	    integer *, integer *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *, doublereal *);
-    STATIC integer np=0;
+    static integer np;
     extern /* Subroutine */ int calfun_(integer *, doublereal *, doublereal *)
-	    , update_(integer *, integer *, doublereal *, doublereal *,
-	    integer *, integer *, doublereal *, doublereal *, integer *,
+	    , update_(integer *, integer *, doublereal *, doublereal *, 
+	    integer *, integer *, doublereal *, doublereal *, integer *, 
 	    doublereal *);
-    STATIC doublereal detrat=0, crvmin=0;
-    STATIC integer nftest=0;
-    STATIC doublereal distsq=0;
-    extern /* Subroutine */ int trsapp_(integer *, integer *, doublereal *,
-	    doublereal *, doublereal *, doublereal *, doublereal *,
-	    doublereal *, doublereal *, doublereal *, doublereal *,
+    static doublereal detrat, crvmin;
+    static integer nftest;
+    static doublereal distsq;
+    extern /* Subroutine */ int trsapp_(integer *, integer *, doublereal *, 
+	    doublereal *, doublereal *, doublereal *, doublereal *, 
+	    doublereal *, doublereal *, doublereal *, doublereal *, 
 	    doublereal *, doublereal *, doublereal *);
-    STATIC doublereal xoptsq=0;
-    STATIC integer nfm=0;
-    STATIC doublereal one=0;
-    STATIC integer idz=0;
-    STATIC doublereal dsq=0, rho=0;
-    STATIC integer ipt=0, jpt=0;
-    STATIC doublereal sum=0;
+    static doublereal xoptsq;
+    static integer nfm;
+    static doublereal one;
+    static integer idz;
+    static doublereal dsq, rho;
+    static integer ipt, jpt;
+    static doublereal sum;
 
 
 /*    The arguments N, NPT, X, RHOBEG, RHOEND, IPRINT and MAXFUN are ident
@@ -227,8 +211,8 @@ e*/
 /*       the elements of DZ are plus or minus one, as specified by IDZ. */
 /*     NDIM is the first dimension of BMAT and has the value NPT+N. */
 /*     D is reserved for trial steps from XOPT. */
-/*    VLAG will contain the values of the Lagrange functions at a new */
-/*    point X.*/
+/*    VLAG will contain the values of the Lagrange functions at a new poin
+t X.*/
 /*      They are part of a product that requires VLAG to be of length NDIM
 .*/
 /*    The array W will be used for working space. Its length must be at le
@@ -267,7 +251,7 @@ ast*/
     np = *n + 1;
     nh = *n * np / 2;
     nptm = *npt - np;
-    nftest = AFmax(*maxfun,1);
+    nftest = max(*maxfun,1);
 
 /*     Set the initial elements of XPT, BMAT, HQ, PQ and ZMAT to zero. */
 
@@ -304,7 +288,7 @@ ast*/
 ber*/
 /*    of function values so far. The coordinates of the displacement of th
 e*/
-/*     next initial interpolation point from XBASE are set in XPT(NF,.).
+/*     next initial interpolation point from XBASE are set in XPT(NF,.). 
 */
 
     rhosq = *rhobeg * *rhobeg;
@@ -343,7 +327,7 @@ L50:
 	xpt[nf + jpt * xpt_dim1] = xjpt;
     }
 
-/*     Calculate the next value of F, label 70 being reached immediately
+/*     Calculate the next value of F, label 70 being reached immediately 
 */
 /*    after this calculation. The least function value so far and its inde
 x*/
@@ -360,11 +344,9 @@ L70:
     if (nf == 1) {
 	fbeg = f;
 	fopt = f;
-if(DEBUG) fprintf(stderr,"\nInitialize fopt=%.14g ;\n",fopt) ;
 	kopt = 1;
     } else if (f < fopt) {
 	fopt = f;
-if(DEBUG) fprintf(stderr,"  fopt=%.14g\n",fopt) ;
 	kopt = nf;
     }
 
@@ -419,7 +401,6 @@ s and*/
 
     rho = *rhobeg;
     delta = rho;
-if(DEBUG) fprintf(stderr,"  rho=delta=%.14g\n",delta) ;
     idz = 1;
     diffa = zero;
     diffb = zero;
@@ -436,7 +417,7 @@ if(DEBUG) fprintf(stderr,"  rho=delta=%.14g\n",delta) ;
 L90:
     nfsav = nf;
 
-/*     Generate the next trust region step and test its length. Set KNEW
+/*     Generate the next trust region step and test its length. Set KNEW 
 */
 /*     to -1 if the purpose of the next F will be to improve the model. */
 
@@ -455,25 +436,21 @@ L100:
     }
 /* Computing MIN */
     d__1 = delta, d__2 = sqrt(dsq);
-if(0&&DEBUG) fprintf(stderr,"  sqrt(dsq=%.14g)=%.14g\n",dsq,d__2) ;
-    dnorm = AFmin(d__1,d__2);
+    dnorm = min(d__1,d__2);
     if (dnorm < half * rho) {
 	knew = -1;
 	delta = tenth * delta;
-if(DEBUG) fprintf(stderr,"  delta/10") ;
 	ratio = -1.;
 	if (delta <= rho * 1.5) {
-if(DEBUG) fprintf(stderr,"  delta=rho") ;
 	    delta = rho;
 	}
-if(DEBUG) fprintf(stderr,"  delta=%.14g\n",delta) ;
 	if (nf <= nfsav + 2) {
 	    goto L460;
 	}
 	temp = crvmin * .125 * rho * rho;
 /* Computing MAX */
-	d__1 = AFmax(diffa,diffb);
-	if (temp <= AFmax(d__1,diffc)) {
+	d__1 = max(diffa,diffb);
+	if (temp <= max(d__1,diffc)) {
 	    goto L460;
 	}
 	goto L490;
@@ -507,13 +484,13 @@ L120:
 		i__3 = i__;
 		for (j = 1; j <= i__3; ++j) {
 /* L140: */
-		    bmat[ip + j * bmat_dim1] = bmat[ip + j * bmat_dim1] +
+		    bmat[ip + j * bmat_dim1] = bmat[ip + j * bmat_dim1] + 
 			    vlag[i__] * w[j] + w[i__] * vlag[j];
 		}
 	    }
 	}
 
-/*     Then the revisions of BMAT that depend on ZMAT are calculated.
+/*     Then the revisions of BMAT that depend on ZMAT are calculated. 
 */
 
 	i__3 = nptm;
@@ -540,7 +517,7 @@ L120:
 		i__1 = *npt;
 		for (i__ = 1; i__ <= i__1; ++i__) {
 /* L170: */
-		    bmat[i__ + j * bmat_dim1] += sum * zmat[i__ + k *
+		    bmat[i__ + j * bmat_dim1] += sum * zmat[i__ + k * 
 			    zmat_dim1];
 		}
 	    }
@@ -582,7 +559,7 @@ ng */
 		gq[i__] += hq[ih] * xopt[j];
 		hq[ih] = hq[ih] + w[i__] * xopt[j] + xopt[i__] * w[j];
 /* L200: */
-		bmat[*npt + i__ + j * bmat_dim1] = bmat[*npt + j + i__ *
+		bmat[*npt + i__ + j * bmat_dim1] = bmat[*npt + j + i__ * 
 			bmat_dim1];
 	    }
 	}
@@ -596,7 +573,7 @@ ng */
     }
 
 /*     Pick the model step if KNEW is positive. A different choice of D */
-/*     may be made later, if the choice of D by BIGLAG causes substantial
+/*     may be made later, if the choice of D by BIGLAG causes substantial 
 */
 /*     cancellation in DENOM. */
 
@@ -606,7 +583,7 @@ ng */
 		vlag[1], &vlag[*npt + 1], &w[1], &w[np], &w[np + *n]);
     }
 
-/*     Calculate VLAG and BETA for the current choice of D. The first NPT
+/*     Calculate VLAG and BETA for the current choice of D. The first NPT 
 */
 /*     components of W_check will be held in W. */
 
@@ -685,7 +662,7 @@ r*/
 	if (abs(temp) <= .8) {
 	    bigden_(n, npt, &xopt[1], &xpt[xpt_offset], &bmat[bmat_offset], &
 		    zmat[zmat_offset], &idz, ndim, &kopt, &knew, &d__[1], &w[
-		    1], &vlag[1], &beta, &xnew[1], &w[*ndim + 1], &w[*ndim *
+		    1], &vlag[1], &beta, &xnew[1], &w[*ndim + 1], &w[*ndim * 
 		    6 + 1]);
 	}
     }
@@ -764,7 +741,6 @@ e*/
     fsave = fopt;
     if (f < fopt) {
 	fopt = f;
-if(DEBUG) fprintf(stderr,"  fopt=%.14g\n",fopt) ;
 	xoptsq = zero;
 	i__1 = *n;
 	for (i__ = 1; i__ <= i__1; ++i__) {
@@ -791,24 +767,19 @@ if(DEBUG) fprintf(stderr,"  fopt=%.14g\n",fopt) ;
     }
     ratio = (f - fsave) / vquad;
     if (ratio <= tenth) {
-if(DEBUG) fprintf(stderr,"  delta=dnorm/2") ;
 	delta = half * dnorm;
     } else if (ratio <= .7) {
 /* Computing MAX */
-if(DEBUG) fprintf(stderr,"  delta=max(delta/2,dnorm)") ;
 	d__1 = half * delta;
-	delta = AFmax(d__1,dnorm);
+	delta = max(d__1,dnorm);
     } else {
 /* Computing MAX */
 	d__1 = half * delta, d__2 = dnorm + dnorm;
-	delta = AFmax(d__1,d__2);
-if(DEBUG) fprintf(stderr,"  delta=max(delta/2,dnorm*2)") ;
+	delta = max(d__1,d__2);
     }
     if (delta <= rho * 1.5) {
-if(DEBUG) fprintf(stderr,"  delta=RHO") ;
 	delta = rho;
     }
-if(DEBUG) fprintf(stderr,"  delta=%.14g\n",delta) ;
 
 /*    Set KNEW to the index of the next interpolation point to be deleted.
 */
@@ -816,7 +787,7 @@ if(DEBUG) fprintf(stderr,"  delta=%.14g\n",delta) ;
 /* Computing MAX */
     d__2 = tenth * delta;
 /* Computing 2nd power */
-    d__1 = AFmax(d__2,rho);
+    d__1 = max(d__2,rho);
     rhosq = d__1 * d__1;
     ktemp = 0;
     detrat = zero;
@@ -864,9 +835,9 @@ if(DEBUG) fprintf(stderr,"  delta=%.14g\n",delta) ;
 	goto L460;
     }
 
-/*     Update BMAT, ZMAT and IDZ, so that the KNEW-th interpolation point
+/*     Update BMAT, ZMAT and IDZ, so that the KNEW-th interpolation point 
 */
-/*     can be moved. Begin the updating of the quadratic model, starting
+/*     can be moved. Begin the updating of the quadratic model, starting 
 */
 /*     with the explicit second derivative term. */
 
@@ -914,9 +885,9 @@ L410:
 	xpt[knew + i__ * xpt_dim1] = xnew[i__];
     }
 
-/*    If a trust region step makes a small change to the objective function
+/*    If a trust region step makes a small change to the objective functio
 n,*/
-/*    then calculate the gradient of the least Frobenius norm interpolant
+/*    then calculate the gradient of the least Frobenius norm interpolant 
 at*/
 /*    XBASE, and store it in W, using VLAG for a vector of right hand side
 s.*/
@@ -1031,7 +1002,7 @@ L460:
 /* L480: */
     }
 
-/*     If KNEW is positive, then set DSTEP, and branch back for the next
+/*     If KNEW is positive, then set DSTEP, and branch back for the next 
 */
 /*     iteration, which will generate a "model step". */
 
@@ -1039,16 +1010,15 @@ L460:
 /* Computing MAX */
 /* Computing MIN */
 	d__2 = tenth * sqrt(distsq), d__3 = half * delta;
-if(0&&DEBUG) fprintf(stderr,"  sqrt(distsq=%.14g)=%.14g\n",distsq,d__2*10.0) ;
-	d__1 = AFmin(d__2,d__3);
-	dstep = AFmax(d__1,rho);
+	d__1 = min(d__2,d__3);
+	dstep = max(d__1,rho);
 	dsq = dstep * dstep;
 	goto L120;
     }
     if (ratio > zero) {
 	goto L100;
     }
-    if (AFmax(delta,dnorm) > rho) {
+    if (max(delta,dnorm) > rho) {
 	goto L100;
     }
 
@@ -1062,16 +1032,12 @@ L490:
 	ratio = rho / *rhoend;
 	if (ratio <= 16.) {
 	    rho = *rhoend;
-if(DEBUG) fprintf(stderr,"  ratio<16") ;
 	} else if (ratio <= 250.) {
-if(DEBUG) fprintf(stderr,"  ratio<250") ;
 	    rho = sqrt(ratio) * *rhoend;
 	} else {
-if(DEBUG) fprintf(stderr,"  ratio=other") ;
 	    rho = tenth * rho;
 	}
-	delta = AFmax(delta,rho);
-if(DEBUG) fprintf(stderr,"  rho=%.14g delta=%.14g\n",rho,delta) ;
+	delta = max(delta,rho);
 /* CC          IF (IPRINT .GE. 2) THEN */
 /* CC              IF (IPRINT .GE. 3) PRINT 500 */
 /* CC  500         FORMAT (5X) */
@@ -1085,7 +1051,7 @@ if(DEBUG) fprintf(stderr,"  rho=%.14g delta=%.14g\n",rho,delta) ;
 	goto L90;
     }
 
-/*     Return from the calculation, after another Newton-Raphson step, if
+/*     Return from the calculation, after another Newton-Raphson step, if 
 */
 /*     it is too short to have been tried before. */
 
@@ -1100,7 +1066,6 @@ L530:
 	    x[i__] = xbase[i__] + xopt[i__];
 	}
 	f = fopt;
-if(DEBUG) fprintf(stderr," ; final set f=%.14g\n",f) ;
     }
 /* CC      IF (IPRINT .GE. 1) THEN */
 /* CC          PRINT 550, NF */
@@ -1111,40 +1076,39 @@ if(DEBUG) fprintf(stderr," ; final set f=%.14g\n",f) ;
     if (*icode == 0) {
 	*icode = nf;
     }
-if(DEBUG) fprintf(stderr," ; return f=%.14g with rho=%.14g\n",f,rho) ;
     return 0;
 } /* newuob_ */
 
-/* Subroutine */ int trsapp_(integer *n, integer *npt, doublereal *xopt,
-	doublereal *xpt, doublereal *gq, doublereal *hq, doublereal *pq,
-	doublereal *delta, doublereal *step, doublereal *d__, doublereal *g,
+/* Subroutine */ int trsapp_(integer *n, integer *npt, doublereal *xopt, 
+	doublereal *xpt, doublereal *gq, doublereal *hq, doublereal *pq, 
+	doublereal *delta, doublereal *step, doublereal *d__, doublereal *g, 
 	doublereal *hd, doublereal *hs, doublereal *crvmin)
 {
     /* System generated locals */
-    integer xpt_dim1=0, xpt_offset=0, i__1=0, i__2=0;
-    doublereal d__1=0, d__2=0;
+    integer xpt_dim1, xpt_offset, i__1, i__2;
+    doublereal d__1, d__2;
 
     /* Builtin functions */
     double atan(doublereal), sqrt(doublereal), cos(doublereal), sin(
 	    doublereal);
 
     /* Local variables */
-    STATIC doublereal qadd=0, half=0, qbeg=0, qred=0, qmin=0, temp=0, qsav=0, qnew=0, zero=0;
-    STATIC integer i__=0, j=0;
-    STATIC doublereal ggbeg=0;
-    STATIC integer k=0;
-    STATIC doublereal alpha=0, angle=0, reduc=0;
-    STATIC integer iterc=0;
-    STATIC doublereal ggsav=0, delsq=0, tempa=0, tempb=0;
-    STATIC integer isave=0;
-    STATIC doublereal bstep=0, ratio=0, twopi=0, dd=0, cf=0, dg=0, gg=0;
-    STATIC integer ih=0;
-    STATIC doublereal ds=0, sg=0;
-    STATIC integer iu=0;
-    STATIC doublereal ss=0;
-    STATIC integer itersw=0;
-    STATIC doublereal dhd=0, dhs=0, cth=0, sgk=0, shs=0, sth=0, angtest=0;
-    STATIC integer itermax=0;
+    static doublereal qadd, half, qbeg, qred, qmin, temp, qsav, qnew, zero;
+    static integer i__, j;
+    static doublereal ggbeg;
+    static integer k;
+    static doublereal alpha, angle, reduc;
+    static integer iterc;
+    static doublereal ggsav, delsq, tempa, tempb;
+    static integer isave;
+    static doublereal bstep, ratio, twopi, dd, cf, dg, gg;
+    static integer ih;
+    static doublereal ds, sg;
+    static integer iu;
+    static doublereal ss;
+    static integer itersw;
+    static doublereal dhd, dhs, cth, sgk, shs, sth, angtest;
+    static integer itermax;
 
 
 /*    N is the number of variables of a quadratic objective function, Q sa
@@ -1155,7 +1119,7 @@ s,*/
 /*     DELTA is the trust region radius, and has to be positive. */
 /*     STEP will be set to the calculated trial step. */
 /*     The arrays D, G, HD and HS will be used for working space. */
-/*     CRVMIN will be set to the least curvature of H along the conjugate
+/*     CRVMIN will be set to the least curvature of H along the conjugate 
 */
 /*       directions that occur, except that it is set to zero if STEP goes
  */
@@ -1167,7 +1131,7 @@ s,*/
 */
 /*     changes to STEP may be made, each one being in the 2D space spanned
  */
-/*     by the current STEP and the corresponding gradient of Q. Thus STEP
+/*     by the current STEP and the corresponding gradient of Q. Thus STEP 
 */
 /*    should provide a substantial reduction to Q within the trust region.
 */
@@ -1252,10 +1216,10 @@ L50:
 	if (iterc == 1) {
 	    *crvmin = temp;
 	}
-	*crvmin = AFmin(*crvmin,temp);
+	*crvmin = min(*crvmin,temp);
 /* Computing MIN */
 	d__1 = alpha, d__2 = gg / dhd;
-	alpha = AFmin(d__1,d__2);
+	alpha = min(d__1,d__2);
     }
     qadd = alpha * (gg - half * alpha * dhd);
     qred += qadd;
@@ -1470,32 +1434,32 @@ L170:
     goto L120;
 } /* trsapp_ */
 
-/* Subroutine */ int update_(integer *n, integer *npt, doublereal *bmat,
-	doublereal *zmat, integer *idz, integer *ndim, doublereal *vlag,
+/* Subroutine */ int update_(integer *n, integer *npt, doublereal *bmat, 
+	doublereal *zmat, integer *idz, integer *ndim, doublereal *vlag, 
 	doublereal *beta, integer *knew, doublereal *w)
 {
     /* System generated locals */
-    integer bmat_dim1=0, bmat_offset=0, zmat_dim1=0, zmat_offset=0, i__1=0, i__2=0;
-    doublereal d__1=0, d__2=0;
+    integer bmat_dim1, bmat_offset, zmat_dim1, zmat_offset, i__1, i__2;
+    doublereal d__1, d__2;
 
     /* Builtin functions */
     double sqrt(doublereal);
 
     /* Local variables */
-    STATIC doublereal temp=0;
-    STATIC integer nptm=0;
-    STATIC doublereal zero=0;
-    STATIC integer i__=0, j=0, iflag=0;
-    STATIC doublereal scala=0, scalb=0, alpha=0, denom=0, tempa=0, tempb=0, tausq=0;
-    STATIC integer ja=0, jb=0, jl=0, jp=0;
-    STATIC doublereal one=0, tau=0;
+    static doublereal temp;
+    static integer nptm;
+    static doublereal zero;
+    static integer i__, j, iflag;
+    static doublereal scala, scalb, alpha, denom, tempa, tempb, tausq;
+    static integer ja, jb, jl, jp;
+    static doublereal one, tau;
 
 
 /*    The arrays BMAT and ZMAT with IDZ are updated, in order to shift the
 */
 /*    interpolation point that has index KNEW. On entry, VLAG contains the
 */
-/*     components of the vector Theta*Wcheck+e_b of the updating formula
+/*     components of the vector Theta*Wcheck+e_b of the updating formula 
 */
 /*    (6.11), and BETA holds the value of the parameter that has this name
 .*/
@@ -1535,9 +1499,9 @@ L170:
 	    tempb = zmat[*knew + j * zmat_dim1] / temp;
 	    i__2 = *npt;
 	    for (i__ = 1; i__ <= i__2; ++i__) {
-		temp = tempa * zmat[i__ + jl * zmat_dim1] + tempb * zmat[i__
+		temp = tempa * zmat[i__ + jl * zmat_dim1] + tempb * zmat[i__ 
 			+ j * zmat_dim1];
-		zmat[i__ + j * zmat_dim1] = tempa * zmat[i__ + j * zmat_dim1]
+		zmat[i__ + j * zmat_dim1] = tempa * zmat[i__ + j * zmat_dim1] 
 			- tempb * zmat[i__ + jl * zmat_dim1];
 /* L10: */
 		zmat[i__ + jl * zmat_dim1] = temp;
@@ -1547,7 +1511,7 @@ L170:
 /* L20: */
     }
 
-/*     Put the first NPT components of the KNEW-th column of HLAG into W,
+/*     Put the first NPT components of the KNEW-th column of HLAG into W, 
 */
 /*     and calculate the parameters of the updating formula. */
 
@@ -1587,7 +1551,7 @@ er.*/
 	i__1 = *npt;
 	for (i__ = 1; i__ <= i__1; ++i__) {
 /* L40: */
-	    zmat[i__ + zmat_dim1] = tempa * zmat[i__ + zmat_dim1] - tempb *
+	    zmat[i__ + zmat_dim1] = tempa * zmat[i__ + zmat_dim1] - tempb * 
 		    vlag[i__];
 	}
 	if (*idz == 1 && temp < zero) {
@@ -1613,10 +1577,10 @@ er.*/
 	scalb = scala * sqrt((abs(denom)));
 	i__1 = *npt;
 	for (i__ = 1; i__ <= i__1; ++i__) {
-	    zmat[i__ + ja * zmat_dim1] = scala * (tau * zmat[i__ + ja *
+	    zmat[i__ + ja * zmat_dim1] = scala * (tau * zmat[i__ + ja * 
 		    zmat_dim1] - temp * vlag[i__]);
 /* L50: */
-	    zmat[i__ + jb * zmat_dim1] = scalb * (zmat[i__ + jb * zmat_dim1]
+	    zmat[i__ + jb * zmat_dim1] = scalb * (zmat[i__ + jb * zmat_dim1] 
 		    - tempa * w[i__] - tempb * vlag[i__]);
 	}
 	if (denom <= zero) {
@@ -1629,7 +1593,7 @@ er.*/
 	}
     }
 
-/*     IDZ is reduced in the following case, and usually the first column
+/*     IDZ is reduced in the following case, and usually the first column 
 */
 /*     of ZMAT is exchanged with a later one. */
 
@@ -1654,10 +1618,10 @@ er.*/
 	tempb = (-(*beta) * w[jp] - tau * vlag[jp]) / denom;
 	i__2 = jp;
 	for (i__ = 1; i__ <= i__2; ++i__) {
-	    bmat[i__ + j * bmat_dim1] = bmat[i__ + j * bmat_dim1] + tempa *
+	    bmat[i__ + j * bmat_dim1] = bmat[i__ + j * bmat_dim1] + tempa * 
 		    vlag[i__] + tempb * w[i__];
 	    if (i__ > *npt) {
-		bmat[jp + (i__ - *npt) * bmat_dim1] = bmat[i__ + j *
+		bmat[jp + (i__ - *npt) * bmat_dim1] = bmat[i__ + j * 
 			bmat_dim1];
 	    }
 /* L70: */
@@ -1666,49 +1630,48 @@ er.*/
     return 0;
 } /* update_ */
 
-/* Subroutine */ int bigden_(integer *n, integer *npt, doublereal *xopt,
-	doublereal *xpt, doublereal *bmat, doublereal *zmat, integer *idz,
-	integer *ndim, integer *kopt, integer *knew, doublereal *d__,
-	doublereal *w, doublereal *vlag, doublereal *beta, doublereal *s,
+/* Subroutine */ int bigden_(integer *n, integer *npt, doublereal *xopt, 
+	doublereal *xpt, doublereal *bmat, doublereal *zmat, integer *idz, 
+	integer *ndim, integer *kopt, integer *knew, doublereal *d__, 
+	doublereal *w, doublereal *vlag, doublereal *beta, doublereal *s, 
 	doublereal *wvec, doublereal *prod)
 {
     /* System generated locals */
-    integer xpt_dim1=0, xpt_offset=0, bmat_dim1=0, bmat_offset=0, zmat_dim1=0,
-	    zmat_offset=0, wvec_dim1=0, wvec_offset=0, prod_dim1=0, prod_offset=0, i__1=0,
-	     i__2=0;
-    doublereal d__1=0;
+    integer xpt_dim1, xpt_offset, bmat_dim1, bmat_offset, zmat_dim1, 
+	    zmat_offset, wvec_dim1, wvec_offset, prod_dim1, prod_offset, i__1,
+	     i__2;
+    doublereal d__1;
 
     /* Builtin functions */
     double atan(doublereal), sqrt(doublereal), cos(doublereal), sin(
 	    doublereal);
 
     /* Local variables */
-    STATIC doublereal diff=0, half=0, temp=0;
-    STATIC integer ksav=0;
-    STATIC doublereal step=0;
-    STATIC integer nptm=0;
-    STATIC doublereal zero=0;
-    STATIC integer i__=0, j=0, k=0;
-    STATIC doublereal alpha=0, angle=0, denex[9]={0,0,0,0,0,0,0,0,0};
-    STATIC integer iterc=0;
-    STATIC doublereal tempa=0, tempb=0, tempc=0;
-    STATIC integer isave=0;
-    STATIC doublereal ssden=0, dtest=0, quart=0, xoptd=0, twopi=0, xopts=0, dd=0;
-    STATIC integer jc=0;
-    STATIC doublereal ds=0;
-    STATIC integer ip=0, iu=0, nw=0;
-    STATIC doublereal ss=0, denold=0, denmax=0, densav=0, dstemp=0, sumold=0, sstemp=0,
-	    xoptsq=0, den[9]={0,0,0,0,0,0,0,0,0}, one=0,
-       par[9]={0,0,0,0,0,0,0,0,0}, tau=0, sum=0, two=0;
+    static doublereal diff, half, temp;
+    static integer ksav;
+    static doublereal step;
+    static integer nptm;
+    static doublereal zero;
+    static integer i__, j, k;
+    static doublereal alpha, angle, denex[9];
+    static integer iterc;
+    static doublereal tempa, tempb, tempc;
+    static integer isave;
+    static doublereal ssden, dtest, quart, xoptd, twopi, xopts, dd;
+    static integer jc;
+    static doublereal ds;
+    static integer ip, iu, nw;
+    static doublereal ss, denold, denmax, densav, dstemp, sumold, sstemp, 
+	    xoptsq, den[9], one, par[9], tau, sum, two;
 
 
 /*     N is the number of variables. */
 /*     NPT is the number of interpolation equations. */
 /*     XOPT is the best interpolation point so far. */
-/*     XPT contains the coordinates of the current interpolation points.
+/*     XPT contains the coordinates of the current interpolation points. 
 */
 /*     BMAT provides the last N columns of H. */
-/*    ZMAT and IDZ give a factorization of the first NPT by NPT submatrix
+/*    ZMAT and IDZ give a factorization of the first NPT by NPT submatrix 
 of H.*/
 /*     NDIM is the first dimension of BMAT and has the value NPT+N. */
 /*     KOPT is the index of the optimal interpolation point. */
@@ -1766,14 +1729,10 @@ rge*/
     quart = .25;
     two = 2.;
     zero = 0.;
-#if 0
     twopi = atan(one) * 8.;
-#else
-    twopi = 3.14159265358979323846 * 2.0 ;
-#endif
     nptm = *npt - *n - 1;
 
-/*     Store the first NPT elements of the KNEW-th column of H in W(N+1)
+/*     Store the first NPT elements of the KNEW-th column of H in W(N+1) 
 */
 /*     to W(N+NPT). */
 
@@ -1800,9 +1759,9 @@ rge*/
 ,*/
 /*     and the initial S is set below, usually to the direction from X_OPT
  */
-/*     to X_KNEW, but a different direction to an interpolation point may
+/*     to X_KNEW, but a different direction to an interpolation point may 
 */
-/*     be chosen, in order to prevent S from being nearly parallel to D.
+/*     be chosen, in order to prevent S from being nearly parallel to D. 
 */
 
     dd = zero;
@@ -1920,7 +1879,7 @@ L70:
 	wvec[ip + wvec_dim1 * 5] = zero;
     }
 
-/*     Put the coefficients of THETA*Wcheck in PROD. */
+/*     Put the coefficents of THETA*Wcheck in PROD. */
 
     for (jc = 1; jc <= 5; ++jc) {
 	nw = *npt;
@@ -1956,7 +1915,7 @@ L70:
 		i__2 = *n;
 		for (j = 1; j <= i__2; ++j) {
 /* L160: */
-		    sum += bmat[k + j * bmat_dim1] * wvec[*npt + j + jc *
+		    sum += bmat[k + j * bmat_dim1] * wvec[*npt + j + jc * 
 			    wvec_dim1];
 		}
 /* L170: */
@@ -1982,7 +1941,7 @@ L70:
     for (k = 1; k <= i__1; ++k) {
 	sum = zero;
 	for (i__ = 1; i__ <= 5; ++i__) {
-	    par[i__ - 1] = half * prod[k + i__ * prod_dim1] * wvec[k + i__ *
+	    par[i__ - 1] = half * prod[k + i__ * prod_dim1] * wvec[k + i__ * 
 		    wvec_dim1];
 /* L200: */
 	    sum += par[i__ - 1];
@@ -1990,30 +1949,30 @@ L70:
 	den[0] = den[0] - par[0] - sum;
 	tempa = prod[k + prod_dim1] * wvec[k + (wvec_dim1 << 1)] + prod[k + (
 		prod_dim1 << 1)] * wvec[k + wvec_dim1];
-	tempb = prod[k + (prod_dim1 << 1)] * wvec[k + (wvec_dim1 << 2)] +
+	tempb = prod[k + (prod_dim1 << 1)] * wvec[k + (wvec_dim1 << 2)] + 
 		prod[k + (prod_dim1 << 2)] * wvec[k + (wvec_dim1 << 1)];
-	tempc = prod[k + prod_dim1 * 3] * wvec[k + wvec_dim1 * 5] + prod[k +
+	tempc = prod[k + prod_dim1 * 3] * wvec[k + wvec_dim1 * 5] + prod[k + 
 		prod_dim1 * 5] * wvec[k + wvec_dim1 * 3];
 	den[1] = den[1] - tempa - half * (tempb + tempc);
 	den[5] -= half * (tempb - tempc);
-	tempa = prod[k + prod_dim1] * wvec[k + wvec_dim1 * 3] + prod[k +
+	tempa = prod[k + prod_dim1] * wvec[k + wvec_dim1 * 3] + prod[k + 
 		prod_dim1 * 3] * wvec[k + wvec_dim1];
-	tempb = prod[k + (prod_dim1 << 1)] * wvec[k + wvec_dim1 * 5] + prod[k
+	tempb = prod[k + (prod_dim1 << 1)] * wvec[k + wvec_dim1 * 5] + prod[k 
 		+ prod_dim1 * 5] * wvec[k + (wvec_dim1 << 1)];
-	tempc = prod[k + prod_dim1 * 3] * wvec[k + (wvec_dim1 << 2)] + prod[k
+	tempc = prod[k + prod_dim1 * 3] * wvec[k + (wvec_dim1 << 2)] + prod[k 
 		+ (prod_dim1 << 2)] * wvec[k + wvec_dim1 * 3];
 	den[2] = den[2] - tempa - half * (tempb - tempc);
 	den[6] -= half * (tempb + tempc);
 	tempa = prod[k + prod_dim1] * wvec[k + (wvec_dim1 << 2)] + prod[k + (
 		prod_dim1 << 2)] * wvec[k + wvec_dim1];
 	den[3] = den[3] - tempa - par[1] + par[2];
-	tempa = prod[k + prod_dim1] * wvec[k + wvec_dim1 * 5] + prod[k +
+	tempa = prod[k + prod_dim1] * wvec[k + wvec_dim1 * 5] + prod[k + 
 		prod_dim1 * 5] * wvec[k + wvec_dim1];
-	tempb = prod[k + (prod_dim1 << 1)] * wvec[k + wvec_dim1 * 3] + prod[k
+	tempb = prod[k + (prod_dim1 << 1)] * wvec[k + wvec_dim1 * 3] + prod[k 
 		+ prod_dim1 * 3] * wvec[k + (wvec_dim1 << 1)];
 	den[4] = den[4] - tempa - half * tempb;
 	den[7] = den[7] - par[3] + par[4];
-	tempa = prod[k + (prod_dim1 << 2)] * wvec[k + wvec_dim1 * 5] + prod[k
+	tempa = prod[k + (prod_dim1 << 2)] * wvec[k + wvec_dim1 * 5] + prod[k 
 		+ prod_dim1 * 5] * wvec[k + (wvec_dim1 << 2)];
 /* L210: */
 	den[8] -= half * tempa;
@@ -2046,7 +2005,7 @@ L70:
     denex[4] = alpha * den[4] + tempa + prod[*knew + (prod_dim1 << 1)] * prod[
 	    *knew + prod_dim1 * 3];
     denex[7] = alpha * den[7] + par[3] - par[4];
-    denex[8] = alpha * den[8] + prod[*knew + (prod_dim1 << 2)] * prod[*knew +
+    denex[8] = alpha * den[8] + prod[*knew + (prod_dim1 << 2)] * prod[*knew + 
 	    prod_dim1 * 5];
 
 /*     Seek the value of the angle that maximizes the modulus of DENOM. */
@@ -2063,7 +2022,6 @@ L70:
 	angle = (doublereal) i__ * temp;
 	par[1] = cos(angle);
 	par[2] = sin(angle);
-if(0&&DEBUG) fprintf(stderr,"  cos(angle=%.14g)=%.14g sin()=%.14g\n",angle,par[1],par[2]) ;
 	for (j = 4; j <= 8; j += 2) {
 	    par[j - 1] = par[1] * par[j - 3] - par[2] * par[j - 2];
 /* L230: */
@@ -2104,7 +2062,6 @@ if(0&&DEBUG) fprintf(stderr,"  cos(angle=%.14g)=%.14g sin()=%.14g\n",angle,par[1
 
     par[1] = cos(angle);
     par[2] = sin(angle);
-if(0&&DEBUG) fprintf(stderr,"  cos(angle=%.14g)=%.14g sin()=%.14g\n",angle,par[1],par[2]) ;
     for (j = 4; j <= 8; j += 2) {
 	par[j - 1] = par[1] * par[j - 3] - par[2] * par[j - 2];
 /* L260: */
@@ -2144,7 +2101,7 @@ if(0&&DEBUG) fprintf(stderr,"  cos(angle=%.14g)=%.14g sin()=%.14g\n",angle,par[1
 	goto L340;
     }
     if (iterc > 1) {
-	densav = AFmax(densav,denold);
+	densav = max(densav,denold);
     }
     if (abs(denmax) <= abs(densav) * 1.1) {
 	goto L340;
@@ -2205,48 +2162,48 @@ L340:
     return 0;
 } /* bigden_ */
 
-/* Subroutine */ int biglag_(integer *n, integer *npt, doublereal *xopt,
-	doublereal *xpt, doublereal *bmat, doublereal *zmat, integer *idz,
-	integer *ndim, integer *knew, doublereal *delta, doublereal *d__,
-	doublereal *alpha, doublereal *hcol, doublereal *gc, doublereal *gd,
+/* Subroutine */ int biglag_(integer *n, integer *npt, doublereal *xopt, 
+	doublereal *xpt, doublereal *bmat, doublereal *zmat, integer *idz, 
+	integer *ndim, integer *knew, doublereal *delta, doublereal *d__, 
+	doublereal *alpha, doublereal *hcol, doublereal *gc, doublereal *gd, 
 	doublereal *s, doublereal *w)
 {
     /* System generated locals */
-    integer xpt_dim1=0, xpt_offset=0, bmat_dim1=0, bmat_offset=0, zmat_dim1=0,
-	    zmat_offset=0, i__1=0, i__2=0;
-    doublereal d__1=0;
+    integer xpt_dim1, xpt_offset, bmat_dim1, bmat_offset, zmat_dim1, 
+	    zmat_offset, i__1, i__2;
+    doublereal d__1;
 
     /* Builtin functions */
     double atan(doublereal), sqrt(doublereal), cos(doublereal), sin(
 	    doublereal);
 
     /* Local variables */
-    STATIC doublereal half=0, temp=0, step=0;
-    STATIC integer nptm=0;
-    STATIC doublereal zero=0;
-    STATIC integer i__=0, j=0, k=0;
-    STATIC doublereal angle=0, scale=0, denom=0;
-    STATIC integer iterc=0, isave=0;
-    STATIC doublereal delsq=0, tempa=0, tempb=0, twopi=0, dd=0, gg=0;
-    STATIC integer iu=0;
-    STATIC doublereal sp=0, ss=0, taubeg=0, tauold=0, cf1=0, cf2=0, cf3=0, cf4=0, cf5=0, taumax=0,
-	     dhd=0, cth=0, one=0, tau=0, sth=0, sum=0;
+    static doublereal half, temp, step;
+    static integer nptm;
+    static doublereal zero;
+    static integer i__, j, k;
+    static doublereal angle, scale, denom;
+    static integer iterc, isave;
+    static doublereal delsq, tempa, tempb, twopi, dd, gg;
+    static integer iu;
+    static doublereal sp, ss, taubeg, tauold, cf1, cf2, cf3, cf4, cf5, taumax,
+	     dhd, cth, one, tau, sth, sum;
 
 
 /*     N is the number of variables. */
 /*     NPT is the number of interpolation equations. */
 /*     XOPT is the best interpolation point so far. */
-/*     XPT contains the coordinates of the current interpolation points.
+/*     XPT contains the coordinates of the current interpolation points. 
 */
 /*     BMAT provides the last N columns of H. */
-/*    ZMAT and IDZ give a factorization of the first NPT by NPT submatrix
+/*    ZMAT and IDZ give a factorization of the first NPT by NPT submatrix 
 of H.*/
 /*     NDIM is the first dimension of BMAT and has the value NPT+N. */
 /*    KNEW is the index of the interpolation point that is going to be mov
 ed.*/
 /*     DELTA is the current trust region bound. */
 /*     D will be set to the step from XOPT to the new point. */
-/*     ALPHA will be set to the KNEW-th diagonal element of the H matrix.
+/*     ALPHA will be set to the KNEW-th diagonal element of the H matrix. 
 */
 /*     HCOL, GC, GD, S and W will be used for working space. */
 
@@ -2460,7 +2417,6 @@ ix.*/
 	angle = (doublereal) i__ * temp;
 	cth = cos(angle);
 	sth = sin(angle);
-if(0&&DEBUG) fprintf(stderr,"  cos(angle=%.14g)=%.14g sin()=%.14g\n",angle,cth,sth) ;
 	tau = cf1 + (cf2 + cf4 * cth) * cth + (cf3 + cf5 * cth) * sth;
 	if (abs(tau) > abs(taumax)) {
 	    taumax = tau;
@@ -2490,7 +2446,6 @@ if(0&&DEBUG) fprintf(stderr,"  cos(angle=%.14g)=%.14g sin()=%.14g\n",angle,cth,s
 
     cth = cos(angle);
     sth = sin(angle);
-if(0&&DEBUG) fprintf(stderr,"  cos(angle=%.14g)=%.14g sin()=%.14g\n",angle,cth,sth) ;
     tau = cf1 + (cf2 + cf4 * cth) * cth + (cf3 + cf5 * cth) * sth;
     i__2 = *n;
     for (i__ = 1; i__ <= i__2; ++i__) {
@@ -2509,8 +2464,3 @@ L160:
     return 0;
 } /* biglag_ */
 
-
-/*---------------------------------------------------------------------------*/
-#undef  AFmax
-#undef  AFmin
-#endif /* __POWELL_NEWUOA__ */
