@@ -8,8 +8,8 @@
    see qh-geom.htm and geom.h
 
    copyright (c) 1993-2010 The Geometry Center.
-   $Id$$Change: 1164 $
-   $DateTime: 2010/01/07 21:52:00 $$Author$
+   $Id: geom2.c,v 1.2 2010/10/01 13:22:54 rwcox Exp $$Change: 1164 $
+   $DateTime: 2010/01/07 21:52:00 $$Author: rwcox $
 
    frequently used code goes into geom.c
 */
@@ -1978,7 +1978,7 @@ boolT qh_sharpnewfacets() {
 
   qh_voronoi_center( dim, points )
     return Voronoi center for a set of points
-    dim is the original dimension of the points
+    dim is the orginal dimension of the points
     gh.gm_matrix/qh.gm_row are scratch buffers
 
   returns:
