@@ -12,8 +12,8 @@
    see qhull_a.h for internal functions
 
    copyright (c) 1993-2010 The Geometry Center.
-   $Id$$Change: 1183 $
-   $DateTime: 2010/01/13 20:59:32 $$Author$
+   $Id: global.c,v 1.3 2010/10/01 13:22:54 rwcox Exp $$Change: 1183 $
+   $DateTime: 2010/01/13 20:59:32 $$Author: rwcox $
  */
 
 #include "qhull_a.h"
@@ -597,12 +597,12 @@ void qh_init_qhull_command(int argc, char *argv[]) {
     for each space-deliminated option group
       if top-level option
         check syntax
-        append appropriate option to option string
+        append approriate option to option string
         set appropriate global variable or append printFormat to print options
       else
         for each sub-option
           check syntax
-          append appropriate option to option string
+          append approriate option to option string
           set appropriate global variable or append printFormat to print options
 */
 void qh_initflags(char *command) {
