@@ -3,11 +3,11 @@
 
    qhull.h
 
-   Proxy for libqhull.h for backwards compatibility
+   Proxy for libqhull.h for backwards compatability
 
    copyright (c) 1993-2010 The Geometry Center.
-   $Id$$Change: 1188 $
-   $DateTime: 2010/01/14 22:35:43 $$Author$
+   $Id: qhull.h,v 1.2 2010/10/01 13:22:54 rwcox Exp $$Change: 1188 $
+   $DateTime: 2010/01/14 22:35:43 $$Author: rwcox $
 */
 
 #ifndef qhDEFqhull
