@@ -12,7 +12,7 @@
  *    - change the dx, dy, dz spacing, to one that is specified
  *    - master a dataset, so that its orientation and spacing matches
  *
- * usage:  3dresample  [options]  -prefix OUTPUT_DSET  -input INPUT_DSET
+ * usage:  3dresample  [options]  -prefix OUTPUT_DSET  -inset INPUT_DSET
  *
  *    options:
  *              -help             : detailed program info
@@ -29,12 +29,10 @@
  *
  *              -rmode RESAM      : one of {"NN", "Li", "Cu", "Bk"}
  *
- *              -bound_type TYPE  : one of {"FOV", "SLAB"}
- *
  *    examples:
- *      3dresample -orient "asl" -rmode NN -prefix asl.dset -input inset+orig
- *      3dresample -dxyz 1.0 1.0 0.9 -prefix 119.dset -input some.input+tlrc
- *      3dresample -master master+orig -prefix new.copy -input old.copy+orig
+ *      3dresample -orient "asl" -rmode NN -prefix asl.dset -inset inset+orig
+ *      3dresample -dxyz 1.0 1.0 0.9 -prefix 119.dset -inset some.input+tlrc
+ *      3dresample -master master+orig -prefix new.copy -inset old.copy+orig
  *----------------------------------------------------------------------
 */
 
@@ -59,10 +57,9 @@ static char g_history[] =
  " 1.7a Mar 22, 2005 - removed tabs\n"
  " 1.8  Aug 02, 2005 - allow dxyz to override those from master\n"
  " 1.9  Apr 27, 2009 - small help update (also, show help if no args)\n"
- " 1.10 Jun 26, 2014 - added -bound_type FOV/SLAB\n"
  "----------------------------------------------------------------------\n";
 
-#define VERSION "Version 1.10 <June 26, 2014>"
+#define VERSION "Version 1.9 <April 27, 2009>"
 
 
 /*--- local stuff ------------------------------------------------------*/
@@ -87,7 +84,6 @@ typedef struct
     char             * orient;
     char             * prefix;
     int                resam;
-    int                bound_type;
     int                debug;
 } options_t;
 
@@ -109,15 +105,12 @@ int main( int argc , char * argv[] )
     mainENTRY("3dresample"); machdep(); AFNI_logger("3dresample",argc,argv);
 
     /* validate inputs and init options structure */
-    if ( (ret_val = init_options(&opts, argc, argv)) != 0 ) {
-        if( ret_val < 0 ) return 1;
-        else              return 0;
-    }
+    if ( (ret_val = init_options(&opts, argc, argv)) != 0 )
+        return ret_val;
 
     /* actually resample and/or reorient the dataset */
-    dout = r_new_resam_dset_eng(opts.dset, opts.mset, opts.dx,opts.dy,opts.dz,
-                                opts.orient, opts.resam, NULL, 1, 0,
-                                opts.bound_type);
+    dout = r_new_resam_dset( opts.dset, opts.mset, opts.dx, opts.dy, opts.dz,
+                             opts.orient, opts.resam, NULL, 1, 0);
     if ( dout == NULL )
     {
         fprintf( stderr, "failure to resample dataset, exiting...\n" );
@@ -142,39 +135,24 @@ int init_options ( options_t * opts, int argc, char * argv [] )
     opts->dset   = opts->mset   = NULL;  
 
     /* show help if there are no arguments */
-    if ( argc < 2 ) { usage( argv[0], USE_LONG ); return 1; }
+    if ( argc < 2 ) { usage( argv[0], USE_LONG ); return FAIL; }
 
     for ( ac = 1; ac < argc; ac++ )
     {
         if ( ! strncmp(argv[ac], "-help", 5) )
         {
             usage( argv[0], USE_LONG );
-            return 1;
+            return FAIL;
         }
         else if ( ! strncmp(argv[ac], "-hist", 5) )
         {
             usage( argv[0], USE_HISTORY );
-            return 1;
+            return FAIL;
         }
         else if ( ! strncmp(argv[ac], "-version", 2) )
         {
             usage( argv[0], USE_VERSION );
-            return 1;
-        }
-        else if ( ! strncmp(argv[ac], "-bound_type", 6) ) /* 26 Jun 2014 */
-        {
-            if ( (ac+1) >= argc )
-            {
-                fputs( "option usage: -bound_type FOV/SLAB\n", stderr );
-                usage( argv[0], USE_SHORT );
-                return FAIL;
-            }
-
-            if ( (opts->bound_type = resam_str2bound(argv[++ac])) < 0 )
-            {
-                fprintf( stderr, "invalid -bound_type <%s>\n", argv[ac] );
-                return FAIL;
-            }
+            return FAIL;
         }
         else if ( ! strncmp(argv[ac], "-debug", 6) )
         {
@@ -285,7 +263,7 @@ int init_options ( options_t * opts, int argc, char * argv [] )
         {
             if ( (ac+1) >= argc )
             {
-                fputs( "option usage: -input INPUT_DSET\n", stderr );
+                fputs( "option usage: -inset INPUT_DSET\n", stderr );
                 usage( argv[0], USE_SHORT );
                 return FAIL;
             }
@@ -463,7 +441,7 @@ int usage ( char * progg, int level )
     if ( level == USE_SHORT )
     {
         fprintf( stderr,
-                 "usage: %s [options] -prefix OUT_DSET -input IN_DSET\n"
+                 "usage: %s [options] -prefix OUT_DSET -inset IN_DSET\n"
                  "usage: %s -help\n",
                  prog, prog );
         return 0;
@@ -500,13 +478,13 @@ int usage ( char * progg, int level )
             "\n"
             "------------------------------------------------------------\n"
             "\n"
-            "  usage: %s [options] -prefix OUT_DSET -input IN_DSET\n"
+            "  usage: %s [options] -prefix OUT_DSET -inset IN_DSET\n"
             "\n"
             "  examples:\n"
             "\n"
-            "    %s -orient asl -rmode NN -prefix asl.dset -input in+orig\n"
-            "    %s -dxyz 1.0 1.0 0.9 -prefix 119.dset -input in+tlrc\n"
-            "    %s -master master+orig -prefix new.dset -input old+orig\n"
+            "    %s -orient asl -rmode NN -prefix asl.dset -inset in+orig\n"
+            "    %s -dxyz 1.0 1.0 0.9 -prefix 119.dset -inset in+tlrc\n"
+            "    %s -master master+orig -prefix new.dset -inset old+orig\n"
             "\n"
             "  note:\n"
             "\n"
@@ -527,24 +505,6 @@ int usage ( char * progg, int level )
             "\n"
             "    -version         : show version information\n"
             "\n"
-            "    -bound_type TYPE : specify which boundary is preserved\n"
-            "          e.g.  -bound_type SLAB\n"
-            "          default is FOV (field of view)\n"
-            "\n"
-            "          The default and original use preserves the field of\n"
-            "          of view when resampling, allowing the extents (SLABs)\n"
-            "          to grow or shrink by half of the difference in the\n"
-            "          dimension size (big voxels to small will cause the\n"
-            "          extents to expand, for example, while small to big\n"
-            "          will cause them to shrink).\n"
-            "\n"
-            "          Using -bound_type SLAB will have the opposite effect.\n"
-            "          The extents should be unchanged, while the FOV will\n"
-            "          grow or shrink in the opposite way as above).\n"
-            "\n"
-            "          Note that when using SLAB, edge voxels should be\n"
-            "          mostly unaffected by the interpolation.\n"
-            "\n"
             "    -dxyz DX DY DZ   : resample to new dx, dy and dz\n"
             "          e.g.  -dxyz 1.0 1.0 0.9\n"
             "          default is to leave unchanged\n"
@@ -589,10 +549,9 @@ int usage ( char * progg, int level )
             "    -prefix OUT_DSET : required prefix for output dataset\n"
             "          e.g.  -prefix reori.asl.pickle\n"
             "\n"
-            "    -input IN_DSET   : required input dataset to reorient\n"
-            "          e.g.  -input old.dset+orig\n"
+            "    -inset IN_DSET   : required input dataset to reorient\n"
+            "          e.g.  -inset old.dset+orig\n"
             "\n"
-            "    -inset IN_DSET   : alternative to -input\n"
             "------------------------------------------------------------\n"
             "\n"
             "  Author: R. Reynolds - %s\n"
@@ -643,7 +602,7 @@ int write_results ( THD_3dim_dataset * dout, options_t * opts,
     if ( DSET_write( dout ) != True )
     {
         fputs( "failure: cannot write dataset, exiting...\n", stderr );
-        return 1;
+        return FAIL;
     }
 
     if ( opts->debug >= RL_DEBUG_LOW )
