@@ -9,8 +9,7 @@
     Add funky stuff to suma_datasets.c       ZSS      Feb 28 08
 ---------------------------------------------------------------*/
 
-#include "suma_objs.h" /* 21 Apr 2020 */
-/*------------------------------------------------------------*/
+#include "suma_suma.h"
 
 NI_group *SUMA_NewAfniSurfaceObject(void)
 {
@@ -64,7 +63,6 @@ NI_group *SUMA_NewAfniSurfaceObjectPointset(void)
    
    SUMA_RETURN(ngr);
 }
-
 NI_group *SUMA_NewAfniSurfaceObjectNormals(void)
 { 
    static char FuncName[]={"SUMA_NewAfniSurfaceObjectNormals"};
@@ -97,11 +95,10 @@ NI_group *SUMA_FreeAfniSurfaceObject(NI_group *aSO)
 
 void SUMA_FindNgrNamedElementRec(NI_group *ngr, 
                                  char *elname, 
-                                 void **nelp)
+                                 NI_element **nelp)
 {
    static char FuncName[]={"SUMA_FindNgrNamedElementRec"};
    NI_element *nel = NULL;
-   NI_group *nelg = NULL;
    char *rs=NULL;
    int ip;
    int LocalHead = 0;
@@ -117,21 +114,11 @@ void SUMA_FindNgrNamedElementRec(NI_group *ngr,
       switch( ngr->part_typ[ip] ){
          /*-- a sub-group ==> recursion! --*/
          case NI_GROUP_TYPE:
-            nelg = (NI_group *)ngr->part[ip] ;
             if (LocalHead > 1)  {
                      fprintf( SUMA_STDERR,
                               "%s:  Looking for %s   in group %s \n",
                               FuncName, elname, ngr->name);
             }
-            if (!strcmp(elname, nelg->name)) {
-               *nelp=(void *)nelg; 
-               if (LocalHead) {
-                  fprintf( SUMA_STDERR,
-                        "%s: Found %s in group %s\n",
-                        FuncName, nelg->name, ngr->name);
-               }
-               SUMA_RETURNe; 
-            } 
             SUMA_FindNgrNamedElementRec(  (NI_group *)ngr->part[ip], 
                                           elname, 
                                           nelp);
@@ -147,7 +134,7 @@ void SUMA_FindNgrNamedElementRec(NI_group *ngr,
                         nel->vec_num );
             }
             if (!strcmp(elname, nel->name)) { 
-               *nelp=(void *)nel; 
+               *nelp=nel; 
                if (LocalHead) {
                   fprintf( SUMA_STDERR,
                         "%s: Found %s in group %s\n",
@@ -166,11 +153,10 @@ void SUMA_FindNgrNamedElementRec(NI_group *ngr,
 
    SUMA_RETURNe;
 }
-
 NI_element *SUMA_FindNgrNamedElement(NI_group *ngr, char *elname)
 {
    static char FuncName[]={"SUMA_FindNgrNamedElement"};
-   void *nel = NULL;
+   NI_element *nel = NULL;
    char *rs=NULL;
    int ip;
    int LocalHead = 0;
@@ -183,15 +169,6 @@ NI_element *SUMA_FindNgrNamedElement(NI_group *ngr, char *elname)
    }
    
    SUMA_FindNgrNamedElementRec(ngr, elname, &nel);
-   if (nel && NI_element_type(nel) == NI_GROUP_TYPE) {
-      /* ignore, return NULL */
-      if (LocalHead) {
-         fprintf( SUMA_STDERR,
-                  "%s: Found ngr named %s, returning null\n",
-                  FuncName, elname);
-      }
-      nel=NULL;
-   }
    if (LocalHead) {
       if (nel) {
          fprintf( SUMA_STDERR,
@@ -203,37 +180,6 @@ NI_element *SUMA_FindNgrNamedElement(NI_group *ngr, char *elname)
                   FuncName, elname);
       }         
    }
-   SUMA_RETURN((NI_element *)nel);
-}
-
-/* Return any element or group named elname */
-void *SUMA_FindNgrNamedAny(NI_group *ngr, char *elname)
-{
-   static char FuncName[]={"SUMA_FindNgrNamedAny"};
-   void *nel = NULL;
-   char *rs=NULL;
-   int ip;
-   int LocalHead = 0;
-   
-   SUMA_ENTRY;
-    
-   if (!ngr || !elname) { 
-      SUMA_S_Err("NULL input "); 
-      SUMA_RETURN(nel); 
-   }
-   
-   SUMA_FindNgrNamedElementRec(ngr, elname, &nel);
-   if (LocalHead) {
-      if (nel) {
-         fprintf( SUMA_STDERR,
-                  "%s: Found nel/ngr %s\n",
-                  FuncName, elname);
-      } else {
-         fprintf( SUMA_STDERR,
-                  "%s: nel/ngr %s not found\n",
-                  FuncName, elname);
-      }         
-   }
    SUMA_RETURN(nel);
 }
 
@@ -340,7 +286,7 @@ void SUMA_NI_set_double(NI_element *nel, char *attrname, double n)
 }
 
 /*! 
-   \brief A function to calculate shortest distance on a graph,
+   \brief A function to calulate shortest distance on a graph,
    and return the path corresponding to the short distance without
    relying on the SurfaceObject structure.
    
@@ -368,7 +314,7 @@ void SUMA_NI_set_double(NI_element *nel, char *attrname, double n)
                      n. Then n1 = FirstNeighb[n][1] and the distance between 
                      n and n1 is d1 = FirstNeighbDist[n][1]. 
                      If FirstNeighbDist is NULL, the d1 is calculated based on
-                     the Euclidean distance between the XYZ triplets starting at
+                     the Euclidian distance between the XYZ triplets starting at
                      NodeList[3*n] and NodeList[3*n1].
                      Naturally, you'll need to pass one of NodeList 
                      or FirstNeighbDist. If both are not NULL, then 
@@ -547,7 +493,7 @@ int * SUMA_Dijkstra_generic (int N_Node,
                            le = sqrt ( le );
                         } else {
                            fprintf (SUMA_STDERR, 
-                                 "ERROR %s: Only Euclidean distance supported\n"
+                                 "ERROR %s: Only Euclidian distance supported\n"
                                  , FuncName);
                            goto CLEANUP; 
                         }
@@ -680,7 +626,7 @@ int * SUMA_Dijkstra_generic (int N_Node,
                            le = sqrt ( le );
                         } else {
                            fprintf (SUMA_STDERR, 
-                                 "ERROR %s: Only Euclidean distance supported\n"
+                                 "ERROR %s: Only Euclidian distance supported\n"
                                  , FuncName);
                            goto CLEANUP; 
                         }
