@@ -23,7 +23,6 @@ static byte gifti_surf_meta_to_afni_surf_meta(
 static byte afni_surf_meta_to_gifti_surf_meta(
                NI_group *aSO,
                gifti_image * gim);
-static int flip_float_triples(float * fdata, int ntrip);
 
 
 
@@ -142,13 +141,8 @@ static NI_group *gifti_surf_to_afni_surf(gifti_image * gim)
    giiDataArray  * dan=NULL; /* normals */
    long long  rows=0, cols=0;
    NI_element *nelxyz=NULL, *nelnormals=NULL, *nelxform=NULL, *nelijk=NULL;
-
-   int rai_convert = 0;
-
    ENTRY("gifti_surf_to_afni_surf");
 
-   rai_convert = !AFNI_yesenv("AFNI_GIFTI_IN_RAI");
-
    gifti_globs_from_env();     /* for thd_gifti */
    if( (dac = gifti_find_DA(gim, NIFTI_INTENT_POINTSET, 0)) &&
        (dat = gifti_find_DA(gim, NIFTI_INTENT_TRIANGLE, 0))    ) {
@@ -189,14 +183,6 @@ static NI_group *gifti_surf_to_afni_surf(gifti_image * gim)
    NI_alter_veclen(nelxyz, (int)(rows*cols));
    NI_add_column(nelxyz, NI_FLOAT, (void *)dac->data); 
    NI_SETA_INT(nelxyz,"EmbedDim",3);
-
-   /* maybe convert LPI to RAI   31 Jul 2013 [rickr/zaid] */
-   if( rai_convert ) {
-      if( cols != 3 ) {
-         fprintf(stderr, "** GIFTI 2 AFNI: cols != 3, no RAI conversion\n");
-         rai_convert = 0;
-      } else flip_float_triples((float *)nelxyz->vec[0], rows);
-   }
    
    gifti_DA_rows_cols(  dat, 
                         &(rows),
@@ -214,8 +200,6 @@ static NI_group *gifti_surf_to_afni_surf(gifti_image * gim)
                         &(cols) );
       NI_alter_veclen(nelnormals, (int)(rows*cols));
       NI_add_column(nelnormals, NI_FLOAT, dan->data);
-      /* maybe convert LPI to RAI   31 Jul 2013 [rickr/zaid] */
-      if( rai_convert ) flip_float_triples((float *)nelnormals->vec[0], rows);
    } 
    
    if (!gifti_surf_meta_to_afni_surf_meta(gim, aSO)) {
@@ -223,36 +207,20 @@ static NI_group *gifti_surf_to_afni_surf(gifti_image * gim)
       RETURN(aSO);
    }
    
+   
+   
    RETURN(aSO);
 }
 
-static int flip_float_triples(float * fdata, int ntrip)
-{
-   float * fp = fdata;
-   int ind;
-   if( !fp || ntrip < 0 ) return 1;
-
-   for( ind = 0; ind < ntrip; ind++ ) {
-      *fp = -*fp;  fp++;
-      *fp = -*fp;  fp++;
-      fp++;
-   }
-   return 0;
-}
-
 /* convert afni surface to GIFTI surface */
 static  gifti_image *afni_surf_to_gifti_surf(NI_group *aSO)
 {
    gifti_image * gim=NULL;
    giiDataArray  * da=NULL; 
    NI_element *nelxyz=NULL, *nelijk=NULL, *nelnormals=NULL, *nelxform=NULL;
-   int           rai_convert=0;
    
    ENTRY("afni_surf_to_gifti_surf");
 
-   /* maybe convert RAI back to LPI   1 Aug 2013 [rickr/zaid] */
-   rai_convert = !AFNI_yesenv("AFNI_GIFTI_IN_RAI");
-
    gifti_globs_from_env();     /* for thd_gifti */
    
    if (!aSO) {
@@ -262,14 +230,14 @@ static  gifti_image *afni_surf_to_gifti_surf(NI_group *aSO)
    }
    
    /* form image */
-   if( gifti_get_verb() > 1 ) {  
+   if( G.verb > 1 ) {  
       fprintf(stderr,"++ creating gifti_image \n" );
    }
    
    /* basic step - create empty image (with a version string) 
       from gifti_create_image */
    gim = (gifti_image *)calloc(1, sizeof(gifti_image));
-   if(!gim){ fprintf(stderr,"** failed to alloc gifti_image\n"); RETURN(NULL); }
+   if(!gim){ fprintf(stderr,"** failed to alloc gifti_image\n"); return NULL; }
 
    gifti_clear_gifti_image(gim);
    gim->version = gifti_strdup(GIFTI_XML_VERSION);
@@ -300,10 +268,7 @@ static  gifti_image *afni_surf_to_gifti_surf(NI_group *aSO)
    }
    memcpy( da->data, (void *)nelxyz->vec[0],
             sizeof(float)*da->dims[0]*da->dims[1]); 
-
-   /* convert AFNI's RAI back to GIFTI's LPI */
-   if( rai_convert ) flip_float_triples((float *)da->data, da->dims[0]);
-
+      
    /* coordsys is added in the afni_surf_meta_to_gifti_surf_meta function */
       
    /* and the triangles */
@@ -363,9 +328,6 @@ static  gifti_image *afni_surf_to_gifti_surf(NI_group *aSO)
    }
    memcpy( da->data, nelnormals->vec[0],
             sizeof(float)*da->dims[0]*da->dims[1]); 
-   /* convert AFNI's RAI back to GIFTI's LPI */
-   if( rai_convert ) flip_float_triples((float *)da->data, da->dims[0]);
-
 #endif  /* end normals */
    
    /* and now for the grits */
@@ -375,9 +337,8 @@ static  gifti_image *afni_surf_to_gifti_surf(NI_group *aSO)
       RETURN(gim);
    }
 
-   if( gifti_get_verb() > 1 ) {  
-      gifti_disp_gifti_image("afni_surf_to_gifti_surf :",
-                             gim, gifti_get_verb() > 3);  
+   if( G.verb > 1 ) {  
+      gifti_disp_gifti_image("afni_surf_to_gifti_surf :",gim, G.verb > 3);  
    }
    
    RETURN(gim);
@@ -388,17 +349,14 @@ static byte gifti_surf_meta_to_afni_surf_meta(
                NI_group *aSO)
 {
    char *cp=NULL;
-   int i=0, j=0, k=0, rai_convert=0;
+   int i=0, j=0, k=0;
    giiDataArray  * dac=NULL; /* coords */
    giiDataArray  * dat=NULL; /* triangles */
    NI_element *nelxyz=NULL, *nelijk=NULL, *nelnormals=NULL, *nelxform=NULL;
-   double M[4][4];
    double *dv = NULL;
    
    ENTRY("gifti_surf_meta_to_afni_surf_meta");
-
-   rai_convert = !AFNI_yesenv("AFNI_GIFTI_IN_RAI");
-
+   
    /* Begin with nodelist */
    dac = gifti_find_DA(gim, NIFTI_INTENT_POINTSET, 0);
    nelxyz = SUMA_FindNgrNamedElement(aSO, "Node_XYZ");
@@ -460,17 +418,10 @@ static byte gifti_surf_meta_to_afni_surf_meta(
                         "xformspace",
                         cp); 
 
-      /* XR = F XL F-1, (F-1 = F) 31 Jul 2013 [rickr/zaid] */ 
-      if (rai_convert) {
-         AFF44_LPI_RAI_FLIP ( M , dac->coordsys[0]->xform );
-      } else {
-         AFF44_COPY( M , dac->coordsys[0]->xform );
-      }
-      
       k = 0;
       for (i=0; i<4;++i) {
          for (j=0; j<4; ++j) {
-            dv[k] = M[i][j];
+            dv[k] = dac->coordsys[0]->xform[i][j];
             ++k;
          }   
       }
@@ -522,17 +473,16 @@ static byte afni_surf_meta_to_gifti_surf_meta(
                NI_group *aSO, 
                gifti_image * gim )
 {
+   char *cp=NULL;
    int i=0, j=0;
    giiDataArray  * dac=NULL; /* coords */
    giiDataArray  * dat=NULL; /* triangles */
    NI_element *nelxyz=NULL, *nelijk=NULL, *nelnormals=NULL, *nelxform=NULL;
-   double *dv=NULL, M[4][4];
-   int k=0, rai_convert=0;
+   double *dv=NULL;
+   int k=0;
    
    ENTRY("afni_surf_meta_to_gifti_surf_meta");
    
-   rai_convert = !AFNI_yesenv("AFNI_GIFTI_IN_RAI");
-      
    /* Begin with nodelist */
    dac = gifti_find_DA(gim, NIFTI_INTENT_POINTSET, 0);
    nelxyz = SUMA_FindNgrNamedElement(aSO,"Node_XYZ");
@@ -592,13 +542,6 @@ static byte afni_surf_meta_to_gifti_surf_meta(
             dac->coordsys[0]->xform[i][j] = dv[k];
             ++k;
          }
-   
-   /* XR = F XL F-1, (F-1 = F) 31 Jul 2013 [rickr/zaid] */ 
-   if (rai_convert) {
-      AFF44_COPY( M , dac->coordsys[0]->xform );
-      AFF44_LPI_RAI_FLIP ( dac->coordsys[0]->xform , M );
-   }
-   
    dac = NULL; /* make sure it is not used below */
    
    /* Now do the FaceSetList */
