@@ -106,7 +106,7 @@ typedef struct learn_parm {
   long   xa_depth;             /* parameter in xi/alpha-estimates upper
 				  bounding the number of SV the current
 				  alpha_t is distributed over */
-  char predfile[200];          /* file for predictions on unlabeled examples
+  char predfile[200];          /* file for predicitions on unlabeled examples
 				  in transduction */
   char alphafile[200];         /* file to store optimal alphas in. use  
 				  empty string if alphas should not be 
@@ -125,10 +125,6 @@ typedef struct learn_parm {
   double svm_unlabbound;
   double *svm_cost;            /* individual upper bounds for each var */
   long   totwords;             /* number of features */
-  
-  /* JL July 2011: Added maximum number of iterations */
-  long max_iterations;
-
 } LEARN_PARM;
 
 typedef struct kernel_parm {
@@ -169,7 +165,7 @@ typedef struct quadratic_program {
 } QP;
 
 typedef struct kernel_cache {
-  long   *index;  /* cache some kernel evaluations */
+  long   *index;  /* cache some kernel evalutations */
   CFLOAT *buffer; /* to improve speed */
   long   *invindex;
   long   *active2totdoc;
