@@ -6,8 +6,6 @@
 
 static int verb = 0 ;
 static int specie = HUMAN;
-static char bottom_cuts[64] = {""};
-
 void mri_brainormalize_verbose( int v ){ verb = v ; THD_automask_verbose(v); }
 
 
@@ -46,15 +44,6 @@ static float thd_bn_ycm = 0.0;
 static float thd_bn_zcm = 0.0;
 static float thd_bn_rat = 0.0;
 
-void mri_brain_normalize_cuts(char *what) {
-   if (!what) {
-      bottom_cuts[0] = '\0';
-   }else{
-      snprintf(bottom_cuts,32,"%s",what);
-   }
-   return;
-}
-
 void mri_speciebusiness( int v ) { 
    if (v < HUMAN || v >= N_SPECIES) {
       fprintf(stderr,"** Bad specie %d\nDefaulting to Human.\n", v);
@@ -445,7 +434,7 @@ ENTRY("partial_cliplevel") ;
      for( npos=0,ii=ncut ; ii < nhist ; ii++ ) npos += hist[ii]; /* number >= cut */
      nhalf = npos/2 ;
      for( kk=0,ii=ncut ; ii < nhist && kk < nhalf ; ii++ )  /* find median of */
-       kk += hist[ii] ;                                     /* values >= cut */
+       kk += hist[ii] ;                                     /* valuess >= cut */
      nold = ncut ;                                          /* last cut */
      ncut = mfrac * ii ;                                    /* new cut */
      qq++ ;
@@ -655,7 +644,7 @@ typedef struct { short i,j,k,val; int basin; } shortvox ;
 /*--------------------------------------------------------------------------*/
 /*! Sort array of shortvox into increasing order (decreasing if dec != 0). */
 
-static void sort_shortvox( int n , shortvox *ar , int dec , float botperc, float topperc )
+static sort_shortvox( int n , shortvox *ar , int dec , float botperc, float topperc )
 {
    int ii,jj , sbot,stop,nsv , sval , pbot,ptop ;
    int *hsv , *csv ;
@@ -809,7 +798,7 @@ MRI_IMAGE * mri_watershedize( MRI_IMAGE *sim , float prefac )
    short *sar , *tar ;
    shortvox *svox ;
    int *isvox , *bcount,*bname ;
-   int nb,vb,mb,m,mu,mq,mz , bp[6]={0,0,0,0,0,0} , hpf ;
+   int nb,vb,mb,m,mu,mq,mz , bp[6] , hpf ;
 
    basin **baslist ;
    int nball , nbtop ;
@@ -1059,7 +1048,7 @@ static byte * make_peel_mask( int nx, int ny, int nz , byte *mmm, int pdepth )
    kk = mask_count(nxyz,ppp) ;
    if( kk == 0 ){ free((void *)ppp) ; return NULL ; }
    if( verb ) fprintf(stderr," + Initial peel mask has %d voxels\n",kk ) ;
-   THD_mask_erode( nx,ny,nz, ppp, 1, 2 ) ; /* NN2 */
+   THD_mask_erode( nx,ny,nz, ppp, 1 ) ;
    THD_mask_clust( nx,ny,nz, ppp ) ;
    kk = mask_count(nxyz,ppp) ;
    if( kk == 0 ){ free((void *)ppp) ; return NULL ; }
@@ -1093,14 +1082,14 @@ static void zedit_mask( int nx, int ny, int nz, byte *mmm, int zdepth, int zbot
 
    for( zz=zb ; zz <= zt ; zz++ ){
      memcpy( zzz , mmm+(zz-zd)*nxy , nxy*zslab ) ;
-     THD_mask_erode( nx,ny,zslab, zzz, 1, 2) ;
+     THD_mask_erode( nx,ny,zslab, zzz, 1 ) ;
      THD_mask_clust( nx,ny,zslab, zzz ) ;
      memcpy( ppp+zz*nxy , zzz+zd*nxy , nxy ) ;
    }
    free((void *)zzz) ;
    memcpy( mmm+zb*nxy , ppp+zb*nxy , (zt-zb+1)*nxy ) ;
    free((void *)ppp) ;
-   THD_mask_erode( nx,ny,nz, mmm, 1, 2 ) ;
+   THD_mask_erode( nx,ny,nz, mmm, 1 ) ;
    THD_mask_clust( nx,ny,nz, mmm ) ;
 }
 
@@ -1331,8 +1320,8 @@ ENTRY("mri_brainormalize") ;
    /* fill in any isolated holes in mask */
 
    (void) THD_mask_fillin_once( nx,ny,nz , mask , 2 ) ;  /* thd_automask.c */
-          THD_mask_dilate     ( nx,ny,nz , mask , 5, 2 ) ;
-          THD_mask_dilate     ( nx,ny,nz , mask , 5, 2 ) ;
+          THD_mask_dilate     ( nx,ny,nz , mask , 5 ) ;
+          THD_mask_dilate     ( nx,ny,nz , mask , 5 ) ;
 
    kk = mask_count(nxyz,mask) ;
    if( verb > 1)
@@ -1425,106 +1414,6 @@ ENTRY("mri_brainormalize") ;
    }}}
    if( sum == 0.0 ){ mri_free(sim); RETURN(NULL); }  /* huh? */
    
-   if (bottom_cuts[0] != '\0' && specie != HUMAN) {
-      WARNING_message("Bottom cuts not set for non-humans, option ignored");
-      bottom_cuts[0] = '\0';
-   }
-   
-   if (bottom_cuts[0] != '\0') { 
-      float jdist, kstack;
-      float hBp = thd_bn_zheight; 
-      float hBa = hBp - 20;
-      float hLR = 110;
-      float hCM = 85;
-      float lA = 70;
-      float lP = 110;
-      float hP = 110;
-      float wLR = 70;
-      float T[3], CM[3], Ba[3], Bp[3], A[3], P[3], R[3], L[3];
-      
-      /* Point Locations, all coords in i,j,k units: 
-      CM: Centroid, its z coord is not reliable as it varies
-          with coverage in IS direction 
-      T: Top of the head, (x,y) same as those of centroid  
-      Ba: Bottom limit for oblique Anterior cut, the z coord
-          is hBa mm from the topmost z coord
-      Bp: Bottom limit for oblique posterior cut, the z coord
-          is hBp mm from the topmost z coord  
-      A: A very anterior point which along with Ba defines the cut 
-         line in the AI cut. Its y coord is offset by lA mm from 
-         the centroid and its z coord is hCM mm from the top
-      P: The poterior equivalent of A. 
-      L, R: Lateral points, equivalent to A, and P   
-      */
-      /* get the index coordinates for the points of interest */
-      T[0] = icm/sum; T[1] = jcm/sum; /* same as CM's */
-                      T[2] = ktop;
-      CM[0] = icm/sum; CM[1] = jcm/sum; CM[2] = kcm/sum;
-      Ba[0] = CM[0]; Ba[1] = CM[1]; Ba[2] = T[2] - hBa/dz; 
-                      //if (Ba[2] < 0) Ba[2] = 0;
-      Bp[0] = CM[0]; Bp[1] = CM[1]; Bp[2] = T[2] - hBp/dz; 
-                      //if (Bp[2] < 0) Bp[2] = 0;
-      A[0]  = CM[0]; A[1] = CM[1]-lA/dy; A[2] = T[2]-hCM/dz;
-                      //if (A[1] < 0) A[1] = 0; if (A[2]<0) A[2] = 0;
-      P[0]  = CM[0]; P[1] = CM[1]+lP/dy; P[2] = T[2]-hCM/dz;
-                      //if (P[1] >= ny) P[1] = ny-1; if (P[2]<0) P[2] = 0;
-      R[0]  = CM[0]-wLR/dx; R[1] = CM[1]; R[2] = T[2]-hLR/dz;
-                      //if (R[0] < 0) R[0] = 0; if (R[2]<0) R[2] = 0;
-      L[0]  = CM[0]+wLR/dx; L[1] = CM[1]; L[2] = T[2]-hLR/dz;
-                      //if (L[0] >= nx) L[0] = nx-1; if (L[2]<0) L[2] = 0;
-
-      /* Cut in AI region */
-      if (strstr(bottom_cuts,"A")) {
-         if (verb) INFO_message("AI cut");
-         for (kk=0; kk<A[2]; ++kk) {
-            for (jj=0; kk<nz && jj<Ba[1]*(1.0-kk/A[2]); ++jj) {
-               for (ii=0; jj<ny && ii<nx; ++ii) {
-                  ijk=kk*nxy+jj*nx+ii;
-                  sar[ijk] = 0;
-               }
-            }
-         }
-      }   
-      /* Cut in PI region */
-      if (strstr(bottom_cuts,"P")) {
-         if (verb) INFO_message("PI cut");
-         for (kk=0; kk<P[2]; ++kk) {
-            for (jj=Bp[1]+(P[1]-Bp[1])*kk/P[2]; kk<nz && jj<ny; ++jj) {
-               for (ii=0; jj>=0 && ii<nx; ++ii) {
-                  ijk=kk*nxy+jj*nx+ii;
-                  sar[ijk] = 0;
-               }
-            }
-         }
-      }   
-
-      /* Cut in RI */
-      if (strstr(bottom_cuts,"R")) {
-         if (verb) INFO_message("RI cut");
-         for (kk=0; kk<R[2]; ++kk) {
-            for (ii=0; kk<nz && ii<Ba[0]*(1.0-kk/R[2]); ++ii) {
-               for (jj=0; ii<nx && jj<ny; ++jj) {
-                  ijk=kk*nxy+jj*nx+ii;
-                  sar[ijk] = 0;
-               }
-            }
-         }
-      }   
-
-      /* Cut in LI */
-      if (strstr(bottom_cuts,"L")) {
-         if (verb) INFO_message("LI cut");
-         for (kk=0; kk<R[2]; ++kk) {
-            for (ii=Ba[0]+(L[0]-Ba[0])*kk/R[2]; kk<nz && ii<nx; ++ii) {
-               for (jj=0; jj<ny && ii>=0; ++jj) {
-                  ijk=kk*nxy+jj*nx+ii;
-                  sar[ijk] = 0;
-               }
-            }
-         }
-      }   
-   }
-   
    ai = thd_bn_dxyz/dx ; 
    bi = icm/sum - (thd_bn_xcm-thd_bn_xorg)/dx ;
    aj = thd_bn_dxyz/dy ; 
@@ -1579,6 +1468,8 @@ ENTRY("mri_brainormalize") ;
            sv   = 1000.0f * sar[ijk] / bval ;
            sar[ijk] = SHORTIZE(sv) ;
            if (sar[ijk] < 0) {
+            /* if( verb ) fprintf(stderr,"--mri_brainormalize: Negative values! sar[%d %d %d (%d)] = %d\nBlasphemy set to 0.\n",
+                           ii, jj, kk, ijk, sar[ijk]); */
             sar[ijk] = 0;  /* ZSS April 11 06 */
            }
          }
@@ -1731,7 +1622,7 @@ ENTRY("mri_brainormalize") ;
      if( verb > 1)
       fprintf(stderr,"++mri_brainormalize: eroding...\n");
    
-     THD_mask_erode( nx,ny,nz, mask, 1, 2) ;
+     THD_mask_erode( nx,ny,nz, mask, 1 ) ;
      if( verb > 1)
       fprintf(stderr,"++mri_brainormalize: clustering 1...\n");
      THD_mask_clust( nx,ny,nz, mask ) ;
