@@ -3,81 +3,9 @@
    of Wisconsin, 1994-2000, and are released under the Gnu General Public
    License, Version 2.  See the file README.Copyright for details.
 ******************************************************************************/
-
-#include "mrilib.h"
-
-/*---- editable configuration variables [moved here 10 May 2013 -- RWcox] ----*/
-
-static char *COMPRESS_program[]    = { "gzip -1c > '%s'"  ,
-                                       "bzip2 -1c > '%s'" ,
-                                       "compress > '%s'"  ,
-                                       "pigz -1c > '%s'"  ,
-                                       "cat > '%s'"} ;         /* shouldn't be called */
-
-static int   COMPRESS_program_ok[] = { 1 , 1 , 1 , 1 , 0 } ;     /* RWCox 03 Aug 1998 */
-
-static char *COMPRESS_unprogram[]  = { "gzip -dc '%s'"  ,
-                                       "bzip2 -dc '%s'" ,
-                                       "uncompress -c '%s'",
-                                       "pigz -dc '%s'"  ,
-                                       "brikcomp -c '%s'" } ;
-
-/*----------------------------------------------------------------------------*/
-/* Check if pigz can be used in place of gzip for compression,
-   and if pbzip2 can be used in place of bzip2.
-*//*--------------------------------------------------------------------------*/
-
-static void COMPRESS_setup_programs(void)  /* 03 May 2013 */
-{
-   char *pgname=NULL ;
-   static char *cprog_gzip=NULL , *cprog_bzip2=NULL ;
-   static char *uprog_gzip=NULL , *uprog_bzip2=NULL ;
-   static int first=1 ;
-   int        cind=-1;
-   int    skip_pigz=AFNI_yesenv("AFNI_DONT_USE_PIGZ") ;
-
-   if( !first ) return ;
-   first = 0 ;
-   if( getenv("SKIP_COMPRESS_SETUP") ) return; /* Temp. fix. Strange R crash. 
-                                                   ZSS  09 May 2013           */ 
-   /* for some symmetry, init pgname based on AFNI_COMPRESSOR
-    * (for either gzip or pigz)           19 Sep 2013 [rickr] */
-   cind = THD_enviro_write_compression();
-   if      ( cind == COMPRESS_GZIP ) pgname = THD_find_executable("gzip") ;
-   else if ( cind == COMPRESS_PIGZ ) pgname = THD_find_executable("pigz") ;
-   else                              pgname = NULL ;
-
-   /* if that failed (ignore which), just start clean */
-   if( pgname == NULL && !skip_pigz ) pgname = THD_find_executable("pigz") ;
-   if( pgname == NULL               ) pgname = THD_find_executable("gzip") ;
-   if( pgname == NULL ){
-     COMPRESS_program_ok[0] = COMPRESS_program_ok[3] = 0 ;
-   } else {
-     cprog_gzip = (char *)malloc(sizeof(char)*(strlen(pgname)+32)) ;
-     sprintf(cprog_gzip,"%s -1c > '%%s'",pgname) ;
-     COMPRESS_program[0] = COMPRESS_program[3] = cprog_gzip ;
-     uprog_gzip = (char *)malloc(sizeof(char)*(strlen(pgname)+32)) ;
-     sprintf(uprog_gzip,"%s -dc '%%s'",pgname) ;
-     COMPRESS_unprogram[0] = COMPRESS_unprogram[3] = uprog_gzip ;
-   }
-
-                        pgname = THD_find_executable("pbzip2") ;
-   if( pgname == NULL ) pgname = THD_find_executable("bzip2") ;
-   if( pgname == NULL ){
-     COMPRESS_program_ok[1] = 0 ;
-   } else {
-     cprog_bzip2 = (char *)malloc(sizeof(char)*(strlen(pgname)+32)) ;
-     sprintf(cprog_bzip2,"%s -1c > '%%s'",pgname) ;
-     COMPRESS_program[1] = cprog_bzip2 ;
-     uprog_bzip2 = (char *)malloc(sizeof(char)*(strlen(pgname)+32)) ;
-     sprintf(uprog_bzip2,"%s -dc '%%s'",pgname) ;
-     COMPRESS_unprogram[1] = uprog_bzip2 ;
-   }
-
-   return ;
-}
-
-/*--------------------------------------------------------------*/
+   
+#include "thd_compress.h"
+#include "Amalloc.h"
 
 /*** check if the file exists on disk
      -- returns 1 if it does, 0 if it does not ***/
@@ -256,7 +184,7 @@ char * COMPRESS_add_suffix( char * fname , int mm )
 
 /*--------------------------------------------------------------*/
 
-/*** open a file for reading, possibly using compresson ***/
+/*** open a file for readin, possibly using compresson ***/
 
 FILE * COMPRESS_fopen_read( char * fname )
 {
@@ -266,11 +194,9 @@ FILE * COMPRESS_fopen_read( char * fname )
 
    if( fname == NULL || fname[0] == '\0' ) return NULL ;
 
-   COMPRESS_setup_programs() ;  /* 03 May 2013 */
-
    mm = COMPRESS_filecode( fname ) ;  /* find compression mode */
 
-   if( mm == COMPRESS_NOFILE ) return NULL ;  /* can't do nothing */
+   if( mm == COMPRESS_NOFILE ) return NULL ;  /* can't do nothin */
 
    if( mm == COMPRESS_NONE ){
       fp = fopen(fname,"r") ;   /* open it normally */
@@ -289,10 +215,7 @@ FILE * COMPRESS_fopen_read( char * fname )
    buf = fname ;
 #endif
 
-   /* allow for longer program names            16 May, 2014 [rickr] */
-   /* (problem noted by D. Thompson)                                 */
-   cmd = AFMALL(char,  sizeof(char) *
-                       (strlen(buf)+strlen(COMPRESS_unprogram[mm])+4) ) ;
+   cmd = AFMALL(char, sizeof(char) * (strlen(buf)+32) ) ;
    sprintf(cmd,COMPRESS_unprogram[mm],buf) ;
 
    fp = popen(cmd,"r") ;    /* open a pipe to read the file */
@@ -315,8 +238,6 @@ FILE * COMPRESS_fopen_write( char * fname , int mm )
 
    if( fname == NULL || fname[0] == '\0' ) return NULL ;
 
-   COMPRESS_setup_programs() ;  /* 03 May 2013 */
-
    /* Don't compress if the compression program isn't marked as OK   */
    /* [For modes that can only be compressed offline, like BRIKCOMP] */
 
@@ -337,10 +258,7 @@ FILE * COMPRESS_fopen_write( char * fname , int mm )
    buf = fname ;
 #endif
 
-   /* allow for longer program names            16 May, 2014 [rickr] */
-   /* (problem noted by D. Thompson)                                 */
-   cmd = AFMALL(char,  sizeof(char) *
-                       (strlen(buf)+strlen(COMPRESS_program[mm])+4) ) ;
+   cmd = AFMALL(char,  sizeof(char) * (strlen(buf)+32) ) ;
    sprintf(cmd,COMPRESS_program[mm],buf) ;
 
    fp = popen(cmd,"w") ;    /* open a pipe to write the file */
