@@ -62,8 +62,8 @@ float spearman_rank_prepare( int n , float *a )
 
    rb = 0.5f*(n-1) ; rs=0.0f ;
    for( ii=0 ; ii < n ; ii++ ){
-     a[ii] -= rb ;                /* remove mean rank */
-     rs    += a[ii]*a[ii] ;       /* sum squares */
+     a[ii] -= rb ;
+     rs    += a[ii]*a[ii] ;
    }
 
    return rs ;
@@ -130,74 +130,8 @@ float quadrant_corr( int n , float *x , float rv , float *r )
    return ( ss/sqrtf(rv*xv) ) ;
 }
 
-/*------------------------------------------------------------------------------*/
-
-static int num_quantile = 9 ;
-void THD_quantile_corr_setup( int nq )
-{
-   if( nq > 1 && nq < 100 ) num_quantile = nq ;
-}
-
-float quantile_prepare( int n , float *a )
-{
-   int ii ;
-   float rb , rs , jf ;
-
-   jf = 0.001f + 1.00001f * (n-0.5f) / (float)num_quantile ;
-   if( jf <= 2.0f ) return spearman_rank_prepare(n,a) ;
-   jf = 1.0f / jf ;
-
-   rank_order_float(n,a) ;        /* convert to ranks */
-
-   for( rb=0.0f,ii=0 ; ii < n ; ii++ ){
-     a[ii] = (int)( (a[ii]+0.333f)*jf ) ; rb += a[ii] ;
-   }
-   rb /= n ;
-   for( rs=0.0f,ii=0 ; ii < n ; ii++ ){
-     a[ii] -= rb ; rs += a[ii]*a[ii] ;
-   }
-
-   return rs ;
-}
-
-float THD_quantile_corr( int n , float *x , float *y )
-{
-   float xv,yv,ss ; int ii ;
-
-   if( n < 2 ) return 0.0f ;
-
-   xv = quantile_prepare(n,x) ; if( xv <= 0.0f ) return 0.0f ;
-   yv = quantile_prepare(n,y) ; if( yv <= 0.0f ) return 0.0f ;
-
-   for( ii=0,ss=0.0f ; ii < n ; ii++ ) ss += x[ii] * y[ii] ;
-
-   return ( ss/sqrtf(yv*xv) ) ;
-}
-
-float quantile_corr( int n , float *x , float rv , float *r )
-{
-   register int ii ;
-   register float ss ; float xv ;
-
-   xv = quantile_prepare( n , x ) ; if( xv <= 0.0f ) return 0.0f ;
-
-   for( ii=0,ss=0.0f ; ii < n ; ii++ ) ss += x[ii] * r[ii] ;
-
-   return ( ss/sqrtf(rv*xv) ) ;
-}
-
 /*---------------------------------------------------------------------------*/
 
-#if 1
-#undef  ttt_bot
-#undef  ttt_top
-#define ttt_bot 0.3333333f
-#define ttt_top 0.6666667f
-
-void tictactoe_set_thresh( float bb , float tt ){ return; }
-
-#else
-
 static float ttt_bot = 0.3333333f ;
 static float ttt_top = 0.6666667f ;
 
@@ -207,8 +141,6 @@ void tictactoe_set_thresh( float bb , float tt )
    else                     { ttt_bot = 0.3333333f; ttt_top = 0.6666667f; }
 }
 
-#endif
-
 /*---------------------------------------------------------------------------*/
 /*! Prepare for tictactoe correlation with a[].
 -----------------------------------------------------------------------------*/
@@ -252,18 +184,6 @@ float tictactoe_corr( int n , float *x , float rv , float *r )
    return ( ss/sqrtf(rv*xv) ) ;
 }
 
-/*------------------------------------------------------------------------------*/
-
-float THD_tictactoe_corr( int n , float *x , float *y )
-{
-   float yv , xv ; register float ss ; register int ii ;
-   if( n < 3 ) return 0.0f ;
-   xv = tictactoe_corr_prepare(n,x) ; if( xv <= 0.0f ) return 0.0f ;
-   yv = tictactoe_corr_prepare(n,y) ; if( yv <= 0.0f ) return 0.0f ;
-   for( ii=0,ss=0.0f ; ii < n ; ii++ ) ss += x[ii]*y[ii] ;
-   return( ss / sqrtf(xv*yv) ) ;
-}
-
 /*=============================================================================
   Compute correlations, destructively (i.e., mangling the input arrays)
 ===============================================================================*/
@@ -273,9 +193,7 @@ float THD_tictactoe_corr( int n , float *x , float *y )
 
 float THD_spearman_corr( int n , float *x , float *y )
 {
-   float xv ;
-   if( n < 2 ) return 0.0f ;
-   xv =  spearman_rank_prepare(n,x) ;
+   float xv = spearman_rank_prepare(n,x) ;
    if( xv <= 0.0f ) return 0.0f ;
    return spearman_rank_corr( n,y,xv,x ) ;
 }
@@ -293,23 +211,11 @@ float THD_spearman_corr_nd( int n , float *x , float *y )
    return cv ;
 }
 
-double THD_spearman_corr_dble( int n , double *x , double *y )
-{
-   float *qx, *qy , cv=0.0f ; int ii ;
-   qx = (float *)malloc(sizeof(float)*n);
-   qy = (float *)malloc(sizeof(float)*n);
-   for( ii=0 ; ii < n ; ii++ ){ qx[ii] = x[ii] ; qy[ii] = y[ii] ; }
-   cv = THD_spearman_corr(n,qx,qy) ;
-   free((void *)qy); free((void *)qx);
-   return (double)cv ;
-}
-
 /*--------------------------------------------------------------------------*/
 /*! Kendall Tau_b (x and y are modified) */
 
 float THD_ktaub_corr( int n , float *x , float *y )
 {
-   if( n < 2 ) return 0.0f ;
    qsort_floatfloat( n , x , y ) ;    /* preliminary sorting of x, carrying y */
    return kendallNlogN( x , y , n ) ; /* the actual work */
 }
@@ -319,9 +225,7 @@ float THD_ktaub_corr( int n , float *x , float *y )
 
 float THD_quadrant_corr( int n , float *x , float *y )
 {
-   float xv ;
-   if( n < 2 ) return 0.0f ;
-   xv = quadrant_corr_prepare(n,x) ;
+   float xv = quadrant_corr_prepare(n,x) ;
    if( xv <= 0.0f ) return 0.0f ;
    return quadrant_corr( n,y,xv,x ) ;
 }
@@ -372,7 +276,6 @@ float THD_pearson_corr( int n, float *x , float *y )
    float xm=0.0f , ym=0.0f ;
    register int ii ;
 
-   if( n < 2 ) return 0.0f ;
    for( ii=0 ; ii < n ; ii++ ){ xm += x[ii] ; ym += y[ii] ; }
    xm /= n ; ym /= n ;
    for( ii=0 ; ii < n ; ii++ ){
@@ -383,82 +286,6 @@ float THD_pearson_corr( int n, float *x , float *y )
    return xy/sqrtf(xv*yv) ;
 }
 
-/*--------------------------------------------------------------------------*/
-/*! Double Pearson correlation of x[] and y[] (x and y are NOT modified) */
-
-double THD_pearson_corrd( int n, double *x , double *y )
-{
-   double xv=0.0 , yv=0.0 , xy=0.0 , vv,ww ;
-   double xm=0.0 , ym=0.0 ;
-   register int ii ;
-
-   if( n < 2 ) return 0.0 ;
-   for( ii=0 ; ii < n ; ii++ ){ xm += x[ii] ; ym += y[ii] ; }
-   xm /= n ; ym /= n ;
-   for( ii=0 ; ii < n ; ii++ ){
-     vv = x[ii]-xm; ww = y[ii]-ym; xv += vv*vv; yv += ww*ww; xy += vv*ww;
-   }
-
-   if( xv <= 0.0 || yv <= 0.0 ) return 0.0 ;
-   return xy/sqrt(xv*yv) ;
-}
-
-/*-----------------------------------------------------------------------*/
-/* Partial Correlation of A & B, adjusting for C.             */
-
-float THD_pearson_partial_corr( int n, float *a, float *b, float *c )
-{
-    float AB, AC, BC;
-    //calculate correlation AB
-    AB = THD_pearson_corr(n, a, b);
-
-    //calculate correlation AC
-    AC = THD_pearson_corr(n, a, c);
-
-    //calculate correlation BC
-    BC = THD_pearson_corr(n, b, c);
-
-    return (AB - (AC*BC)) / sqrt( (1-(AC*AC)) * (1-(BC*BC)) );
-}
-
-/*-----------------------------------------------------------------------*/
-/* Double Partial Correlation of A & B, adjusting for C.             */
-
-double THD_pearson_partial_corrd( int n, double *a, double *b, double *c )
-{
-    double AB, AC, BC;
-    //calculate correlation AB
-    AB = THD_pearson_corrd(n, a, b);
-
-    //calculate correlation AC
-    AC = THD_pearson_corrd(n, a, c);
-
-    //calculate correlation BC
-    BC = THD_pearson_corrd(n, b, c);
-
-    return (AB - (AC*BC)) / sqrt( (1-(AC*AC)) * (1-(BC*BC)) );
-}
-
-/*--------------------------------------------------------------------------*/
-/*! Covariance of x[] and y[] (x and y are NOT modified).    ZSS May 18 2012*/
-
-float THD_covariance( int n, float *x , float *y )
-{
-   float xy=0.0f , vv,ww ;
-   float xm=0.0f , ym=0.0f ;
-   register int ii ;
-
-   if( n < 2 ) return 0.0f ;
-   for( ii=0 ; ii < n ; ii++ ){ xm += x[ii] ; ym += y[ii] ; }
-   xm /= n ; ym /= n ;
-   for( ii=0 ; ii < n ; ii++ ){
-     xy += (x[ii]-xm)*(y[ii]-ym);
-   }
-
-   return xy/(float)(n-1) ;
-}
-
-
 /*-------------------------------------------------------------------------*/
 /*! Returns a float_triple with (a,b,r) where
       y = a*x + b
@@ -503,8 +330,8 @@ float_triple THD_pearson_indexed( int nix, int *ix, float *x, float *y )
 #undef  NBOOT
 #undef  NB5
 
-#define NBOOT 960
-#define NB5    24  /* must be 2.5% of the above */
+#define NBOOT 600
+#define NB5    15  /* must be 2.5% of the above */
 
 void THD_pearson_corr_boot( int n , float *x , float *y ,
                             float_triple *rrr ,
@@ -559,86 +386,6 @@ void THD_pearson_corr_boot( int n , float *x , float *y ,
    return ;
 }
 
-/*---------------------------------------------------------------------------*/
-
-float THD_spearman_indexed( int nix, int *ix, float *x, float *y )
-{
-   float *xt , *yt ; float r ;
-
-   xt = (float *)malloc(sizeof(float)*nix) ;
-   yt = (float *)malloc(sizeof(float)*nix) ;
-   if( ix == NULL ){
-     memcpy(xt,x,sizeof(float)*nix) ;
-     memcpy(yt,y,sizeof(float)*nix) ;
-   } else {
-     int ii , jj ;
-     for( jj=0 ; jj < nix ; jj++ ){
-       ii = ix[jj] ; xt[jj] = x[ii] ; yt[jj] = y[ii] ;
-     }
-   }
-
-   r = THD_spearman_corr( nix , xt , yt ) ;
-   free(yt) ; free(xt) ; return r ;
-}
-
-/*------------------------------------------------------------------------------*/
-
-float_pair THD_l1_fit_to_line( int n , float *x , float *y )
-{
-   float_pair ab={0.0f,0.0f} ;
-   float *A[2] , coef[2] , val ;
-   int ii ;
-
-   if( n < 3 || x == NULL || y == NULL ) return ab ;
-
-   A[0] = x ;
-   A[1] = (float *)malloc(sizeof(float)*n) ;
-   for( ii=0 ; ii < n ; ii++ ) A[1][ii] = 1.0f ;
-
-   val = cl1_solve( n , 2 , y , A , coef , 0 ) ;
-   free(A[1]) ;
-   if( val >= 0.0f ){
-     ab.a = coef[0] ; ab.b = coef[1] ;
-   }
-   return ab ;
-}
-
-/*------------------------------------------------------------------------------*/
-
-void THD_spearman_corr_boot( int n , float *x , float *y , float_triple *rrr )
-{
-   int ii,kk ; float rr ; float_triple qqq ;
-   int *ix ; float rx[NBOOT] ;
-
-ENTRY("THD_spearman_corr_boot") ;
-
-   if( n < 5 || x == NULL || y == NULL ) EXRETURN ;
-   if( rrr == NULL ) EXRETURN ;
-
-   /* compute standard result */
-
-   rr = THD_spearman_indexed( n , NULL , x , y ) ; /* non-bootstrapped answer */
-   ix = (int *)malloc(sizeof(int)*n) ;
-
-   /* compute bootstrap results */
-
-   for( kk=0 ; kk < NBOOT ; kk++ ){
-     for( ii=0 ; ii < n ; ii++ ) ix[ii] = lrand48() % n ;
-     rx[kk] = THD_spearman_indexed( n , ix , x , y ) ;
-   }
-   free(ix) ;
-
-   /* sort, then find 2.5% and 97.5% points, save into output structs */
-   /*    [bootstrap confidence intervals are now bias-corrected!]     */
-
-   qqq = THD_bootstrap_confinv( rr , 0.05f , NBOOT , rx ) ;
-   rrr->a = rr ;      /* would use qqq.b for bias-corrected estimate */
-   rrr->b = qqq.a ;   /* lower edge of confidence interval */
-   rrr->c = qqq.c ;   /* upper edge */
-
-   EXRETURN ;
-}
-
 /*----------------------------------------------------------------*/
 
 float THD_pearson_corr_wt( int n, float *x , float *y , float *wt )
@@ -667,58 +414,6 @@ ININFO_message("THD_pearson_corr_wt: n=%d ws=%g xm=%g ym=%g xv=%g yv=%g xy=%g",
    return xy/sqrtf(xv*yv) ;
 }
 
-/*----------------------------------------------------------------*/
-
-// [PT: Nov 9, 2022] weighted Pearson corr--double time!
-double THD_pearson_corrd_wt( int n, double *x , double *y , float *wt )
-{
-   double xv=0.0 , yv=0.0 , xy=0.0 , vv,ww ;
-   double xm=0.0 , ym=0.0 , ws=0.0 ;
-   int ii ;
-
-   if( wt == NULL ) return THD_pearson_corrd(n,x,y) ;
-
-   for( ii=0 ; ii < n ; ii++ ){
-     xm += wt[ii]*x[ii]; ym += wt[ii]*y[ii]; ws += wt[ii];
-   }
-   xm /= ws ; ym /= ws ;
-   for( ii=0 ; ii < n ; ii++ ){
-     vv = x[ii]-xm ; ww = y[ii]-ym ;
-     xv += wt[ii]*vv*vv ; yv += wt[ii]*ww*ww ; xy += wt[ii]*vv*ww ;
-   }
-
-#if 0
-ININFO_message("THD_pearson_corrd_wt: n=%d ws=%g xm=%g ym=%g xv=%g yv=%g xy=%g",
-               n,ws,xm,ym,xv,yv,xy ) ;
-#endif
-
-   if( xv <= 0.0f || yv <= 0.0f ) return 0.0f ;
-   return xy/sqrt(xv*yv) ;
-}
-
-/*----------------------------------------------------------------*/
-/* compute distance between two arrays    ZSS May 04 2012 */
-float THD_distance( int n, float *x , float *y, int abs)
-{
-  float dp=0.0, a1, a2;
-  int ii, n1 = n-1;
-
-  for( ii=0 ; ii < n1 ; ii+=2 ) {
-     a1 = x[ii]-y[ii]; a2 = x[ii+1]-y[ii+1];
-     if (!abs) dp += (a1*a1+a2*a2);
-     else dp += (ABS(a1)+ABS(a2));
-  }
-  if( ii == n1 ) {
-    a1 = x[ii]-y[ii];
-    if (!abs) dp += a1*a1;
-    else dp += ABS(a1);
-  }
-
-  if (!abs) dp = sqrt(dp) ;
-
-  return (dp);
-}
-
 /*--------------------------------------------------------------------------*/
 /*! Compute the rank-order correlation between 2 images [08 Mar 2006].
 ----------------------------------------------------------------------------*/
@@ -768,71 +463,6 @@ float THD_eta_squared( int n, float *x , float *y )
    return 1.0 - num/denom ;
 }
 
-/*----------------------------------------------------------------*/
-/*! eta^2 (Cohen, NeuroImage 2008)              16 Jun 2011 [rickr]
- *
- *  Same as THD_eta_squared, but allow a mask and return a double.
- *
- *  eta^2 = 1 -  SUM[ (a_i - m_i)^2 + (b_i - m_i)^2 ]
- *               ------------------------------------
- *               SUM[ (a_i - M  )^2 + (b_i - M  )^2 ]
- *
- *  where  o  a_i and b_i are the vector elements
- *         o  m_i = (a_i + b_i)/2
- *         o  M = mean across both vectors
- -----------------------------------------------------------------*/
-double THD_eta_squared_masked( int n, float *x , float *y, byte *mask )
-{
-   double num=0.0f , denom = 0.0f ;
-   float gm=0.0f , lm, vv, ww;
-   int ii, nm ;
-
-   for( ii=0, nm=0 ; ii < n ; ii++ )
-      if( !mask || mask[ii] ) { gm += x[ii] + y[ii] ; nm++ ; }
-
-   if( nm == 0 ) return 0.0 ;          /* bail on empty mask */
-
-   gm /= (2*nm) ;
-
-   for( ii=0 ; ii < n ; ii++ ){
-     if( mask && !mask[ii] ) continue;  /* skip any not in mask */
-
-     lm = 0.5f * ( x[ii] + y[ii] ) ;
-     vv = (x[ii]-lm); ww = (y[ii]-lm); num   += ( vv*vv + ww*ww );
-     vv = (x[ii]-gm); ww = (y[ii]-gm); denom += ( vv*vv + ww*ww );
-   }
-
-   if( num < 0.0 || denom <= 0.0 || num >= denom ) return 0.0 ;
-
-   return 1.0 - num/denom ;
-}
-
-/*----------------------------------------------------------------*/
-/*! dice coefficient (allow for mask)          27 Oct 2015 [rickr]
- *  (float input)
- *
- *  dice = 2 * size(intersection) / ( size(A) + size(B) )
- *
- *  Simply count voxels for the 3 cases.
- -----------------------------------------------------------------*/
-float THD_dice_coef_f_masked( int n, float *x , float *y, byte *mask )
-{
-   int nA=0, nB=0, nAB=0;
-   int  ii;
-
-   for( ii=0 ; ii < n ; ii++ ) {
-      if( mask && !mask[ii] ) continue;
-      if( x[ii] ) {
-         nA++;
-         if( y[ii] ) { nB++; nAB++; }
-      } else
-         if ( y[ii] ) nB++;
-   }
-
-   if( (nA+nB) > 0 ) return 2.0*nAB/(nA+nB);
-   return 0.0;
-}
-
 /****************************************************************************/
 /*** Histogram-based measurements of dependence between two float arrays. ***/
 /****************************************************************************/
@@ -848,7 +478,7 @@ float THD_dice_coef_f_masked( int n, float *x , float *y, byte *mask )
 #define WW(i) ((w==NULL) ? 1.0f : w[i])   /* weight function for i'th datum */
 
 static float *xc=NULL , *yc=NULL , *xyc=NULL , nww=0.0f ;
-static int nbin=0 , nbp=0 , nbm=0 ;
+static int nbin=0 , nbp=0 ;
 
 static float *xbin=NULL , *ybin=NULL ;
 static int  nxybin=0 ;
@@ -880,7 +510,7 @@ static float yclip_bot, yclip_top ;
 
 void clear_2Dhist(void)
 {
-   FREEIF(xc); FREEIF(yc); FREEIF(xyc); nbin = nbp = nbm = 0; nww = 0.0f; return;
+   FREEIF(xc); FREEIF(yc); FREEIF(xyc); nbin = nbp = 0; return;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1114,15 +744,15 @@ int get_2Dhist_xybin( float **xb , float **yb )
 }
 
 /*--------------------------------------------------------------------------*/
-/*! Load 2D histogram of x[0..n-1] and y[0..n-1], each point optionally
+/*! Build 2D histogram of x[0..n-1] and y[0..n-1], each point optionally
     weighted by w[0..n-1] (weights are all 1 if w==NULL).
     Used in the histogram-based measures of dependence between x[] and y[i].
     If something is bad on input, nbin is set to 0.  Otherwise, these global
     variables are set:
       - nbin = # of bins, nbp = nbin+1
       - nww  = sum of the weights used
-      - xc   = marginal histogram of x[], for xc[0..nbin]   (nbp points in)
-      - yc   = marginal histogram of y[], for yc[0..nbin]   (each direction)
+      - xc   = marginal histogram of x[], for xc[0..nbin]
+      - yc   = marginal histogram of y[], for yc[0..nbin]
       - xyc  = joint histogram of (x[],y[]), for XYC(0..nbin,0..nbin)
       - The histograms are normalized (by 1/nww) to have sum==1
       - Histogram can be retrieved by retrieve_2Dhist() and can be
@@ -1136,110 +766,106 @@ int get_2Dhist_xybin( float **xb , float **yb )
         not be used in the histogram; mutatis mutandum for y[]
 ----------------------------------------------------------------------------*/
 
-static void stuff_2Dhist( int n, float xbot,float xtop,float *x,
-                                 float ybot,float ytop,float *y, float *w, int addon )
+void build_2Dhist( int n , float xbot,float xtop,float *x ,
+                           float ybot,float ytop,float *y , float *w )
 {
    register int ii,jj,kk ;
    float xb,xi , yb,yi , xx,yy , x1,y1 , ww ;
-   byte *good ; int ngood , xyclip ;
-   static float xxbot=0.0f,xxtop=0.0f , yybot=0.0f,yytop=0.0f ;
+   byte *good ; int ngood , xyclip , nbm ;
 
-ENTRY("stuff_2Dhist") ;
+ENTRY("build_2Dhist") ;
 
-   if( n <= 0 || x == NULL || y == NULL ) EXRETURN ;
+   /* bad inputs? */
 
-   /* get the min..max range for x and y data? */
+   if( n <= 1 || x == NULL || y == NULL ){ clear_2Dhist(); EXRETURN; }
 
+   /* get the min..max range for x data? */
+
+   STATUS("compute good[]") ;
    good = (byte *)malloc(sizeof(byte)*n) ;         /* 28 Feb 2007 */
    for( ii=0 ; ii < n ; ii++ )
      good[ii] = GOODVAL(x[ii]) && GOODVAL(y[ii]) ;
 
-   addon = addon && (xxbot < xxtop) && (yybot < yytop) && (nww > 0.0f) ;
-
-   if( addon ){
-
-     xbot = xxbot ; ybot = yybot ; xtop = xxtop ; ytop = yytop ;
-
-   } else {
-
-     clear_2Dhist() ;
-
-     if( nxybin > 2 ){                       /* unequal bins */
-       xbot = xbin[0] ; xtop = xbin[nxybin] ;
-     } else if( xbot >= xtop ){              /* equal bins, and must find range */
-       xbot = WAY_BIG ; xtop = -WAY_BIG ;
-       for( ii=0 ; ii < n ; ii++ )
-         if( good[ii] ){
-                if( x[ii] > xtop ) xtop = x[ii] ;
-           else if( x[ii] < xbot ) xbot = x[ii] ;
-         }
-     }
-     if( xbot >= xtop ){ clear_2Dhist(); free(good); EXRETURN; }
-
-     if( nxybin > 2 ){
-       ybot = ybin[0] ; ytop = ybin[nxybin] ;
-     } else if( ybot >= ytop ){
-       ybot = WAY_BIG ; ytop = -WAY_BIG ;
-       for( ii=0 ; ii < n ; ii++ )
-         if( good[ii] ){
-                if( y[ii] > ytop ) ytop = y[ii] ;
-           else if( y[ii] < ybot ) ybot = y[ii] ;
-         }
-     }
-     if( ybot >= ytop ){ free(good); EXRETURN; }
-
-     xxbot = xbot ; xxtop = xtop ; yybot = ybot ; yytop = ytop ;
-
+   if( nxybin > 2 ){                       /* unequal bins */
+     xbot = xbin[0] ; xtop = xbin[nxybin] ;
+#if 0
+     INFO_message("build_2Dhist: nxybin=%d x=%f..%f",nxybin,xbot,xtop) ;
+#endif
+   } else if( xbot >= xtop ){              /* equal bins, and must find range */
+     xbot = WAY_BIG ; xtop = -WAY_BIG ;
+     STATUS("compute xbot..xtop") ;
+     for( ii=0 ; ii < n ; ii++ )
+       if( good[ii] ){
+              if( x[ii] > xtop ) xtop = x[ii] ;
+         else if( x[ii] < xbot ) xbot = x[ii] ;
+       }
    }
+   if( xbot >= xtop ){ clear_2Dhist(); free(good); EXRETURN; }
+
+   /* get the min..max range for y data? */
+
+   if( nxybin > 0 ){
+     ybot = ybin[0] ; ytop = ybin[nxybin] ;
+#if 0
+     INFO_message("build_2Dhist: nxybin=%d y=%f..%f",nxybin,ybot,ytop) ;
+#endif
+   } else if( ybot >= ytop ){
+     ybot = WAY_BIG ; ytop = -WAY_BIG ;
+     STATUS("compute ybot..ytop") ;
+     for( ii=0 ; ii < n ; ii++ )
+       if( good[ii] ){
+              if( y[ii] > ytop ) ytop = y[ii] ;
+         else if( y[ii] < ybot ) ybot = y[ii] ;
+       }
+   }
+   if( ybot >= ytop ){ clear_2Dhist(); free(good); EXRETURN; }
+
+   /*--- allocate space for 2D and 1D histograms ---*/
+
+   if( nxybin > 2 ){                        /* array size is fixed by bins */
+     nbin = nxybin ;
+   } else {                                 /* compute new histo array size */
+     nbin = (nhbin > 2) ? nhbin : (int)pow((double)n,hpow) ;
+     if( nbin > 255 ) nbin = 255; else if( nbin < 3 ) nbin = 3;
+   }
+   nbp = nbin+1 ; nbm = nbin-1 ;
+
+   STATUS("free-ing") ;
+   FREEIF(xc) ; FREEIF(yc) ; FREEIF(xyc) ;
+
+   STATUS("malloc-ing") ;
+   xc  = (float *)calloc(sizeof(float),nbp) ;
+   yc  = (float *)calloc(sizeof(float),nbp) ;
+   xyc = (float *)calloc(sizeof(float),nbp*nbp) ;
 
    /*-- count number of good values left in range (in both x and y) --*/
 
+   STATUS("counting") ;
    memset(good,0,n) ;
    for( ngood=ii=0 ; ii < n ; ii++ ){
      if( RANGVAL(x[ii],xbot,xtop) && RANGVAL(y[ii],ybot,ytop) && WW(ii) > 0.0f ){
        good[ii] = 1 ; ngood++ ;
      }
    }
-   if( ngood == 0 ){ free(good) ; EXRETURN ; }
-
-   /*--- allocate space for 2D and 1D histograms ---*/
-
-   if( !addon ){
-     if( nxybin > 2 ){                        /* array size is fixed by bins */
-       nbin = nxybin ;
-     } else {                                 /* compute new histo array size */
-       nbin = (nhbin > 2) ? nhbin : (int)pow((double)n,hpow) ;
-       if( nbin > 255 ) nbin = 255; else if( nbin < 3 ) nbin = 3;
-     }
-     nbp = nbin+1 ; nbm = nbin-1 ;
-
-     FREEIF(xc) ; FREEIF(yc) ; FREEIF(xyc) ;
-
-     xc  = (float *)calloc(sizeof(float),nbp) ;
-     yc  = (float *)calloc(sizeof(float),nbp) ;
-     xyc = (float *)calloc(sizeof(float),nbp*nbp) ;
-     nww = 0.0f ;
-   }
+   if( ngood < 3*nbin ){ clear_2Dhist(); free(good); EXRETURN; }
 
    /*--------------- make the 2D and 1D histograms ---------------*/
 
-   xyclip = (nxybin <= 2) && use_xyclip &&
+   xyclip = (nxybin <= 0) && use_xyclip &&
             (xbot < xclip_bot) && (xclip_bot < xclip_top) && (xclip_top < xtop) &&
             (ybot < yclip_bot) && (yclip_bot < yclip_top) && (yclip_top < ytop) ;
 
    if( nxybin <= 0 && !xyclip ){  /*------------ equal size bins ------------*/
 
-#if 0
 if(PRINT_TRACING){
   char str[256];
   sprintf(str,"equal size bins: xbot=%g xtop=%g ybot=%g ytop=%g nbin=%d nval=%d ngood=%d",
           xbot,xtop,ybot,ytop,nbin,n,ngood);
   STATUS(str);
 }
-#endif
 
      xb = xbot ; xi = nbm/(xtop-xbot) ;
-     yb = ybot ; yi = nbm/(ytop-ybot) ;
+     yb = ybot ; yi = nbm/(ytop-ybot) ; nww = 0.0f ;
      for( ii=0 ; ii < n ; ii++ ){
        if( !good[ii] ) continue ;
        xx = (x[ii]-xb)*xi ;
@@ -1265,16 +891,15 @@ if(PRINT_TRACING){
 
      float xbc=xclip_bot , xtc=xclip_top , ybc=yclip_bot , ytc=yclip_top ;
 
-#if 0
 if(PRINT_TRACING){
   char str[256];
   sprintf(str,"mostly equal bins: xbc=%g xtc=%g ybc=%g ytc=%g nbin=%d",
           xbc,xtc,ybc,ytc,nbin) ; STATUS(str);
 }
-#endif
 
+     STATUS("mostly equal bins") ;
      xi = (nbin-2.000001f)/(xtc-xbc) ;
-     yi = (nbin-2.000001f)/(ytc-ybc) ;
+     yi = (nbin-2.000001f)/(ytc-ybc) ; nww = 0.0f ;
      for( ii=0 ; ii < n ; ii++ ){
        if( !good[ii] ) continue ;
        xx = x[ii] ;
@@ -1306,7 +931,7 @@ if(PRINT_TRACING){
      float *xdup, *ydup, *xv, *yv, *wv, frac,val,xt,yt ;
      int   *xn, *yn, *xin, *yin , ib,nb , maxsort ;
 
-     maxsort = 32*nxybin ; if( maxsort > 2048 ) maxsort = 2048 ;
+     maxsort = 16*nxybin ; if( maxsort > 512 ) maxsort = 512 ;
      xdup = (float *)malloc(sizeof(float)*maxsort) ;
      ydup = (float *)malloc(sizeof(float)*maxsort) ;
      xv   = (float *)malloc(sizeof(float)*maxsort) ;
@@ -1319,14 +944,15 @@ if(PRINT_TRACING){
 
      /* outer loop: process points starting at index = ib */
 
+     STATUS("unequal sized bins") ;
+     nww = 0.0f ;
      for( ib=0 ; ib < n ; ){
 
        /* extract up to maxsort good points from the data arrays */
 
        for( nb=0,ii=ib ; ii < n && nb < maxsort ; ii++ ){
          if( good[ii] ){
-           wv[nb]=WW(ii); xdup[nb]=x[ii]; ydup[nb]=y[ii]; xn[nb]=yn[nb]=nb;
-           nb++; /* separate for clarity */
+           wv[nb]=WW(ii); xdup[nb]=x[ii]; ydup[nb]=y[ii]; xn[nb]=yn[nb]=nb++;
          }
        }
 #if 0
@@ -1402,42 +1028,20 @@ if(PRINT_TRACING){
 
    } /*----- end of test on equal or unequal size bins -----*/
 
-   free(good); EXRETURN;
-}
+   STATUS("binning done") ;
 
-/*............................................................................*/
+   /*--- 26 Sep 2006: scale histogram to have sum==1 ---*/
 
-void build_2Dhist( int n , float xbot,float xtop,float *x ,
-                           float ybot,float ytop,float *y , float *w )
-{
-   if( n > 9 && x != NULL && y != NULL )
-     stuff_2Dhist( n , xbot,xtop,x , ybot,ytop,y , w , 0 ) ;
-   return ;
-}
-
-/*............................................................................*/
-
-void addto_2Dhist( int n , float xbot,float xtop,float *x ,
-                           float ybot,float ytop,float *y , float *w )
-{
-   if( n > 0 && x != NULL && y != NULL )
-     stuff_2Dhist( n , xbot,xtop,x , ybot,ytop,y , w , 1 ) ;
-   return ;
-}
-
-/*............................................................................*/
-/* scale histogram to have sum==1 */
-
-void normalize_2Dhist(void)
-{
-   if( nww > 0.0f && xyc != NULL && xc != NULL && yc != NULL ){
-     register float ni ; register int nbq , ii ;
+   if( nww > 0.0f ){
+     register float ni ; register int nbq ;
+     STATUS("scaling") ;
      ni = 1.0f / nww ;
      for( ii=0 ; ii < nbp ; ii++ ){ xc[ii]  *= ni; yc[ii] *= ni; }
      nbq = nbp*nbp ;
      for( ii=0 ; ii < nbq ; ii++ ){ xyc[ii] *= ni; }
    }
-   return ;
+
+   free(good); EXRETURN;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1571,8 +1175,7 @@ ENTRY("build_byteized_vectors") ;
 
        for( nb=0,ii=ib ; ii < n && nb < maxsort ; ii++ ){
          if( good[ii] ){
-           xdup[nb]=x[ii]; ydup[nb]=y[ii]; xn[nb]=yn[nb]=nb;
-           nb++;
+           xdup[nb]=x[ii]; ydup[nb]=y[ii]; xn[nb]=yn[nb]=nb++;
          }
        }
        ib = ii ;             /* where to start extracting next outer loop */
@@ -1636,10 +1239,6 @@ ENTRY("build_byteized_vectors") ;
 static int ignore_zz = 0 ;
 void THD_correlate_ignore_zerozero( int z ){ ignore_zz = z ; }
 
-/*-------------------- Shannon entropy function --------------------*/
-
-#define SHANENT(z) ( ( (z) <= 0.0f ) ? 0.0f : (z)*logf(z) )
-
 /*--------------------------------------------------------------------------*/
 /*! Compute the mutual info between two vectors, sort of.  [16 Aug 2006]
 ----------------------------------------------------------------------------*/
@@ -1654,7 +1253,6 @@ float THD_mutual_info_scl( int n , float xbot,float xtop,float *x ,
 
    build_2Dhist( n,xbot,xtop,x,ybot,ytop,y,w ) ;
    if( nbin <= 0 || nww <= 0 ) return 0.0f ;  /* something bad happened! */
-   normalize_2Dhist() ;
 
    /*-- compute MI from histogram --*/
 
@@ -1664,7 +1262,8 @@ float THD_mutual_info_scl( int n , float xbot,float xtop,float *x ,
 #if 0
      if( ii==0 && jj==0 && ignore_zz ) continue ;
 #endif
-     val += SHANENT( XYC(ii,jj) ) ;
+     if( XYC(ii,jj) > 0.0f )
+      val += XYC(ii,jj) * logf( XYC(ii,jj)/(xc[ii]*yc[jj]) ) ;
    }}
    return (1.4427f*val) ;  /* units are bits, just for fun */
 }
@@ -1693,18 +1292,18 @@ float THD_norm_mutinf_scl( int n , float xbot,float xtop,float *x ,
 
    build_2Dhist( n,xbot,xtop,x,ybot,ytop,y,w ) ;
    if( nbin <= 0 || nww <= 0 ) return 0.0f ;  /* something bad happened! */
-   normalize_2Dhist() ;
 
    /*-- compute NMI from histogram --*/
 
    denom = numer = 0.0f ;
    for( ii=0 ; ii < nbp ; ii++ ){
-     denom += SHANENT( xc[ii] ) + SHANENT( yc[ii] ) ;
+     if( xc[ii] > 0.0f ) denom += xc[ii] * logf( xc[ii] ) ;
+     if( yc[ii] > 0.0f ) denom += yc[ii] * logf( yc[ii] ) ;
      for( jj=0 ; jj < nbp ; jj++ ){
 #if 0
        if( ii==0 && jj==0 && ignore_zz ) continue ;
 #endif
-       numer += SHANENT( XYC(ii,jj) ) ;
+       if( XYC(ii,jj) > 0.0f ) numer += XYC(ii,jj) * logf( XYC(ii,jj) );
      }
    }
    if( denom != 0.0f ) denom = numer / denom ;
@@ -1733,14 +1332,14 @@ float THD_jointentrop_scl( int n , float xbot,float xtop,float *x ,
 
    build_2Dhist( n,xbot,xtop,x,ybot,ytop,y,w ) ;
    if( nbin <= 0 || nww <= 0 ) return 0.0f ;  /* something bad happened! */
-   normalize_2Dhist() ;
 
    /*-- compute MI from histogram --*/
 
    val = 0.0f ;
    for( ii=0 ; ii < nbp ; ii++ ){
     for( jj=0 ; jj < nbp ; jj++ ){
-     val -= SHANENT( XYC(ii,jj) ) ;
+     if( XYC(ii,jj) > 0.0f )
+      val -= XYC(ii,jj) * logf( XYC(ii,jj) ) ;
    }}
    return (1.4427f*val) ;  /* units are bits, just for fun */
 }
@@ -1776,7 +1375,6 @@ float THD_corr_ratio_scl( int n , float xbot,float xtop,float *x ,
 
    build_2Dhist( n,xbot,xtop,x,ybot,ytop,y,w ) ;
    if( nbin <= 0 ) return 0.0f ;  /* something bad happened! */
-   normalize_2Dhist() ;
 
    /*-- compute CR(y|x) from histogram --*/
 
@@ -1847,7 +1445,6 @@ float THD_hellinger_scl( int n , float xbot,float xtop,float *x ,
 
    build_2Dhist( n,xbot,xtop,x,ybot,ytop,y,w ) ;
    if( nbin <= 0 || nww <= 0 ) return 0.0f ;  /* something bad happened! */
-   normalize_2Dhist() ;
 
    /*-- compute metric from histogram --*/
 
@@ -1898,17 +1495,19 @@ float_quad THD_helmicra_scl( int n , float xbot,float xtop,float *x ,
 
    build_2Dhist( n,xbot,xtop,x,ybot,ytop,y,w ) ;
    if( nbin <= 0 || nww <= 0 ) return hmc ;  /* something bad happened! */
-   normalize_2Dhist() ;
 
    /*-- compute Hel, MI, NMI from histogram --*/
 
    hel = vv = uu = 0.0f ;
    for( ii=0 ; ii < nbp ; ii++ ){
-     vv += SHANENT( xc[ii] ) + SHANENT( yc[ii] ) ;
+     if( xc[ii] > 0.0f ) vv += xc[ii] * logf( xc[ii] ) ;
+     if( yc[ii] > 0.0f ) vv += yc[ii] * logf( yc[ii] ) ;
      for( jj=0 ; jj < nbp ; jj++ ){
-       pq   = XYC(ii,jj) ;
-       hel += sqrtf( pq * xc[ii] * yc[jj] ) ;
-       uu  += SHANENT( pq ) ;
+       pq = XYC(ii,jj) ;
+       if( pq > 0.0f ){
+         hel += sqrtf( pq * xc[ii] * yc[jj] ) ;
+         uu  += pq * logf( pq );
+       }
      }
    }
    hmc.a = 1.0f - hel ;                   /* Hellinger */
@@ -1967,69 +1566,6 @@ float_quad THD_helmicra( int n , float *x , float *y )
    return THD_helmicra_scl( n, 1.0f,-1.0f, x, 1.0f,-1.0f, y, NULL ) ;
 }
 
-/*---------------------------------------------------------------------------*/
-/* Return the MI and NMI of the 2 arrays y0[] and y1[] as 'correlated'
-   with the binary 0-1 variable. That is, does knowing a value is in
-   group 0 or 1 help predict it?
-*//*-------------------------------------------------------------------------*/
-
-float_pair THD_binary_mutinfo( int n0 , float *y0 , int n1 , float *y1 )
-{
-   float_pair mmii = {-666.6f,666.6f} ;
-   float *y0h , *y1h ; int nbin=64 , ii,kk ;
-   float ymin,ymax , dy,dc, hsum,hjoint ;
-
-   if( n0 < nbin || y0 == NULL || n1 < nbin || y1 == NULL ) return mmii ;
-
-   /* data range */
-
-   ymin = ymax = y0[0] ;
-   for( ii=1 ; ii < n0 ; ii++ ){
-          if( ymin > y0[ii] ) ymin = y0[ii] ;
-     else if( ymax < y0[ii] ) ymax = y0[ii] ;
-   }
-   for( ii=0 ; ii < n1 ; ii++ ){
-          if( ymin > y1[ii] ) ymin = y1[ii] ;
-     else if( ymax < y1[ii] ) ymax = y1[ii] ;
-   }
-   if( ymin >= ymax ) return mmii ;
-
-   /* histograms */
-
-   y0h = (float *)calloc(sizeof(float),nbin) ;
-   y1h = (float *)calloc(sizeof(float),nbin) ;
-
-   dy = nbin / (ymax-ymin) ;
-   dc = 1.0f / (float)(n0+n1) ;
-   for( ii=0 ; ii < n0 ; ii++ ){
-     kk = ( y0[ii] - ymin ) * dy ;
-     if( kk < 0 ) kk = 0 ; else if( kk >= nbin ) kk = nbin-1 ;
-     y0h[kk] += dc ;
-   }
-   for( ii=0 ; ii < n1 ; ii++ ){
-     kk = (int)( ( y1[ii] - ymin ) * dy ) ;
-     if( kk < 0 ) kk = 0 ; else if( kk >= nbin ) kk = nbin-1 ;
-     y1h[kk] += dc ;
-   }
-
-   /* calculate mutual info vs. 0/1 */
-
-            /* entropy of the 0/1 'variable' */
-   hsum   = - ( SHANENT(n0*dc) + SHANENT(n1*dc) ) ;
-
-   hjoint = 0.0f ;
-   for( kk=0 ; kk < nbin ; kk++ ){
-     hjoint -= ( SHANENT( y0h[kk] ) + SHANENT( y1h[kk] ) ) ;
-     hsum   -= SHANENT( y0h[kk] + y0h[kk] ) ;
-   }
-
-   free(y0h) ; free(y1h) ;
-
-   mmii.a = hsum - hjoint ;
-   if( hjoint > 0.0f ) mmii.b = hsum / hjoint ;
-   return mmii ;
-}
-
 /*---------------------------------------------------------------------------*/
 /*! Rank orders a collection of float arrays; ties get the average rank.
     The output overwrites the input.
@@ -2089,7 +1625,7 @@ void rank_order_float_arrays( int nar , int *nn , float **aa )
 
    for( kk=0 ; kk < ntot ; kk++ ){
      jj = b[kk] / nmax ;  /* which array did it come from? */
-     ii = b[kk] % nmax ;  /* which element in that array? */
+     ii = b[kk] % nmax ;  /* which element in that arrary? */
      aa[jj][ii] = c[kk] ; /* replace data with rank */
    }
 
@@ -2140,9 +1676,7 @@ float_triple THD_bootstrap_confinv( float estim , float alpha ,
    float_triple rval = {0.0f,0.0f,0.0f} ;
    int ii ; float z0 , zal , pp ;
 
-ENTRY("THD_bootstrap_confinv") ;
-
-   if( nboot < 100 || eboot == NULL ) RETURN( rval ) ;          /* bad user */
+   if( nboot < 100 || eboot == NULL ) return rval ;             /* bad user */
 
    if( alpha <= 0.001f || alpha >= 0.9f ) alpha = 0.05f ;    /* stupid user */
    alpha *= 0.5f ;                                          /* 1-sided tail */
@@ -2152,7 +1686,7 @@ ENTRY("THD_bootstrap_confinv") ;
    qsort_float( nboot , eboot ) ;                       /* increasing order */
 
    for( ii=0 ; ii < nboot && eboot[ii] < estim ; ii++ ) ;             /*nada*/
-   if( ii <= 1 || ii >= nboot-1 ) RETURN( rval ) ;           /* crummy data */
+   if( ii <= 1 || ii >= nboot-1 ) return rval ;              /* crummy data */
    z0 = PHINV( (ii+0.5f) / nboot ) ;                /* ii = #values < estim */
    if( z0 < -ZLIM ) z0 = -ZLIM ; else if( z0 > ZLIM ) z0 = ZLIM ; /* limits */
 
@@ -2168,7 +1702,7 @@ ENTRY("THD_bootstrap_confinv") ;
    ii = (int)pp ; pp = pp - ii ; if( ii >= nboot-1 ) ii = nboot-2 ;
    rval.b = (1.0f-pp)*eboot[ii] + pp*eboot[ii+1] ;
 
-   RETURN( rval ) ;
+   return rval ;
 }
 
 /*----------------------------------------------------------------------------*/
