@@ -163,9 +163,9 @@ THD_3dim_dataset * THD_open_ctfmri( char *fname )
    THD_ivec3 nxyz , orixyz ;
    THD_fvec3 dxyz , orgxyz ;
    int iview ;
-   int ngood , length , datum_type=0 , datum_len , oxx,oyy,ozz ;
+   int ngood , length , datum_type , datum_len , oxx,oyy,ozz ;
    int   nx,ny,nz ;
-   float dx,dy,dz=0.0, xorg,yorg,zorg=0.0;
+   float dx,dy,dz , xorg,yorg,zorg ;
 
 ENTRY("THD_open_ctfmri") ;
 
@@ -420,9 +420,8 @@ ENTRY("THD_open_ctfmri") ;
    /*-- for fun, add a set of tags for MEG fiducial points, if present --*/
 
    if( hh.headModel.LeftEar_Sag != hh.headModel.RightEar_Sag ){
-     THD_usertaglist *tagset = myRwcNew(THD_usertaglist) ;
-     int nas_ii,nas_jj,nas_kk=0 , lft_ii,lft_jj,lft_kk=0 , 
-         rgt_ii,rgt_jj,rgt_kk=0 ;
+     THD_usertaglist *tagset = myXtNew(THD_usertaglist) ;
+     int nas_ii,nas_jj,nas_kk , lft_ii,lft_jj,lft_kk , rgt_ii,rgt_jj,rgt_kk ;
      THD_fvec3 fv ; THD_ivec3 iv ;
 
      tagset->num = 3 ;
@@ -515,7 +514,7 @@ ENTRY("THD_open_ctfmri") ;
 void THD_load_ctfmri( THD_datablock *dblk )
 {
    THD_diskptr *dkptr ;
-   int nx,ny,nz,nv , nxy,nxyz,nxyzv , ibr=0,nbad ;
+   int nx,ny,nz,nv , nxy,nxyz,nxyzv , ibr,nbad ;
    FILE *fp ;
    void *ptr ;
 
@@ -548,7 +547,6 @@ ENTRY("THD_load_ctfmri") ;
    fseek( fp , sizeof(Version_2_Header) , SEEK_SET ) ;  /* old */
 #else
    switch( DBLK_BRICK_TYPE(dblk,0) ){
-     default:  ERROR_exit("Unrecognized type in CTF file") ; break ;
      case MRI_float: ibr = sizeof(float) ; break ;   /* illegal */
      case MRI_short: ibr = sizeof(short) ; break ;
      case MRI_byte:  ibr = sizeof(byte)  ; break ;
@@ -595,7 +593,6 @@ ENTRY("THD_load_ctfmri") ;
    if( dkptr->byte_order != mri_short_order() ){
      for( ibr=0 ; ibr < nv ; ibr++ ){
        switch( DBLK_BRICK_TYPE(dblk,ibr) ){
-         default: break ;
          case MRI_short:
            mri_swap2( DBLK_BRICK_NVOX(dblk,ibr) , DBLK_ARRAY(dblk,ibr) ) ;
          break ;
