@@ -8,18 +8,6 @@
 
 /*-------------------------------------------------------------------------*/
 
-int THD_is_zero( int npt , float *xx )  /* 20 May 2011 */
-{
-   int ii ;
-
-   if( npt <= 0 || xx == NULL ) return 1 ;
-   
-   for( ii=0 ; ii < npt ; ii++ ) if( xx[ii] != 0.0f ) return 0 ;
-   return 1 ;
-}
-
-/*-------------------------------------------------------------------------*/
-
 int THD_is_constant( int npt , float *xx )  /* 20 May 2011 */
 {
    int ii ; float val ;
@@ -77,7 +65,7 @@ void get_linear_trend( int npt, float *xx, float *f0, float *f1 )
 
 void THD_linear_detrend( int npt, float *far, float *xx0, float *xx1 )
 {
-   int ii ;
+   register int ii ;
    float f0=0.0, f1=0.0;
 
    if( npt < 3 || far == NULL ) return ;
@@ -97,7 +85,7 @@ void THD_linear_detrend( int npt, float *far, float *xx0, float *xx1 )
 
 void THD_linear_detrend_complex( int npt , complex *cx )  /* 05 Mar 2007 */
 {
-   float *f ; int ii ;
+   register float *f ; register int ii ;
 
    if( npt < 3 || cx == NULL ) return ;
 
@@ -119,8 +107,8 @@ void THD_linear_detrend_complex( int npt , complex *cx )  /* 05 Mar 2007 */
 
 void get_quadratic_trend( int npt, float *xx, float *f0, float *f1, float *f2 )
 {
-   double x0,x1,x2 ; double N=npt ;
-   int ii ;
+   register double x0,x1,x2 ; double N=npt ;
+   register int ii ;
 
    if( npt < 3 || xx == NULL || f0 == NULL || f1 == NULL || f2 == NULL ) return;
 
@@ -155,7 +143,7 @@ void get_quadratic_trend( int npt, float *xx, float *f0, float *f1, float *f2 )
 void THD_quadratic_detrend( int npt, float *far,
                             float *xx0, float *xx1, float *xx2 )
 {
-   int ii ;
+   register int ii ;
    float f0 , f1 , f2 ;
 
    if( npt < 4 || far == NULL ) return ;
@@ -177,7 +165,7 @@ void THD_quadratic_detrend( int npt, float *far,
 
 void THD_cubic_detrend( int npt , float *far )  /* 15 Nov 1999 */
 {
-   int ii ;
+   register int ii ;
    float g0,g1,g2,g3 , f0,f1,f2,f3 , t1,t2,t5,t8 , t95,t56,t22,t25,txx ;
 
    if( npt < 5 || far == NULL ) return ;
@@ -224,14 +212,14 @@ void THD_cubic_detrend( int npt , float *far )  /* 15 Nov 1999 */
 
 float THD_normalize( int npt , float *far )
 {
-   int ii ;
-   float fac ;
+   register int ii ;
+   register float fac ;
 
    if( npt <= 0 || far == NULL ) return 0.0f ;
 
    fac = 0.0f ;
    for( ii=0 ; ii < npt ; ii++ ) fac += far[ii]*far[ii] ;
-   if( fac <= 1.e-20f ) return 0.0f ;
+   if( fac <= 0.0f ) return 0.0f ;
    fac = 1.0f / sqrtf(fac) ;
    for( ii=0 ; ii < npt ; ii++ ) far[ii] *= fac ;
    return fac ;
@@ -243,8 +231,8 @@ float THD_normalize( int npt , float *far )
 
 void THD_normRMS( int npt , float *far )
 {
-   int ii ;
-   float fac ;
+   register int ii ;
+   register float fac ;
 
    if( npt <= 0 || far == NULL ) return ;
 
@@ -261,8 +249,8 @@ void THD_normRMS( int npt , float *far )
 
 void THD_normmax( int npt , float *far )
 {
-   int ii ;
-   float fac , val ;
+   register int ii ;
+   register float fac , val ;
 
    if( npt <= 0 || far == NULL ) return ;
    fac = 0.0f ;
@@ -278,8 +266,8 @@ void THD_normmax( int npt , float *far )
 
 void THD_normL1( int npt , float *far )
 {
-   int ii ;
-   float fac , val ;
+   register int ii ;
+   register float fac , val ;
 
    if( npt <= 0 || far == NULL ) return ;
    fac = 0.0f ;
@@ -294,8 +282,8 @@ void THD_normL1( int npt , float *far )
 /*! Detrend a vector with a given polort level, plus some others, using
     least squares regression.
      - npt    = length of vector
-     - far    = vector of data (will be modified)
-     - polort = polynomial order
+     - far    = vector of data
+     - polort = polynomial order (-1..3)
      - nort   = number of extra orts in ort[] (can be 0)
      - ort    = array of extra time series to detrend:
                  ort[j][i] for j=0..nort-1, i=0..npt-1
@@ -309,29 +297,18 @@ void THD_generic_detrend_LSQ( int npt, float *far ,
    int ii,jj , nref ;
    float **ref , *qfit , xmid , xfac , val ;
 
-ENTRY("THD_generic_detrend_LSQ") ;
-
    /* check inputs */
 
-   if( npt <= 1 || far == NULL ){
-     ERROR_message("THD_generic_detrend_LSQ :: bad inputs"); EXRETURN;
-   }
+   if( npt <= 1 || far == NULL ) return ;
    if( nort > 0 ){
-     if( ort == NULL ){
-       ERROR_message("THD_generic_detrend_LSQ :: ort == NULL"); EXRETURN;
-     }
-     for( jj=0 ; jj < nort ; jj++ ){
-       if( ort[jj] == NULL || THD_is_zero(npt,ort[jj]) ){
-         ERROR_message("THD_generic_detrend_LSQ :: ort[%d] is invalid",jj) ;
-         EXRETURN ;
-       }
-     }
+     if( ort == NULL ) return ;
+     for( jj=0 ; jj < nort ; jj++ ) if( ort[jj] == NULL ) return ;
    }
    if( polort <  0 ) polort = -1 ;
    if( nort   <  0 ) nort   =  0 ;
 
    nref = polort+1+nort ;
-   if( nref <= 0 || nref >= npt-1 ) EXRETURN ;
+   if( nref == 0 || nref >= npt-1 ) return ;
 
    /* assemble all reference vectors */
 
@@ -339,13 +316,44 @@ ENTRY("THD_generic_detrend_LSQ") ;
    xmid = 0.5*(npt-1) ; xfac = 1.0 / xmid ;
    for( jj=0 ; jj <= polort ; jj++ ){
      ref[jj] = (float *) malloc( sizeof(float) * npt ) ;
+#if 1  /* the new way */
      for( ii=0 ; ii < npt ; ii++ )
        ref[jj][ii] = (float)Plegendre(xfac*(ii-xmid),jj) ;
+#else  /* the olden way */
+     switch( jj ){
+       case 0:
+         for( ii=0 ; ii < npt ; ii++ ) ref[jj][ii] = 1.0 ;
+       break ;
+
+       case 1:
+         for( ii=0 ; ii < npt ; ii++ ) ref[jj][ii] = xfac*(ii-xmid) ;
+       break ;
+
+       case 2:
+         for( ii=0 ; ii < npt ; ii++ ){
+           val = xfac*(ii-xmid) ; ref[jj][ii] = val*val ;
+         }
+       break ;
+
+       case 3:
+         for( ii=0 ; ii < npt ; ii++ ){
+           val = xfac*(ii-xmid) ; ref[jj][ii] = val*val*val ;
+         }
+       break ;
+
+       default:
+         for( ii=0 ; ii < npt ; ii++ ){
+           val = xfac*(ii-xmid) ;
+           ref[jj][ii] = pow(val,(double)(jj)) ;
+         }
+       break ;
+     }
+#endif
    }
    for( jj=0 ; jj < nort ; jj++ )   /* user supplied refs */
      ref[polort+1+jj] = ort[jj] ;
 
-   qfit = lsqfit( npt , far , NULL , nref , ref ) ;     /* actual fitting */
+   qfit = lsqfit( npt , far , NULL , nref , ref ) ;
 
    if( qfit != NULL ){                                  /* good */
      for( ii=0 ; ii < npt ; ii++ ){
@@ -361,16 +369,15 @@ ENTRY("THD_generic_detrend_LSQ") ;
    }
 
    for( jj=0 ; jj <= polort ; jj++ ) free(ref[jj]) ;
-   free(ref) ; EXRETURN ;
+   free(ref) ; return ;
 }
 
 /*-----------------------------------------------------------------------*/
 /*! Detrend a vector with a given polort level, plus some others, using
     L1 regression.
      - npt    = length of vector
-                 (if < 0, then abs(npt) is used, and the fit isn't subtracted)
-     - far    = vector of data (will be modified)
-     - polort = polynomial order
+     - far    = vector of data
+     - polort = polynomial order (-1..3)
      - nort   = number of extra orts in ort[] (can be 0)
      - ort    = array of extra time series to detrend:
                  ort[j][i] for j=0..nort-1, i=0..npt-1
@@ -381,34 +388,21 @@ ENTRY("THD_generic_detrend_LSQ") ;
 void THD_generic_detrend_L1( int npt, float *far ,
                              int polort, int nort, float **ort , float *fit )
 {
-   int ii,jj , nref , nosub=0 ;
+   int ii,jj , nref ;
    float **ref , *qfit , xmid , xfac , val ;
 
-ENTRY("THD_generic_detrend_L1") ;
-
    /* check inputs */
 
-   if( npt < -1 ){ nosub = 1 ; npt = -npt ; }  /* 02 Jan 2013 */
-
-   if( npt <= 1 || far == NULL ){
-     ERROR_message("THD_generic_detrend_L1 :: bad inputs"); EXRETURN;
-   }
+   if( npt <= 1 || far == NULL ) return ;
    if( nort > 0 ){
-     if( ort == NULL ){
-       ERROR_message("THD_generic_detrend_LSQ :: ort == NULL"); EXRETURN;
-     }
-     for( jj=0 ; jj < nort ; jj++ ){
-       if( ort[jj] == NULL || THD_is_zero(npt,ort[jj]) ){
-         ERROR_message("THD_generic_detrend_L1 :: ort[%d] is invalid",jj) ;
-         EXRETURN ;
-       }
-     }
+     if( ort == NULL ) return ;
+     for( jj=0 ; jj < nort ; jj++ ) if( ort[jj] == NULL ) return ;
    }
    if( polort <  0 ) polort = -1 ;
    if( nort   <  0 ) nort   =  0 ;
 
    nref = polort+1+nort ;
-   if( nref <= 0 || nref >= npt-1 ) EXRETURN ;
+   if( nref == 0 || nref >= npt-1 ) return ;
 
    /* assemble all reference vectors */
 
@@ -416,8 +410,33 @@ ENTRY("THD_generic_detrend_L1") ;
    xmid = 0.5*(npt-1) ; xfac = 1.0 / xmid ;
    for( jj=0 ; jj <= polort ; jj++ ){
      ref[jj] = (float *) malloc( sizeof(float) * npt ) ;
-     for( ii=0 ; ii < npt ; ii++ )
-       ref[jj][ii] = (float)Plegendre(xfac*(ii-xmid),jj) ;
+     switch( jj ){
+       case 0:
+         for( ii=0 ; ii < npt ; ii++ ) ref[jj][ii] = 1.0 ;
+       break ;
+
+       case 1:
+         for( ii=0 ; ii < npt ; ii++ ) ref[jj][ii] = xfac*(ii-xmid) ;
+       break ;
+
+       case 2:
+         for( ii=0 ; ii < npt ; ii++ ){
+           val = xfac*(ii-xmid) ; ref[jj][ii] = val*val ;
+         }
+       break ;
+
+       case 3:
+         for( ii=0 ; ii < npt ; ii++ ){
+           val = xfac*(ii-xmid) ; ref[jj][ii] = val*val*val ;
+         }
+       break ;
+
+       default:
+         for( ii=0 ; ii < npt ; ii++ ){
+           val = xfac*(ii-xmid) ; ref[jj][ii] = pow(val,(double)(jj)) ;
+         }
+       break ;
+     }
    }
    for( jj=0 ; jj < nort ; jj++ )   /* user supplied refs */
      ref[polort+1+jj] = ort[jj] ;
@@ -426,12 +445,10 @@ ENTRY("THD_generic_detrend_L1") ;
    val = cl1_solve( npt , nref , far , ref , qfit , 0 ) ;
 
    if( val >= 0.0f ){                                  /* good */
-     if( !nosub ){
-       for( ii=0 ; ii < npt ; ii++ ){
-         val = far[ii] ;
-         for( jj=0 ; jj < nref ; jj++ ) val -= qfit[jj] * ref[jj][ii] ;
-         far[ii] = val ;
-       }
+     for( ii=0 ; ii < npt ; ii++ ){
+       val = far[ii] ;
+       for( jj=0 ; jj < nref ; jj++ ) val -= qfit[jj] * ref[jj][ii] ;
+       far[ii] = val ;
      }
      if( fit != NULL ){ for( ii=0 ; ii < nref ; ii++ ) fit[ii] = qfit[ii] ; }
    } else {
@@ -441,7 +458,7 @@ ENTRY("THD_generic_detrend_L1") ;
    free(qfit) ;
 
    for( jj=0 ; jj <= polort ; jj++ ) free(ref[jj]) ;
-   free(ref) ; EXRETURN ;
+   free(ref) ; return ;
 }
 
 /*-----------------------------------------------------------------------*/
@@ -454,29 +471,18 @@ void THD_generic_retrend( int npt , float *far ,
    int ii,jj , nref ;
    float **ref , xmid , xfac , val ;
 
-ENTRY("THD_generic_retrend") ;
-
    /* check inputs */
 
-   if( npt <= 1 || far == NULL ){
-     ERROR_message("THD_generic_retrend :: bad inputs"); EXRETURN;
-   }
+   if( npt <= 1 || far == NULL || fit == NULL ) return ;
    if( nort > 0 ){
-     if( ort == NULL ){
-       ERROR_message("THD_generic_detrend_LSQ :: ort == NULL"); EXRETURN;
-     }
-     for( jj=0 ; jj < nort ; jj++ ){
-       if( ort[jj] == NULL || THD_is_zero(npt,ort[jj]) ){
-         ERROR_message("THD_generic_retrend :: ort[%d] is invalid",jj) ;
-         EXRETURN ;
-       }
-     }
+     if( ort == NULL ) return ;
+     for( jj=0 ; jj < nort ; jj++ ) if( ort[jj] == NULL ) return ;
    }
    if( polort <  0 ) polort = -1 ;
    if( nort   <  0 ) nort   =  0 ;
 
    nref = polort+1+nort ;
-   if( nref == 0 || nref >= npt-1 ) EXRETURN ;
+   if( nref == 0 || nref >= npt-1 ) return ;
 
    /* assemble all reference vectors */
 
@@ -522,7 +528,7 @@ ENTRY("THD_generic_retrend") ;
    }
 
    for( jj=0 ; jj <= polort ; jj++ ) free(ref[jj]) ;
-   free(ref) ; EXRETURN ;
+   free(ref) ; return ;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -666,7 +672,7 @@ ENTRY("THD_time_fit_dataset") ;
        switch(meth){                    /* get stdev or MAD */
          default:
          case 2:{
-           float mm,vv ;
+           register float mm,vv ;
            for( mm=0.0,tt=0 ; tt < nval ; tt++ ) mm += far[tt] ;
            mm /= nval ;
            for( vv=0.0,tt=0 ; tt < nval ; tt++ ) vv += (far[tt]-mm)*(far[tt]-mm) ;
