@@ -1,6 +1,6 @@
 /***** This code is part of the AFNI software package, which is   *****
  ***** partly in the public domain and partly covered by the GPL. *****
- ***** See https://afni.nimh.nih.gov/afni for more information.    *****/
+ ***** See http://afni.nimh.nih.gov/afni for more information.    *****/
 
 #include "mrilib.h"
 
@@ -10,10 +10,8 @@ static floatvec * THD_deconvolve_autopen( int npt    , float *far   ,
                                           int meth   , float *ccon  , int dcon   ,
                                           int pencode, float *penfac_used         );
 
-/* 'AO' changes (from Aomp.h) are for compatibility with OpenMP */
-
-AO_DEFINE_SCALAR(int,voxid) ;
-void THD_fitter_voxid( int i ){ AO_VALUE(voxid) = i; }
+static int voxid = 0 ;
+void THD_fitter_voxid( int i ){ voxid = i; }
 
 /*------------------------------------------------------------------*/
 /* Least squares fitting without constraints. (cf mri_matrix.c) */
@@ -59,19 +57,14 @@ ENTRY("new_lsqfit") ;
 
 /**--- 05 Mar 2008: stuff to get the fitted model back ---**/
 
-/* this variable is set once-and-for-all so doesn't need to be thread-ized */
+static floatvec *gfitv= NULL ;
 static int    do_fitv = 0 ;    /* if 1, will compute fitts into fitv */
 void       THD_fitter_do_fitts(int qq){ do_fitv = qq; }
+floatvec * THD_retrieve_fitts(void){ return gfitv; }
 
-AO_DEFINE_SCALAR(floatvec*,gfitv) ;
-#if 0
-static floatvec *gfitv= NULL ;
-#endif
+static int       nggfitvv = 0 ;
+static floatvec **ggfitvv = NULL ;
 
-/* get the fitted time series vector (immediately after getting params) */
-floatvec * THD_retrieve_fitts(void){ return AO_VALUE(gfitv); }
-
-/* these variables are set once-and-for-all so don't need to be thread-ized */
 static int use_rcmat = 0 ;
 
 static float vthresh = 0.0f ;             /* 18 May 2010: vector threshold */
@@ -89,7 +82,7 @@ void THD_fitter_set_vthresh( float vvv ){
                        ccon[i] = 0 == no constraint
                                > 0 == coef #i must be >= 0
                                < 0 == coef #i must be <= 0
-    - Output is vector of coefficients (nref of them).
+    - Output is vector of coefficiens (nref of them).
     - Output is NULL if some error transpired.
 *//*----------------------------------------------------------------*/
 
@@ -104,7 +97,7 @@ floatvec * THD_fitter( int npt , float *far  ,
 
 ENTRY("THD_fitter") ;
 
-   KILL_floatvec(AO_VALUE(gfitv)) ;  /* 05 Mar 2008 */
+   KILL_floatvec(gfitv) ;  /* 05 Mar 2008 */
 
    /* check inputs for stupid users */
 
@@ -211,8 +204,8 @@ ENTRY("THD_fitter") ;
    MAKE_floatvec(fv,nref) ;                      /* copy output array */
    memcpy( fv->ar, qfit, sizeof(float)*nref ) ;  /* into floatvec and */
    free(qfit) ;                                  /* free the trashola */
-   if( do_fitv )                                              /* compute fitts? */
-     AO_VALUE(gfitv) = THD_fitter_fitts( npt,fv,nref,ref,NULL ); /* 05 Mar 2008 */
+   if( do_fitv )                                    /* compute fitts? */
+     gfitv = THD_fitter_fitts( npt,fv,nref,ref,NULL ); /* 05 Mar 2008 */
 
    free(qmag) ; RETURN(fv) ;                      /* return to caller */
 }
@@ -255,15 +248,6 @@ ENTRY("THD_fitter_fitts") ;
 # define ERREX(s) RETURN(NULL)
 #endif
 
-/* these fitted time series vectors are for deconvolution */
-
-AO_DEFINE_SCALAR(int,nggfitvv) ;
-AO_DEFINE_SCALAR(floatvec**,ggfitvv) ;
-#if 0
-static int       nggfitvv = 0 ;
-static floatvec **ggfitvv = NULL ;
-#endif
-
 /*------------------------------------------------------------------------*/
 /* Fit a deconvolution model, using THD_fitter() as the workhorse.
     - npt    = length of time series
@@ -306,11 +290,9 @@ floatvec ** THD_deconvolve_multipen( int npt    , float *far   ,
 
 ENTRY("THD_deconvolve_multipen") ;
 
-   /* delete any leftover junk */
-
-   if( AO_VALUE(nggfitvv) > 0 ){
-     for( ii=0 ; ii < AO_VALUE(nggfitvv) ; ii++ ) KILL_floatvec(AO_VALUE(ggfitvv)[ii]) ;
-     free((void *)AO_VALUE(ggfitvv)) ; AO_VALUE(nggfitvv) = 0 ; AO_VALUE(ggfitvv) = NULL ;
+   if( nggfitvv > 0 ){
+     for( ii=0 ; ii < nggfitvv ; ii++ ) KILL_floatvec(ggfitvv[ii]) ;
+     free((void *)ggfitvv) ; nggfitvv = 0 ; ggfitvv = NULL ;
    }
 
    /* check inputs for stupid users */
@@ -439,11 +421,9 @@ STATUS("make up penalty factors") ;
 
    fvv = (floatvec **)calloc(sizeof(floatvec *),npfac) ;
 
-   /* allocate space for multiple fit vectors, for multiple penalty factors */
-
    if( do_fitv ){
-      AO_VALUE(ggfitvv) = (floatvec **)calloc(sizeof(floatvec *),npfac) ;
-     AO_VALUE(nggfitvv) = npfac ;
+      ggfitvv = (floatvec **)calloc(sizeof(floatvec *),npfac) ;
+     nggfitvv = npfac ;
    }
 
    p1scl = AFNI_numenv("AFNI_TFITTER_P1SCALE"); if( p1scl <= 0.0f ) p1scl=1.0f ;
@@ -492,11 +472,9 @@ STATUS(" setup p3") ;
 
      fvv[ipf] = THD_fitter( nplu , zar , nref , ref , meth , zcon ) ;
 
-     /* fvv = fitted params; gfitv = fitted time series */
-
-     if( do_fitv && fvv[ipf] != NULL && AO_VALUE(gfitv) != NULL ){
+     if( do_fitv && fvv[ipf] != NULL && gfitv != NULL ){
 STATUS("copy fitvec") ;
-       COPY_floatvec( AO_VALUE(ggfitvv)[ipf] , AO_VALUE(gfitv) ) ;
+       COPY_floatvec( ggfitvv[ipf] , gfitv ) ;
 STATUS(" end copy fitvec") ;
      }
 
@@ -645,7 +623,7 @@ ENTRY("THD_deconvolve_autopen") ;
    if( fvv == NULL ){
      ERROR_message(
        "THD_deconvolve_autopen failed to solve initial problems: voxel ID=%d",
-       AO_VALUE(voxid) ) ;
+       voxid ) ;
      RETURN(NULL) ;
    }
 
@@ -683,11 +661,11 @@ ENTRY("THD_deconvolve_autopen") ;
      free((void *)fvv) ;
      ERROR_message(
        "THD_deconvolve_autopen fails to find initial good fit: voxel ID=%d",
-       AO_VALUE(voxid));
+       voxid);
      RETURN(NULL) ;
    }
 
-   fv = fvv[ipk] ; if( do_fitv ){ COPY_floatvec(gv,AO_VALUE(ggfitvv)[ipk]); }
+   fv = fvv[ipk] ; if( do_fitv ){ COPY_floatvec(gv,ggfitvv[ipk]); }
    for( ii=0 ; ii < NPFAC ; ii++ ) if( ii != ipk ) KILL_floatvec(fvv[ii]) ;
    free((void *)fvv) ;
    if( penfac_used != NULL ) *penfac_used = pfac[ipk] ;
@@ -709,8 +687,8 @@ ENTRY("THD_deconvolve_autopen") ;
                                   pencode , NPFAC , pfac , pres,psiz ) ;
 
    if( fvv == NULL ){  /* failed ==> return what we found earlier */
-     ERROR_message("THD_deconvolve_autopen semi-failed: voxel ID=%d",AO_VALUE(voxid)) ;
-     if( do_fitv ){ KILL_floatvec(AO_VALUE(gfitv)); AO_VALUE(gfitv) = gv; }
+     ERROR_message("THD_deconvolve_autopen semi-failed: voxel ID=%d",voxid) ;
+     if( do_fitv ){ KILL_floatvec(gfitv); gfitv = gv; }
      RETURN(fv) ;
    }
 
@@ -744,13 +722,13 @@ ENTRY("THD_deconvolve_autopen") ;
    if( ipk < 0 || ppk == 0.0f ){ /* all failed?  use old result */
      for( ii=0 ; ii < NPFAC ; ii++ ) KILL_floatvec(fvv[ii]) ;
      free((void *)fvv) ;
-     ERROR_message("THD_deconvolve_autopen semi-fails: voxel ID=%d",AO_VALUE(voxid)) ;
-     if( do_fitv ){ KILL_floatvec(AO_VALUE(gfitv)); AO_VALUE(gfitv) = gv; }
+     ERROR_message("THD_deconvolve_autopen semi-fails: voxel ID=%d",voxid) ;
+     if( do_fitv ){ KILL_floatvec(gfitv); gfitv = gv; }
      RETURN(fv) ;
    }
 
    KILL_floatvec(fv) ; fv = fvv[ipk] ;
-   if( do_fitv ){ KILL_floatvec(gv); COPY_floatvec(gv,AO_VALUE(ggfitvv)[ipk]); }
+   if( do_fitv ){ KILL_floatvec(gv); COPY_floatvec(gv,ggfitvv[ipk]); }
    for( ii=0 ; ii < NPFAC ; ii++ ) if( ii != ipk ) KILL_floatvec(fvv[ii]) ;
    free((void *)fvv) ;
    if( penfac_used != NULL ) *penfac_used = pfac[ipk] ;
@@ -759,6 +737,6 @@ ENTRY("THD_deconvolve_autopen") ;
      ININFO_message("Optimal penfac_used#%d = %g",ipk,pfac[ipk]) ;
 #endif
 
-   if( do_fitv ){ KILL_floatvec(AO_VALUE(gfitv)); AO_VALUE(gfitv) = gv; }
+   if( do_fitv ){ KILL_floatvec(gfitv); gfitv = gv; }
    RETURN(fv) ;
 }
