@@ -5,7 +5,7 @@
  *
  * THD_3dim_dataset * THD_open_gifti (char *fname)
  * THD_3dim_dataset * THD_load_gifti (THD_datablock *dblk)
- * RwcBoolean            THD_write_gifti( THD_3dim_dataset *dset, 
+ * Boolean            THD_write_gifti( THD_3dim_dataset *dset, 
                                        int write_data, int forcencode)
  *
  * NI_group         * NI_read_gifti (char *fname, int read_data)
@@ -26,7 +26,7 @@ typedef struct {        /* put this in thd_gifti.h ? */
     int verb;
 } gifti_globs_t;
 
-gifti_globs_t gifti_globs = { 0, NI_BINARY_MODE, 1, 1, 1 };
+gifti_globs_t gifti_globs = { 0, NI_BINARY_MODE, 1, 1 };
 static gifti_globs_t * GP = &gifti_globs; /* for ease of access */
 
 /*--- read gifti routines ---*/
@@ -141,7 +141,7 @@ int THD_load_gifti(THD_datablock * dblk)
     RETURN(0);
 }
 
-RwcBoolean THD_write_gifti(THD_3dim_dataset * dset, int write_data, int forcencode)
+Boolean THD_write_gifti(THD_3dim_dataset * dset, int write_data, int forcencode)
 {
     NI_group * ngr;
     char     * prefix;
@@ -152,8 +152,7 @@ RwcBoolean THD_write_gifti(THD_3dim_dataset * dset, int write_data, int forcenco
     gifti_globs_from_env();     /* for thd_gifti */
     set_ni_globs_from_env();    /* for thd_niml */
 
-    /* HEADNAME should be path + prefix   [5 Feb 2024 rickr] */
-    prefix = DSET_HEADNAME(dset);
+    prefix = DSET_PREFIX(dset);
 
     if( !prefix ) {
         if( GP->verb ) fprintf(stderr,"** THD_write_gifti: no dset prefix\n");
@@ -597,13 +596,9 @@ static int nsdg_add_index_list(NI_group *ngr, gifti_image *gim)
     /* okay, let's actually add the list as NIFTI_INTENT_NODE_INDEX */
     if( GP->verb > 3 ) fprintf(stderr,"++ inserting NODE_INDEX element...\n");
 
-    /* append a new element and grab the pointer */
     if( gifti_add_empty_darray(gim, 1) ) RETURN(1);
-    da = gim->darray[gim->numDA-1];
 
-    /* INDEX_LIST should be first DA, according to standard, so move new one */
-    /* (brought up by Nick Oosterhof)                    24 Jul 2015 [rickr] */
-    gifti_rotate_DAs_to_front(gim, 1);
+    da = gim->darray[gim->numDA-1];
 
     gifti_set_DA_defaults(da);
     da->intent   = NIFTI_INTENT_NODE_INDEX;
@@ -811,14 +806,6 @@ static NI_group * gifti_to_NSD(gifti_image * gim, int copy_data)
     cp = gifti_get_meta_value(&gim->meta, "filename");
     if( cp ) NI_set_attribute(ngr, "filename", cp);
 
-    /* DA-type processing follows, so handle any INDEX_LIST now
-
-       SPARSE_DATA and related attributes (e.g. COLMS_TYPE) should not
-       be affected by or include information pertaining to INDEX_LIST,
-       so any such DA well be removed from gim.
-    */
-    nsd_add_gifti_index_list(ngr, gim);
-
     /* add COLMS_LABS from "Name" MetaData values */
     cp = gifti_DA_meta_concat(gim, "Name", "none", ";");
     add_string_attribute(ngr, "COLMS_LABS", cp);
@@ -833,6 +820,8 @@ static NI_group * gifti_to_NSD(gifti_image * gim, int copy_data)
 
     if( haslt ) gnsd_add_gifti_labeltable(ngr, gim); /* if LT, add it */
 
+    nsd_add_gifti_index_list(ngr, gim);
+
     gnsd_add_sparse_data(ngr, gim, copy_data);
 
     RETURN(ngr);
@@ -1135,37 +1124,19 @@ static int has_negatives(void *data, long long nvals, int type)
     RETURN(0);
 }
 
-/* add an INDEX_LIST attribute element from the gifti_image
- * side effect: remove that DA from gim->darray (numDA--)  21 Aug 2019 [rickr]
-*/
+/* add an INDEX_LIST attribute element from the gifti_image */
 static int nsd_add_gifti_index_list(NI_group * ngr, gifti_image * gim)
 {
     NI_element   * nel;
     giiDataArray * da;
     int          * node_list, * new_list = NULL;
-    int            c, da_ind, length;
+    int            c, length;
 
     ENTRY("nsd_add_gifti_index_list");
 
     if( !ngr || !gim || !gim->darray ) RETURN(1);
 
-    /* set da and da_ind (was gifti_find_DA(gim,NI,0)) */
-    da = NULL;
-    da_ind = -1;
-    for( c = 0; c < gim->numDA; c++ ) {
-        if( gim->darray[c]->intent == NIFTI_INTENT_NODE_INDEX ) {
-           da = gim->darray[c];
-           da_ind = c;
-        }
-    }
-
-    /* if found, remove da from gim->darray    21 Aug 2019 [rickr] */
-    if( da ) {
-       for( c = da_ind+1; c < gim->numDA; c++ )
-          gim->darray[c-1] = gim->darray[c];
-       gim->numDA--;
-    }
-    
+    da = gifti_find_DA(gim, NIFTI_INTENT_NODE_INDEX, 0);
     if( GP->verb > 2 )
         fprintf(stderr,"-- add_index_list: %s N_INTENT_NODE_INDEX\n",
                 da ? "found" : "did not find");
@@ -1356,14 +1327,13 @@ static int nsd_add_gifti_colms_type(NI_group * ngr, gifti_image * gim)
 static char * nifti2suma_typestring(int niftitype)
 {
     switch(niftitype) {
-        case DT_NONE:              return "Col_Type_Undefined";
-        case NIFTI_TYPE_INT8:      return "Generic_Byte";
-        case NIFTI_TYPE_INT16:     return "Generic_Short";
-        case NIFTI_TYPE_INT32:     return "Generic_Int";
-        case NIFTI_TYPE_UINT32:    return "Generic_Int";/* pretend, 5 Mar 2010 */
-        case NIFTI_TYPE_FLOAT32:   return "Generic_Float";
-        case NIFTI_TYPE_COMPLEX64: return "Generic_Complex";
-        case NIFTI_TYPE_FLOAT64:   return "Generic_Double";
+        case DT_NONE:            return "Col_Type_Undefined";
+        case NIFTI_TYPE_INT8:    return "Generic_Byte";
+        case NIFTI_TYPE_INT16:   return "Generic_Short";
+        case NIFTI_TYPE_INT32:   return "Generic_Int";
+        case NIFTI_TYPE_UINT32:  return "Generic_Int"; /* pretend, 5 Mar 2010 */
+        case NIFTI_TYPE_FLOAT32: return "Generic_Float";
+        case NIFTI_TYPE_FLOAT64: return "Generic_Double";
     }
 
     return NULL;  /* bad idea? */
@@ -1422,19 +1392,6 @@ static int nsd_add_gifti_colms_range(NI_group * ngr, gifti_image * gim)
                 if(data[eye]<min){ min=data[eye]; minp=eye; }           \
                 else if(data[eye]>max){ max=data[eye]; maxp=eye; }      \
         } while (0)
-#undef NOTYPE_GETC_MIN_MAX_POSN
-#define NOTYPE_GETC_MIN_MAX_POSN(data,len,min,minp,max,maxp,phase)      \
-        do { int ii; double dd;                                         \
-             if (phase)  min=max=CARG(data[0]);                         \
-             else   min=max=CABS(data[0]);                              \
-             minp=maxp=0;                                               \
-             for(ii = 1; ii < len; ii++){                               \
-                if (phase)  dd=CARG(data[ii]);                          \
-                else   dd=CABS(data[ii]);                               \
-                if(dd<min){ min=dd; minp=ii; }                          \
-                else if(dd>max){ max=dd; maxp=ii; }                     \
-             }                                                          \
-        } while (0)
 
 /* get min and max values (as float), along with their indices
    (reqiure NIFTI_TYPE datatype)
@@ -1519,14 +1476,6 @@ static int nifti_get_min_max_posn(void * vdata, int nitype, int len,
             *imin = minp; *imax = maxp;
             break;
         }
-        case NIFTI_TYPE_COMPLEX64: {
-            complex * data = (complex *)vdata;
-            double   min, max;
-            NOTYPE_GETC_MIN_MAX_POSN(data, len, min, minp, max, maxp, 0);
-            *dmin = (double)min;  *dmax = (double)max;
-            *imin = minp; *imax = maxp;
-            break;
-        }
     }
 
     if( GP->verb > 5 )
@@ -1537,7 +1486,7 @@ static int nifti_get_min_max_posn(void * vdata, int nitype, int len,
 }
 
 /* append 2 floats and ints to str, subject to total length, len,
-   and prepended with sep */
+   and pre-pended with sep */
 static int append_vals(char ** str, int * len, char * sep,
                            float f1, float f2, int i1, int i2)
 {
@@ -1663,7 +1612,7 @@ static int gifti_has_NSD_form(gifti_image * gim, int whine)
     return 1;
 }
 
-/* find all DA meta data of the given name, and concat using separator sep
+/* find all DA meta data of the given name, and concat using separater sep
  *
  * if 'name' is not found, use 'defval'
  * if 'sep' is set, separate values with that string
