@@ -15,15 +15,15 @@
                  datasets are in one array (no anat/func distinction).
 -----------------------------------------------------------------------*/
 
-THD_session * THD_init_session( char *sessname )
+THD_session * THD_init_session( char * sessname )
 {
    THD_session            *sess ;
-   RwcPointer_array        *dblk_arrarr ;
+   XtPointer_array        *dblk_arrarr ;
    THD_datablock_array    *dblk_arr ;
    THD_3dim_dataset       *dset=NULL , *temp_dset;
    THD_3dim_dataset_array *dset_arr ;
 
-   int ibar , idset , iview  , nds , qview=-666 ;
+   int ibar , idset , iview  , nds ;
 
 ENTRY("THD_init_session") ;
 
@@ -34,7 +34,7 @@ ENTRY("THD_init_session") ;
 
    /*-- initialize session --*/
 
-   sess         = myRwcNew( THD_session ) ;
+   sess         = myXtNew( THD_session ) ;
    sess->type   = SESSION_TYPE ;
    sess->parent = NULL ;
 #ifdef DEBUG_SESSIONS
@@ -55,7 +55,7 @@ fprintf(stderr, "blanking session\n");
 
    /* save last name from sessname */
 #if 1
-   { char *env = my_getenv( "AFNI_SESSTRAIL" ) ; int tt = 0 ;
+   { char * env = my_getenv( "AFNI_SESSTRAIL" ) ; int tt = 0 ;
      if( env != NULL ) tt = strtol(env,NULL,10) ;
      env = THD_trailname(sess->sessname,tt) ;
      tt = 1+strlen(env) - THD_MAX_NAME ; if( tt < 0 ) tt = 0 ;
@@ -67,17 +67,6 @@ fprintf(stderr, "blanking session\n");
      MCW_strncpy( sess->lastname, &(sess->sessname[iview+1]), THD_MAX_NAME ) ;
 #endif
 
-   /*-- override dataset 'view'??  [30 May 2013] --*/
-
-   { char *env = my_getenv("AFNI_OVERRIDE_VIEW") ;
-     if( env != NULL ){
-            if( toupper(*env) == 'T' ) qview = VIEW_TALAIRACH_TYPE ;
-       else if( toupper(*env) == 'O' ) qview = VIEW_ORIGINAL_TYPE  ;
-       else
-         WARNING_message("AFNI_OVERRIDE_VIEW=%s is not understood",env) ;
-     }
-   }
-
    /*-- read all datablocks --*/
 
    dblk_arrarr = THD_init_alldir_datablocks( sess->sessname ) ;
@@ -115,9 +104,8 @@ fprintf(stderr, "blanking session\n");
       for( idset=0 ; idset < dset_arr->num ; idset++ ){
         dset  = dset_arr->ar[idset] ;
         iview = dset->view_type ;
-        if( qview >= 0 ) iview = qview ;  /* 30 May 2013 */
-
-        if( GET_SESSION_DSET(sess,nds,iview) != NULL ){  /* should never happen */
+        
+        if( GET_SESSION_DSET(sess, nds, iview) != NULL ){  /* should never happen */
           fprintf(stderr,
            "\n*** Session %s has duplicate dataset views of %s ***\n",
            sessname , dset->self_name) ;
@@ -127,6 +115,7 @@ fprintf(stderr, "blanking session\n");
 fprintf(stderr,"\nputting datasets into initial view \n");
 #endif
           SET_SESSION_DSET(dset, sess, nds, iview);  /* should always happen */
+/*        sess->dsset_xform_table[nds][iview] = dset ; */  /* should always happen */
         }
       }
 
@@ -146,6 +135,40 @@ fprintf(stderr,"\nputting datasets into initial view \n");
    }
    FREE_XTARR( dblk_arrarr ) ;
 
+   /*-- 29 Oct 2001: try to read .mnc "datasets" --*/
+
+   if( !AFNI_noenv("AFNI_MINC_DATASETS") ){
+     char ename[THD_MAX_NAME] , **fn_minc , *eee ;
+     int num_minc , ii ;
+
+     STATUS("looking for MINC files") ;
+
+     strcpy(ename,sess->sessname) ; strcat(ename,"*.mnc") ;
+     eee = ename ;
+     MCW_file_expand( 1,&eee , &num_minc,&fn_minc ) ;  /* find files */
+
+     if( num_minc > 0 ){                               /* got some! */
+       STATUS("opening MINC files") ;
+       for( ii=0 ; ii < num_minc ; ii++ ){             /* loop over files */
+         dset = THD_open_minc( fn_minc[ii] ) ;         /* try it on */
+         if( !ISVALID_DSET(dset) ) continue ;          /* doesn't fit? */
+         nds = sess->num_dsset ;
+         if( nds >= THD_MAX_SESSION_SIZE ){
+           fprintf(stderr,
+             "\n*** Session %s table overflow with MINC dataset %s ***\n",
+             sessname , fn_minc[ii] ) ;
+           THD_delete_3dim_dataset( dset , False ) ;
+           break ; /* out of for loop */
+         }
+         iview = dset->view_type ;
+         SET_SESSION_DSET(dset, sess, nds, iview);
+/*         sess->dsset_xform_table[nds][iview] = dset ;*/
+         sess->num_dsset ++ ;
+       } /* end of loop over files */
+       MCW_free_expand( num_minc , fn_minc ) ;
+     } /* end of if we found MINC files */
+   }
+
    /*-- 06 Apr 2005: try to read NIfTI-1 files [KRH and RWC] --*/
 
    if( !AFNI_noenv("AFNI_NIFTI_DATASETS") ){
@@ -175,7 +198,8 @@ fprintf(stderr,"\nputting datasets into initial view \n");
            break ; /* out of for loop */
          }
          iview = dset->view_type ;
-         SET_SESSION_DSET(dset, sess, nds, iview);
+         SET_SESSION_DSET(dset, sess, nds, iview); 
+/*         sess->dsset_xform_table[nds][iview] = dset ;*/
          sess->num_dsset ++ ;
        } /* end of loop over files */
        MCW_free_expand( num_nifti , fn_nifti ) ;
@@ -220,6 +244,7 @@ fprintf(stderr,"\nputting datasets into initial view \n");
         }
         iview = dset->view_type ;
         SET_SESSION_DSET(dset, sess, nds, iview);
+/*      sess->dsset_xform_table[nds][iview] = dset ; */
         sess->num_dsset ++ ;
 #ifdef ALLOW_FSL_FEAT
              if( strcmp(DSET_PREFIX(dset),"example_func.hdr") == 0 ) feat_exf = nds;
@@ -373,7 +398,7 @@ printf("warp_exf_std BEFORE:") ; DUMP_LMAP(warp_exf_std->rig_bod.warp) ;
                to_std = AFNI_make_affwarp_mat( nnn ) ;
                AFNI_concatenate_warp( warp_exf_std , from_exf ) ;
                AFNI_concatenate_warp( to_std , warp_exf_std ) ;
-               myRwcFree(warp_exf_std) ; myRwcFree(from_exf) ;
+               myXtFree(warp_exf_std) ; myXtFree(from_exf) ;
                warp_exf_std = to_std ;
 
 #if 0
@@ -416,7 +441,7 @@ printf("warp_exf_hrs BEFORE:") ; DUMP_LMAP(warp_exf_hrs->rig_bod.warp) ;
              to_hrs = AFNI_make_affwarp_mat( nnn ) ;
              AFNI_concatenate_warp( warp_exf_hrs , from_exf ) ;
              AFNI_concatenate_warp( to_hrs , warp_exf_hrs ) ;
-             myRwcFree(warp_exf_hrs) ; myRwcFree(from_exf) ;
+             myXtFree(warp_exf_hrs) ; myXtFree(from_exf) ;
              warp_exf_hrs = to_hrs ;
 
 #if 0
@@ -457,7 +482,7 @@ printf("warp_std_hrs BEFORE:") ; DUMP_LMAP(warp_std_hrs->rig_bod.warp) ;
              to_hrs = AFNI_make_affwarp_mat( nnn ) ;
              AFNI_concatenate_warp( warp_std_hrs , from_std ) ;
              AFNI_concatenate_warp( to_hrs , warp_std_hrs ) ;
-             myRwcFree(warp_std_hrs) ; myRwcFree(from_std) ;
+             myXtFree(warp_std_hrs) ; myXtFree(from_std) ;
              warp_std_hrs = to_hrs ;
 
 #if 0
@@ -564,63 +589,22 @@ printf("warp_std_hrs AFTER:") ; DUMP_LMAP(warp_std_hrs->rig_bod.warp) ;
          }
          iview = dset->view_type ;
          SET_SESSION_DSET(dset, sess, nds, iview);
+/*         sess->dsset_xform_table[nds][iview] = dset ;*/
          sess->num_dsset ++ ;
        } /* end of loop over files */
        MCW_free_expand( num_ctf , fn_ctf ) ;
      } /* end of if we found CTF files */
    }
 
-   /*-- 02 Feb 2018: try to read .jpg and .png "datasets" --*/
-
-   if( !AFNI_noenv("AFNI_IMAGE_DATASETS") ){
-     char *ename[4] , **fn_img ;
-     int num_img , ii ;
-
-     STATUS("looking for JPG/PNG files") ;
-
-     ename[0] = AFMALL(char, THD_MAX_NAME) ;
-     ename[1] = AFMALL(char, THD_MAX_NAME) ;
-     ename[2] = AFMALL(char, THD_MAX_NAME) ;
-     ename[3] = AFMALL(char, THD_MAX_NAME) ;
-     strcpy(ename[0],sess->sessname) ; strcat(ename[0],"*.png") ;
-     strcpy(ename[1],sess->sessname) ; strcat(ename[1],"*.PNG") ;
-     strcpy(ename[2],sess->sessname) ; strcat(ename[2],"*.jpg") ;
-     strcpy(ename[3],sess->sessname) ; strcat(ename[3],"*.JPG") ;
-     MCW_file_expand( 4,ename , &num_img,&fn_img ) ;  /* find files */
-     free(ename[0]) ; free(ename[1]) ; free(ename[2]) ; free(ename[3]) ;
-
-     if( num_img > 0 ){                               /* got some files! */
-       STATUS("opening JPG/PNG files") ;
-       for( ii=0 ; ii < num_img ; ii++ ){             /* loop over files */
-
-         dset = THD_open_image( fn_img[ii] ) ;        /* try top read */
-
-         if( !ISVALID_DSET(dset) ) continue ;         /* doesn't read? */
-         nds = sess->num_dsset ;
-         if( nds >= THD_MAX_SESSION_SIZE ){
-           fprintf(stderr,
-            "\n*** Session %s table overflow with dataset %s ***\n",
-            sessname , fn_img[ii] ) ;
-           THD_delete_3dim_dataset( dset , False ) ;
-           break ; /* out of for(ii) loop */
-         }
-         iview = dset->view_type ;
-         SET_SESSION_DSET(dset, sess, nds, iview);
-         sess->num_dsset ++ ;
-       } /* end of loop over files */
-       MCW_free_expand( num_img , fn_img ) ;
-     } /* end of if we found JPG/PNG files */
-   }
-
    /*-- 03 Dec 2001: try to read MPEG "datasets" --*/
 
-   if( AFNI_yesenv("AFNI_MPEG_DATASETS") ){
+   if( !AFNI_noenv("AFNI_MPEG_DATASETS") ){
      char ename[4*THD_MAX_NAME+64] , **fn_mpeg ;
      int num_mpeg , ii ;
 
      STATUS("looking for MPEG files") ;
 
-     sprintf(ename,"%s*.mpg %s*.mpeg %s*.MPEG %s*.MPG" ,
+     sprintf(ename,"%s*.mpg %s*.mpeg %s*.MPEG %s*.MPG" , 
              sess->sessname, sess->sessname, sess->sessname, sess->sessname ) ;
      MCW_wildcards( ename , &num_mpeg , &fn_mpeg ) ;   /* find files */
 
@@ -639,6 +623,7 @@ printf("warp_std_hrs AFTER:") ; DUMP_LMAP(warp_std_hrs->rig_bod.warp) ;
          }
          iview = dset->view_type ;
          SET_SESSION_DSET(dset, sess, nds, iview);
+/*         sess->dsset_xform_table[nds][iview] = dset ;*/
          sess->num_dsset ++ ;
        } /* end of loop over files */
        MCW_free_expand( num_mpeg , fn_mpeg ) ;
@@ -648,7 +633,7 @@ printf("warp_std_hrs AFTER:") ; DUMP_LMAP(warp_std_hrs->rig_bod.warp) ;
    /*-- done! --*/
 
    if( sess->num_dsset == 0 ){
-      myRwcFree( sess ) ; RETURN( NULL ) ;
+      myXtFree( sess ) ; RETURN( NULL ) ;
    }
 
    /*-- 29 Jul 2003: order dataset rows --*/
@@ -665,7 +650,7 @@ printf("warp_std_hrs AFTER:") ; DUMP_LMAP(warp_std_hrs->rig_bod.warp) ;
 void THD_order_session( THD_session *sess )
 {
    THD_3dim_dataset *qset[THD_MAX_SESSION_SIZE][LAST_VIEW_TYPE+1] ;
-   THD_3dim_dataset *dset=NULL ;
+   THD_3dim_dataset *dset ;
    int iview , ids , nds ;
 
 ENTRY("THD_order_session") ;
@@ -694,16 +679,8 @@ ENTRY("THD_order_session") ;
      for( iview=0 ; iview <= LAST_VIEW_TYPE ; iview++ ){
        dset = GET_SESSION_DSET(sess, ids, iview);
 /*     dset = sess->dsset_xform_table[ids][iview] ;*/
-       /* if( dset != NULL && ISFUNC(dset) ) break ; */
-       if( dset ) break ;
+       if( dset != NULL && ISFUNC(dset) ) break ;
      }
-
-     /* might be ANAT in one view and FUNC in another (consider qsort()?)
-      *                                        17 Nov 2011 [rickr, dglen] */
-     if( ! dset )            continue;
-     else if( ISANAT(dset) ) continue;   /* already found above */
-     /* else, add ... */
-
      if( iview <= LAST_VIEW_TYPE ){
        for( iview=0 ; iview <= LAST_VIEW_TYPE ; iview++ )
           qset[nds][iview] = GET_SESSION_DSET(sess, ids, iview);
@@ -716,216 +693,8 @@ ENTRY("THD_order_session") ;
 
    for( ids=0 ; ids < nds ; ids++ )
      for( iview=0 ; iview <= LAST_VIEW_TYPE ; iview++ )
+/*       sess->dsset_xform_table[ids][iview] = qset[ids][iview] ;*/
         SET_SESSION_DSET(qset[ids][iview], sess, ids, iview);
    sess->num_dsset = nds ;  /* shouldn't change */
    EXRETURN ;
 }
-
-/*---------------------------------------------------------------------*/
-/*! Append datasets in THD_session ssb to those in ssa.
-    \date 20 Dec 2001
-*/
-
-void THD_append_sessions( THD_session *ssa , THD_session *ssb )
-{
-   int qs, qd, vv ;
-   THD_3dim_dataset *temp_dset;
-
-ENTRY("THD_append_sessions") ;
-
-   if( !ISVALID_SESSION(ssa) || !ISVALID_SESSION(ssb)  ) EXRETURN ;
-   if( THD_equiv_files(ssa->sessname,ssb->sessname)==1 ) EXRETURN ;
-
-   qs = ssa->num_dsset ;
-   for( qd=0; qd < ssb->num_dsset && qd+qs < THD_MAX_SESSION_SIZE ; qd++ )
-     for( vv=0 ; vv <= LAST_VIEW_TYPE ; vv++ ) {
-       temp_dset = GET_SESSION_DSET(ssb, qd, vv);
-       SET_SESSION_DSET(temp_dset, ssa,qd+qs,vv);
-     }
-   ssa->num_dsset += qd ;
-
-   EXRETURN ;
-}
-
-/*---------------------------------------------------------------------*/
-/* read from the pipe into 1 big string [01 Feb 2018] */
-
-#undef  PSIZ
-#define PSIZ 8192
-
-char * THD_suck_pipe( char *cmd )
-{
-   char *flist=NULL ; FILE *fp=NULL ;
-
-   if( cmd == NULL || *cmd == '\0' ) return NULL ;
-
-   fp = popen( cmd , "r" ) ;
-   if( fp == NULL ){
-     ERROR_message("Unable to pipe command '%s'",cmd) ;
-     return NULL ;
-   }
-
-   flist = (char *)malloc(sizeof(char)*PSIZ) ; flist[0] = '\0' ;
-   while( fgets(flist+strlen(flist),PSIZ-2,fp) != NULL ){
-     flist = (char *)realloc(flist,sizeof(char)*(strlen(flist)+PSIZ)) ;
-   }
-
-   (void)pclose(fp) ;
-   if( *flist == '\0' ){ free(flist); flist=NULL; }
-
-   return flist ;
-}
-
-/*---------------------------------------------------------------------*/
-/* Find all sub-directories with BIDS name form sub-XXX [01 Feb 2018] */
-
-NI_str_array * THD_get_subdirs_bysub( char *dirname , char *subid )
-{
-   NI_str_array *qsar=NULL ;
-   char *cmd , *flist , *newsubid=NULL ; FILE *fp ;
-
-ENTRY("THD_get_subdirs_bysub") ;
-
-   if( ! THD_is_directory(dirname) || subid == NULL || strlen(subid) < 2 )
-     RETURN(NULL) ;
-
-   if( strncmp(subid,"sub-",4) != 0 ){
-     newsubid = (char *)malloc(sizeof(char)*(8+strlen(subid))) ;
-     sprintf(newsubid,"sub-%s",subid) ;
-   } else {
-     newsubid = strdup(subid) ;
-   }
-
-   /* get dirnames via piping from find */
-
-   cmd = (char *)malloc(sizeof(char)*(128+strlen(dirname)+strlen(newsubid))) ;
-   sprintf( cmd, "find %s -maxdepth 9 -type d -name '%s'", dirname , newsubid ) ;
-
-   flist = THD_suck_pipe( cmd ) ;
-
-   if( flist == NULL || strlen(flist) < 4 ){
-#if 0
-     ERROR_message("-bysub: Didn't find any '%s' under %s",newsubid,dirname) ;
-#endif
-     free(newsubid) ; free(cmd) ;
-     if( flist != NULL ) free(flist) ;
-     RETURN(NULL) ;
-   }
-
-   /* break output into discrete strings */
-
-   qsar = NI_decode_string_list( flist , ";" ) ;
-   if( qsar == NULL || qsar->num == 0 ){    /* should never happen */
-     ERROR_message("-bysub: Unable to decode output from command \"%s\"",cmd) ;
-     free(newsubid) ; free(cmd) ; free(flist) ; RETURN(NULL) ;
-   }
-
-#if 0
-  { int qq ;
-    INFO_message("-bysub: Found %d '%s' under %s",qsar->num,newsubid,dirname) ;
-    for( qq=0 ; qq < qsar->num ; qq++ ) ININFO_message(" %s",qsar->str[qq]) ;
-  }
-#endif
-
-   free(newsubid) ; free(cmd) ; free(flist) ; RETURN(qsar) ;
-}
-
-/*---------------------------------------------------------------------*/
-/* A recursive form of THD_init_session() [01 Feb 2018] */
-
-THD_session * THD_init_session_recursive( char *dirname )
-{
-   NI_str_array *qsar ;
-   THD_session *sess=NULL , *qss ;
-   char *cmd , *flist ;
-   int qq , nss=0 ;
-ENTRY("THD_init_session_recursive") ;
-
-   if( dirname == NULL || *dirname == '\0' ) RETURN(NULL) ;
-
-   /* get list of all subdir names */
-
-   cmd = (char *)malloc(sizeof(char)*(strlen(dirname)+128)) ;
-   /* [PT: 18 Apr 2022] bug fix for this command, would not work as it
-      was previously (see below); might still need help/changing? */
-   sprintf( cmd, "find %s -maxdepth 9 -type d", dirname );
-   //sprintf( cmd, "find %s -type d -depth -9", dirname) ;
-   flist = THD_suck_pipe( cmd ) ;
-   if( flist == NULL || strlen(flist) < 1 ) RETURN(NULL) ;
-
-   /* break output into discrete strings */
-
-   qsar = NI_decode_string_list( flist , ";" ) ;
-   free(flist) ;
-   if( qsar == NULL || qsar->num == 0 ){    /* should never happen */
-     ERROR_message("Unable to decode output from command \"%s\"",cmd) ;
-     free(cmd) ; RETURN(NULL) ;
-   }
-
-   /* try to read each subdir as a session by itself */
-
-   for( qq=0 ; qq < qsar->num ; qq++ ){
-     if( qsar->str[qq] != NULL && qsar->str[qq][0] != '\0' ){
-       qss = THD_init_session( qsar->str[qq] ) ;
-       if( qss != NULL ){    /* got something */
-         if( sess == NULL ){ /* the first something */
-           sess = qss ;
-         } else {            /* a later something */
-           THD_append_sessions( sess , qss ) ;
-         }
-         nss++ ;
-       }
-     }
-   }
-
-   if( nss > 1 ){
-     THD_order_session( sess ) ;
-     sess->is_collection = 1 ;
-   }
-
-   free(cmd) ;
-   RETURN(sess) ;
-}
-
-/*---------------------------------------------------------------------*/
-/* Make a session from all subdirectories that match the subject ID */
-
-THD_session * THD_init_session_bysub( char *dirname , char *subid )
-{
-   NI_str_array *qsar ;
-   THD_session *sess=NULL , *qss ;
-   int qq , nss=0 ;
-
-ENTRY("THD_init_session_bysub") ;
-
-   qsar = THD_get_subdirs_bysub( dirname , subid ) ;
-   if( qsar == NULL ) RETURN(NULL) ;
-
-   for( qq=0 ; qq < qsar->num ; qq++ ){
-     if( qsar->str[qq] != NULL && qsar->str[qq][0] != '\0' ){
-       qss = THD_init_session_recursive( qsar->str[qq] ) ;
-       if( qss != NULL ){    /* got something */
-         if( sess == NULL ){ /* the first something */
-           sess = qss ;
-         } else {            /* a later something */
-           THD_append_sessions( sess , qss ) ;
-         }
-         nss++ ;
-       }
-     }
-   }
-   NI_delete_str_array(qsar) ;  /* oops [15 Apr 2019] */
-
-   if( sess != NULL && nss > 1 ){
-     THD_order_session( sess ) ;
-     sess->is_collection = 1 ;
-   }
-   if( sess != NULL ){
-     char *env = my_getenv( "AFNI_SESSTRAIL" ) ; int tt = 0 ;
-     if( env != NULL ) tt = (int)strtol(env,NULL,10) ;
-     env = THD_trailname(dirname,tt) ;
-     sprintf( sess->lastname , "%.32s:%s",env,subid) ;
-   }
-
-   RETURN(sess) ;
-}
