@@ -7,7 +7,6 @@
 #include "thd_iochan.h"
 #include "Amalloc.h"
 #include <errno.h>
-#include "niml.h"
 
 static char *error_string=NULL ; /* 21 Nov 2001 */
 
@@ -112,7 +111,7 @@ static int nosigpipe = 0 ;  /* 20 Apr 1997: turn off SIGPIPE signals */
      < 0  ==> wait until something happens
 
    Return values are
-     -1 = some error occurred (socket closed at other end?)
+     -1 = some error occured (socket closed at other end?)
       0 = socket is not ready to read
       1 = socket has data
 ---------------------------------------------------------------------*/
@@ -230,7 +229,7 @@ int tcp_alivecheck( int sd )
 
 /*------------------------------------------------------------------------
    Open a socket to the given host, to the given TCP port.
-   Returns socket id; if -1, some error occurred (e.g., nobody listening).
+   Returns socket id; if -1, some error occured (e.g., nobody listening).
 --------------------------------------------------------------------------*/
 
 int tcp_connect( char * host , int port )
@@ -277,17 +276,6 @@ int tcp_connect( char * host , int port )
    return sd ;
 }
 
-static int tcp_listen_mute = 0;
-
-void set_tcp_listen_mute(int v) {
-   tcp_listen_mute = v;
-}
-
-int get_tcp_listen_mute(void) {
-   return(tcp_listen_mute);
-}  
-
-
 /*--------------------------------------------------------------------------
    Set up to listen for a connection on a given port.  This does not
    actually form the connection.  That must be done separately.
@@ -302,18 +290,13 @@ int tcp_listen( int port )
    static int nobindmsg;
    int sd , l ;
    struct sockaddr_in sin ;
-   char serr[128]={""}; /*ZSS June 2011*/
 
    if( port < 1 ){ STATUS("tcp_listen: illegal port") ; return -1 ; }
 
    /** open a socket **/
 
    sd = socket( AF_INET , SOCK_STREAM , 0 ) ;
-   if( sd == -1 ){ 
-      sprintf(serr,"Can't create? (socket): (Name %s, Port %d)", 
-                  get_port_numbered(port), port);
-      PERROR(serr); return -1; 
-   }
+   if( sd == -1 ){ PERROR("Can't create? tcp_listen[socket]"); return -1; }
 
    /** set socket options (no delays, large buffers) **/
 
@@ -333,11 +316,8 @@ int tcp_listen( int port )
    sin.sin_addr.s_addr = INADDR_ANY ;  /* reader reads from anybody */
 
    if( bind(sd , (struct sockaddr *)&sin , sizeof(sin)) == -1 ){
-      if (!tcp_listen_mute &&
-          !(nobindmsg % 10000)) { /* slow message printing down! ZSS */
-         sprintf(serr,"\nCan't bind? tcp_listen[bind] (Name %s, Port %d, sd %d)",
-                        get_port_numbered(port), port,sd);
-         PERROR(serr);
+      if (!(nobindmsg % 10000)) { /* slow message printing down! ZSS */
+         PERROR("\nCan't bind? tcp_listen[bind]");
          nobindmsg = 0;
       }
       ++nobindmsg;
@@ -345,11 +325,7 @@ int tcp_listen( int port )
    }
 
    if( listen(sd,1) == -1 ){
-      if (!tcp_listen_mute) {
-         sprintf(serr,"Can't listen? tcp_listen[listen] (Name %s, Port %d)",
-               get_port_numbered(port), port);
-      }
-      PERROR(serr); CLOSEDOWN(sd); return -1;
+      PERROR("Can't listen? tcp_listen[listen]"); CLOSEDOWN(sd); return -1;
    }
 
    return sd ;
@@ -358,7 +334,7 @@ int tcp_listen( int port )
 /*--------------------------------------------------------------------------
    Accept incoming connection on a socket.  Return value is the attached
    socket (which is not the original socket!).  If -1 is returned, some
-   error occurred.  If the accept works, then the original socket is
+   error occured.  If the accept works, then the original socket is
    still open and listening for further attachments.
 
    If hostname is not NULL, then the char * it points to will be filled
@@ -380,7 +356,7 @@ int tcp_listen( int port )
 int tcp_accept( int sd , char ** hostname , char ** hostaddr )
 {
    struct sockaddr_in pin ;
-   int sd_new ; socklen_t addrlen ;
+   int addrlen , sd_new ;
    struct hostent * hostp ;
    char * sout , * str ;
 
@@ -425,14 +401,13 @@ int tcp_accept( int sd , char ** hostname , char ** hostaddr )
 
 /*---------------------------------------------------------------
    Convert a string to a key, for IPC operations.
-   Augment sum by port offset value (-np option)
 -----------------------------------------------------------------*/
 
 key_t string_to_key( char * key_string )
 {
-   int ii , sum = get_user_np();
+   int ii , sum ;
 
-   sum += 666;
+   sum = 666 ;
    if( key_string == NULL ) return (key_t) sum ;
 
    for( ii=0 ; key_string[ii] != '\0' ; ii++ )
@@ -719,7 +694,6 @@ fprintf(stderr,"iochan_init: name=%s  mode=%s\n",name,mode) ;
       for( ii=4 ; name[ii] != ':' ; ii++ ) key[ii-4] = name[ii] ;
       key[ii-4] = '\0' ;
 
-      
       /** get size **/
 
       size = strtol( name+ii+1 , &kend , 10 ) ;
@@ -1489,14 +1463,7 @@ int iochan_recvall( IOCHAN * ioc , char * buffer , int nbytes )
       if( ii == -1 ) return -1 ;                             /* an error!?      */
       ntot += ii ;                                           /* total so far    */
       if( ntot == nbytes ) return nbytes ;                   /* all done!?      */
-
-      /* Only slow down if we are receiving little bits, otherwise any large
-         buffer that is broken into small pieces could take a very long time,
-         even such as a single anatomical volume.         17 Jul 2015 [rickr]   */
-      /* Note that the limit is likely SOCKET_BUFSIZE (31*1024) bytes.          */
-      if( ii < 4096 ) dms = NEXTDMS(dms) ;
-
-      iochan_sleep(dms) ;                                    /* wait a while    */
+      dms = NEXTDMS(dms) ; iochan_sleep(dms) ;               /* wait a while    */
    }
    return -1 ;   /* should never be reached */
 }
