@@ -17,10 +17,7 @@ static int floatscan    = -1 ;  /* 30 Jul 1999 */
 static int verbose = 0 ;
 
 void THD_load_datablock_verbose( int v ){ verbose = v; }
-
-void THD_load_no_mmap(void){ no_mmap = 2 ; }
-
-int THD_alloc_datablock( THD_datablock *blk ) ;       /* prototype */
+int THD_alloc_datablock( THD_datablock *blk ) ;
 
 /*-----------------------------------------------------------------*/
 /*! Check if all sub-bricks have the same datum type. [14 Mar 2002]
@@ -38,14 +35,13 @@ int THD_datum_constant( THD_datablock *blk )
 
 /*---------------------------------------------------------------*/
 /*! Return a float representation of a given voxel. [15 Sep 2004]
-*//*-------------------------------------------------------------*/
+-----------------------------------------------------------------*/
 
 float THD_get_voxel( THD_3dim_dataset *dset , int ijk , int ival )
 {
    void *ar ;
    float val , fac ;
 
-   if( !ISVALID_DSET(dset) )                  return 0.0f ;
    if( ival < 0 || ival >= DSET_NVALS(dset) ) return 0.0f ;
    if( ijk < 0  || ijk  >= DSET_NVOX(dset)  ) return 0.0f ;
 
@@ -70,7 +66,7 @@ float THD_get_voxel( THD_3dim_dataset *dset , int ijk , int ival )
 
      case MRI_complex:{
        complex c = (((complex *)ar)[ijk]) ;
-       val = sqrtf(c.r*c.r+c.i*c.i) ;
+       val = sqrt(c.r*c.r+c.i*c.i) ;
        break ;
      }
 
@@ -93,23 +89,6 @@ float THD_get_voxel( THD_3dim_dataset *dset , int ijk , int ival )
    return val ;
 }
 
-/*----------------------------------------------------------------------------*/
-
-float THD_get_voxel_dicom( THD_3dim_dataset *dset, float x,float y,float z, int ival )
-{
-   THD_fvec3 vv , uu ; THD_ivec3 ii ; int ijk ;
-
-   if( !ISVALID_DSET(dset) )                  return 0.0f ;
-   if( ival < 0 || ival >= DSET_NVALS(dset) ) return 0.0f ;
-
-   LOAD_FVEC3( vv , x,y,z ) ;
-   uu = THD_dicomm_to_3dmm( dset , vv ) ;
-   ii = THD_3dmm_to_3dind_no_wod( dset , uu ) ;
-   ijk = DSET_ixyz_to_index(dset,ii.ijk[0],ii.ijk[1],ii.ijk[2]) ;
-
-   return THD_get_voxel( dset , ijk , ival ) ;
-}
-
 /*---------------------------------------------------------------
   18 Oct 2001:
   Put freeup function here, and set it by a function, rather
@@ -122,13 +101,14 @@ void THD_set_freeup( generic_func *ff ){ freeup = ff; }
 
 /*---------------------------------------------------------------*/
 
-RwcBoolean THD_load_datablock( THD_datablock *blk )
+Boolean THD_load_datablock( THD_datablock *blk )
 {
    THD_diskptr *dkptr ;
+   int id , offset ;
    int nx,ny,nz , nxy,nxyz , nv , ii , ibr ;
    char *ptr ;
    int verb=verbose ;
-   int64_t idone , print_size=PRINT_SIZE , id ;
+   int64_t idone , print_size=PRINT_SIZE ;
 
 ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
 
@@ -136,16 +116,15 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
 
    floatscan = AFNI_yesenv("AFNI_FLOATSCAN") ;  /* check float bricks? */
 
-   if( no_mmap < 2 ){
-     if( floatscan ) no_mmap = 1 ;                          /* perhaps disable */
-     else            no_mmap = AFNI_yesenv("AFNI_NOMMAP") ; /* use of mmap()  */
-   }
+   if( floatscan ) no_mmap = 1 ;                          /* perhaps disable */
+   else            no_mmap = AFNI_yesenv("AFNI_NOMMAP") ; /* use of mmap()  */
 
    /*-- sanity checks --*/
 
    if( ! ISVALID_DATABLOCK(blk) || blk->brick == NULL ){
      STATUS("Illegal inputs"); RETURN( False );
    }
+
    ii = THD_count_databricks( blk ) ;
    if( ii == blk->nvals ) RETURN( True );   /* already loaded! */
 
@@ -173,12 +152,21 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
      fprintf(stderr,"\n*** Cannot read non 3D datablocks ***\n"); RETURN(False);
    }
 
-   if( !no_mmap && dkptr->storage_mode == STORAGE_BY_VOLUMES ) no_mmap = 1 ;  /* 20 Jun 2002 */
+   if( dkptr->storage_mode == STORAGE_BY_VOLUMES ) no_mmap = 1 ;  /* 20 Jun 2002 */
 
    /*-- 29 Oct 2001: MINC input (etc.) --*/
 
    if( dkptr->storage_mode == STORAGE_BY_MINC ){
-     ERROR_message("MINC-1 dataset input support is disabled") ;
+     THD_load_minc( blk ) ;
+     ii = THD_count_databricks( blk ) ;
+     if( ii == blk->nvals ){
+       THD_update_statistics( (THD_3dim_dataset *)blk->parent ) ;
+       ii = dblk_floatscan(blk) ;  /* 22 Feb 2007 */
+       if(ii>0) WARNING_message("fixed %d bad floats in %s",ii,dkptr->brick_name);
+       RETURN( True ) ;
+     }
+     STATUS("can't read MINC file?!") ;
+     RETURN( False ) ;
    }
 
    { THD_3dim_dataset *ds = (THD_3dim_dataset *)blk->parent ;  /* 04 Aug 2004 */
@@ -256,11 +244,7 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
    }
 
    if( dkptr->storage_mode == STORAGE_BY_NIFTI ){   /* 28 Aug 2003 */
-     /* check for failure  [2 Sep 2022 rickr] */
-     if( THD_load_nifti( blk ) ) {
-        STATUS("failed to load NIFTI dataset file") ;
-        RETURN( False );
-     }
+     THD_load_nifti( blk ) ;
      ii = THD_count_databricks( blk ) ;
      if( ii == blk->nvals ){
        THD_update_statistics( (THD_3dim_dataset *)blk->parent ) ;
@@ -306,11 +290,6 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
      RETURN( False ) ;
    }
 
-   if( dkptr->storage_mode == STORAGE_BY_NI_TRACT ) {
-      ERROR_message("Cannot handle tracts here");
-      RETURN( False ) ;
-   }
-   
    if( dkptr->storage_mode == STORAGE_BY_GIFTI ) {  /* 13 Feb 2008 */
      THD_load_gifti( blk ) ;
      ii = THD_count_databricks( blk ) ;
@@ -322,12 +301,6 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
      RETURN( False ) ;
    }
 
-   if( dkptr->storage_mode == STORAGE_BY_IMAGE_FILE ){ /* 06 Jul 2016 */
-     WARNING_message("attempt to reload an image file 'dataset' -- not supported") ;
-     STATUS("can't reload image file dataset") ;
-     RETURN( False ) ;
-   }
-
    /*** END OF SPECIAL CASES ABOVE; NOW FOR THE AFNI FORMAT! ***/
 
    /*-- allocate data space --*/
@@ -391,7 +364,7 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
          fprintf( stderr , "\n*** cannot open brick file %s for mmap\n"
                            "   - do you have permission? does file exist?\n" ,
                   dkptr->brick_name ) ;
-         perror("*** Unix error message") ; TRACEBACK ;
+         perror("*** Unix error message") ;
          STATUS("open failed") ;
          RETURN( False );
       }
@@ -414,31 +387,24 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
       ptr = (char *) mmap( 0 , (size_t)blk->total_bytes ,
                                PROT_READ , THD_MMAP_FLAG , fd , 0 ) ;
 
-      if( verbose && blk->total_bytes >= 1000000000ll )
-        fprintf(stderr , "%s: mmap(%s bytes) -- %s\n" ,
-                dkptr->brick_name ,
-                approximate_number_string((double)blk->total_bytes) ,
-                (ptr == (char*)(-1)) ? "FAILED" : "SUCCEEDED" ) ;
-
       /* if that fails, maybe try again (via freeup) */
 
       if( ptr == (char *)(-1) ){
          fprintf(stderr ,
                  "\n*** cannot mmap brick file %s - maybe hit a system limit?\n" ,
                  dkptr->brick_name ) ;
-         perror("*** Unix error message") ; TRACEBACK ;
+         perror("*** Unix error message") ;
          if( freeup != NULL ){
+            fprintf(stderr,"*** trying to fix problem\n") ; /* 18 Oct 2001 */
             freeup() ;                          /* AFNI_purge_unused_dsets */
-            fprintf(stderr,"*** purge and retry mmap(%s bytes)",
-                    approximate_number_string((double)blk->total_bytes) ) ;
             ptr = (char *) mmap( 0 , (size_t)blk->total_bytes ,
                                      PROT_READ , THD_MMAP_FLAG , fd , 0 ) ;
             if( ptr == (char *)(-1) ){
-               fprintf(stderr,"*** FAILED: cannot fix problem :-(\n") ;
+               fprintf(stderr,"*** cannot fix problem!\n") ;
                close(fd) ;
                STATUS("freeup failed") ; RETURN( False );
             } else {
-               fprintf(stderr,"*** SUCCEEDED: was able to fix problem :-)\n") ;
+               fprintf(stderr,"*** was able to fix problem!\n") ;
             }
          } else {       /* no freeup function to try */
             close(fd) ;
@@ -450,6 +416,7 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
 
       /* (re)create pointers to all sub-bricks */
 
+      offset = 0 ;
       for( ibr=0 ; ibr < nv ; ibr++ ){
          mri_fix_data_pointer( ptr , DBLK_BRICK(blk,ibr) ) ;
          ptr += DBLK_BRICK_BYTES(blk,ibr) ;
@@ -509,7 +476,7 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
                     "\n*** failure while opening brick file %s "
                     "- do you have permission?\n" ,
                     dkptr->brick_name ) ;
-            perror("*** Unix error message") ; TRACEBACK ;
+            perror("*** Unix error message") ;
             RETURN( False );
          }
 
@@ -527,7 +494,7 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
 
          } else {  /* 11 Jan 1999: read brick from master, put into place(s) */
 
-            int nfilled = 0 , jbr ; int64_t nbuf=0 , nbr ;
+            int nfilled = 0 , nbuf=0 , jbr, nbr ;
             char *buf=NULL ;  /* temp buffer for master sub-brick */
 
             /* loop over master sub-bricks until dataset is filled */
@@ -576,7 +543,7 @@ ENTRY("THD_load_datablock") ; /* 29 Aug 2001 */
                       "*** desired %lld bytes but only got %lld\n" ,
                     dkptr->brick_name ,
                     (long long)blk->total_bytes , (long long)idone ) ;
-            perror("*** Unix error message") ; TRACEBACK ;
+            perror("*** Unix error message") ;
             RETURN( False );
          }
       }
@@ -676,7 +643,7 @@ fprintf(stderr,"VOL[%d]: opening %s\n",ibr,fnam[ibr]) ;
                       "\n*** Failure while opening volume file %s "
                       "- do you have permission?\n" ,
                     fnam[ibr] ) ;
-              perror("*** Unix error message") ; TRACEBACK ;
+              perror("*** Unix error message") ;
               THD_purge_datablock( blk , blk->malloc_type ) ;
               for( ii=0 ; ii < nv ; ii++ ) free(fnam[ii]) ;
               free(fnam); RETURN( False );
@@ -696,8 +663,7 @@ fprintf(stderr,"VOL[%d]: id=%d\n",ibr,id) ;
 
             if( id < DBLK_BRICK_BYTES(blk,ibr) ){
               fprintf(stderr,
-                      "\n*** Volume file %s only gave"
-                      " %" PRId64 " out of %" PRId64 " bytes needed!\n",
+                      "\n*** Volume file %s only gave %d out of %d bytes needed!\n",
                      fnam[ibr] , id , DBLK_BRICK_BYTES(blk,ibr) ) ;
               THD_purge_datablock( blk , blk->malloc_type ) ;
               for( ii=0 ; ii < nv ; ii++ ) free(fnam[ii]) ;
@@ -721,7 +687,7 @@ fprintf(stderr,"VOL[%d]: id=%d\n",ibr,id) ;
                       "\n*** Failure while opening volume file %s "
                       "- do you have permission?\n" ,
                     fnam[ibr] ) ;
-              perror("*** Unix error message") ; TRACEBACK ;
+              perror("*** Unix error message") ;
               THD_purge_datablock( blk , blk->malloc_type ) ;
               for( ii=0 ; ii < nv ; ii++ ) free(fnam[ii]) ;
               free(fnam); RETURN( False );
@@ -737,8 +703,7 @@ fprintf(stderr,"VOL[%d]: id=%d\n",ibr,id) ;
 
             if( id < DBLK_BRICK_BYTES(blk,jbr) ){
               fprintf(stderr,
-                      "\n*** Volume file %s only gave "
-                      "%" PRId64 " out of %" PRId64 " bytes needed!\n",
+                      "\n*** Volume file %s only gave %d out of %d bytes needed!\n",
                      fnam[ibr] , id , DBLK_BRICK_BYTES(blk,jbr) ) ;
               THD_purge_datablock( blk , blk->malloc_type ) ;
               for( ii=0 ; ii < nv ; ii++ ) free(fnam[ii]) ;
@@ -774,7 +739,6 @@ fprintf(stderr,"VOL[%d]: id=%d\n",ibr,id) ;
 
       for( ibr=0 ; ibr < nv ; ibr++ ){
          switch( DBLK_BRICK_TYPE(blk,ibr) ){
-            default: break ;
             case MRI_short:
                mri_swap2( DBLK_BRICK_NVOX(blk,ibr) , DBLK_ARRAY(blk,ibr) ) ;
             break ;
@@ -794,9 +758,7 @@ fprintf(stderr,"VOL[%d]: id=%d\n",ibr,id) ;
    /* 30 July 1999: check float sub-brick for errors? */
    /* 14 Sep  1999: also check complex sub-bricks!    */
 
-   if( floatscan  &&
-      (( DBLK_BRICK_TYPE(blk,0) == MRI_float )  ||
-       ( DBLK_BRICK_TYPE(blk,0) == MRI_complex ))){
+   if( floatscan ){
       int nerr=0 ;
       STATUS("float scanning") ;
       if( verb ) fprintf(stderr,".float scan") ;
@@ -821,14 +783,7 @@ fprintf(stderr,"VOL[%d]: id=%d\n",ibr,id) ;
 #if 0
 fprintf(stderr,"master_bot=%g master_top=%g\n",blk->master_bot,blk->master_top) ;
 #endif
-   /* rcr - replace this with DBLK_IS_RANGE_MASTERED to also check for
-    *       csv list
-    *     - then call a new parent function to THD_apply_master_subrange
-    *
-    * *** same as in thd_load_nifti and thd_niml.c
-    */
-
-   if( DBLK_IS_MASTER_SUBRANGED(blk) )
+   if( DBLK_IS_MASTERED(blk) && blk->master_bot <= blk->master_top )
       THD_apply_master_subrange(blk) ;
 
    if( verb ) fprintf(stderr,".done\n") ;
@@ -839,7 +794,7 @@ fprintf(stderr,"master_bot=%g master_top=%g\n",blk->master_bot,blk->master_top)
 /*----------------------------------------------------------------------------*/
 /*! Allocate memory for the volumes in a datablock -- 02 May 2003.
     Return value is 1 if OK, 0 if not.
-*//*--------------------------------------------------------------------------*/
+------------------------------------------------------------------------------*/
 
 int THD_alloc_datablock( THD_datablock *blk )
 {
@@ -954,7 +909,8 @@ ENTRY("THD_alloc_datablock") ;
 
      case DATABLOCK_MEM_SHARED:
 #if !defined(DONT_USE_SHM) && !defined(CYGWIN)
-     { if( blk->shm_idcode[0] == '\0' ){   /* new segment */
+     { unsigned int offset ;
+       if( blk->shm_idcode[0] == '\0' ){   /* new segment */
          UNIQ_idcode_fill( blk->shm_idcode ) ;
          blk->shm_idint = shm_create( blk->shm_idcode , (int)blk->total_bytes ) ;
          if( blk->shm_idint < 0 ){ blk->shm_idcode[0] = '\0'; RETURN(0); }
@@ -963,6 +919,7 @@ ENTRY("THD_alloc_datablock") ;
            shmctl( blk->shm_idint , IPC_RMID , NULL ) ;
            blk->shm_idint = -1; blk->shm_idcode[0] = '\0'; RETURN(0);
          }
+         offset = 0 ;
          for( ibr=0 ; ibr < nv ; ibr++ ){
            mri_fix_data_pointer( ptr , DBLK_BRICK(blk,ibr) ) ;
            ptr += DBLK_BRICK_BYTES(blk,ibr) ;
@@ -981,7 +938,7 @@ ENTRY("THD_alloc_datablock") ;
 
 /*----------------------------------------------------------------------------*/
 /*! Fill up a dataset with zero-ed out sub-bricks, if needed.
-*//*--------------------------------------------------------------------------*/
+------------------------------------------------------------------------------*/
 
 void THD_zerofill_dataset( THD_3dim_dataset *dset )
 {
@@ -1006,7 +963,7 @@ ENTRY("THD_zerofill_dataset") ;
     (from THD_load_datablock())
 
     return 0 on success
-*//*--------------------------------------------------------------------------*/
+------------------------------------------------------------------------------*/
 int THD_apply_master_subrange( THD_datablock * blk )
 {
    THD_diskptr * dkptr ;
@@ -1015,15 +972,7 @@ int THD_apply_master_subrange( THD_datablock * blk )
 
 ENTRY("THD_apply_master_limits") ;
 
-   if( ! DBLK_IS_MASTERED(blk) )
-        RETURN(0);
-
-   /* if set, process csv list instead of bot..top      30 Nov 2016 [rickr] */
-   if( (blk->master_ncsv > 0) && (blk->master_csv != NULL) )
-        RETURN(THD_apply_master_subrange_list(blk));
-
-   /* if not applicable, skip bot..top range */
-   if( blk->master_bot > blk->master_top )
+   if( ! DBLK_IS_MASTERED(blk) || blk->master_bot > blk->master_top )
         RETURN(0);
 
    dkptr = blk->diskptr ;
@@ -1043,23 +992,9 @@ ENTRY("THD_apply_master_limits") ;
         case MRI_short:{
            short mbot, mtop, *mar = (short *) DBLK_ARRAY(blk,jbr) ;
            float mfac = DBLK_BRICK_FACTOR(blk,jbr) ;
-           float fval, fvmax;
            if( mfac == 0.0 ) mfac = 1.0 ;
-           /* - do not use SHORTIZE, rounding can include unwanted values    */
-           /* - use ceil() for bot and floor() for top   21 Nov 2016 [rickr] */
-           fval = bot/mfac;
-           fvmax = MRI_TYPE_maxval[MRI_short];
-           if     ( fval < -fvmax ) mbot = (short)-fvmax;
-           else if( fval >  fvmax ) mbot = (short)fvmax;
-           else                     mbot = (short)ceilf(fval);
-           
-           fval = top/mfac;
-           if     ( fval < -fvmax ) mtop = (short)-fvmax;
-           else if( fval >  fvmax ) mtop = (short)fvmax;
-           else                     mtop = (short)floorf(fval);
-           /* mbot = SHORTIZE(bot/mfac) ; mtop = SHORTIZE(top/mfac) ; */
+           mbot = SHORTIZE(bot/mfac) ; mtop = SHORTIZE(top/mfac) ;
 #if 0
-fprintf(stderr,"bot=%f top=%f\n",bot,top) ;
 fprintf(stderr,"mbot=%d mtop=%d\n",(int)mbot,(int)mtop) ;
 #endif
            for( ii=0 ; ii < nxyz ; ii++ )
@@ -1071,8 +1006,7 @@ fprintf(stderr,"mbot=%d mtop=%d\n",(int)mbot,(int)mtop) ;
            int mbot, mtop, *mar = (int *) DBLK_ARRAY(blk,jbr) ;
            float mfac = DBLK_BRICK_FACTOR(blk,jbr) ;
            if( mfac == 0.0 ) mfac = 1.0 ;
-           /* do not include unrequested values    21 Nov 2016 [rickr] */
-           mbot = ceilf(bot/mfac) ; mtop = floor(top/mfac) ;
+           mbot = rint(bot/mfac) ; mtop = rint(top/mfac) ;
            for( ii=0 ; ii < nxyz ; ii++ )
               if( mar[ii] < mbot || mar[ii] > mtop ) mar[ii] = 0 ;
         }
@@ -1080,20 +1014,9 @@ fprintf(stderr,"mbot=%d mtop=%d\n",(int)mbot,(int)mtop) ;
 
         case MRI_byte:{
            byte mbot, mtop, *mar = (byte *) DBLK_ARRAY(blk,jbr) ;
-           float fval, fvmax, mfac = DBLK_BRICK_FACTOR(blk,jbr) ;
+           float mfac = DBLK_BRICK_FACTOR(blk,jbr) ;
            if( mfac == 0.0 ) mfac = 1.0 ;
-           fval = bot/mfac;
-           fvmax = MRI_TYPE_maxval[MRI_byte];
-           if     ( fval < 0     ) mbot = (byte)0;
-           else if( fval > fvmax ) mbot = (byte)fvmax;
-           else                    mbot = (byte)ceilf(fval);
-           
-           fval = top/mfac;
-           if     ( fval < 0     ) mtop = (byte)0;
-           else if( fval > fvmax ) mtop = (byte)fvmax;
-           else                    mtop = (byte)floorf(fval);
-           
-           /* old way: mbot = BYTEIZE(bot/mfac) ; mtop = BYTEIZE(top/mfac) ; */
+           mbot = BYTEIZE(bot/mfac) ; mtop = BYTEIZE(top/mfac) ;
            for( ii=0 ; ii < nxyz ; ii++ )
               if( mar[ii] < mbot || mar[ii] > mtop ) mar[ii] = 0 ;
         }
@@ -1127,174 +1050,22 @@ fprintf(stderr,"mbot=%d mtop=%d\n",(int)mbot,(int)mtop) ;
   RETURN(0) ;
 }
 
-/*----------------------------------------------------------------------------*/
-/*! Apply master limit lists to data sub-bricks.           30 Nov 2016 [rickr]
-  
-    Like THD_apply_master_subrange(), but require all values to have
-    corresponding entries in master_csv list.
-
-    This will be a slower function.
-
-    Perhaps this should all go directly through floats?  Perhaps generalize
-    to list of float ranges?  It would not be difficult.
-  
-    return 0 on success
-*//*--------------------------------------------------------------------------*/
-int THD_apply_master_subrange_list( THD_datablock * blk )
-{
-   THD_diskptr * dkptr ;
-   float       * fcsv=NULL;
-   int           jbr, ii, ic, ncsv, nxyz ;
-
-ENTRY("THD_apply_master_limits") ;
-
-   if( ! DBLK_IS_MASTERED(blk) || blk->master_ncsv <= 0 ||
-                                  blk->master_csv == NULL )
-        RETURN(0);
-
-   /* should we warn if DBLK_BRICK_FACTOR() != 0.0 or 1.0? */
-
-   /* do all work as floats, to ease issues with brick factors */
-   /* (unless we do not allow factors, and then re-write this) */
-   ncsv = blk->master_ncsv;
-   fcsv = (float *)malloc(ncsv * sizeof(float));
-   for( ii=0; ii < ncsv; ii++)
-      fcsv[ii] = (float)blk->master_csv[ii];
-
-   dkptr = blk->diskptr ;
-   nxyz = dkptr->dimsizes[0] * dkptr->dimsizes[1] * dkptr->dimsizes[2];
-
-   for( jbr=0 ; jbr < dkptr->nvals ; jbr++ ){
-     switch( DBLK_BRICK_TYPE(blk,jbr) ){
-
-        default:
-           fprintf(stderr, "** TAMSL: cannot sub-range datum type %s\n",
-                           MRI_TYPE_name[DBLK_BRICK_TYPE(blk,jbr)]) ;
-           RETURN(1);
-        break ;
-
-        case MRI_short:{
-           short *mar = (short *) DBLK_ARRAY(blk,jbr) ;
-           float dval, mfac = DBLK_BRICK_FACTOR(blk,jbr) ;
-           if( mfac == 0.0 ) mfac = 1.0 ;
-           for( ii=0 ; ii < nxyz ; ii++ ) {
-              /* write as function?  overhead per voxel, hmmmm... */
-              dval = mar[ii] * mfac;
-              for( ic=0; ic < ncsv; ic++ )
-                 if( dval == fcsv[ic] ) break;
-              /* if not found, clear */
-              if( ic == ncsv ) mar[ii] = 0 ;
-           }
-        }
-        break ;
-
-        /* going through float limits to 24 of 32 bits, ~16 million */
-        case MRI_int:{
-           int *mar = (int *) DBLK_ARRAY(blk,jbr) ;
-           float dval, mfac = DBLK_BRICK_FACTOR(blk,jbr) ;
-           if( mfac == 0.0 ) mfac = 1.0 ;
-           for( ii=0 ; ii < nxyz ; ii++ ) {
-              dval = mar[ii] * mfac;
-              for( ic=0; ic < ncsv; ic++ )
-                 if( dval == fcsv[ic] ) break;
-              if( ic == ncsv ) mar[ii] = 0 ; /* if not found, clear */
-           }
-        }
-        break ;
-
-        case MRI_byte:{
-           byte *mar = (byte *) DBLK_ARRAY(blk,jbr) ;
-           float dval, mfac = DBLK_BRICK_FACTOR(blk,jbr) ;
-           if( mfac == 0.0 ) mfac = 1.0 ;
-           for( ii=0 ; ii < nxyz ; ii++ ) {
-              dval = mar[ii] * mfac;
-              for( ic=0; ic < ncsv; ic++ )
-                 if( dval == fcsv[ic] ) break;
-              if( ic == ncsv ) mar[ii] = 0 ; /* if not found, clear */
-           }
-        }
-        break ;
-
-        case MRI_float:{
-           float *mar = (float *) DBLK_ARRAY(blk,jbr) ;
-           float dval, mfac = DBLK_BRICK_FACTOR(blk,jbr) ;
-           if( mfac == 0.0 ) mfac = 1.0 ;
-           for( ii=0 ; ii < nxyz ; ii++ ) {
-              dval = mar[ii] * mfac;
-              for( ic=0; ic < ncsv; ic++ )
-                 if( dval == fcsv[ic] ) break;
-              if( ic == ncsv ) mar[ii] = 0 ; /* if not found, clear */
-           }
-        }
-        break ;
-
-        case MRI_complex:{
-           complex *mar = (complex *) DBLK_ARRAY(blk,jbr) ;
-           float dval, mfac = DBLK_BRICK_FACTOR(blk,jbr) ;
-           if( mfac == 0.0 ) mfac = 1.0 ;
-           for( ii=0 ; ii < nxyz ; ii++ ){
-              dval = CABS(mar[ii]) ;
-              for( ic=0; ic < ncsv; ic++ )
-                 if( dval == fcsv[ic] ) break;
-              /* if not found, clear */
-              if( ic == ncsv ) mar[ii].r = mar[ii].i = 0 ;
-           }
-        }
-        break ;
-     }
-  }
-
-  free(fcsv);
-
-  RETURN(0) ;
-}
-
 /*----------------------------------------------------------------------*/
 /*! Set dx,dy,dz fields for MRI_IMAGEs in a dataset.
-    [19 Dec 2011] Also patch the dataset grid spacing if it is 0.
-*//*--------------------------------------------------------------------*/
+------------------------------------------------------------------------*/
 
 void THD_patch_brickim( THD_3dim_dataset *dset )
 {
-   float dx,dy,dz , dm ;
-   int iv , nvals , nfix=0 ;
-   static char *cfix[8] = { NULL ,
-                            "x-axis" , "y-axis"      , "x- & y-axes" ,
-                            "z-axis" , "x- & z-axes" , "y- & z-axes" ,
-                            "x- & y- & z-axes" } ;
-   static char **idstr=NULL ; static int nidstr=0 ;  /* no repeating */
+   float dx,dy,dz ;
+   int iv , nvals ;
 
-ENTRY("THD_patch_brickim") ;
+ENTRY("THD_patch_dxyz") ;
 
    if( !ISVALID_DSET(dset) ) EXRETURN ;
 
-   dx = fabsf(DSET_DX(dset)) ;  /* unsigned grid spacings */
-   dy = fabsf(DSET_DY(dset)) ;
-   dz = fabsf(DSET_DZ(dset)) ;
-
-   /* check to see if any axis spacing was 0; if so, spackle over it */
-
-   dm = dx + dy + dz ;
-   dm = (dm == 0.0f) ? 1.0f : dm*0.5f ;
-
-   if( dx == 0.0f ){ dx = dset->daxes->xxdel = dm ; nfix += 1 ; }
-   if( dy == 0.0f ){ dy = dset->daxes->yydel = dm ; nfix += 2 ; }
-   if( dz == 0.0f ){ dz = dset->daxes->zzdel = dm ; nfix += 4 ; }
-
-   if( nfix > 0 ){                         /* have to patch at least one axis */
-     int ii ;
-     for( ii=0 ; ii < nidstr ; ii++ )    /* see if we did this dataset before */
-       if( strcmp(DSET_IDCODE_STR(dset),idstr[ii]) == 0 ) break ;
-     if( ii == nidstr ){                     /* this is a new dataset (to us) */
-       if( nidstr == 0 ) fprintf(stderr,"\n") ;
-       WARNING_message("Dataset %s : patched zero grid spacing along %s to %g",
-                       THD_trailname(DSET_HEADNAME(dset),0) , cfix[nfix] , dm ) ;
-       idstr = (char **)realloc(idstr,sizeof(char *)*(nidstr+1)) ;
-       idstr[nidstr++] = strdup(DSET_IDCODE_STR(dset)) ; /* remember the past */
-     }
-   }
-
-   /* fix the sub-brick (MRI_IMAGE) headers */
+   dx = fabs(DSET_DX(dset)) ; if( dx == 0.0f ) dx = 1.0f ;
+   dy = fabs(DSET_DY(dset)) ; if( dy == 0.0f ) dy = 1.0f ;
+   dz = fabs(DSET_DZ(dset)) ; if( dz == 0.0f ) dz = 1.0f ;
 
    nvals = DSET_NVALS(dset) ;
    for( iv=0 ; iv < nvals ; iv++ ){
