@@ -49,8 +49,6 @@ byte * THD_makemask( THD_3dim_dataset *mask_dset ,
 
    switch( DSET_BRICK_TYPE(mask_dset,miv) ){
       default:
-         WARNING_message("makemask: bad brick type %d",
-                         DSET_BRICK_TYPE(mask_dset,miv));
          free(mmm) ; DSET_unload(mask_dset) ; return NULL ;
 
       case MRI_short:{
@@ -91,8 +89,7 @@ byte * THD_makemask( THD_3dim_dataset *mask_dset ,
             mtop = BYTEIZE(mask_top/mfac) ;
          } else {
             mbot = 0 ;
-            // [PT: Dec 22, 2020] Thanks for the fix here, C Rorden!
-            mtop = (byte) MRI_TYPE_maxval[MRI_byte] ;
+            mtop = (byte) MRI_TYPE_maxval[MRI_short] ;
          }
          if( !empty )   /* 6 Jun 2007 */
             for( ii=0 ; ii < nvox ; ii++ )
@@ -197,13 +194,11 @@ int THD_makedsetmask( THD_3dim_dataset *mask_dset ,
             for( ii=0 ; ii < nvox ; ii++ ) mar[ii] = 0;
          } else if (cmask)  {
             for( ii=0 ; ii < nvox ; ii++ )
-               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0
-                                   && cmask[ii]) { mar[ii]=1; ++nonzero; }
+               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 && cmask[ii]) { mar[ii]=1; ++nonzero; }
                else { mar[ii] = 0; }
          } else {
             for( ii=0 ; ii < nvox ; ii++ )
-               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 )
-                    { mar[ii]=1; ++nonzero; }
+               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 ) { mar[ii]=1; ++nonzero; }
                else { mar[ii] = 0; }
          }
       }
@@ -224,20 +219,17 @@ int THD_makedsetmask( THD_3dim_dataset *mask_dset ,
             mtop = BYTEIZE(mask_top/mfac) ;
          } else {
             mbot = 0 ;
-            // [PT: Dec 22, 2020] Thanks for the fix here, C Rorden!
-            mtop = (byte) MRI_TYPE_maxval[MRI_byte] ;
+            mtop = (byte) MRI_TYPE_maxval[MRI_short] ;
          }
          if (empty) {  /* if empty, clear result   6 Jun 2007 */
             for( ii=0 ; ii < nvox ; ii++ ) mar[ii] = 0;
          } else if (cmask) {
             for( ii=0 ; ii < nvox ; ii++ )
-               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0
-                                   && cmask[ii]){ mar[ii]=1; ++nonzero; }
+               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 && cmask[ii]){ mar[ii]=1; ++nonzero; }
                else { mar[ii] = 0; }
          } else {
             for( ii=0 ; ii < nvox ; ii++ )
-               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 )
-                    { mar[ii]=1; ++nonzero; }
+               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 ){ mar[ii]=1; ++nonzero; }
                else { mar[ii] = 0; }
          }
       }
@@ -257,13 +249,11 @@ int THD_makedsetmask( THD_3dim_dataset *mask_dset ,
          }
          if (cmask) {
             for( ii=0 ; ii < nvox ; ii++ )
-               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0
-                                   && cmask[ii]) { mar[ii]=1; ++nonzero; }
+               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 && cmask[ii]) { mar[ii]=1; ++nonzero; }
                else { mar[ii] = 0; }
          } else {
             for( ii=0 ; ii < nvox ; ii++ )
-               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 )
-                    { mar[ii]=1; ++nonzero; }
+               if( mar[ii] >= mbot && mar[ii] <= mtop && mar[ii] != 0 ) { mar[ii]=1; ++nonzero; }
                else { mar[ii] = 0; }
          }
       }
@@ -276,137 +266,10 @@ int THD_makedsetmask( THD_3dim_dataset *mask_dset ,
    return (nonzero) ;
 }
 
-
-/*---------------------------------------------------------------------------*/
-/*!  Convert an entire dataset of MRI_byte, and all values to binary
-     (set or not).
-
-     return 1 on failure, 0 on success           3 Jun, 2014 [rickr]
-*/
-
-int THD_dset_to_mask(THD_3dim_dataset * dset, float mask_bot, float mask_top)
-{
-   byte * bvol = NULL;
-   int    ivol;
-
-   ENTRY("THD_dset_to_mask");
-
-   if( !ISVALID_DSET(dset) ) {
-      ERROR_message("dset_to_mask: dset not valid");
-      RETURN(1);
-   }
-
-   DSET_mallocize(dset); DSET_load(dset) ;
-   if( !DSET_LOADED(dset) ) {
-      ERROR_message("dset_to_mask: dset not loaded");
-      RETURN(1);
-   }
-
-   for( ivol = 0; ivol < DSET_NVALS(dset); ivol++ ) {
-
-      bvol = THD_makemask(dset, ivol, mask_bot, mask_top);
-      if( !bvol ) {
-         ERROR_message("dset_to_mask: failed to mask vol %d", ivol);
-         RETURN(1);
-      }
-
-      EDIT_substitute_brick(dset, ivol, MRI_byte, bvol);
-      EDIT_BRICK_FACTOR(dset, ivol, 0.0);
-   }
-
-   RETURN(0);
-}
-
-/*
-   Zero out voxels vv in dset where cmask[vv]=0
-   Returns the number of voxels edited in dset (across all sub-bricks)
-      -1 if dset was null
-*/
-int THD_applydsetmask( THD_3dim_dataset *dset ,  byte *cmask )
-{
-   int ss, ii, jj, kk, vv, nedited = -1 ;
-   
-   ENTRY("THD_applydsetmask");
-   
-   if (!dset) RETURN(nedited);
-   
-   if (!cmask) RETURN(0);
-   
-   DSET_mallocize(dset); DSET_load(dset);
-   for (ss=0; ss<DSET_NVALS(dset); ++ss) {
-      switch (DSET_BRICK_TYPE(dset,ss)) {
-         case MRI_byte:
-            {  byte *bv = (byte *)DSET_ARRAY(dset,ss) ;
-               vv=0; 
-               for (kk=0; kk<DSET_NZ(dset); ++kk) {
-               for (jj=0; jj<DSET_NY(dset); ++jj) {
-               for (ii=0; ii<DSET_NX(dset); ++ii) {
-                  if (!cmask[vv]) {
-                     bv[vv] = 0; 
-                     ++nedited;
-                  }
-                  ++vv;
-               } } }
-            }
-            break;
-         case MRI_short:
-            {  short *sv = (short *)DSET_ARRAY(dset,ss) ;
-               vv=0; 
-               for (kk=0; kk<DSET_NZ(dset); ++kk) {
-               for (jj=0; jj<DSET_NY(dset); ++jj) {
-               for (ii=0; ii<DSET_NX(dset); ++ii) {
-                  if (!cmask[vv]) {
-                     sv[vv] = 0; 
-                     ++nedited;
-                  }
-                  ++vv;
-               } } }
-            }
-            break;
-         case MRI_float:
-            {  float *fv = (float *)DSET_ARRAY(dset,ss) ;
-               vv=0; 
-               for (kk=0; kk<DSET_NZ(dset); ++kk) {
-               for (jj=0; jj<DSET_NY(dset); ++jj) {
-               for (ii=0; ii<DSET_NX(dset); ++ii) {
-                  if (!cmask[vv]) {
-                     fv[vv] = 0; 
-                     ++nedited;
-                  }
-                  ++vv;
-               } } }
-            }
-            break;
-         case MRI_complex:
-            {  complex *cv = (complex *)DSET_ARRAY(dset,ss) ;
-               vv=0; 
-               for (kk=0; kk<DSET_NZ(dset); ++kk) {
-               for (jj=0; jj<DSET_NY(dset); ++jj) {
-               for (ii=0; ii<DSET_NX(dset); ++ii) {
-                  if (!cmask[vv]) {
-                     cv[vv].i = cv[vv].r = 0.0; 
-                     ++nedited;
-                  }
-                  ++vv;
-               } } }
-            }
-            break;
-         default:
-            ERROR_message(
-               "THD_applydsetmask: Dset type %d for subbrick %d not supported\n",
-                          DSET_BRICK_TYPE(dset,ss), ss);
-            break;
-      }
-   }
-
-   RETURN(nedited);
-}
-
 /*----------------------------------------------------------------------------*/
 extern int * UniqueInt (int *y, int ysz, int *kunq, int Sorted );
 
-int is_integral_sub_brick ( THD_3dim_dataset *dset, int isb, int check_values)
-{
+int is_integral_sub_brick ( THD_3dim_dataset *dset, int isb, int check_values) {
    float mfac = 0.0;
    void *vv=NULL;
 
@@ -449,8 +312,7 @@ int is_integral_sub_brick ( THD_3dim_dataset *dset, int isb, int check_values)
    return(1);
 }
 
-int is_integral_dset ( THD_3dim_dataset *dset, int check_values)
-{
+int is_integral_dset ( THD_3dim_dataset *dset, int check_values) {
    int i=0;
 
    if(   !ISVALID_DSET(dset)  ) return(0);
@@ -560,7 +422,7 @@ the rank of the voxel value in mask_dset
 int *THD_unique_rank( THD_3dim_dataset *mask_dset ,
                         int miv,
                         byte *cmask,
-                        char *mapname,
+                        char *mapname, 
                         int **unqp, int *N_unq)
 {
    int nvox , ii, *unq = NULL, *vals=NULL, imax=0;
@@ -575,7 +437,7 @@ int *THD_unique_rank( THD_3dim_dataset *mask_dset ,
       fprintf(stderr,"** unqp (%p) not initialized properly to NULL", *unqp);
       return (vals) ;
    }
-
+   
    if( !ISVALID_DSET(mask_dset)    ||
        miv < 0                     ||
        miv >= DSET_NVALS(mask_dset)  ) {
@@ -1063,35 +925,27 @@ ENTRY("thd_mask_from_brick");
     {
         case MRI_byte:
         {
-            if (thresh <= (float)MRI_maxbyte) { /* ZSS: Oct 2011
-                  Without this test, a high threshold value might end up
-                  equal to MRI_maxbyte when BYTEIZED below, resulting in
-                  the highest voxel making it to the mask no matter how
-                  much higher the threshold is set.                  */
-               byte * dp  = DSET_ARRAY(dset, volume);
-               byte   thr = BYTEIZE(thresh + 0.99999);  /* ceiling */
-               for ( c = 0; c < nvox; c++ )
-                   if ( dp[c] != 0 && ( dp[c] >= thr ) )
-                   {
-                       size++;
-                       tmask[c] = 1;
-                   }
-            }
+            byte * dp  = DSET_ARRAY(dset, volume);
+            byte   thr = BYTEIZE(thresh + 0.99999);  /* ceiling */
+            for ( c = 0; c < nvox; c++ )
+                if ( dp[c] != 0 && ( dp[c] >= thr ) )
+                {
+                    size++;
+                    tmask[c] = 1;
+                }
         }
             break;
 
         case MRI_short:
         {
-            if (thresh <= (float)MRI_maxshort) { /* ZSS: Oct 2011 */
-               short * dp  = DSET_ARRAY(dset, volume);
-               short   thr = SHORTIZE(thresh + 0.99999);  /* ceiling */
-               for ( c = 0; c < nvox; c++, dp++ )
-                   if ( *dp != 0 && ( *dp >= thr || (absolute && *dp <= -thr) ) )
-                   {
-                       size++;
-                       tmask[c] = 1;
-                   }
-            }
+            short * dp  = DSET_ARRAY(dset, volume);
+            short   thr = SHORTIZE(thresh + 0.99999);  /* ceiling */
+            for ( c = 0; c < nvox; c++, dp++ )
+                if ( *dp != 0 && ( *dp >= thr || (absolute && *dp <= -thr) ) )
+                {
+                    size++;
+                    tmask[c] = 1;
+                }
         }
             break;
 
@@ -1146,7 +1000,7 @@ int thd_multi_mask_from_brick(THD_3dim_dataset * dset, int volume, byte ** mask)
     byte  * tmask;
     int     nvox, type, c;
 
-ENTRY("thd_multi_mask_from_brick");
+ENTRY("thd_mask_from_brick");
 
     if ( mask ) *mask = NULL;   /* to be sure */
 
@@ -1277,7 +1131,7 @@ char * mask_to_b64string( int nvox , byte *mful )
    if( nvox < 1 || mful == NULL ) return NULL ;          /* bad inputs */
 
    mbin = mask_binarize( nvox , mful ) ;
-   str  = array_to_zzb64( 1+(nvox-1)/8 , (char *)mbin , 72 ) ; free(mbin) ;
+   str  = array_to_zzb64( 1+(nvox-1)/8 , mbin , 72 ) ; free(mbin) ;
    if( str == NULL ) return NULL ;              /* should never happen */
 
    nstr = strlen(str) ;
@@ -1377,8 +1231,7 @@ byte * mask_unbinarize( int nvox , byte *mbin )
 
 bytevec * THD_create_mask_from_string( char *str )  /* Jul 2010 */
 {
-   bytevec *bvec=NULL ; int nstr ; char *buf=NULL ;
-   int ferr=0;
+   bytevec *bvec ; int nstr ; char *buf=NULL ;
 
 ENTRY("THD_create_mask") ;
 
@@ -1394,15 +1247,12 @@ ENTRY("THD_create_mask") ;
      if( dset != NULL ){
        bvec->nar = DSET_NVOX(dset) ;
        bvec->ar  = THD_makemask( dset , 0 , 1.0f,0.0f ) ;
-       DSET_delete(dset) ;
        if( bvec->ar == NULL ){
          ERROR_message("Can't make mask from dataset '%s'",str) ;
          free(bvec) ; bvec = NULL ;
        }
        RETURN(bvec) ;
      }
-
-     ferr = 1; /* string is short, but failed to open as dataset */
    }
 
    /* if str is a filename, read that file;
@@ -1423,16 +1273,11 @@ ENTRY("THD_create_mask") ;
      if( bvec->ar != NULL ){
        bvec->nar = nvox ;
      } else {
-       /* might be a non-existent file        14 Jan 2014 [rickr] */
-       if( ferr ) ERROR_message("Failed to open mask from '%s'", str);
-       else       ERROR_message("Can't make mask from string '%.16s' %s",
-                                buf,(nstr<=16)?" ":"...") ;
+       ERROR_message("Can't make mask from string '%.16s' %s",buf,(nstr<=16)?" ":"...") ;
        free(bvec) ; bvec = NULL ;
      }
    } else {
-     if( ferr ) ERROR_message("Failed to open mask '%s'", str);
-     else       ERROR_message("Don't understand mask string '%.16s'",
-                              buf,(nstr<=16)?" ":"...") ;
+     ERROR_message("Don't understand mask string '%.16s'",buf,(nstr<=16)?" ":"...") ;
      free(bvec) ; bvec = NULL ;
    }
 
