@@ -3,38 +3,20 @@
 #ifndef DONT_INCLUDE_ANALYZE_STRUCT
 #define DONT_INCLUDE_ANALYZE_STRUCT
 #endif
-#include "nifti2_io.h"   /** will include nifti1.h **/
+#include "nifti1_io.h"   /** will include nifti1.h **/
 static void NIFTI_code_to_space(int code,THD_3dim_dataset *dset);
-static int NIFTI_code_to_view(int code, char *atlas_space);
-static int NIFTI_default_view();
 extern char *THD_get_space(THD_3dim_dataset *dset);
-static int THD_nifti_process_afni_ext(THD_3dim_dataset *dset,
-                                      nifti_image *nim, char *pathnew);
-
-#undef  KILL_pathnew
-#define KILL_pathnew if( pathnew != NULL && pathnew != pathname ) free(pathnew)
-
-#undef  NULLRET
-#define NULLRET      do{ KILL_pathnew ; RETURN(NULL) ; } while(0)
 
 /*******************************************************************/
 /********** 26 Aug 2003: read a NIFTI-1 file as a dataset **********/
 /*******************************************************************/
 
-/*
- [PT,DRG: Mar 8, 2019] Updated to include [qs]form_code = 5 
-
- [PT,DRG: Mar 12, 2019] some fixes for [qs]form behavior.  Still need
- to look at [qs]form=2 case, changing space/views.
-
-*/
-
 THD_3dim_dataset * THD_open_nifti( char *pathname )
 {
    THD_3dim_dataset *dset=NULL ;
    nifti_image *nim ;
    int ntt , nbuc , nvals ;
-   int use_qform = 0 , use_sform = 0, form_code = 0 ;
+   int use_qform = 0 , use_sform = 0 ;
    int statcode = 0 , datum , iview , ibr ;
    int scale_data = 0 ;  /* flag based on scl_slope and inter  20 Jun 2008 */
    int xform_data = 0;
@@ -45,8 +27,6 @@ THD_3dim_dataset * THD_open_nifti( char *pathname )
    char *ppp , prefix[THD_MAX_PREFIX] ;
    char form_priority = 'S' ;             /* 23 Mar 2006 */
    static int n_xform_warn=0;
-   char *pathnew = NULL ;
-   char *rpath   = NULL , *rp=NULL ;;
    
 ENTRY("THD_open_nifti") ;
 
@@ -57,45 +37,16 @@ ENTRY("THD_open_nifti") ;
       if( ept != NULL ) nifti_set_debug_level(atoi(ept));
    }
 
-   nifti_set_alter_cifti(1) ;  /* if CIFTI, shift dims   23 Jul 2015 [rickr] */
+   nim = nifti_image_read( pathname, 0 ) ;
 
-   /* pathname munge by RWC [07 Feb 2019] */
-
-   if( pathname == NULL || *pathname == '\0' ) NULLRET ;
-   if( THD_is_file(pathname) ){
-     pathnew = pathname ;
-   } else if( strstr(pathname,".gz") == NULL ){
-     pathnew = (char *)malloc(sizeof(char)*(strlen(pathname)+16)) ;
-     sprintf(pathnew,"%s.gz",pathname) ;
-     if( ! THD_is_file(pathnew) ) NULLRET ;
-   } else {
-     NULLRET ;
-   }
-   if( !AFNI_yesenv("AFNI_NOREALPATH") && !THD_is_symlink(pathnew) ){ /* 21 Mar 2020 */
-     rpath = (char *)malloc(sizeof(char)*RPMAX) ;
-     rp    = realpath( pathnew , rpath ) ;
-     if( rp == NULL ){ free(rpath) ; NULLRET ; }
-     KILL_pathnew ; pathnew = rpath ;
-   }
-#if 0
-   INFO_message("NIFTI - opening dataset %s",pathnew) ;
-#endif
-
-   /*-- Read read read --*/
-
-   nim = nifti_image_read( pathnew, 0 ) ;
-
-   if( nim == NULL || nim->nifti_type == 0 ) NULLRET ;
-
-   if( pathname != pathnew && pathnew != rpath )
-     ININFO_message("reading %s instead of non-existing %s",pathnew,pathname) ;
+   if( nim == NULL || nim->nifti_type == 0 ) RETURN(NULL) ;
 
    /*-- extract some useful AFNI-ish information from the nim struct --*/
 
    /* we must have at least 2 spatial dimensions */
 
    /* this should be okay                 11 Jun 2007 */
-   /* if( nim->nx < 2 || nim->ny < 2 ) NULLRET ;      */
+   /* if( nim->nx < 2 || nim->ny < 2 ) RETURN(NULL) ; */
 
    /* 4th dimension = time; 5th dimension = bucket:
       these are mutually exclusive in AFNI at present */
@@ -113,49 +64,29 @@ ENTRY("THD_open_nifti") ;
    if( ntt > 1 && nbuc > 1 ){
      fprintf(stderr,
              "** AFNI can't deal with 5 dimensional NIfTI(%s)\n",
-             pathnew ) ;
-     NULLRET ;
+             pathname ) ;
+     RETURN(NULL) ;
    }
-
    nvals = MAX(ntt,nbuc) ;
 
-   /* collapse higher-dimensional datasets    23 Jul 2015 [rickr] */
-   /* (this includes CIFTI)                                       */
-   if( nim->nv > 1 ) nvals *= nim->nv;
-   if( nim->nw > 1 ) nvals *= nim->nw;
-   if( ntt > 1 ) ntt = nvals;
-   else          nbuc = nvals;
-
    /* determine type of dataset values:
       if we are scaling, or if the data type in the NIfTI file
       is something AFNI can't handle, then the result will be floats */
 
    /* do not scale if slope is 0 or if slope is 1 and inter is 0 */
-   if( !isfinite(nim->scl_slope) || !isfinite(nim->scl_inter) ){
+   if( !finite(nim->scl_slope) || !finite(nim->scl_inter) ){
       fprintf(stderr,"** bad scl_slope and inter = %f, %f, ignoring...\n",
               nim->scl_slope, nim->scl_inter);
-   } else {
-       /* do not scale if either slope or inter is zero
-        *    slope==0 : treat as unset (rather than constant data)
-        *    inter==0 : use slope as brick_fac */
-
-       /* Any NIFTI scalar previously implied conversion to float.
-        * No longer scale if inter==0 && slope!=0 (set brick_fac).
-        * Thanks to C Caballero and S Moia for reporting this.  
-        *                                      26 Jan 2021 [rickr] */
-       /* still scale if slope == 1 && inter != 0 */
-       scale_data = nim->scl_slope != 0.0 && nim->scl_inter != 0.0 ;
-   }
-   { char *eee = getenv("AFNI_NIFTI_SCALE") ;
-     if( eee != NULL && toupper(*eee) == 'N' ) scale_data = 0 ;
-   }
+   } else
+       scale_data = nim->scl_slope != 0.0 &&
+                        (nim->scl_slope != 1.0 || nim->scl_inter != 0.0) ;
 
    switch( nim->datatype ){
      default:
        fprintf(stderr,
                "** AFNI can't handle NIFTI datatype=%d (%s) in file %s\n",
-               nim->datatype, nifti_datatype_string(nim->datatype), pathnew );
-       NULLRET ;
+               nim->datatype, nifti_datatype_string(nim->datatype), pathname );
+       RETURN(NULL) ;
      break ;
 
      case DT_UINT8:     datum = scale_data ? MRI_float : MRI_byte  ;
@@ -178,21 +109,21 @@ ENTRY("THD_open_nifti") ;
      case DT_COMPLEX128:  /* this case would be too much like real work */
        fprintf(stderr,
                "** AFNI convert NIFTI_datatype=%d (%s) in file %s to COMPLEX64\n",
-               nim->datatype, nifti_datatype_string(nim->datatype), pathnew );
+               nim->datatype, nifti_datatype_string(nim->datatype), pathname );
        datum = MRI_complex ;
      break ;
 #endif
    }
 
-   if( xform_data && !AFNI_noenv("AFNI_NIFTI_TYPE_WARN")) {
+   if( xform_data ) {
       if (!n_xform_warn || AFNI_yesenv("AFNI_NIFTI_TYPE_WARN")) {/* ZSS 04/11 */
          fprintf(stderr,
              "** AFNI converts NIFTI_datatype=%d (%s) in file %s to FLOAT32\n",
-             nim->datatype, nifti_datatype_string(nim->datatype), pathnew );
+             nim->datatype, nifti_datatype_string(nim->datatype), pathname );
          if (!AFNI_yesenv("AFNI_NIFTI_TYPE_WARN")) {
             fprintf(stderr,
                "     Warnings of this type will be muted for this session.\n"
-      "     Set AFNI_NIFTI_TYPE_WARN to YES to see them all, NO to see none.\n");
+               "     Set AFNI_NIFTI_TYPE_WARN to YES to see them all.\n");
          }
       }
       ++n_xform_warn;
@@ -205,13 +136,13 @@ ENTRY("THD_open_nifti") ;
      if( nim->intent_code > FUNC_PT_TYPE ){
        fprintf(stderr,
                "** AFNI doesn't understand NIFTI statistic type %d (%s) in file %s\n",
-               nim->intent_code , nifti_intent_string(nim->intent_code) , pathnew ) ;
+               nim->intent_code , nifti_intent_string(nim->intent_code) , pathname ) ;
      } else {
        statcode = nim->intent_code ;
        if( nbuc > 1 ){
          fprintf(stderr,
                  "** AFNI doesn't support NIFTI voxel-dependent statistic parameters"
-                 " in file %s\n" , pathnew ) ;
+                 " in file %s\n" , pathname ) ;
          statcode = 0 ;
        }
      }
@@ -219,11 +150,15 @@ ENTRY("THD_open_nifti") ;
 
    /* 23 Mar 2006: set qform or sform as having priority -- RWCox */
 
-   ppp = my_getenv("AFNI_NIFTI_PRIORITY") ;
+   ppp = my_getenv("NIFTI_FORM_PRIORITY") ;
+   if( ppp == NULL ) ppp = getenv("AFNI_FORM_PRIORITY") ;
+   if( ppp == NULL ) ppp = getenv("AFNI_NIFTI_PRIORITY") ;
+   if( ppp == NULL ) ppp = getenv("AFNI_NIFTI_FORM") ;
+   if( ppp == NULL ) ppp = getenv("AFNI_NIFTI_FORM_PRIORITY") ;
    if( ppp != NULL ){
      char fp = toupper(*ppp) ;
      if( fp == 'S' || fp == 'Q' ) form_priority = fp ;
-     else WARNING_message("Illegal AFNI_NIFTI_PRIORITY='%s'",ppp) ;
+     else WARNING_message("Illegal NIFTI_FORM_PRIORITY='%s'",ppp) ;
    }
 
    /** 24 Mar 2006: check determs of qform and sform, if have both **/
@@ -252,13 +187,13 @@ ENTRY("THD_open_nifti") ;
 
      if( qdet*sdet < 0.0f )
        WARNING_message("NIfTI('%s'): Qform/Sform handedness differ; %c wins!",
-                       pathnew , form_priority ) ;
+                       pathname , form_priority ) ;
    }
 
    /* KRH 07/11/05 -- adding ability to choose spatial transform
       from the options of qform, sform, bothform, or noform.
 
-      If sform is present, it will be used.
+      If qform is present, it will be used.
 
       If qform is absent, but sform present, then the sform
         will be modified to be an orthogonal rotation and used.
@@ -279,7 +214,7 @@ ENTRY("THD_open_nifti") ;
                                     use_qform = 0 ; use_sform = 0 ;
      WARNING_message(
       "NO spatial transform (neither qform nor sform), in NIfTI file '%s'" ,
-      pathnew ) ;
+      pathname ) ;
    }
 
    /** now take NIfTI-1.1 coords and transform to AFNI codes **/
@@ -288,8 +223,6 @@ ENTRY("THD_open_nifti") ;
 
      float orgx, orgy, orgz ;
 
-     form_code = nim->qform_code;
-
      /* determine orientation from the qto_xyz matrix,
       which transforms (i,j,k) voxel indexes to (x,y,z) LPI coordinates */
 
@@ -319,8 +252,10 @@ ENTRY("THD_open_nifti") ;
 
      orixyz = THD_matrix_to_orientation( R ) ;   /* compute orientation codes */
 
-     // [PT,DRG: Mar 8, 2019] Done below.
-     //iview = NIFTI_code_to_view(nim->qform_code, NULL);
+     iview = ((nim->qform_code == NIFTI_XFORM_TALAIRACH ) ||
+              (nim->qform_code == NIFTI_XFORM_MNI_152 ))
+             ? VIEW_TALAIRACH_TYPE : VIEW_ORIGINAL_TYPE ;
+
 
      /* load the offsets and the grid spacings */
 
@@ -373,13 +308,9 @@ ENTRY("THD_open_nifti") ;
      float orgx, orgy, orgz ;
      float fig_merit, ang_merit ;
 
-     form_code = nim->sform_code;
-
      /* convert sform to nifti orientation codes */
 
-     /* n2   10 Jul, 2015 [rickr] */
-     nifti_dmat44_to_orientation(nim->sto_xyz,
-                                 &oritmp[0], &oritmp[1], &oritmp[2] ) ;
+     nifti_mat44_to_orientation(nim->sto_xyz, &oritmp[0], &oritmp[1], &oritmp[2] ) ;
 
      /* convert nifti orientation codes to AFNI codes and store in vector */
 
@@ -388,8 +319,10 @@ ENTRY("THD_open_nifti") ;
                           orimap[oritmp[2]] ) ;
 
      /* assume original view if there's no talairach id present */
-     // [PT,DRG: Mar 8, 2019] Done below.
-     //iview = NIFTI_code_to_view(nim->sform_code, NULL);
+
+     iview = ((nim->sform_code == NIFTI_XFORM_TALAIRACH ) ||
+              (nim->sform_code == NIFTI_XFORM_MNI_152 ))
+             ? VIEW_TALAIRACH_TYPE : VIEW_ORIGINAL_TYPE ;
 
      /* load the offsets and the grid spacings */
 
@@ -459,7 +392,7 @@ ENTRY("THD_open_nifti") ;
          "  you should consider running: \n"
          "     3dWarp -deoblique \n"
          "  on this and  other oblique datasets in the same session.\n"
-         ,pathnew, ang_merit ) ;
+         ,pathname, ang_merit ) ;
      }
 #endif
 
@@ -513,10 +446,7 @@ ENTRY("THD_open_nifti") ;
                         (ORIENT_sign[orixyz.ijk[1]]=='+') ? dytmp : -dytmp ,
                         (ORIENT_sign[orixyz.ijk[2]]=='+') ? dztmp : -dztmp ) ;
 
-     /* no qform/sform should default to orig */
-     /* use VIEW_ORIGINAL_TYPE, not NIFTI_default_view()  5 Feb 2016 [rickr] */
-     // [PT,DRG: Mar 8, 2019] Done below.
-     //iview = VIEW_ORIGINAL_TYPE;
+     iview = VIEW_ORIGINAL_TYPE ;
 
      /* set origin to 0,0,0   */
 
@@ -534,19 +464,15 @@ ENTRY("THD_open_nifti") ;
    /*-- make an AFNI dataset! --*/
 
    dset = EDIT_empty_copy(NULL) ;
+   /* copy transformation matrix to dataset structure */
+   dset->daxes->ijk_to_dicom_real = ijk_to_dicom44;
 
-   ppp  = THD_trailname(pathnew,0) ;               /* strip directory */
+   /* set atlas space based on NIFTI sform code */
+   NIFTI_code_to_space(nim->sform_code,dset);
+
+   ppp  = THD_trailname(pathname,0) ;               /* strip directory */
    MCW_strncpy( prefix , ppp , THD_MAX_PREFIX ) ;   /* to make prefix */
-   
-   /* You need to set the path too
-      before, if you loaded ~/tmp/joe.nii the path appeared
-      to be ./joe.nii, troubling in multiple instances.
-                                                      ZSS Dec 2011 */
-   THD_init_diskptr_names( dset->dblk->diskptr ,
-                           THD_filepath(pathnew) ,
-                           NULL , prefix ,
-                           dset->view_type , True );
-                           
+
    nxyz.ijk[0] = nim->nx ;                          /* grid dimensions */
    nxyz.ijk[1] = nim->ny ;
    nxyz.ijk[2] = nim->nz ;
@@ -555,42 +481,20 @@ ENTRY("THD_open_nifti") ;
    dset->idcode.str[1] = 'I' ;
    dset->idcode.str[2] = 'I' ;
 
-   MCW_hash_idcode( pathnew , dset ) ;  /* 06 May 2005 */
+   MCW_hash_idcode( pathname , dset ) ;  /* 06 May 2005 */
 
-   // [PT,DRG: Mar 8, 2019] We assume that the SPACE, whether it
-   // existed upon dset read or not, has been set correctly by this
-   // point.
-   // Also note, using the *generic space*, so TT_N27 and TLRC are
-   // both considered TLRC.
-   if (use_qform) {
-      iview = NIFTI_code_to_view(nim->qform_code, NULL);
-   }
-   else if (use_sform) {
-      iview = NIFTI_code_to_view(nim->sform_code, NULL);
-   }
-   else{ /* NO SPATIAL XFORM. BAD BAD BAD BAD BAD BAD. */
-      iview = VIEW_ORIGINAL_TYPE;
-   }
-   
-   // And set the dset header
    EDIT_dset_items( dset ,
                       ADN_prefix      , prefix ,
                       ADN_datum_all   , datum ,
                       ADN_nxyz        , nxyz ,
                       ADN_xyzdel      , dxyz ,
                       ADN_xyzorg      , orgxyz ,
-                      ADN_view_type   , iview ,
                       ADN_xyzorient   , orixyz ,
                       ADN_malloc_type , DATABLOCK_MEM_MALLOC ,
+                      ADN_view_type   , iview ,
                       ADN_type        , (statcode != 0) ? HEAD_FUNC_TYPE
                                                         : HEAD_ANAT_TYPE ,
                     ADN_none ) ;
-   // [PT,DRG: Mar 8, 2019] Done below.
-   //ADN_view_type   , iview ,
-
-   /* copy transformation matrix to dataset structure */
-   /* moved after setting grid     4 Apr 2014 [rickr,drg] */
-   dset->daxes->ijk_to_dicom_real = ijk_to_dicom44;
 
    /* not a time dependent dataset */
 
@@ -692,17 +596,8 @@ ENTRY("THD_open_nifti") ;
          break ;
        }
 
-       /* not ready for 64-bits, cast nz as (int)     [17 Jul 2019 rickr] */
-       if( nim->nz >> 31 ) {
-          static int nnnz=0;
-          if( nnnz == 0 ) {
-             WARNING_message("have NIFTI nz > 2^31, chaos to ensue, enjoy ...");
-             nnnz = 1;
-          }
-       }
-
        EDIT_dset_items( dset ,
-                          ADN_nsl     , (int)nim->nz  ,
+                          ADN_nsl     , nim->nz       ,
                           ADN_zorg_sl , orgxyz.xyz[2] ,
                           ADN_dz_sl   , dxyz.xyz[2]   ,
                           ADN_toff_sl , toff          ,
@@ -714,18 +609,6 @@ ENTRY("THD_open_nifti") ;
 
    } /* end of 3D+time dataset stuff */
 
-   /* if scalars are attached (and we did not xform data), set them  */
-   /* note: this MUST be after EDIT_dset_items(ADN_datum_all), as it
-            will clear any existing values        8 Mar 2021 [rickr] */
-   if( ! xform_data && nim->scl_slope != 0.0 && nim->scl_slope != 1.0) {
-     for( ibr=0 ; ibr < nvals ; ibr++ )
-       DBLK_BRICK_FACTOR(dset->dblk, ibr) = nim->scl_slope;
-   }
-
-
-   /* set atlas space based on NIFTI s/qform code */
-   NIFTI_code_to_space(form_code,dset);
-
    /* add statistics, if present */
 
    if( statcode != 0 ){
@@ -736,7 +619,7 @@ ENTRY("THD_open_nifti") ;
    /*-- flag to read data from disk using NIFTI functions --*/
 
    dset->dblk->diskptr->storage_mode = STORAGE_BY_NIFTI ;
-   strcpy( dset->dblk->diskptr->brick_name , pathnew ) ;
+   strcpy( dset->dblk->diskptr->brick_name , pathname ) ;
    dset->dblk->diskptr->byte_order = nim->byteorder ;
 
 #if 0
@@ -749,160 +632,89 @@ ENTRY("THD_open_nifti") ;
    /** 10 May 2005: see if there is an AFNI extension;
                     if so, load attributes from it and
                     then edit the dataset appropriately **/
-   /** 12 Nov 2021: moved to new thd_nifti_process_afni_ext [rickr] **/
-   (void)THD_nifti_process_afni_ext(dset, nim, pathnew);
+
+   { int ee ;  /* extension index */
+
+     /* scan extension list to find the first AFNI extension */
+
+     for( ee=0 ; ee < nim->num_ext ; ee++ )
+       if( nim->ext_list[ee].ecode == NIFTI_ECODE_AFNI &&
+           nim->ext_list[ee].esize > 32                &&
+           nim->ext_list[ee].edata != NULL               ) break ;
+
+     /* if found an AFNI extension ... */
+
+     if( ee < nim->num_ext ){
+       char *buf = nim->ext_list[ee].edata , *rhs , *cpt ;
+       int  nbuf = nim->ext_list[ee].esize - 8 ;
+       NI_stream ns ;
+       void     *nini ;
+       NI_group *ngr , *nngr ;
+
+       /* if have data, it's long enough, and starts properly, then ... */
+
+       if( buf != NULL && nbuf > 32 && strncmp(buf,"<?xml",5)==0 ){
+         if( buf[nbuf-1] != '\0' ) buf[nbuf-1] = '\0' ;         /* for safety */
+         cpt = strstr(buf,"?>") ;                    /* find XML prolog close */
+         if( cpt != NULL ){                          /* if found it, then ... */
+           ns = NI_stream_open( "str:" , "r" ) ;
+           NI_stream_setbuf( ns , cpt+2 ) ;        /* start just after prolog */
+           nini = NI_read_element(ns,1) ;                 /* get root element */
+           NI_stream_close(ns) ;
+           if( NI_element_type(nini) == NI_GROUP_TYPE ){   /* must be a group */
+             ngr = (NI_group *)nini ;
+             if( strcmp(ngr->name,"AFNI_attributes") == 0 ){    /* root is OK */
+               nngr = ngr ;
+             } else {                   /* search in group for proper element */
+               int nn ; void **nnini ;
+               nn = NI_search_group_deep( ngr , "AFNI_attributes" , &nnini ) ;
+               if( nn <= 0 ) nngr = NULL ;
+               else        { nngr = (NI_group *)nnini[0]; NI_free(nnini); }
+             }
+
+             if( NI_element_type(nngr) == NI_GROUP_TYPE ){ /* have  good name */
+               rhs = NI_get_attribute( nngr , "self_idcode" ) ;
+               if( rhs == NULL )
+                 rhs = NI_get_attribute( nngr , "AFNI_idcode" ) ;
+               if( rhs != NULL )    /* set dataset ID code from XML attribute */
+                 MCW_strncpy( dset->idcode.str , rhs , MCW_IDSIZE ) ;
+               rhs = NI_get_attribute( nngr , "NIfTI_nums" ) ;    /* check if */
+               if( rhs != NULL ){                       /* dataset dimensions */
+                 char buf[128] ;                              /* were altered */
+                 sprintf(buf,"%d,%d,%d,%d,%d,%d" ,             /* 12 May 2005 */
+                   nim->nx, nim->ny, nim->nz, nim->nt, nim->nu, nim->datatype );
+                 if( strcmp(buf,rhs) != 0 ){
+                   static int nnn=0 ;
+                   if(nnn==0){fprintf(stderr,"\n"); nnn=1;}
+                   fprintf(stderr,
+                     "** WARNING: NIfTI file %s dimensions altered since "
+                                 "AFNI extension was added\n",pathname ) ;
+                 }
+               }
+               THD_dblkatr_from_niml( nngr , dset->dblk ); /* load attributes */
+               THD_datablock_apply_atr( dset ) ;   /* apply to dataset struct */
+             }
+             NI_free_element( ngr ) ;          /* get rid of the root element */
+
+           } /* end of if found a group element at the root */
+         } /* end of if extension data array had an XML prolog close */
+       } /* end of if had a good extension data array */
+     } /* end of if had an AFNI extension */
+   } /* end of processing extensions */
 
    /* return unpopulated dataset */
 
-   
-   // [PT,DRG: Mar 8, 2019] ... go back and fix case of sform_code==2
-   // from above: The fix is in!
-   if (form_code==2) {
-      iview = NIFTI_code_to_view(form_code, 
-                                 THD_get_generic_space(dset));
-  
-      /* duplicating here how Rick did this in 3drefit */ 
-      dset->view_type = iview ;
-      THD_init_diskptr_names( dset->dblk->diskptr ,
-                              NULL , NULL , NULL , iview , True ) ;
-   }
-
-   nifti_image_free(nim) ; KILL_pathnew ; RETURN(dset) ;
+   nifti_image_free(nim) ; RETURN(dset) ;
 }
 
-/* If there is an AFNI extension in the NIFTI dataset, process it.
- * (moved from THD_open_nifti)
- * 
- * Modify logic to return on the "failed" tests, rather than having a
- * set of nested if's to proceed.                 [15 Nov 2021 rickr]
- */
-static int THD_nifti_process_afni_ext(THD_3dim_dataset * dset,
-                                      nifti_image * nim, char * pathnew)
-{
-   NI_stream  ns ;
-   NI_group  *ngr , *nngr ;
-   void      *nini ;
-   char      *buf , *rhs , *cpt ;
-   int        nbuf, ee ;  /* buf size, extension index */
-
-ENTRY("THD_nifti_process_afni_ext") ;
-
-   /* scan extension list to find the first AFNI extension */
-
-   for( ee=0 ; ee < nim->num_ext ; ee++ )
-     if( nim->ext_list[ee].ecode == NIFTI_ECODE_AFNI &&
-         nim->ext_list[ee].esize > 32                &&
-         nim->ext_list[ee].edata != NULL               ) break ;
-
-   /* if no AFNI extension, we are done */
-   if( ee >= nim->num_ext ) RETURN(0);
-
-   /* point to extension buffer */
-   buf = nim->ext_list[ee].edata ;
-   nbuf = nim->ext_list[ee].esize - 8 ;
-
-   /* if have data, it's long enough, and starts properly, then ... */
-
-   /* if insufficient data, fail */
-   if( buf == NULL || nbuf <= 32 || strncmp(buf,"<?xml",5) != 0 )
-      RETURN(1);
-
-   /* be sure buf is terminated, and find XML prolog close */
-   if( buf[nbuf-1] != '\0' ) buf[nbuf-1] = '\0' ;
-   cpt = strstr(buf,"?>") ;
-
-   /* if no XML prolog close, fail */
-   if( cpt == NULL )
-      RETURN(1);
-
-   /* read contents of NIML stream */
-   ns = NI_stream_open( "str:" , "r" ) ;
-   NI_stream_setbuf( ns , cpt+2 ) ;        /* start just after prolog */
-   nini = NI_read_element(ns,1) ;                 /* get root element */
-   NI_stream_close(ns) ;
-
-   /* if not a group, fail */
-   if( NI_element_type(nini) != NI_GROUP_TYPE )
-      RETURN(0);
-
-   /* have nngr point to AFNI_attributes */
-   ngr = (NI_group *)nini ;
-   if( strcmp(ngr->name,"AFNI_attributes") == 0 ){    /* root is OK */
-     nngr = ngr ;
-   } else {                   /* search in group for proper element */
-     int nn ; void **nnini ;
-     nn = NI_search_group_deep( ngr , "AFNI_attributes" , &nnini ) ;
-     if( nn <= 0 ) nngr = NULL ;
-     else        { nngr = (NI_group *)nnini[0]; NI_free(nnini); }
-   }
-
-   /* if such a group is found, process it */
-   if( NI_element_type(nngr) == NI_GROUP_TYPE ) {
-
-     rhs = NI_get_attribute( nngr , "self_idcode" ) ;
-     if( rhs == NULL )
-       rhs = NI_get_attribute( nngr , "AFNI_idcode" ) ;
-     if( rhs != NULL )    /* set dataset ID code from XML attribute */
-       MCW_strncpy( dset->idcode.str , rhs , MCW_IDSIZE ) ;
-
-
-     /***** This is an example of what might go into consistency check. */
-
-     rhs = NI_get_attribute( nngr , "NIfTI_nums" ) ;    /* check if */
-     if( rhs != NULL ){                       /* dataset dimensions */
-       char buf[128] ;                              /* were altered */
-       /* %ld fails on older systems            [17 Jul 2019 rickr] */
-       sprintf(buf,"%" PRId64 ",%" PRId64 ",%" PRId64 ",%" PRId64
-                   ",%" PRId64 ",%d" ,        /* 12 May 2005 */
-               nim->nx, nim->ny, nim->nz,
-               nim->nt, nim->nu, nim->datatype );
-       if( strcmp(buf,rhs) != 0 ){
-         static int nnn=0 ;
-         if(nnn==0){fprintf(stderr,"\n"); nnn=1;}
-         fprintf(stderr,
-           "** WARNING: NIfTI file %s dimensions altered since "
-                       "AFNI extension was added\n",pathnew ) ;
-         /* fprintf(stderr, "            buf=%s\n", buf); */
-       }
-     }
-
-     /* the main point: apply AFNI extension attributes to dset */
-     THD_dblkatr_from_niml( nngr , dset->dblk ); /* load attributes */
-     THD_datablock_apply_atr( dset ) ;   /* apply to dataset struct */
-   }
-
-   NI_free_element( ngr ) ;          /* get rid of the root element */
-
-   RETURN(0);
-}
-
-/* n2   10 Jul, 2015 [rickr] */
-int64_t * copy_ints_as_i64(int * ivals, int nvals)
-{
-   int64_t * i64;
-   int       c;
-
-   i64 = (int64_t *)malloc(nvals * sizeof(int64_t));
-   if( ! i64 ) {
-      fprintf(stderr,"** CIA64: failed to alloc %d int64_t's\n", nvals);
-      return NULL;
-   }
-   for( c=0; c<nvals; c++ ) i64[c] = ivals[c];
-
-   return i64;
-}
-
-
 /*-----------------------------------------------------------------
   Load a NIFTI dataset's data into memory
   (called from THD_load_datablock in thd_loaddblk.c)
     - RWC: modified 07 Apr 2005 to read data bricks via nifti_io.c
       'NBL' functions, rather than directly from disk
-    - RCR: modified 02 Sep 2022 to return status
-  return 0 on success, else an error
 -------------------------------------------------------------------*/
 
-int THD_load_nifti( THD_datablock *dblk )
+void THD_load_nifti( THD_datablock *dblk )
 {
    THD_diskptr *dkptr ;
    int nx,ny,nz,nxy,nxyz,nxyzv , nerr=0,ibr,nv, nslice ;
@@ -918,29 +730,19 @@ ENTRY("THD_load_nifti") ;
 
    if( !ISVALID_DATABLOCK(dblk)                        ||
        dblk->diskptr->storage_mode != STORAGE_BY_NIFTI ||
-       dblk->brick == NULL                               ) RETURN(1) ;
+       dblk->brick == NULL                               ) EXRETURN ;
 
    dkptr = dblk->diskptr ;
 
-   /* purge any existing bricks [10 Mar 2014] */
-
-   STATUS("purging existing data bricks (if any)") ;
-   THD_purge_datablock(dblk,DATABLOCK_MEM_ANY) ;
-
    STATUS("calling nifti_image_read_bricks") ;
    NBL.nbricks = 0 ;
-
    if( ! DBLK_IS_MASTERED(dblk) )   /* allow mastering   14 Apr 2006 [rickr] */
        nim = nifti_image_read_bricks( dkptr->brick_name, 0,NULL , &NBL ) ;
-   else {
-       /* n2   10 Jul, 2015 [rickr] */
-       /* convert master_ival to an array of int64_t */
-       int64_t * i64_vals = copy_ints_as_i64(dblk->master_ival, dblk->nvals);
+   else
        nim = nifti_image_read_bricks( dkptr->brick_name, dblk->nvals,
-                                      i64_vals, &NBL ) ;
-   }
+                                      dblk->master_ival, &NBL ) ;
 
-   if( nim == NULL || NBL.nbricks <= 0 ) RETURN(1) ;
+   if( nim == NULL || NBL.nbricks <= 0 ) EXRETURN ;
 
    datum = DBLK_BRICK_TYPE(dblk,0) ;  /* destination data type */
 
@@ -1006,7 +808,6 @@ ENTRY("THD_load_nifti") ;
 
        if( DBLK_ARRAY(dblk,ibr) == NULL ){                     /* make space */
          ptr = AFMALL(void, DBLK_BRICK_BYTES(dblk,ibr) ) ;     /* for this   */
-         if( ptr == NULL ) ERROR_message("malloc fails for NIfTI sub-brick #%d",ibr) ;
          mri_fix_data_pointer( ptr ,  DBLK_BRICK(dblk,ibr) ) ; /* sub-brick! */
        }
        ptr = DBLK_ARRAY(dblk,ibr) ; if( ptr == NULL ) break ;  /* bad news!! */
@@ -1022,8 +823,6 @@ ENTRY("THD_load_nifti") ;
 
        /* load from nbuf into brick array (will be float or complex) */
 
-       STATUS(" converting sub-brick") ;
-
        switch( nim->datatype ){
          case DT_UINT8:    CPF(unsigned char)  ; break ;
          case DT_INT8:     CPF(signed char)    ; break ;
@@ -1031,43 +830,24 @@ ENTRY("THD_load_nifti") ;
          case DT_UINT16:   CPF(unsigned short) ; break ;
          case DT_INT32:    CPF(signed int)     ; break ;
          case DT_UINT32:   CPF(unsigned int)   ; break ;
-         case DT_FLOAT64:  /* added floatscan  2 Dec, 2014 [rickr] */
-            { CPF(double) ; thd_floatscan(nxyz, (float *)ptr) ; break ; }
+         case DT_FLOAT64:  CPF(double)         ; break ;
 #if 0
          case DT_COMPLEX128: break ;
 #endif
        }
 
-       STATUS(" free-ing NIfTI volume") ;
-
        free(NBL.bricks[ibr]) ; NBL.bricks[ibr] = NULL ;
      }
    }
 
-   STATUS("free-ing NBL") ;
-
    nifti_free_NBL( &NBL ) ;  /* done with this */
 
    /*-- scale results? ---*/
 
-   /* errors for !isfinite() have been printed */
-
-   /* do not scale if either slope or inter is zero
-    *    slope==0 : treat as unset (rather than constant data)
-    *    inter==0 : use slope as brick_fac
-    * (unless need_copy is applied, then apply slope/inter) */
-
-   /* Any NIFTI scalar previously implied conversion to float.
-    * No longer scale if inter==0 && slope!=0 (set brick_fac).
-    * Thanks to C Caballero and S Moia for reporting this.  
-    *                                      26 Jan 2021 [rickr]
-    * Also, if need_copy, apply any finite scl_slope, regardless
-    * of whether scl_inter == 0.
-    * Thanks to @liningpan on github for reporting this.
-    *                                      17 Apr 2024 [rickr] */
-   scale_data = isfinite(nim->scl_slope) && isfinite(nim->scl_inter) 
-                     && (nim->scl_slope != 0.0)
-                     &&((nim->scl_inter != 0.0) || need_copy);
+   /* errors for !finite() have been printed */
+   scale_data = finite(nim->scl_slope) && finite(nim->scl_inter) 
+                    && (nim->scl_slope != 0.0)
+                    && (nim->scl_slope != 1.0 || nim->scl_inter != 0.0) ;
 
    if( scale_data ){
      STATUS("scaling sub-bricks") ;
@@ -1076,7 +856,7 @@ ENTRY("THD_load_nifti") ;
          float *far = (float *) DBLK_ARRAY(dblk,ibr) ; int ii ;
          for( ii=0 ; ii < nxyz ; ii++ ){
            far[ii] = nim->scl_slope * far[ii] + nim->scl_inter ;
-           if( !isfinite(far[ii]) ) far[ii] = 0.0f ;
+           if( !finite(far[ii]) ) far[ii] = 0.0f ;
          }
        } else if( DBLK_BRICK_TYPE(dblk,ibr) == MRI_complex ){
          complex *car = (complex *) DBLK_ARRAY(dblk,ibr) ; int ii ;
@@ -1086,29 +866,21 @@ ENTRY("THD_load_nifti") ;
          }
        }
      }
-   } else if ( isfinite(nim->scl_slope) && nim->scl_slope != 0.0 ) {
-
-     /* actually pass slope as brick_fac   26 Jan 2021 [rickr] */
-     for( ibr=0 ; ibr < nv ; ibr++ )
-       DBLK_BRICK_FACTOR(dblk, ibr) = nim->scl_slope;
    }
 
-   /* rcr - replace this with DBLK_IS_RANGE_MASTERED to also check for
-    *       csv list
-    *     - then call a new parent function to THD_apply_master_subrange
-    */
-   if( DBLK_IS_MASTER_SUBRANGED(dblk) )
+   if( DBLK_IS_MASTERED(dblk) && dblk->master_bot <= dblk->master_top )
      THD_apply_master_subrange(dblk) ;
 
    /*-- throw away the trash and return --*/
 
-   nifti_image_free(nim) ; RETURN(0) ;
+   nifti_image_free(nim) ; EXRETURN ;
 }
 
 
 /* set atlas space based on NIFTI sform code */
 static void NIFTI_code_to_space(int code,THD_3dim_dataset *dset)
 {
+   
     switch(code) {
         case NIFTI_XFORM_TALAIRACH:
             MCW_strncpy(dset->atlas_space, "TLRC", THD_MAX_NAME);
@@ -1119,99 +891,5 @@ static void NIFTI_code_to_space(int code,THD_3dim_dataset *dset)
         default:
             THD_get_space(dset);
     }
-}
 
-/* return dataset view code based on NIFTI sform/qform code */
-/* code for +tlrc, +orig */
-static int NIFTI_code_to_view(int code, char *atlas_space)
-{
-   int iview;
-
-   /*
-     SFORM     SPACE    VIEW     
-     -----     -----    ----     
-     1 (or 0)  ORIG     orig     
-     4         MNI      tlrc     
-     3         TLRC     tlrc     
-     ?2 (->1)  ACPC     acpc     
-     5         A_TEMP   tlrc     
-
-    */
-
-   ENTRY("NIFTI_code_to_view");
-
-   //INFO_message("atlas_space = %s", atlas_space);
-   //INFO_message("code = %d", code);
-
-   /* only two standard templates now defined */
-   switch(code) {
-   case NIFTI_XFORM_TALAIRACH:       /* TLRC space -> tlrc view */
-      // sform_code = 3
-      iview = VIEW_TALAIRACH_TYPE;
-      break;
-   case NIFTI_XFORM_MNI_152:         /* MNI space -> tlrc 'view' */
-      // sform_code = 4
-      iview = VIEW_TALAIRACH_TYPE;
-      break;
-   case NIFTI_XFORM_SCANNER_ANAT:    /* no code set or scanner -> orig 'view' */
-      // sform_code = 1
-   case NIFTI_XFORM_UNKNOWN:
-      // sform_code = 0
-      iview = VIEW_ORIGINAL_TYPE;
-      break;
-   case NIFTI_XFORM_TEMPLATE_OTHER:  // [PT,DRG: Mar 8, 2019] For sform_code=5
-      // sform_code = 5 !!
-      iview = VIEW_TALAIRACH_TYPE;
-      break;
-   case NIFTI_XFORM_ALIGNED_ANAT:    /* aligned to something... */
-      // sform_code = 2 (booo)
-      if( !atlas_space ) {
-         // *this* special scenario is to allow use of this function
-         // before checking for AFNI extension; it can be called with
-         // a 'NULL' atlas_space, which won't affect any
-         // sform_code!=2, but will allow a dummy value for
-         // sform_code=2 to exist until it is set "properly"
-         iview = NIFTI_default_view(); // should just be a dummy case
-      }
-      else if ( !strcmp(atlas_space, "ORIG") )
-         iview = VIEW_ORIGINAL_TYPE;
-      else if ( !strcmp(atlas_space, "ACPC") )
-         iview = VIEW_ACPCALIGNED_TYPE;
-      else if ( strlen(atlas_space) )
-         iview = VIEW_TALAIRACH_TYPE;
-      else { // no space!
-         WARNING_message("Hmm, {s,q}form_code = 2, but no space set??\n"
-                         "-> rollin' the dice here!");
-         iview = NIFTI_default_view();
-      }
-      break;
-   default:                     /* or something else we don't know
-                                   about yet (higher form codes)*/
-      // sform_code > 5 or sform_code<0
-      WARNING_message("I don't think this sform code '%d' is allowed!", code);
-      iview = NIFTI_default_view();
-   }
-   RETURN(iview);
-}
-
-/* get default view from environment variable */
-static int NIFTI_default_view()
-{
-  char *ppp;
-  /* finally default back to orig view            [29 Mar 2024 rickr ] */
-  int iview = VIEW_ORIGINAL_TYPE; /* default view if not otherwise set */
-
-  ENTRY("NIFTI_default_view");
-  ppp = my_getenv("AFNI_NIFTI_VIEW");
-  if(ppp){
-     if(strcasecmp(ppp, "TLRC")==0)
-        iview = VIEW_TALAIRACH_TYPE;
-     else if (strcasecmp(ppp,"ORIG")==0) {
-           iview = VIEW_ORIGINAL_TYPE;
-     }
-     else if (strcasecmp(ppp,"ACPC")==0) {
-           iview = VIEW_ACPCALIGNED_TYPE;
-     }
-  }
-  RETURN(iview);
 }
