@@ -132,6 +132,7 @@ ENTRY("THD_dblkatr_from_niml") ;
    /*-- loop over parts and extract data from any '<AFNI_atr ...>' elements --*/
 
    for( ip=0 ; ip < ngr->part_num ; ip++ ){
+
      switch( ngr->part_typ[ip] ){
 
        /*-- a sub-group ==> recursion! --*/
@@ -148,6 +149,7 @@ ENTRY("THD_dblkatr_from_niml") ;
          char       *rhs = NI_get_attribute( nel , "atr_name" ) ;
          if( rhs == NULL )
                      rhs = NI_get_attribute( nel , "AFNI_name" ) ;
+
          if( strcasecmp(nel->name,"AFNI_atr") == 0 &&    /* AFNI attribute?   */
              nel->vec_num == 1                     &&    /* with some data?   */
              nel->vec_len >  0                     &&    /* that is nonempty? */
@@ -157,7 +159,7 @@ ENTRY("THD_dblkatr_from_niml") ;
             *rhs != '\0'                              ){ /* a nonempty name?  */
 
            STATUS(rhs) ;
-           
+
            switch( nel->vec_typ[0] ){ /* 3 different data types of attributes */
 
              /* float attribute: copy 1st column of numbers into AFNI */
@@ -181,29 +183,9 @@ ENTRY("THD_dblkatr_from_niml") ;
                if (nel->vec) { /* to be expected */
                   char **sar = (char **)nel->vec[0] , *str ;
                   int nch , nstr=nel->vec_len , istr , lll=0 ;
-                  for( istr=0 ; istr < nstr ; istr++) 
-                     if (sar[istr]) lll += strlen(sar[istr]); /* ZSS Nov 2012 */
+                  for( istr=0 ; istr < nstr ; istr++) lll += strlen(sar[istr]);
                   str = malloc(lll+4) ; *str = '\0' ;
-
-               /* for( istr=0 ; istr < nstr ; istr++ ) strcat(str,sar[istr]); */
-
-                  /* The loop of strcat() is very slow in the case of a long
-                     history element, O(n^2), so replace with something linear.
-                     Javier complained that afni took forever to start.  One 
-                     NIfTI dset with 8 MB history took ~8 seconds in loop.
-                                                        31 Jul 2012 [rickr] */
-                  {  char * cp, * sp = str; int slen;
-                     for( istr=0; istr < nstr; istr++ ) {
-                        if (sar[istr]) {  /* ZSS Nov 2012 */
-                           cp = sar[istr];
-                           slen = strlen(cp);
-                           memcpy(sp, cp, slen*sizeof(char));
-                           sp += slen;
-                        }
-                     }
-                     *sp = '\0';
-                  }
-
+                  for( istr=0 ; istr < nstr ; istr++ ) strcat(str,sar[istr]);
                   nch = strlen(str) ;
                   THD_unzblock( nch+1 , str ) ;  /* re-insert NULs */
                   THD_set_char_atr( blk , rhs , nch+1 , str ) ;
@@ -405,7 +387,7 @@ ENTRY("THD_add_bricks") ;
    fac = 0.0 ;
                      str = NI_get_attribute( nel , "scale_factor" ) ;
    if( str == NULL ) str = NI_get_attribute( nel , "AFNI_factor"  ) ;
-   if( str != NULL && isnumeric(*str) )
+   if( str != NULL && ( *str== '-' || isdigit(*str) ) )
      fac = (float)strtod( str , NULL ) ;
 
    if(PRINT_TRACING){
@@ -517,7 +499,7 @@ ENTRY("THD_add_sparse_bricks") ;
      float *xdd , *ydd , *zdd ;
      THD_fvec3 xyz ; THD_ivec3 ijk ;
 
-     nd  = 3 ; /* indicating we use the first 3 columns for index computation */
+     nd  = 3 ; /* indicating we use the first 3 columns for index compuation */
      id  = (int *)malloc(sizeof(int)*vlen) ;       /* indexes computed below */
      xdd = (float *)nel->vec[0] ;                       /* DICOM coordinates */
      ydd = (float *)nel->vec[1] ;
@@ -586,7 +568,7 @@ ENTRY("THD_add_sparse_bricks") ;
    fac = 0.0 ;
                      str = NI_get_attribute( nel , "scale_factor" ) ;
    if( str == NULL ) str = NI_get_attribute( nel , "AFNI_factor"  ) ;
-   if( str != NULL && isnumeric(*str) )
+   if( str != NULL && ( *str== '-' || isdigit(*str) ) )
      fac = (float)strtod( str , NULL ) ;
 
    /* check if doing infill or if we should set brick to all zero first */
@@ -829,7 +811,7 @@ ENTRY("mri_to_niml") ;
    }
 
    if( im->name != NULL && im->name[0] != '\0' )
-     NI_set_attribute( nel , "mri_name" , im->name ) ;
+     NI_set_attribute( nel , "mri_name" , rhs ) ;
 
    /* put in the data */
     NI_add_column( nel , im->kind , vpt ) ;
