@@ -6,20 +6,20 @@
     add_I = number of zero planes to add at inferior edge
             (if < 0, number of data planes to cut off inferior edge)
 
-  09 Feb 2001 - added "flag" input, which is the OR (|) of
+  09 Feb 2001 - added "flag" input, which is the OR of
     ZPAD_EMPTY = produce only an padded "empty copy" of the input
     ZPAD_PURGE = purge input dataset bricks after they are copied
     ZPAD_MM    = increments are mm instead of slice counts
                  (at least 'add_?' mm will be added/subtracted)
-    ZPAD_IJK   = increments are relative to dset axes I0--I1 J0--J1
+    ZPAD_IJK   = increments are relative to dset axes I0--I1 J0-- J1 
                  K0--K1 not I--S A--P L---R
   14 May 2002: if inputs crops are all zero, return something anyway
 ---------------------------------------------------------------------*/
 
-THD_3dim_dataset * THD_zeropad( THD_3dim_dataset *inset ,
+THD_3dim_dataset * THD_zeropad( THD_3dim_dataset * inset ,
                                 int add_I , int add_S , int add_A ,
                                 int add_P , int add_L , int add_R ,
-                                char *prefix , int flag )
+                                char * prefix , int flag )
 {
    THD_3dim_dataset *outset ;
    int nxold,nyold,nzold , nxnew,nynew,nznew , nxyold,nxynew ,
@@ -30,12 +30,12 @@ THD_3dim_dataset * THD_zeropad( THD_3dim_dataset *inset ,
    int purge_flag = (flag & ZPAD_PURGE) ;  /* 09 Feb 2001 */
    int mm_flag    = (flag & ZPAD_MM   ) ;  /* 13 Feb 2001 */
    int ijk_flag   = (flag & ZPAD_IJK   );  /* ZSS: 23 Dec The year of the war on Christmas */
-
+   
    THD_ivec3 iv_nxyz ;
    THD_fvec3 fv_xyzorg ;
 
-   MRI_IMAGE *oldim ;
-   void *vnew ;
+   MRI_IMAGE * oldim ;
+   void * vnew ;
 
 ENTRY("THD_zeropad") ;
 
@@ -43,22 +43,17 @@ ENTRY("THD_zeropad") ;
 
    if( !ISVALID_DSET(inset) ) RETURN( NULL ) ;
 
-   if( !THD_filename_ok(prefix) ) prefix = "zeropad" ;
-
    if( add_I==0 && add_S==0 && add_P==0 &&
        add_A==0 && add_L==0 && add_R==0    ){
 
-      INFO_message("THD_zeropad: all pad values are zero - just copying dataset") ;
-      if( !empty_flag ){
-        outset = EDIT_full_copy( inset , prefix ) ;  /* 14 May 2002 */
-      } else {
-        outset = EDIT_empty_copy( inset ) ;          /* 15 Sep 2020 - oops */
-        EDIT_dset_items( outset , ADN_prefix , prefix , ADN_none ) ;
-        EDIT_dset_items( outset , ADN_prefix , prefix , ADN_none ) ;
-      }
+      fprintf(stderr,"++ THD_zeropad: all pad values are zero!\n") ;
+
+      outset = EDIT_full_copy( inset , prefix ) ;  /* 14 May 2002 */
       RETURN( outset );
    }
 
+   if( !THD_filename_ok(prefix) ) prefix = "zeropad" ;
+
    /*-- map add_? values into dataset xyz coordinate directions --*/
 
    nxold = DSET_NX(inset) ;
@@ -72,7 +67,7 @@ ENTRY("THD_zeropad") ;
    } else {
       /* comput n?top and n?bot, the number of planes to add at
          the top and bottom of the ? direction, for ? = x, y, or z */
-
+      
       switch( inset->daxes->xxorient ){
          default:
            fprintf(stderr,"*** THD_zeropad: Unknown orientation codes!\n") ;
@@ -141,13 +136,7 @@ ENTRY("THD_zeropad") ;
        nynew < 1 || jjbot > jjtop ||   /* and ranges of dataset     */
        nznew < 1 || kkbot > kktop   ){
 
-      ERROR_message("*** THD_zeropad: Can't cut dataset down too much!\n"
-                    "            new: %d %d %d\n"
-                    "             ii: %d..%d\n"
-                    "             jj: %d..%d\n"
-                    "             kk: %d..%d\n",
-                    nxnew, nynew, nznew,
-                    iibot, iitop, jjbot, jjtop, kkbot, kktop ) ;
+      fprintf(stderr,"*** THD_zeropad: Can't cut dataset down too much!\n") ;
       RETURN( NULL );
    }
 
@@ -171,13 +160,6 @@ ENTRY("THD_zeropad") ;
                           inset->daxes->yyorg - nybot * inset->daxes->yydel,
                           inset->daxes->zzorg - nzbot * inset->daxes->zzdel );
 
-#if 0
-DUMP_IVEC3("THD_zeropad new dimensions",iv_nxyz) ;
-DUMP_FVEC3("            new origin    ",fv_xyzorg) ;
-INFO_message("         grid spacings = %g %g %g",
-             inset->daxes->xxdel,inset->daxes->yydel,inset->daxes->zzdel) ;
-#endif
-
 STATUS("setting new dimensions") ;
 
    EDIT_dset_items( outset ,
@@ -270,7 +252,8 @@ STATUS("padding") ;
 
       oldim = DSET_BRICK(inset,iv) ;  /* image structure of old brick */
 
-      vnew  = (void*)calloc( nxnew*nynew*nznew , oldim->pixel_size ) ; /* new brick */
+      vnew  = (void*)calloc( nxnew*nynew*nznew , 
+			     oldim->pixel_size ) ; /* new brick */
       if( vnew == NULL ){
          fprintf(stderr,
                  "*** THD_zeropad: Can't malloc space for new sub-brick %d\n",
@@ -287,8 +270,6 @@ STATUS("padding") ;
 
       switch( oldim->kind ){  /* copy rows of old into new */
 
-         default: break ;
-
          case MRI_byte:{
             byte * bnew = (byte *) vnew, * bold = mri_data_pointer(oldim) ;
             for( kk=kkbot ; kk < kktop ; kk++ )
@@ -357,172 +338,3 @@ STATUS("padding") ;
 
    RETURN( outset );
 }
-
-/*-------------------------------------------------------------------*/
-/* Create a 1-volume dataset built from
-   (a) a master dataset 'mset' -- for the geometry
-   (b) an image 'imin' containing the data
-   (c) padding amounts that reckon with the dimensional
-       differences between imin and mset -- that is, for positive
-       'pad' values, imin should be bigger than mset.
-   This function is for use in 3dAllineate.       [25 Jan 2021 - RWC]
-*//*-----------------------------------------------------------------*/
-
-THD_3dim_dataset * THD_volume_to_dataset( THD_3dim_dataset *mset  ,
-                                          MRI_IMAGE *imin         ,
-                                          char *prefix            ,
-                                          int pad_xm , int pad_xp ,
-                                          int pad_ym , int pad_yp ,
-                                          int pad_zm , int pad_zp  )
-{
-   THD_3dim_dataset *dset ;
-   MRI_IMAGE *dim ;
-   int nxx,nyy,nzz ;
-
-ENTRY("THD_volume_to_dataset") ;
-
-   if( mset == NULL || imin == NULL ) RETURN(NULL) ;
-
-   if( !THD_filename_ok(prefix) ) prefix = "volumized" ;
-
-   /* size of dataset after it gets padded */
-
-   nxx = DSET_NX(mset) + pad_xm + pad_xp ;
-   nyy = DSET_NY(mset) + pad_ym + pad_yp ;
-   nzz = DSET_NZ(mset) + pad_zm + pad_zp ;
-
-   /* should match input image */
-
-   if( nxx != imin->nx || nyy != imin->ny || nzz != imin->nz ){
-     WARNING_message("THD_volume_to_dataset mismatch:\n"
-                     "        Dataset = %3d %3d %3d\n"
-                     "        x-pad   = %3d %3d\n"
-                     "        y-pad   = %3d %3d\n"
-                     "        z-pad   = %3d %3d\n"
-                     "        Image   = %3d %3d %3d" ,
-                     DSET_NX(mset),DSET_NY(mset),DSET_NZ(mset) ,
-                     pad_xm , pad_xp ,
-                     pad_ym , pad_yp ,
-                     pad_zm , pad_zp ,
-                     imin->nx , imin->ny , imin->nz ) ;
-     RETURN(NULL) ;
-   }
-
-   /* create an empty (no data) dataset properly padded from mset */
-
-   dset = THD_zeropad( mset ,
-                       pad_xm , pad_xp ,
-                       pad_ym , pad_yp ,
-                       pad_zm , pad_zp ,
-                       prefix , ZPAD_EMPTY | ZPAD_IJK ) ;
-
-   EDIT_dset_items( dset ,
-                      ADN_nvals     , 1 ,
-                      ADN_ntt       , 0 ,
-                      ADN_datum_all , imin->kind ,
-                    ADN_none ) ;
-
-   /* copy the data */
-
-   dim = mri_copy(imin) ;
-
-   /* shove it into the new dataset */
-
-   EDIT_substitute_brick( dset , 0 , dim->kind , mri_data_pointer(dim) ) ;
-
-   /* erase the shell of the image copy */
-
-   mri_clear_and_free( dim ) ;
-
-   /* get the hell out of Dodge */
-
-   RETURN(dset) ;
-}
-
-/*-------------------------------------------------------------------*/
-/* Create a dataset from an MRI_IMARR.
-   All sub-images must be the same dimensions.
-   All sub-images will be converted (if necessary) to the same
-     datum type as the [0] image.
-   NULL is returned if inputs are stooopid.
-   [RWC - 05 Mar 2021]
-*//*-----------------------------------------------------------------*/
-
-THD_3dim_dataset * THD_imarr_to_dataset( MRI_IMARR *imar, char *prefix )
-{
-   int nx,ny,nz , nvals , vv ;
-   MRI_IMAGE *qim ;
-   MRI_TYPE   qtyp ;
-   THD_3dim_dataset *qset ;
-   THD_ivec3  nxyz ;
-   THD_fvec3  dxyz ;
-
-ENTRY("THD_imarr_to_dataset") ;
-
-   if( imar == NULL || IMARR_COUNT(imar) == 0 ) RETURN(NULL) ;
-
-   qim = IMARR_SUBIM(imar,0); if( qim == NULL ) RETURN(NULL) ;
-
-   /* dimensions */
-
-   nx = qim->nx ; ny = qim->ny ; nz = qim->nz ;
-   if( nx < 2 && ny < 2 && nz < 2 )             RETURN(NULL) ;
-   LOAD_IVEC3(nxyz,nx,ny,nz) ;
-   LOAD_FVEC3(dxyz,1.0f,1.0f,1.0f) ;
-
-   qtyp  = qim->kind ;
-   nvals = IMARR_COUNT(imar) ;
-
-   /* dimension check */
-
-   for( vv=1 ; vv < nvals ; vv++ ){
-     qim = IMARR_SUBIM(imar,vv) ;        if( qim == NULL ) RETURN(NULL) ;
-     if( qim->nx != nx || qim->ny != ny || qim->nz != nz ) RETURN(NULL) ;
-   }
-
-   /* create empty shell of dataset and set dimensions */
-
-   qset = EDIT_empty_copy(NULL) ;
-
-   if( !THD_filename_ok(prefix) ) prefix = "fromIMARR" ;
-
-   EDIT_dset_items( qset ,
-                     ADN_datum_all , (int)qtyp ,
-                     ADN_nvals     , nvals ,
-                     ADN_nxyz      , nxyz ,
-                     ADN_xyzdel    , dxyz ,
-                     ADN_prefix    , prefix ,
-                    ADN_none ) ;
-
-   /* make a copy of each image,
-      and stuff its data into the dataset,
-      then clear out copy's data (now inside dataset) and free image struct */
-
-   for( vv=0 ; vv < nvals ; vv++ ){
-     qim = mri_to_mri( (int)qtyp , IMARR_SUBIM(imar,vv) ) ;
-     EDIT_substitute_brick( qset , vv , (int)qtyp , mri_data_pointer(qim) ) ;
-     mri_clear_and_free( qim ) ;
-   }
-
-   RETURN(qset) ;
-}
-
-/*-------------------------------------------------------------------*/
-
-THD_3dim_dataset * THD_image_to_dataset( MRI_IMAGE *imin, char *prefix )
-{
-   MRI_IMARR *imar ;
-   THD_3dim_dataset *qset ;
-
-ENTRY("THD_image_to_dataset") ;
-
-   if( imin == NULL ) RETURN(NULL) ;
-
-   INIT_IMARR(imar) ; ADDTO_IMARR(imar,imin) ;
-
-   qset = THD_imarr_to_dataset( imar , prefix ) ;
-
-   FREE_IMARR(imar) ;
-
-   RETURN(qset) ;
-}
