@@ -20,7 +20,7 @@ double waveform( double t ) ;
 double waveform_GAM( double t ) ;
 double waveform_WAV( double t ) ;
 void Process_Options( int c , char * a[] ) ;
-void Syntax(int) ;
+void Syntax(void) ;
 
 double waveform_EXPR( double t ) ;  /* 01 Aug 2001 */
 double waveform_FILE( double t ) ;  /* 23 Aug 2005 */
@@ -223,16 +223,13 @@ int main( int argc , char * argv[] )
    int ii , jj ;
    double val ;
 
+   if( argc < 2 || strncmp(argv[1],"-help",5) == 0 ) Syntax() ;
 
    /* this writes to stdout (default), so no version    06 Jan 2006 [rickr] */
    /* PRINT_VERSION("waver"); */
-   mainENTRY("waver"); machdep(); AFNI_logger("waver",argc,argv);
-   
+   machdep(); AFNI_logger("waver",argc,argv);
+
    Process_Options( argc , argv ) ;
-   if( argc < 2) {
-      Syntax(0);
-      exit(0) ;
-   } 
 
    /*---- compute duration of sampled waveform ----*/
 
@@ -410,7 +407,7 @@ int main( int argc , char * argv[] )
 
 /*----------------------------------------------------------------*/
 
-void Syntax(int detail)
+void Syntax(void)
 {
    printf(
     "Usage: waver [options] > output_filename\n"
@@ -439,7 +436,7 @@ void Syntax(int detail)
     "--------\n"
     "  -WAV = Sets waveform to Cox special                    [default]\n"
     "           cf. AFNI FAQ list for formulas:\n"
-    "           https://afni.nimh.nih.gov/afni/doc/faq/17\n"
+    "           http://afni.nimh.nih.gov/afni/doc/faq/17\n"
     "  -GAM = Sets waveform to form t^b * exp(-t/c)\n"
     "           (cf. Mark Cohen)\n"
     "\n"
@@ -527,7 +524,7 @@ void Syntax(int detail)
     "                     period from time 'a' to time 'b'.  For example,\n"
     "                       -dt 2.0 -tstim 13.2:15.7 20.3:25.3\n"
     "                     The amplitude of a response of duration equal to\n"
-    "                     'dt' is equal to the amplitude of a single impulse\n"
+    "                     'dt' is equal the the amplitude of a single impulse\n"
     "                     response (which is the special case a=b).  N.B.: This\n"
     "                     means that something like '5:5.01' is very different\n"
     "                     from '5' (='5:5').  The former will have a small amplitude\n"
@@ -571,7 +568,7 @@ void Syntax(int detail)
     "* If a square wave is desired, see the 'sqwave' program.\n"
    ) ;
 
-   PRINT_COMPILE_DATE ; return;
+   PRINT_COMPILE_DATE ; exit(0) ;
 }
 
 /*----------------------------------------------------------------*/
@@ -583,10 +580,7 @@ void Process_Options( int argc , char * argv[] )
    while( nopt < argc ){
 
       /*-----*/
-      if(!strcmp(argv[nopt],"-help") || !strcmp(argv[nopt],"-h")){
-         Syntax(strlen(argv[nopt])>3?2:1);
-         exit(0);
-      }
+
       if( strncmp(argv[nopt],"-FILE",4) == 0 ){  /* 23 Aug 2005 */
         MRI_IMAGE *fim ;
         waveform_type = FILE_TYPE ;
@@ -944,9 +938,7 @@ void Process_Options( int argc , char * argv[] )
 
       /*-----*/
 
-      ERROR_message("Unknown option '%s'",argv[nopt]) ;
-      suggest_best_prog_option(argv[0], argv[nopt]);
-      exit(1);
+      ERROR_exit("Unknown option '%s'",argv[nopt]) ;
    }
 
    if( WAV_peak == 0.0 && waveform_type != EXPR_TYPE )
